@@ -1,4 +1,4 @@
-// Copyright (c) 1999-2016  David Muse
+// Copyright (c) 1999-2018 David Muse
 // See the file COPYING for more information
 
 #include <config.h>
@@ -101,9 +101,18 @@ class sqlrconnectionprivate {
 		// current database name
 		char		*_currentdbname;
 
+		// current schema name
+		char		*_currentschemaname;
+
 		// bind format
 		char		*_bindformat;
 
+		// bind delimiters
+		bool		_questionmarksupported;
+		bool		_colonsupported;
+		bool		_atsignsupported;
+		bool		_dollarsignsupported;
+
 		// client info
 		char		*_clientinfo;
 		uint64_t	_clientinfolen;
@@ -217,9 +226,18 @@ void sqlrconnection::init(const char *server, uint16_t port,
 	// current database name
 	pvt->_currentdbname=NULL;
 
+	// current schema name
+	pvt->_currentschemaname=NULL;
+
 	// bind format
 	pvt->_bindformat=NULL;
 
+	// bind delimiters
+	pvt->_questionmarksupported=true;
+	pvt->_colonsupported=true;
+	pvt->_atsignsupported=true;
+	pvt->_dollarsignsupported=true;
+
 	// client info
 	pvt->_clientinfo=NULL;
 	pvt->_clientinfolen=0;
@@ -236,16 +254,9 @@ void sqlrconnection::init(const char *server, uint16_t port,
 	if (!sqlrdebug || !*sqlrdebug) {
 		sqlrdebug=environment::getValue("SQLR_CLIENT_DEBUG");
 	}
-	const char	*yesset[]={"YES","ON","TRUE","Y","T","1",
-					"yes","on","true","y","t",
-					"Yes","On","True",NULL};
-	const char	*noset[]={"NO","OFF","FALSE","N","F","0",
-					"no","off","false","n","f",
-					"No","Off","False",NULL};
-	pvt->_debug=(sqlrdebug && *sqlrdebug &&
-				!charstring::inSet(sqlrdebug,noset));
-	if (pvt->_debug && !charstring::inSet(sqlrdebug,yesset) &&
-				!charstring::inSet(sqlrdebug,noset)) {
+	pvt->_debug=(sqlrdebug && *sqlrdebug && !charstring::isNo(sqlrdebug));
+	if (pvt->_debug && !charstring::isYes(sqlrdebug) &&
+				!charstring::isNo(sqlrdebug)) {
 		setDebugFile(sqlrdebug);
 	}
 	pvt->_webdebug=-1;
@@ -273,6 +284,9 @@ sqlrconnection::~sqlrconnection() {
 		endSession();
 	}
 
+	// deallocate error
+	delete[] pvt->_error;
+
 	// deallocate id
 	delete[] pvt->_id;
 
@@ -285,6 +299,15 @@ sqlrconnection::~sqlrconnection() {
 	// deallocate db ip address
 	delete[] pvt->_dbipaddress;
 
+	// deallocate server version
+	delete[] pvt->_serverversion;
+
+	// deallocate current database name
+	delete[] pvt->_currentdbname;
+
+	// deallocate current schema name
+	delete[] pvt->_currentschemaname;
+
 	// deallocate bindformat
 	delete[] pvt->_bindformat;
 
@@ -335,7 +358,7 @@ void sqlrconnection::enableKerberos(const char *service,
 		disableEncryption();
 	}
 
-	if (!gss::supportsGSS()) {
+	if (!gss::supported()) {
 		return;
 	}
 
@@ -380,7 +403,7 @@ void sqlrconnection::enableTls(const char *version,
 		disableEncryption();
 	}
 
-	if (!tls::supportsTLS()) {
+	if (!tls::supported()) {
 		return;
 	}
 
@@ -463,7 +486,7 @@ void sqlrconnection::setTimeoutFromEnv(const char *var,
 	const char	*timeout=environment::getValue(var);
 	if (charstring::isNumber(timeout)) {
 		*timeoutsec=charstring::toInteger(timeout);
-		long double	dbl=charstring::toFloat(timeout);
+		long double	dbl=charstring::toFloatC(timeout);
 		dbl=dbl-(long double)(*timeoutsec);
 		*timeoutusec=(int32_t)(dbl*1000000.0);
 	} else {
@@ -472,6 +495,24 @@ void sqlrconnection::setTimeoutFromEnv(const char *var,
 	}
 }
 
+void sqlrconnection::getConnectTimeout(int32_t *timeoutsec,
+					int32_t *timeoutusec) {
+	*timeoutsec=pvt->_connecttimeoutsec;
+	*timeoutusec=pvt->_connecttimeoutusec;
+}
+
+void sqlrconnection::getAuthenticationTimeout(int32_t *timeoutsec,
+						int32_t *timeoutusec) {
+	*timeoutsec=pvt->_authtimeoutsec;
+	*timeoutusec=pvt->_authtimeoutusec;
+}
+
+void sqlrconnection::getResponseTimeout(int32_t *timeoutsec,
+						int32_t *timeoutusec) {
+	*timeoutsec=pvt->_responsetimeoutsec;
+	*timeoutusec=pvt->_responsetimeoutusec;
+}
+
 void sqlrconnection::endSession() {
 
 	if (pvt->_debug) {
@@ -578,6 +619,10 @@ bool sqlrconnection::openSession() {
 						pvt->_connecttimeoutusec,
 						pvt->_retrytime,pvt->_tries);
 		if (openresult==RESULT_SUCCESS) {
+
+			pvt->_ucs.setSocketReadBufferSize(65536);
+			pvt->_ucs.setSocketWriteBufferSize(65536);
+
 			pvt->_cs=&pvt->_ucs;
 		}
 	}
@@ -601,6 +646,12 @@ bool sqlrconnection::openSession() {
 						pvt->_connecttimeoutusec,
 						pvt->_retrytime,pvt->_tries);
 		if (openresult==RESULT_SUCCESS) {
+
+			pvt->_ics.setSocketReadBufferSize(65536);
+			pvt->_ics.setSocketWriteBufferSize(65536);
+
+			pvt->_ics.dontUseNaglesAlgorithm();
+
 			pvt->_cs=&pvt->_ics;
 		}
 	}
@@ -640,7 +691,7 @@ bool sqlrconnection::validateCertificate() {
 	// If we're not doing any validation then just return true. If we're
 	// just doing ca validation then the connect would have failed if the
 	// certificate was invalid, so we can just return true for that too.
-	if (!charstring::compareIgnoringCase(pvt->_tlsvalidate,"no") ||
+	if (charstring::isNo(pvt->_tlsvalidate) ||
 		!charstring::compareIgnoringCase(pvt->_tlsvalidate,"ca")) {
 		return true;
 	}
@@ -733,17 +784,13 @@ bool sqlrconnection::validateCertificate() {
 
 bool sqlrconnection::reConfigureSockets() {
 
-	pvt->_ucs.dontUseNaglesAlgorithm();
-	//pvt->_ucs.setTcpReadBufferSize(65536);
-	//pvt->_ucs.setTcpWriteBufferSize(65536);
 	pvt->_ucs.setReadBufferSize(65536);
 	pvt->_ucs.setWriteBufferSize(65536);
+	//pvt->_ucs.useAsyncWrite();
 
-	pvt->_ics.dontUseNaglesAlgorithm();
-	//pvt->_ics.setTcpReadBufferSize(65536);
-	//pvt->_ics.setTcpWriteBufferSize(65536);
 	pvt->_ics.setReadBufferSize(65536);
 	pvt->_ics.setWriteBufferSize(65536);
+	//pvt->_ics.useAsyncWrite();
 
 
 	if (pvt->_usekrb) {
@@ -820,6 +867,7 @@ bool sqlrconnection::reConfigureSockets() {
 			if (pvt->_tlsversion) {
 				debugPrint(pvt->_tlsversion);
 			}
+			debugPrint("\n");
 			debugPrint("  cert: ");
 			if (pvt->_tlscert) {
 				debugPrint(pvt->_tlscert);
@@ -897,12 +945,12 @@ void sqlrconnection::protocol() {
 
 	if (pvt->_debug) {
 		debugPreStart();
-		debugPrint("Protocol : sqlrclient version 1\n");
+		debugPrint("Protocol : sqlrclient version 2\n");
 		debugPreEnd();
 	}
 
 	pvt->_cs->write((uint16_t)PROTOCOLVERSION);
-	pvt->_cs->write((uint16_t)1);
+	pvt->_cs->write((uint16_t)2);
 }
 
 void sqlrconnection::auth() {
@@ -912,7 +960,10 @@ void sqlrconnection::auth() {
 		debugPrint("Auth : ");
 		debugPrint(pvt->_user);
 		debugPrint(":");
-		debugPrint(pvt->_password);
+		// hide the password
+		for (uint8_t i=0; i<pvt->_passwordlen; i++) {
+			debugPrint("*");
+		}
 		debugPrint("\n");
 		debugPreEnd();
 	}
@@ -937,7 +988,7 @@ bool sqlrconnection::getNewPort() {
 	if (pvt->_cs->read(&size)!=sizeof(uint16_t)) {
 		setError("Failed to get the size of "
 				"the unix connection port.\n"
-				"A network error may have ocurred.");
+				"A network error may have occurred.");
 		return false;
 	}
 	
@@ -957,7 +1008,7 @@ bool sqlrconnection::getNewPort() {
 	// get the unix port string
 	if (size && pvt->_cs->read(pvt->_connectionunixportbuffer,size)!=size) {
 		setError("Failed to get the unix connection port.\n"
-				"A network error may have ocurred.");
+				"A network error may have occurred.");
 		return false;
 	}
 	pvt->_connectionunixportbuffer[size]='\0';
@@ -966,7 +1017,7 @@ bool sqlrconnection::getNewPort() {
 	// get the inet port
 	if (pvt->_cs->read(&pvt->_connectioninetport)!=sizeof(uint16_t)) {
 		setError("Failed to get the inet connection port.\n"
-				"A network error may have ocurred.");
+				"A network error may have occurred.");
 		return false;
 	}
 
@@ -1149,7 +1200,7 @@ const char *sqlrconnection::identify() {
 	if (pvt->_cs->read(&size,pvt->_responsetimeoutsec,
 				pvt->_responsetimeoutusec)!=sizeof(uint16_t)) {
 		setError("Failed to identify.\n"
-			"A network error may have ocurred.");
+			"A network error may have occurred.");
 		return NULL;
 	}
 
@@ -1158,7 +1209,7 @@ const char *sqlrconnection::identify() {
 	pvt->_id=new char[size+1];
 	if (pvt->_cs->read(pvt->_id,size)!=size) {
 		setError("Failed to identify.\n"
-			"A network error may have ocurred.");
+			"A network error may have occurred.");
 		delete[] pvt->_id;
 		pvt->_id=NULL;
 		return NULL;
@@ -1202,7 +1253,7 @@ const char *sqlrconnection::dbVersion() {
 	if (pvt->_cs->read(&size,pvt->_responsetimeoutsec,
 				pvt->_responsetimeoutusec)!=sizeof(uint16_t)) {
 		setError("Failed to get DB version.\n"
-			"A network error may have ocurred.");
+			"A network error may have occurred.");
 		return NULL;
 	} 
 
@@ -1211,7 +1262,7 @@ const char *sqlrconnection::dbVersion() {
 	pvt->_dbversion=new char[size+1];
 	if (pvt->_cs->read(pvt->_dbversion,size)!=size) {
 		setError("Failed to get DB version.\n"
-			"A network error may have ocurred.");
+			"A network error may have occurred.");
 		delete[] pvt->_dbversion;
 		pvt->_dbversion=NULL;
 		return NULL;
@@ -1255,7 +1306,7 @@ const char *sqlrconnection::dbHostName() {
 	if (pvt->_cs->read(&size,pvt->_responsetimeoutsec,
 				pvt->_responsetimeoutusec)!=sizeof(uint16_t)) {
 		setError("Failed to get DB host name.\n"
-				"A network error may have ocurred.");
+				"A network error may have occurred.");
 		return NULL;
 	}
 
@@ -1264,7 +1315,7 @@ const char *sqlrconnection::dbHostName() {
 	pvt->_dbhostname=new char[size+1];
 	if (pvt->_cs->read(pvt->_dbhostname,size)!=size) {
 		setError("Failed to get DB host name.\n"
-				"A network error may have ocurred.");
+				"A network error may have occurred.");
 		delete[] pvt->_dbhostname;
 		pvt->_dbhostname=NULL;
 		return NULL;
@@ -1308,7 +1359,7 @@ const char *sqlrconnection::dbIpAddress() {
 	if (pvt->_cs->read(&size,pvt->_responsetimeoutsec,
 				pvt->_responsetimeoutusec)!=sizeof(uint16_t)) {
 		setError("Failed to get DB ip address.\n"
-				"A network error may have ocurred.");
+				"A network error may have occurred.");
 		return NULL;
 	}
 
@@ -1317,7 +1368,7 @@ const char *sqlrconnection::dbIpAddress() {
 	pvt->_dbipaddress=new char[size+1];
 	if (pvt->_cs->read(pvt->_dbipaddress,size)!=size) {
 		setError("Failed to get DB ip address.\n"
-				"A network error may have ocurred.");
+				"A network error may have occurred.");
 		delete[] pvt->_dbipaddress;
 		pvt->_dbipaddress=NULL;
 		return NULL;
@@ -1361,7 +1412,7 @@ const char *sqlrconnection::serverVersion() {
 	if (pvt->_cs->read(&size,pvt->_responsetimeoutsec,
 				pvt->_responsetimeoutusec)!=sizeof(uint16_t)) {
 		setError("Failed to get Server version.\n"
-				"A network error may have ocurred.");
+				"A network error may have occurred.");
 		return NULL;
 	}
 
@@ -1370,7 +1421,7 @@ const char *sqlrconnection::serverVersion() {
 	pvt->_serverversion=new char[size+1];
 	if (pvt->_cs->read(pvt->_serverversion,size)!=size) {
 		setError("Failed to get Server version.\n"
-				"A network error may have ocurred.");
+				"A network error may have occurred.");
 		delete[] pvt->_serverversion;
 		pvt->_serverversion=NULL;
 		return NULL;
@@ -1419,7 +1470,7 @@ const char *sqlrconnection::bindFormat() {
 	if (pvt->_cs->read(&size,pvt->_responsetimeoutsec,
 				pvt->_responsetimeoutusec)!=sizeof(uint16_t)) {
 		setError("Failed to get bind format.\n"
-				"A network error may have ocurred.");
+				"A network error may have occurred.");
 		return NULL;
 	}
 
@@ -1428,7 +1479,7 @@ const char *sqlrconnection::bindFormat() {
 	pvt->_bindformat=new char[size+1];
 	if (pvt->_cs->read(pvt->_bindformat,size)!=size) {
 		setError("Failed to get bind format.\n"
-				"A network error may have ocurred.");
+				"A network error may have occurred.");
 		delete[] pvt->_bindformat;
 		pvt->_bindformat=NULL;
 		return NULL;
@@ -1494,7 +1545,7 @@ const char *sqlrconnection::getCurrentDatabase() {
 
 	clearError();
 
-	// tell the server we want to select a db
+	// tell the server we want to get the current db
 	pvt->_cs->write((uint16_t)GET_CURRENT_DATABASE);
 	flushWriteBuffer();
 
@@ -1507,7 +1558,7 @@ const char *sqlrconnection::getCurrentDatabase() {
 	if (pvt->_cs->read(&size,pvt->_responsetimeoutsec,
 				pvt->_responsetimeoutusec)!=sizeof(uint16_t)) {
 		setError("Failed to get the current database.\n"
-				"A network error may have ocurred.");
+				"A network error may have occurred.");
 		return NULL;
 	}
 
@@ -1516,7 +1567,7 @@ const char *sqlrconnection::getCurrentDatabase() {
 	pvt->_currentdbname=new char[size+1];
 	if (pvt->_cs->read(pvt->_currentdbname,size)!=size) {
 		setError("Failed to get the current database.\n"
-				"A network error may have ocurred.");
+				"A network error may have occurred.");
 		delete[] pvt->_currentdbname;
 		pvt->_currentdbname=NULL;
 		return NULL;
@@ -1532,6 +1583,60 @@ const char *sqlrconnection::getCurrentDatabase() {
 	return pvt->_currentdbname;
 }
 
+const char *sqlrconnection::getCurrentSchema() {
+
+	if (!openSession()) {
+		return NULL;
+	}
+
+	clearError();
+
+	if (pvt->_debug) {
+		debugPreStart();
+		debugPrint("Getting the current schema...\n");
+		debugPreEnd();
+	}
+
+	clearError();
+
+	// tell the server we want to get the current schema
+	pvt->_cs->write((uint16_t)GET_CURRENT_SCHEMA);
+	flushWriteBuffer();
+
+	if (gotError()) {
+		return NULL;
+	}
+
+	// get the current schema name size
+	uint16_t	size;
+	if (pvt->_cs->read(&size,pvt->_responsetimeoutsec,
+				pvt->_responsetimeoutusec)!=sizeof(uint16_t)) {
+		setError("Failed to get the current database.\n"
+				"A network error may have occurred.");
+		return NULL;
+	}
+
+	// get the current schema name
+	delete[] pvt->_currentschemaname;
+	pvt->_currentschemaname=new char[size+1];
+	if (pvt->_cs->read(pvt->_currentschemaname,size)!=size) {
+		setError("Failed to get the current database.\n"
+				"A network error may have occurred.");
+		delete[] pvt->_currentschemaname;
+		pvt->_currentschemaname=NULL;
+		return NULL;
+	}
+	pvt->_currentschemaname[size]='\0';
+
+	if (pvt->_debug) {
+		debugPreStart();
+		debugPrint(pvt->_currentschemaname);
+		debugPrint("\n");
+		debugPreEnd();
+	}
+	return pvt->_currentschemaname;
+}
+
 uint64_t sqlrconnection::getLastInsertId() {
 
 	if (!openSession()) {
@@ -1558,7 +1663,7 @@ uint64_t sqlrconnection::getLastInsertId() {
 	uint64_t	id=0;
 	if (pvt->_cs->read(&id)!=sizeof(uint64_t)) {
 		setError("Failed to get the last insert id.\n"
-				"A network error may have ocurred.");
+				"A network error may have occurred.");
 		return 0;
 	}
 
@@ -1710,7 +1815,7 @@ uint16_t sqlrconnection::getError() {
 	if (pvt->_cs->read(&status,pvt->_responsetimeoutsec,
 				pvt->_responsetimeoutusec)!=sizeof(uint16_t)) {
 		setError("Failed to get the error status.\n"
-				"A network error may have ocurred.");
+				"A network error may have occurred.");
 		return ERROR_OCCURRED;
 	}
 
@@ -1733,7 +1838,7 @@ uint16_t sqlrconnection::getError() {
 	// get the error code
 	if (pvt->_cs->read((uint64_t *)&pvt->_errorno)!=sizeof(uint64_t)) {
 		setError("Failed to get the error code.\n"
-				"A network error may have ocurred.");
+				"A network error may have occurred.");
 		return status;
 	}
 
@@ -1741,7 +1846,7 @@ uint16_t sqlrconnection::getError() {
 	uint16_t	size;
 	if (pvt->_cs->read(&size)!=sizeof(uint16_t)) {
 		setError("Failed to get the error size.\n"
-				"A network error may have ocurred.");
+				"A network error may have occurred.");
 		return status;
 	}
 
@@ -1749,7 +1854,7 @@ uint16_t sqlrconnection::getError() {
 	pvt->_error=new char[size+1];
 	if (pvt->_cs->read(pvt->_error,size)!=size) {
 		setError("Failed to get the error string.\n"
-				"A network error may have ocurred.");
+				"A network error may have occurred.");
 		return status;
 	}
 	pvt->_error[size]='\0';
@@ -1960,3 +2065,34 @@ void sqlrconnection::lastcursor(sqlrcursor *cur) {
 sqlrcursor *sqlrconnection::lastcursor() {
 	return pvt->_lastcursor;
 }
+
+bool sqlrconnection::isYes(const char *str) {
+	return charstring::isYes(str);
+}
+
+bool sqlrconnection::isNo(const char *str) {
+	return charstring::isNo(str);
+}
+
+void sqlrconnection::setBindVariableDelimiters(const char *delimiters) {
+	pvt->_questionmarksupported=charstring::contains(delimiters,'?');
+	pvt->_colonsupported=charstring::contains(delimiters,':');
+	pvt->_atsignsupported=charstring::contains(delimiters,'@');
+	pvt->_dollarsignsupported=charstring::contains(delimiters,'$');
+}
+
+bool sqlrconnection::getBindVariableDelimiterQuestionMarkSupported() {
+	return pvt->_questionmarksupported;
+}
+
+bool sqlrconnection::getBindVariableDelimiterColonSupported() {
+	return pvt->_colonsupported;
+}
+
+bool sqlrconnection::getBindVariableDelimiterAtSignSupported() {
+	return pvt->_atsignsupported;
+}
+
+bool sqlrconnection::getBindVariableDelimiterDollarSignSupported() {
+	return pvt->_dollarsignsupported;
+}
