@@ -5,6 +5,12 @@ sqlrcon	sqlrcon_alloc_copyrefs(const char *server,
 					int32_t retrytime, int32_t tries,
 					int copyreferences);
 
+SQLRCLIENT_DLLSPEC
+int sqlrcon_isYes(const char *string);
+
+SQLRCLIENT_DLLSPEC
+int sqlrcon_isNo(const char *string);
+
 SQLRCLIENT_DLLSPEC
 sqlrcur	sqlrcur_alloc_copyrefs(sqlrcon sqlrconref, int copyreferences);
 
