@@ -1,4 +1,4 @@
-// Copyright (c) 2012-2015  David Muse
+// Copyright (c) 1999-2018 David Muse
 // See the file COPYING for more information
 
 using System;
@@ -167,7 +167,7 @@ public class SQLRCursor : IDisposable
     /** Sends "query" directly and gets a result set. */
     public Boolean sendQuery(String query)
     {
-        return sqlrcur_sendQuery(sqlrcurref, query) != 0;
+        return sqlrcur_sendQueryWithLength(sqlrcurref, query, (uint)System.Text.Encoding.Default.GetByteCount(query)) != 0;
     }
 
     /** Sends "query" with length "length" directly and gets a result set. This
@@ -188,7 +188,7 @@ public class SQLRCursor : IDisposable
     /** Prepare to execute "query". */
     public void prepareQuery(String query)
     {
-        sqlrcur_prepareQuery(sqlrcurref, query);
+        sqlrcur_prepareQueryWithLength(sqlrcurref, query, (uint)System.Text.Encoding.Default.GetByteCount(query));
     }
 
     /** Prepare to execute "query" with length "length".  This function must be
@@ -256,7 +256,7 @@ public class SQLRCursor : IDisposable
     /** Defines a String input bind variable. */
     public void inputBind(String variable, String val)
     {
-        sqlrcur_inputBindString(sqlrcurref, variable, val);
+        sqlrcur_inputBindStringWithLength(sqlrcurref, variable, val, (val != null) ? (uint)System.Text.Encoding.Default.GetByteCount(val) : 0);
     }
 
     /** Defines a String input bind variable. */
@@ -315,9 +315,9 @@ public class SQLRCursor : IDisposable
     /**  Defines a date input bind variable.  "day" should be
      *  1-31 and "month" should be 1-12.  "tz" may be left NULL.
      *  Most databases ignore "tz".  */
-    public void inputBind(String variable, Int16 year, Int16 month, Int16 day, Int16 hour, Int16 minute, Int16 second, Int32 microsecond, String tz)
+    public void inputBind(String variable, Int16 year, Int16 month, Int16 day, Int16 hour, Int16 minute, Int16 second, Int32 microsecond, String tz, Boolean isnegative)
     {
-        sqlrcur_inputBindDate(sqlrcurref, variable, year, month, day, hour, minute, second, microsecond, tz);
+        sqlrcur_inputBindDate(sqlrcurref, variable, year, month, day, hour, minute, second, microsecond, tz, (isnegative) ? 1 : 0);
     }
 
     /** Defines a binary lob input bind variable. */
@@ -446,7 +446,7 @@ public class SQLRCursor : IDisposable
 
     /** Get the value stored in a previously defined
      *  decimal output bind variable. */
-    public Boolean getOutputBindDate(String variable, out Int16 year, out Int16 month, out Int16 day, out Int16 hour, out Int16 minute, out Int16 second, out Int32 microsecond, out String tz)
+    public Boolean getOutputBindDate(String variable, out Int16 year, out Int16 month, out Int16 day, out Int16 hour, out Int16 minute, out Int16 second, out Int32 microsecond, out String tz, out Boolean isnegative)
     {
         year = -1;
         month = -1;
@@ -456,9 +456,12 @@ public class SQLRCursor : IDisposable
         second = -1;
         microsecond = -1;
         tz = "";
+        isnegative = false;
         IntPtr tzptr = (IntPtr)0;
-        sqlrcur_getOutputBindDate(sqlrcurref, variable, ref year, ref month, ref day, ref hour, ref minute, ref second, ref microsecond, ref tzptr);
+        Int32 isneg = 0;
+        sqlrcur_getOutputBindDate(sqlrcurref, variable, ref year, ref month, ref day, ref hour, ref minute, ref second, ref microsecond, ref tzptr, ref isneg);
         tz = Marshal.PtrToStringAnsi(tzptr);
+        isnegative = (isneg!=0);
         return false;
     }
 
@@ -1037,7 +1040,7 @@ public class SQLRCursor : IDisposable
     private static extern void sqlrcur_inputBindDouble(IntPtr sqlrcurref, String variable, Double val, UInt32 precision, UInt32 scale);
 
     [DllImport("libsqlrclientwrapper.dll", CallingConvention = CallingConvention.Cdecl)]
-    private static extern void sqlrcur_inputBindDate(IntPtr sqlrcurref, String variable, Int16 year, Int16 month, Int16 day, Int16 hour, Int16 minute, Int16 second, Int32 microsecond, String tz);
+    private static extern void sqlrcur_inputBindDate(IntPtr sqlrcurref, String variable, Int16 year, Int16 month, Int16 day, Int16 hour, Int16 minute, Int16 second, Int32 microsecond, String tz, Int32 isnegative);
 
     [DllImport("libsqlrclientwrapper.dll", CallingConvention = CallingConvention.Cdecl)]
     private static extern void sqlrcur_inputBindBlob(IntPtr sqlrcurref, String variable, Byte[] val, UInt32 size);
@@ -1094,7 +1097,7 @@ public class SQLRCursor : IDisposable
     private static extern Double sqlrcur_getOutputBindDouble(IntPtr sqlrcurref, String variable);
 
     [DllImport("libsqlrclientwrapper.dll", CallingConvention = CallingConvention.Cdecl)]
-    private static extern Int32 sqlrcur_getOutputBindDate(IntPtr sqlrcurref, String variable, ref Int16 year, ref Int16 month, ref Int16 day, ref Int16 hour, ref Int16 minute, ref Int16 second, ref Int32 microsecond, ref IntPtr tz);
+    private static extern Int32 sqlrcur_getOutputBindDate(IntPtr sqlrcurref, String variable, ref Int16 year, ref Int16 month, ref Int16 day, ref Int16 hour, ref Int16 minute, ref Int16 second, ref Int32 microsecond, ref IntPtr tz, ref Int32 isnegative);
 
     [DllImport("libsqlrclientwrapper.dll", CallingConvention = CallingConvention.Cdecl)]
     private static extern IntPtr sqlrcur_getOutputBindBlob(IntPtr sqlrcurref, String variable);
