@@ -1,4 +1,4 @@
-// Copyright (c) 2001  David Muse
+// Copyright (c) 1999-2018 David Muse
 // See the file COPYING for more information.
 package com.firstworks.sqlrelay;
 
@@ -460,4 +460,14 @@ public class SQLRCursor {
 	public SQLRConnection	connection;
 	private native long	alloc(long con);
 	private native long	getOutputBindCursorInternal(String variable);
+	public native boolean	getDatabaseListWithFormat(
+						String wild, int listformat);
+	public native boolean	getSchemaListWithFormat(
+						String wild, int listformat);
+	public native boolean	getTableListWithFormat(
+						String wild, int listformat,
+						int objecttypes);
+	public native boolean	getColumnListWithFormat(
+						String table, String wild,
+						int listformat);
 }
