@@ -1,4 +1,4 @@
-// Copyright (c) 2001  David Muse
+// Copyright (c) 1999-2018 David Muse
 // See the file COPYING for more information.
 
 #ifdef __CYGWIN__
@@ -1557,6 +1557,70 @@ JNIEXPORT void JNICALL Java_com_firstworks_sqlrelay_SQLRCursor_closeResultSet
 	getSqlrCursor(env,self)->closeResultSet();
 }
 
+/*
+ * Class:     com_firstworks_sqlrelay_SQLRCursor
+ * Method:    getDatabaseListWithFormat
+ * Signature: (Ljava/lang/String;I;)Z
+ */
+JNIEXPORT jboolean JNICALL Java_com_firstworks_sqlrelay_SQLRCursor_getDatabaseListWithFormat
+  (JNIEnv *env, jobject self, jstring wild, jint listformat) {
+	char	*wildstring=curGetStringUTFChars(env,wild,0);
+	jboolean	retval=getSqlrCursor(env,self)->
+				getDatabaseList(wildstring,
+					(sqlrclientlistformat_t)listformat);
+	curReleaseStringUTFChars(env,wild,wildstring);
+	return retval;
+}
+
+/*
+ * Class:     com_firstworks_sqlrelay_SQLRCursor
+ * Method:    getSchemaListWithFormat
+ * Signature: (Ljava/lang/String;I;)Z
+ */
+JNIEXPORT jboolean JNICALL Java_com_firstworks_sqlrelay_SQLRCursor_getSchemaListWithFormat
+  (JNIEnv *env, jobject self, jstring wild, jint listformat) {
+	char	*wildstring=curGetStringUTFChars(env,wild,0);
+	jboolean	retval=getSqlrCursor(env,self)->
+				getSchemaList(wildstring,
+					(sqlrclientlistformat_t)listformat);
+	curReleaseStringUTFChars(env,wild,wildstring);
+	return retval;
+}
+
+/*
+ * Class:     com_firstworks_sqlrelay_SQLRCursor
+ * Method:    getTableListWithFormat
+ * Signature: (Ljava/lang/String;I;S;)Z
+ */
+JNIEXPORT jboolean JNICALL Java_com_firstworks_sqlrelay_SQLRCursor_getTableListWithFormat
+  (JNIEnv *env, jobject self, jstring wild, jint listformat, jint objecttypes) {
+	char	*wildstring=curGetStringUTFChars(env,wild,0);
+	jboolean	retval=getSqlrCursor(env,self)->
+				getTableList(wildstring,
+					(sqlrclientlistformat_t)listformat,
+					(uint16_t)objecttypes);
+	curReleaseStringUTFChars(env,wild,wildstring);
+	return retval;
+}
+
+/*
+ * Class:     com_firstworks_sqlrelay_SQLRCursor
+ * Method:    getColumnListWithFormat
+ * Signature: (Ljava/lang/String;Ljava/lang/String;I;)Z
+ */
+JNIEXPORT jboolean JNICALL Java_com_firstworks_sqlrelay_SQLRCursor_getColumnListWithFormat
+  (JNIEnv *env, jobject self, jstring table, jstring wild, jint listformat) {
+	char	*tablestring=curGetStringUTFChars(env,table,0);
+	char	*wildstring=curGetStringUTFChars(env,wild,0);
+	jboolean	retval=getSqlrCursor(env,self)->
+				getColumnList(tablestring,wildstring,
+					(sqlrclientlistformat_t)listformat);
+	curReleaseStringUTFChars(env,wild,wildstring);
+	curReleaseStringUTFChars(env,table,tablestring);
+	return retval;
+}
+
+
 #ifdef __cplusplus
 }
 #endif
