@@ -1,4 +1,4 @@
-// Copyright (c) 2015  David Muse
+// Copyright (c) 1999-2018 David Muse
 // See the file COPYING for more information.
 
 #include <sqlrelay/sqlrclient.h>
@@ -15,12 +15,16 @@ using namespace node;
 // macros to deal with differences between major versions of node.js
 #if NODE_MAJOR_VERSION > 0 || NODE_MINOR_VERSION >= 12
 
+	#if NODE_MAJOR_VERSION >= 12
+		#define Handle Local
+	#endif
+
 	#define RET void
 	#define ARGS FunctionCallbackInfo<Value>
 
 	#define initLocalScope() Isolate *isolate=Isolate::GetCurrent(); HandleScope	localscope(isolate)
 
-	#define resetConstructor(constructor,tpl) constructor.Reset(isolate,tpl->GetFunction())
+	#define resetConstructor(constructor,tpl) constructor.Reset(isolate,GetFunction(tpl))
 
 	#define returnObject(object) args.GetReturnValue().Set(object)
 	#define returnString(result) if (result) { args.GetReturnValue().Set(newString(result)); } else { args.GetReturnValue().Set(Null(isolate)); }
@@ -34,7 +38,11 @@ using namespace node;
 
 	#define newFunctionTemplate(func) FunctionTemplate::New(isolate,func)
 	#define newLocalFunction(func) Local<Function>::New(isolate,func)
-	#define newString(val) String::NewFromUtf8(isolate,val)
+	#if NODE_MAJOR_VERSION < 14
+		#define newString(val) String::NewFromUtf8(isolate,val)
+	#else
+		#define newString(val) String::NewFromUtf8(isolate,val).ToLocalChecked()
+	#endif
 	#define newBoolean(val) Boolean::New(isolate,val)
 	#define newInteger(val) Integer::New(isolate,val)
 	#define newUnsignedInteger(val) Integer::NewFromUnsigned(isolate,val)
@@ -42,9 +50,22 @@ using namespace node;
 	#define newInt32(val) Int32::New(isolate,val)
 	#define newNumber(val) Number::New(isolate,val)
 	#define newArray(len) Array::New(isolate,len)
+	#if NODE_MAJOR_VERSION >= 10
+		#define newInstance(argc,argv) cons->NewInstance(isolate->GetCurrentContext(),argc,argv).ToLocalChecked()
+	#else
+		#define newInstance(argc,argv) cons->NewInstance(argc,argv)
+	#endif
 
 	#define checkArgCount(args,count) if (args.Length()!=count) { throwWrongNumberOfArguments(); return; }
 
+	#if NODE_MAJOR_VERSION < 14
+		#define set(a,b,c) a->Set(b,c)
+		#define get(a,b) a->Get(b)
+	#else
+		#define set(a,b,c) a->Set(isolate->GetCurrentContext(),b,c)
+		#define get(a,b) a->Get(isolate->GetCurrentContext(),b).ToLocalChecked()
+	#endif
+
 #else
 
 	#define RET Handle<Value>
@@ -74,14 +95,34 @@ using namespace node;
 	#define newInt32(val) Int32::New(val)
 	#define newNumber(val) Number::New(val)
 	#define newArray(len) Array::New(len)
+	#define newInstance(argc,argv) cons->NewInstance(argc,argv)
 
 	#define checkArgCount(args,count) if (args.Length()!=count) { throwWrongNumberOfArguments(); returnBoolean(false); }
 
+	#define set(a,b,c) a->Set(b,c)
+	#define get(a,b) a->Get(b)
+
 #endif
 
 
 // convenience macros
-#define toString(arg) ((arg->IsNull())?NULL:*(String::Utf8Value(arg)))
+#if NODE_MAJOR_VERSION < 12
+	#define toString(arg) ((arg->IsNull())?NULL:*(String::Utf8Value(arg)))
+	#define toInt32(arg) arg->Int32Value()
+	#define toUint32(arg) arg->Uint32Value()
+	#define toInteger(arg) arg->IntegerValue()
+	#define toNumber(arg) arg->NumberValue()
+	#define toObject(arg) arg->ToObject()
+	#define GetFunction(arg) arg->GetFunction()
+#else
+	#define toString(arg) ((arg->IsNull())?NULL:*(String::Utf8Value(isolate,arg)))
+	#define toInt32(arg) arg->Int32Value(isolate->GetCurrentContext()).ToChecked()
+	#define toUint32(arg) arg->Uint32Value(isolate->GetCurrentContext()).ToChecked()
+	#define toInteger(arg) arg->IntegerValue(isolate->GetCurrentContext()).ToChecked()
+	#define toNumber(arg) arg->NumberValue(isolate->GetCurrentContext()).ToChecked()
+	#define toObject(arg) arg->ToObject(isolate->GetCurrentContext()).ToLocalChecked()
+	#define GetFunction(arg) arg->GetFunction(isolate->GetCurrentContext()).ToLocalChecked()
+#endif
 #define toArray(arg) Handle<Array>::Cast(arg);
 
 #if NODE_MAJOR_VERSION > 0 || NODE_MINOR_VERSION >= 12
@@ -107,6 +148,15 @@ class SQLRConnection : public ObjectWrap {
 		static RET	setConnectTimeout(const ARGS &args);
 		static RET	setAuthenticationTimeout(const ARGS &args);
 		static RET	setResponseTimeout(const ARGS &args);
+		static RET	setBindVariableDelimiters(const ARGS &args);
+		static RET	getBindVariableDelimiterQuestionMarkSupported(
+							const ARGS &args);
+		static RET	getBindVariableDelimiterColonSupported(
+							const ARGS &args);
+		static RET	getBindVariableDelimiterAtSignSupported(
+							const ARGS &args);
+		static RET	getBindVariableDelimiterDollarSignSupported(
+							const ARGS &args);
 		static RET	enableKerberos(const ARGS &args);
 		static RET	enableTls(const ARGS &args);
 		static RET	disableEncryption(const ARGS &args);
@@ -264,6 +314,21 @@ void SQLRConnection::Init(Handle<Object> exports) {
 	NODE_SET_PROTOTYPE_METHOD(tpl,"setAuthenticationTimeout",
 						setAuthenticationTimeout);
 	NODE_SET_PROTOTYPE_METHOD(tpl,"setResponseTimeout",setResponseTimeout);
+	NODE_SET_PROTOTYPE_METHOD(tpl,
+			"setBindVariableDelimiters",
+			setBindVariableDelimiters);
+	NODE_SET_PROTOTYPE_METHOD(tpl,
+			"getBindVariableDelimiterQuestionMarkSupported",
+			getBindVariableDelimiterQuestionMarkSupported);
+	NODE_SET_PROTOTYPE_METHOD(tpl,
+			"getBindVariableDelimiterColonSupported",
+			getBindVariableDelimiterColonSupported);
+	NODE_SET_PROTOTYPE_METHOD(tpl,
+			"getBindVariableDelimiterAtSignSupported",
+			getBindVariableDelimiterAtSignSupported);
+	NODE_SET_PROTOTYPE_METHOD(tpl,
+			"getBindVariableDelimiterDollarSignSupported",
+			getBindVariableDelimiterDollarSignSupported);
 	NODE_SET_PROTOTYPE_METHOD(tpl,"enableKerberos",enableKerberos);
 	NODE_SET_PROTOTYPE_METHOD(tpl,"enableTls",enableTls);
 	NODE_SET_PROTOTYPE_METHOD(tpl,"disableEncryption",disableEncryption);
@@ -299,7 +364,7 @@ void SQLRConnection::Init(Handle<Object> exports) {
 	NODE_SET_PROTOTYPE_METHOD(tpl,"getClientInfo",getClientInfo);
 
 	resetConstructor(constructor,tpl);
-	exports->Set(newString("SQLRConnection"),tpl->GetFunction());
+	set(exports,newString("SQLRConnection"),GetFunction(tpl));
 }
 
 SQLRConnection::SQLRConnection() {
@@ -319,12 +384,12 @@ RET SQLRConnection::New(const ARGS &args) {
 		// invoked as constructor: new SQLRConnection(...)
 		SQLRConnection	*obj=new SQLRConnection();
 		obj->sqlrc=new sqlrconnection(toString(args[0]),
-						args[1]->Uint32Value(),
+						toUint32(args[1]),
 						toString(args[2]),
 						toString(args[3]),
 						toString(args[4]),
-						args[5]->Int32Value(),
-						args[6]->Int32Value(),
+						toInt32(args[5]),
+						toInt32(args[6]),
 						true);
 		obj->Wrap(args.This());
 		returnObject(args.This());
@@ -335,7 +400,7 @@ RET SQLRConnection::New(const ARGS &args) {
 		const int	argc=1;
 		Local<Value>	argv[argc]={args[0]};
 		Local<Function>	cons=newLocalFunction(constructor);
-		returnObject(cons->NewInstance(argc,argv));
+		returnObject(newInstance(argc,argv));
 	}
 }
 
@@ -345,8 +410,7 @@ RET SQLRConnection::setConnectTimeout(const ARGS &args) {
 
 	checkArgCount(args,2);
 
-	sqlrcon(args)->setConnectTimeout(args[0]->Int32Value(),
-						args[1]->Int32Value());
+	sqlrcon(args)->setConnectTimeout(toInt32(args[0]),toInt32(args[1]));
 
 	returnVoid();
 }
@@ -357,8 +421,8 @@ RET SQLRConnection::setAuthenticationTimeout(const ARGS &args) {
 
 	checkArgCount(args,2);
 
-	sqlrcon(args)->setAuthenticationTimeout(args[0]->Int32Value(),
-						args[1]->Int32Value());
+	sqlrcon(args)->setAuthenticationTimeout(toInt32(args[0]),
+						toInt32(args[1]));
 
 	returnVoid();
 }
@@ -369,12 +433,74 @@ RET SQLRConnection::setResponseTimeout(const ARGS &args) {
 
 	checkArgCount(args,2);
 
-	sqlrcon(args)->setResponseTimeout(args[0]->Int32Value(),
-						args[1]->Int32Value());
+	sqlrcon(args)->setResponseTimeout(toInt32(args[0]),toInt32(args[1]));
 
 	returnVoid();
 }
 
+RET SQLRConnection::setBindVariableDelimiters(const ARGS &args) {
+
+	initLocalScope();
+
+	checkArgCount(args,1);
+
+	sqlrcon(args)->setBindVariableDelimiters(toString(args[0]));
+
+	returnVoid();
+}
+
+RET SQLRConnection::getBindVariableDelimiterQuestionMarkSupported(
+							const ARGS &args) {
+
+	initLocalScope();
+
+	checkArgCount(args,0);
+
+	bool	result=sqlrcon(args)->
+			getBindVariableDelimiterQuestionMarkSupported();
+
+	returnBoolean(result);
+}
+
+RET SQLRConnection::getBindVariableDelimiterColonSupported(
+							const ARGS &args) {
+
+	initLocalScope();
+
+	checkArgCount(args,0);
+
+	bool	result=sqlrcon(args)->
+			getBindVariableDelimiterColonSupported();
+
+	returnBoolean(result);
+}
+
+RET SQLRConnection::getBindVariableDelimiterAtSignSupported(
+							const ARGS &args) {
+
+	initLocalScope();
+
+	checkArgCount(args,0);
+
+	bool	result=sqlrcon(args)->
+			getBindVariableDelimiterAtSignSupported();
+
+	returnBoolean(result);
+}
+
+RET SQLRConnection::getBindVariableDelimiterDollarSignSupported(
+							const ARGS &args) {
+
+	initLocalScope();
+
+	checkArgCount(args,0);
+
+	bool	result=sqlrcon(args)->
+			getBindVariableDelimiterDollarSignSupported();
+
+	returnBoolean(result);
+}
+
 RET SQLRConnection::enableKerberos(const ARGS &args) {
 
 	initLocalScope();
@@ -400,7 +526,7 @@ RET SQLRConnection::enableTls(const ARGS &args) {
 					toString(args[3]),
 					toString(args[4]),
 					toString(args[5]),
-					args[6]->Uint32Value());
+					toUint32(args[6]));
 
 	returnVoid();
 }
@@ -466,7 +592,7 @@ RET SQLRConnection::resumeSession(const ARGS &args) {
 
 	checkArgCount(args,2);
 
-	bool	result=sqlrcon(args)->resumeSession(args[0]->Int32Value(),
+	bool	result=sqlrcon(args)->resumeSession(toInt32(args[0]),
 							toString(args[1]));
 
 	returnBoolean(result);
@@ -864,7 +990,7 @@ void SQLRCursor::Init(Handle<Object> exports) {
 	NODE_SET_PROTOTYPE_METHOD(tpl,"closeResultSet",closeResultSet);
 
 	resetConstructor(constructor,tpl);
-	exports->Set(newString("SQLRCursor"),tpl->GetFunction());
+	set(exports,newString("SQLRCursor"),GetFunction(tpl));
 }
 
 SQLRCursor::SQLRCursor() {
@@ -884,7 +1010,7 @@ RET SQLRCursor::New(const ARGS &args) {
 		// invoked as constructor: new SQLRCursor(...)
 		sqlrconnection	*sqlrcon=
 			node::ObjectWrap::Unwrap<SQLRConnection>(
-						args[0]->ToObject())->sqlrc;
+						toObject(args[0]))->sqlrc;
 
 		SQLRCursor	*obj=new SQLRCursor();
 		obj->sqlrc=new sqlrcursor(sqlrcon,true);
@@ -897,7 +1023,7 @@ RET SQLRCursor::New(const ARGS &args) {
 		const int	argc=1;
 		Local<Value>	argv[argc]={args[0]};
 		Local<Function>	cons=newLocalFunction(constructor);
-		returnObject(cons->NewInstance(argc,argv));
+		returnObject(newInstance(argc,argv));
 	}
 }
 
@@ -907,7 +1033,7 @@ RET SQLRCursor::setResultSetBufferSize(const ARGS &args) {
 
 	checkArgCount(args,1);
 
-	sqlrcur(args)->setResultSetBufferSize(args[0]->IntegerValue());
+	sqlrcur(args)->setResultSetBufferSize(toInteger(args[0]));
 
 	returnVoid();
 }
@@ -995,7 +1121,7 @@ RET SQLRCursor::setCacheTtl(const ARGS &args) {
 
 	checkArgCount(args,1);
 
-	sqlrcur(args)->setCacheTtl(args[0]->Uint32Value());
+	sqlrcur(args)->setCacheTtl(toUint32(args[0]));
 
 	returnVoid();
 }
@@ -1066,7 +1192,7 @@ RET SQLRCursor::sendQuery(const ARGS &args) {
 		result=sqlrcur(args)->sendQuery(toString(args[0]));
 	} else if (args.Length()==2) {
 		result=sqlrcur(args)->sendQuery(toString(args[0]),
-						args[1]->Uint32Value());
+						toUint32(args[1]));
 	} else {
 		throwWrongNumberOfArguments();
 	}
@@ -1096,7 +1222,7 @@ RET SQLRCursor::prepareQuery(const ARGS &args) {
 		sqlrcur(args)->prepareQuery(toString(args[0]));
 	} else if (args.Length()==2) {
 		sqlrcur(args)->prepareQuery(toString(args[0]),
-						args[1]->Uint32Value());
+						toUint32(args[1]));
 	} else {
 		throwWrongNumberOfArguments();
 	}
@@ -1126,15 +1252,15 @@ RET SQLRCursor::substitution(const ARGS &args) {
 							toString(args[1]));
 		} else if (args[1]->IsNumber()) {
 			sqlrcur(args)->substitution(toString(args[0]),
-						args[1]->IntegerValue());
+							toInteger(args[1]));
 		} else {
 			throwInvalidArgumentType();
 		}
 	} else if (args.Length()==4) {
 		sqlrcur(args)->substitution(toString(args[0]),
-						args[1]->NumberValue(),
-						args[2]->Uint32Value(),
-						args[3]->Uint32Value());
+						toNumber(args[1]),
+						toUint32(args[2]),
+						toUint32(args[3]));
 	} else {
 		throwWrongNumberOfArguments();
 	}
@@ -1156,7 +1282,7 @@ RET SQLRCursor::substitutions(const ARGS &args) {
 			if (vars->Length()) {
 
 				Local<Value>	first=
-					vals->Get(newInteger(0));
+					get(vals,newInteger(0));
 
 				if (first->IsString() || first->IsNull()) {
 
@@ -1166,10 +1292,10 @@ RET SQLRCursor::substitutions(const ARGS &args) {
 						sqlrcur(args)->
 							substitution(
 
-							toString(vars->Get(
+							toString(get(vars,
 							newInteger(i))),
 
-							toString(vals->Get(
+							toString(get(vals,
 							newInteger(i)))
 							);
 					}
@@ -1182,12 +1308,11 @@ RET SQLRCursor::substitutions(const ARGS &args) {
 						sqlrcur(args)->
 							substitution(
 
-							toString(vars->Get(
+							toString(get(vars,
 							newInteger(i))),
 
-							vals->Get(
-							newInteger(i))->
-							IntegerValue());
+							toInteger(get(vals,
+							newInteger(i))));
 					}
 
 				} else {
@@ -1210,7 +1335,7 @@ RET SQLRCursor::substitutions(const ARGS &args) {
 			if (vars->Length()) {
 
 				Local<Value>	first=
-					vals->Get(newInteger(0));
+					get(vals,newInteger(0));
 
 				if (first->IsNumber()) {
 
@@ -1219,20 +1344,20 @@ RET SQLRCursor::substitutions(const ARGS &args) {
 
 						sqlrcur(args)->substitution(
 
-							toString(vars->Get(
+							toString(get(vars,
 							newInteger(i))),
 
-							vals->Get(
-							newInteger(i))->
-							NumberValue(),
+							toNumber(
+							get(vals,
+							newInteger(i))),
 
-							precs->Get(
-							newInteger(i))->
-							Uint32Value(),
+							toUint32(
+							get(precs,
+							newInteger(i))),
 
-							scales->Get(
-							newInteger(i))->
-							Uint32Value());
+							toUint32(
+							get(scales,
+							newInteger(i))));
 					}
 
 				} else {
@@ -1264,7 +1389,7 @@ RET SQLRCursor::inputBind(const ARGS &args) {
 
 			// integer
 			sqlrcur(args)->inputBind(toString(args[0]),
-						args[1]->IntegerValue());
+							toInteger(args[1]));
 		} else {
 			throwInvalidArgumentType();
 		}
@@ -1274,28 +1399,29 @@ RET SQLRCursor::inputBind(const ARGS &args) {
 		// string with length
 		sqlrcur(args)->inputBind(toString(args[0]),
 						toString(args[1]),
-						args[2]->Uint32Value());
+						toUint32(args[2]));
 
 	} else if (args.Length()==4) {
 
 		// decimal
 		sqlrcur(args)->inputBind(toString(args[0]),
-						args[1]->NumberValue(),
-						args[2]->Uint32Value(),
-						args[3]->Uint32Value());
+						toNumber(args[1]),
+						toUint32(args[2]),
+						toUint32(args[3]));
 
 	} else if (args.Length()==9) {
 
 		// date
 		sqlrcur(args)->inputBind(toString(args[0]),
-						args[1]->Int32Value(),
-						args[2]->Int32Value(),
-						args[3]->Int32Value(),
-						args[4]->Int32Value(),
-						args[5]->Int32Value(),
-						args[6]->Int32Value(),
-						args[7]->Int32Value(),
-						toString(args[8]));
+						toInt32(args[1]),
+						toInt32(args[2]),
+						toInt32(args[3]),
+						toInt32(args[4]),
+						toInt32(args[5]),
+						toInt32(args[6]),
+						toInt32(args[7]),
+						toString(args[8]),
+						toInt32(args[9]));
 
 	} else {
 		throwWrongNumberOfArguments();
@@ -1312,7 +1438,7 @@ RET SQLRCursor::inputBindBlob(const ARGS &args) {
 
 	sqlrcur(args)->inputBindBlob(toString(args[0]),
 					toString(args[1]),
-					args[2]->Uint32Value());
+					toUint32(args[2]));
 
 	returnVoid();
 }
@@ -1325,7 +1451,7 @@ RET SQLRCursor::inputBindClob(const ARGS &args) {
 
 	sqlrcur(args)->inputBindClob(toString(args[0]),
 					toString(args[1]),
-					args[2]->Uint32Value());
+					toUint32(args[2]));
 
 	returnVoid();
 }
@@ -1344,7 +1470,7 @@ RET SQLRCursor::inputBinds(const ARGS &args) {
 			if (vars->Length()) {
 
 				Local<Value>	first=
-					vals->Get(newInteger(0));
+					get(vals,newInteger(0));
 
 				if (first->IsString() || first->IsNull()) {
 
@@ -1354,10 +1480,10 @@ RET SQLRCursor::inputBinds(const ARGS &args) {
 						sqlrcur(args)->
 							inputBind(
 
-							toString(vars->Get(
+							toString(get(vars,
 							newInteger(i))),
 
-							toString(vals->Get(
+							toString(get(vals,
 							newInteger(i)))
 							);
 					}
@@ -1370,12 +1496,12 @@ RET SQLRCursor::inputBinds(const ARGS &args) {
 						sqlrcur(args)->
 							inputBind(
 
-							toString(vars->Get(
+							toString(get(vars,
 							newInteger(i))),
 
-							vals->Get(
-							newInteger(i))->
-							IntegerValue());
+							toInteger(
+							get(vals,
+							newInteger(i))));
 					}
 
 				} else {
@@ -1398,7 +1524,7 @@ RET SQLRCursor::inputBinds(const ARGS &args) {
 			if (vars->Length()) {
 
 				Local<Value>	first=
-					vals->Get(newInteger(0));
+					get(vals,newInteger(0));
 
 				if (first->IsNumber()) {
 
@@ -1407,20 +1533,21 @@ RET SQLRCursor::inputBinds(const ARGS &args) {
 
 						sqlrcur(args)->inputBind(
 
-							toString(vars->Get(
+							toString(
+							get(vars,
 							newInteger(i))),
 
-							vals->Get(
-							newInteger(i))->
-							NumberValue(),
+							toNumber(
+							get(vals,
+							newInteger(i))),
 
-							precs->Get(
-							newInteger(i))->
-							Uint32Value(),
+							toUint32(
+							get(precs,
+							newInteger(i))),
 
-							scales->Get(
-							newInteger(i))->
-							Uint32Value());
+							toUint32(
+							get(scales,
+							newInteger(i))));
 					}
 
 				} else {
@@ -1444,7 +1571,7 @@ RET SQLRCursor::defineOutputBindString(const ARGS &args) {
 	checkArgCount(args,2);
 
 	sqlrcur(args)->defineOutputBindString(toString(args[0]),
-						args[1]->Uint32Value());
+						toUint32(args[1]));
 
 	returnVoid();
 }
@@ -1785,10 +1912,10 @@ RET SQLRCursor::getField(const ARGS &args) {
 	const char	*result=NULL;
 
 	if (args[1]->IsNumber()) {
-		result=sqlrcur(args)->getField(args[0]->IntegerValue(),
-							args[1]->Uint32Value());
+		result=sqlrcur(args)->getField(toInteger(args[0]),
+							toUint32(args[1]));
 	} else if (args[1]->IsString()) {
-		result=sqlrcur(args)->getField(args[0]->IntegerValue(),
+		result=sqlrcur(args)->getField(toInteger(args[0]),
 							toString(args[1]));
 	} else {
 		throwInvalidArgumentType();
@@ -1807,11 +1934,11 @@ RET SQLRCursor::getFieldAsInteger(const ARGS &args) {
 
 	if (args[1]->IsNumber()) {
 		result=sqlrcur(args)->getFieldAsInteger(
-						args[0]->IntegerValue(),
-						args[1]->Uint32Value());
+						toInteger(args[0]),
+						toUint32(args[1]));
 	} else if (args[1]->IsString()) {
 		result=sqlrcur(args)->getFieldAsInteger(
-						args[0]->IntegerValue(),
+						toInteger(args[0]),
 						toString(args[1]));
 	} else {
 		throwInvalidArgumentType();
@@ -1830,11 +1957,11 @@ RET SQLRCursor::getFieldAsDouble(const ARGS &args) {
 
 	if (args[1]->IsNumber()) {
 		result=sqlrcur(args)->getFieldAsDouble(
-						args[0]->IntegerValue(),
-						args[1]->Uint32Value());
+						toInteger(args[0]),
+						toUint32(args[1]));
 	} else if (args[1]->IsString()) {
 		result=sqlrcur(args)->getFieldAsDouble(
-						args[0]->IntegerValue(),
+						toInteger(args[0]),
 						toString(args[1]));
 	} else {
 		throwInvalidArgumentType();
@@ -1853,11 +1980,11 @@ RET SQLRCursor::getFieldLength(const ARGS &args) {
 
 	if (args[1]->IsNumber()) {
 		result=sqlrcur(args)->getFieldLength(
-						args[0]->IntegerValue(),
-						args[1]->Uint32Value());
+						toInteger(args[0]),
+						toUint32(args[1]));
 	} else if (args[1]->IsString()) {
 		result=sqlrcur(args)->getFieldLength(
-						args[0]->IntegerValue(),
+						toInteger(args[0]),
 						toString(args[1]));
 	} else {
 		throwInvalidArgumentType();
@@ -1872,13 +1999,12 @@ RET SQLRCursor::getRow(const ARGS &args) {
 
 	checkArgCount(args,1);
 
-	const char * const *fields=sqlrcur(args)->getRow(
-						args[0]->IntegerValue());
+	const char * const *fields=sqlrcur(args)->getRow(toInteger(args[0]));
 	uint32_t	colcount=sqlrcur(args)->colCount();
 
 	Handle<Array>	result=newArray(colcount);
 	for (uint32_t i=0; i<colcount; i++) {
-		result->Set(newInteger(i),newString(fields[i]));
+		set(result,newInteger(i),newString(fields[i]));
 	}
 
 	returnObject(result);
@@ -1891,13 +2017,12 @@ RET SQLRCursor::getRowLengths(const ARGS &args) {
 	checkArgCount(args,1);
 
 	uint32_t	*lengths=sqlrcur(args)->getRowLengths(
-						args[0]->IntegerValue());
+						toInteger(args[0]));
 	uint32_t	colcount=sqlrcur(args)->colCount();
 
 	Handle<Array>	result=newArray(colcount);
 	for (uint32_t i=0; i<colcount; i++) {
-		result->Set(newInteger(i),
-				newUint32(lengths[i]));
+		set(result,newInteger(i),newUint32(lengths[i]));
 	}
 
 	returnObject(result);
@@ -1914,7 +2039,7 @@ RET SQLRCursor::getColumnNames(const ARGS &args) {
 
 	Handle<Array>	result=newArray(colcount);
 	for (uint32_t i=0; i<colcount; i++) {
-		result->Set(newInteger(i),newString(names[i]));
+		set(result,newInteger(i),newString(names[i]));
 	}
 
 	returnObject(result);
@@ -1927,7 +2052,7 @@ RET SQLRCursor::getColumnName(const ARGS &args) {
 	checkArgCount(args,1);
 
 	const char	*result=sqlrcur(args)->getColumnName(
-						args[0]->Uint32Value());
+						toUint32(args[0]));
 
 	returnString(result);
 }
@@ -1941,7 +2066,7 @@ RET SQLRCursor::getColumnType(const ARGS &args) {
 	const char	*result=NULL;
 
 	if (args[0]->IsNumber()) {
-		result=sqlrcur(args)->getColumnType(args[0]->Uint32Value());
+		result=sqlrcur(args)->getColumnType(toUint32(args[0]));
 	} else if (args[0]->IsString()) {
 		result=sqlrcur(args)->getColumnType(toString(args[0]));
 	} else {
@@ -1960,7 +2085,7 @@ RET SQLRCursor::getColumnLength(const ARGS &args) {
 	uint32_t	result=0;
 
 	if (args[0]->IsNumber()) {
-		result=sqlrcur(args)->getColumnLength(args[0]->Uint32Value());
+		result=sqlrcur(args)->getColumnLength(toUint32(args[0]));
 	} else if (args[0]->IsString()) {
 		result=sqlrcur(args)->getColumnLength(toString(args[0]));
 	} else {
@@ -1979,11 +2104,9 @@ RET SQLRCursor::getColumnPrecision(const ARGS &args) {
 	uint32_t	result=0;
 
 	if (args[0]->IsNumber()) {
-		result=sqlrcur(args)->getColumnPrecision(
-						args[0]->Uint32Value());
+		result=sqlrcur(args)->getColumnPrecision(toUint32(args[0]));
 	} else if (args[0]->IsString()) {
-		result=sqlrcur(args)->getColumnPrecision(
-						toString(args[0]));
+		result=sqlrcur(args)->getColumnPrecision(toString(args[0]));
 	} else {
 		throwInvalidArgumentType();
 	}
@@ -2000,7 +2123,7 @@ RET SQLRCursor::getColumnScale(const ARGS &args) {
 	uint32_t	result=0;
 
 	if (args[0]->IsNumber()) {
-		result=sqlrcur(args)->getColumnScale(args[0]->Uint32Value());
+		result=sqlrcur(args)->getColumnScale(toUint32(args[0]));
 	} else if (args[0]->IsString()) {
 		result=sqlrcur(args)->getColumnScale(toString(args[0]));
 	} else {
@@ -2019,11 +2142,9 @@ RET SQLRCursor::getColumnIsNullable(const ARGS &args) {
 	bool	result=false;
 
 	if (args[0]->IsNumber()) {
-		result=sqlrcur(args)->getColumnIsNullable(
-						args[0]->Uint32Value());
+		result=sqlrcur(args)->getColumnIsNullable(toUint32(args[0]));
 	} else if (args[0]->IsString()) {
-		result=sqlrcur(args)->getColumnIsNullable(
-						toString(args[0]));
+		result=sqlrcur(args)->getColumnIsNullable(toString(args[0]));
 	} else {
 		throwInvalidArgumentType();
 	}
@@ -2040,11 +2161,9 @@ RET SQLRCursor::getColumnIsPrimaryKey(const ARGS &args) {
 	bool	result=false;
 
 	if (args[0]->IsNumber()) {
-		result=sqlrcur(args)->getColumnIsPrimaryKey(
-						args[0]->Uint32Value());
+		result=sqlrcur(args)->getColumnIsPrimaryKey(toUint32(args[0]));
 	} else if (args[0]->IsString()) {
-		result=sqlrcur(args)->getColumnIsPrimaryKey(
-						toString(args[0]));
+		result=sqlrcur(args)->getColumnIsPrimaryKey(toString(args[0]));
 	} else {
 		throwInvalidArgumentType();
 	}
@@ -2062,11 +2181,9 @@ RET SQLRCursor::getColumnIsUnique(const ARGS &args) {
 	bool	result=false;
 
 	if (args[0]->IsNumber()) {
-		result=sqlrcur(args)->getColumnIsUnique(
-						args[0]->Uint32Value());
+		result=sqlrcur(args)->getColumnIsUnique(toUint32(args[0]));
 	} else if (args[0]->IsString()) {
-		result=sqlrcur(args)->getColumnIsUnique(
-						toString(args[0]));
+		result=sqlrcur(args)->getColumnIsUnique(toString(args[0]));
 	} else {
 		throwInvalidArgumentType();
 	}
@@ -2083,11 +2200,9 @@ RET SQLRCursor::getColumnIsPartOfKey(const ARGS &args) {
 	bool	result=false;
 
 	if (args[0]->IsNumber()) {
-		result=sqlrcur(args)->getColumnIsPartOfKey(
-						args[0]->Uint32Value());
+		result=sqlrcur(args)->getColumnIsPartOfKey(toUint32(args[0]));
 	} else if (args[0]->IsString()) {
-		result=sqlrcur(args)->getColumnIsPartOfKey(
-						toString(args[0]));
+		result=sqlrcur(args)->getColumnIsPartOfKey(toString(args[0]));
 	} else {
 		throwInvalidArgumentType();
 	}
@@ -2104,11 +2219,9 @@ RET SQLRCursor::getColumnIsUnsigned(const ARGS &args) {
 	bool	result=false;
 
 	if (args[0]->IsNumber()) {
-		result=sqlrcur(args)->getColumnIsUnsigned(
-						args[0]->Uint32Value());
+		result=sqlrcur(args)->getColumnIsUnsigned(toUint32(args[0]));
 	} else if (args[0]->IsString()) {
-		result=sqlrcur(args)->getColumnIsUnsigned(
-						toString(args[0]));
+		result=sqlrcur(args)->getColumnIsUnsigned(toString(args[0]));
 	} else {
 		throwInvalidArgumentType();
 	}
@@ -2125,11 +2238,9 @@ RET SQLRCursor::getColumnIsZeroFilled(const ARGS &args) {
 	bool	result=false;
 
 	if (args[0]->IsNumber()) {
-		result=sqlrcur(args)->getColumnIsZeroFilled(
-						args[0]->Uint32Value());
+		result=sqlrcur(args)->getColumnIsZeroFilled(toUint32(args[0]));
 	} else if (args[0]->IsString()) {
-		result=sqlrcur(args)->getColumnIsZeroFilled(
-						toString(args[0]));
+		result=sqlrcur(args)->getColumnIsZeroFilled(toString(args[0]));
 	} else {
 		throwInvalidArgumentType();
 	}
@@ -2146,11 +2257,9 @@ RET SQLRCursor::getColumnIsBinary(const ARGS &args) {
 	bool	result=false;
 
 	if (args[0]->IsNumber()) {
-		result=sqlrcur(args)->getColumnIsBinary(
-						args[0]->Uint32Value());
+		result=sqlrcur(args)->getColumnIsBinary(toUint32(args[0]));
 	} else if (args[0]->IsString()) {
-		result=sqlrcur(args)->getColumnIsBinary(
-						toString(args[0]));
+		result=sqlrcur(args)->getColumnIsBinary(toString(args[0]));
 	} else {
 		throwInvalidArgumentType();
 	}
@@ -2168,7 +2277,7 @@ RET SQLRCursor::getColumnIsAutoIncrement(const ARGS &args) {
 
 	if (args[0]->IsNumber()) {
 		result=sqlrcur(args)->getColumnIsAutoIncrement(
-						args[0]->Uint32Value());
+						toUint32(args[0]));
 	} else if (args[0]->IsString()) {
 		result=sqlrcur(args)->getColumnIsAutoIncrement(
 						toString(args[0]));
@@ -2188,7 +2297,7 @@ RET SQLRCursor::getLongest(const ARGS &args) {
 	uint32_t	result=0;
 
 	if (args[0]->IsNumber()) {
-		result=sqlrcur(args)->getLongest(args[0]->Uint32Value());
+		result=sqlrcur(args)->getLongest(toUint32(args[0]));
 	} else if (args[0]->IsString()) {
 		result=sqlrcur(args)->getLongest(toString(args[0]));
 	} else {
@@ -2226,7 +2335,7 @@ RET SQLRCursor::resumeResultSet(const ARGS &args) {
 
 	checkArgCount(args,1);
 
-	bool	result=sqlrcur(args)->resumeResultSet(args[0]->Uint32Value());
+	bool	result=sqlrcur(args)->resumeResultSet(toUint32(args[0]));
 
 	returnBoolean(result);
 }
@@ -2238,7 +2347,7 @@ RET SQLRCursor::resumeCachedResultSet(const ARGS &args) {
 	checkArgCount(args,2);
 
 	bool	result=sqlrcur(args)->resumeCachedResultSet(
-						args[0]->Uint32Value(),
+						toUint32(args[0]),
 						toString(args[1]));
 
 	returnBoolean(result);
