@@ -677,13 +677,8 @@ PGresult *PQprepare(PGconn *conn,
 
 			const char	*dbtype=conn->sqlrcon->identify();
 			if (!dbtype) {
-				size_t	errorlen=
-					charstring::length(conn->sqlrcur->
-							errorMessage())+2;
-				conn->error=new char[errorlen];
-				charstring::printf(
-					conn->error,errorlen,"%s\n",
-					conn->sqlrcur->errorMessage());
+				charstring::printf(&conn->error,"%s\n",
+						conn->sqlrcur->errorMessage());
 				PQclear(result);
 				return NULL;
 			}
@@ -770,11 +765,7 @@ PGresult *PQexecPrepared(PGconn *conn,
 				result->execstatus=PGRES_TUPLES_OK;
 			}
 		} else {
-			size_t	errorlen=
-				charstring::length(result->
-						sqlrcur->errorMessage())+2;
-			conn->error=new char[errorlen];
-			charstring::printf(conn->error,errorlen,"%s\n",
+			charstring::printf(&conn->error,"%s\n",
 					result->sqlrcur->errorMessage());
 			PQclear(result);
 			result=NULL;
@@ -1283,7 +1274,13 @@ static Oid postgresqltypemap[]={
 	// "BYTE"
 	26,
 	// "BOOLEAN"
-	16
+	16,
+	// "TINY_TEXT"
+	26,
+	// "MEDIUM_TEXT"
+	26,
+	// "LONG_TEXT"
+	26
 };
 
 Oid PQftype(const PGresult *res, int field_num) {
@@ -1409,12 +1406,14 @@ size_t PQescapeString(char *to, const char *from, size_t length) {
 
 	while (remaining>0) {
 		switch (*source) {
-			case '\\':
+			// did this change at some point?
+			// this used to be correct
+			/*case '\\':
 				*target='\\';
 				target++;
 				*target='\\';
 				// target and remaining are updated below.
-				break;
+				break;*/
 
 			case '\'':
 				*target='\'';
