@@ -1,4 +1,4 @@
-// Copyright (c) 2000-2001  David Muse
+// Copyright (c) 1999-2018 David Muse
 // See the file COPYING for more information.
 
 #ifndef DATATYPES_H
@@ -202,7 +202,22 @@ typedef	enum {
 	// added by informix
 	SMALLFLOAT_DATATYPE,
 	BYTE_DATATYPE,
-	BOOLEAN_DATATYPE
+	BOOLEAN_DATATYPE,
+	// also added by mysql
+	TINYTEXT_DATATYPE,
+	MEDIUMTEXT_DATATYPE,
+	LONGTEXT_DATATYPE,
+	JSON_DATATYPE,
+	GEOMETRY_DATATYPE,
+	// also added by oracle
+	SDO_GEOMETRY_DATATYPE,
+	// added by mssql
+	NCHAR_DATATYPE,
+	NVARCHAR_DATATYPE,
+	NTEXT_DATATYPE,
+	XML_DATATYPE,
+	DATETIMEOFFSET_DATATYPE,
+	END_DATATYPE
 } datatype;
 
 #ifdef NEED_DATATYPESTRING
@@ -279,8 +294,8 @@ static const char	*datatypestring[] = {
 	"DBCLOB",
 	"DATALINK",
 	"USER_DEFINED_TYPE",
-	"SHORT_DATATYPE",
-	"TINY_DATATYPE",
+	"SHORT",
+	"TINY",
 	// added by firebird
 	"D_FLOAT",	// 67
 	"ARRAY",
@@ -399,37 +414,93 @@ static const char	*datatypestring[] = {
 	"SMALLFLOAT",
 	"BYTE",
 	"BOOLEAN",
+	// also added by mysql
+	"TINYTEXT",
+	"MEDIUMTEXT",
+	"LONGTEXT",
+	"JSON",
+	"GEOMETRY",
+	// also added by oracle
+	"SDO_GEOMETRY",
+	// added by mssql
+	"NCHAR",
+	"NVARCHAR",
+	"NTEXT",
+	"XML",
+	"DATETIMEOFFSET",
 	NULL
 };
 #endif
 
 #ifdef NEED_IS_BIT_TYPE_CHAR
 static bool isBitTypeChar(const char *type) {
-  return (!charstring::compareIgnoringCase(type,"BIT") ||
-	  !charstring::compareIgnoringCase(type,"VARBIT"));
+	return (!charstring::compareIgnoringCase(type,"BIT") ||
+		!charstring::compareIgnoringCase(type,"VARBIT"));
+}
+#endif
+
+#ifdef NEED_IS_BIT_TYPE_INT
+static bool isBitTypeInt(int16_t type) {
+	return (type==BIT_DATATYPE ||
+		type==VARBIT_DATATYPE);
 }
 #endif
 
 #ifdef NEED_IS_BOOL_TYPE_CHAR
 static bool isBoolTypeChar(const char *type) {
-  return !charstring::compareIgnoringCase(type,"BOOL");
+	return !charstring::compareIgnoringCase(type,"BOOL");
+}
+#endif
+
+#ifdef NEED_IS_BOOL_TYPE_INT
+static bool isBoolTypeInt(int16_t type) {
+	return (type==BOOL_DATATYPE);
 }
 #endif
 
 #ifdef NEED_IS_FLOAT_TYPE_CHAR
 static bool isFloatTypeChar(const char *type) {
-  return (!charstring::compareIgnoringCase(type,"NUMERIC") ||
-	  !charstring::compareIgnoringCase(type,"REAL") ||
-	  !charstring::compareIgnoringCase(type,"FLOAT") ||
-	  !charstring::compareIgnoringCase(type,"DOUBLE") ||
-	  !charstring::compareIgnoringCase(type,"D_FLOAT") ||
-	  !charstring::compareIgnoringCase(type,"DECIMAL") ||
-	  !charstring::compareIgnoringCase(type,"MONEY") ||
-	  !charstring::compareIgnoringCase(type,"SMALLMONEY") ||
-	  !charstring::compareIgnoringCase(type,"DOUBLE PRECISION") ||
-	  !charstring::compareIgnoringCase(type,"FLOAT4") ||
-	  !charstring::compareIgnoringCase(type,"FLOAT8") ||
-	  !charstring::compareIgnoringCase(type,"_NUMERIC"));
+	return (!charstring::compareIgnoringCase(type,"NUMERIC") ||
+		!charstring::compareIgnoringCase(type,"REAL") ||
+		!charstring::compareIgnoringCase(type,"FLOAT") ||
+		!charstring::compareIgnoringCase(type,"DOUBLE") ||
+		!charstring::compareIgnoringCase(type,"D_FLOAT") ||
+		!charstring::compareIgnoringCase(type,"DECIMAL") ||
+		!charstring::compareIgnoringCase(type,"MONEY") ||
+		!charstring::compareIgnoringCase(type,"SMALLMONEY") ||
+		!charstring::compareIgnoringCase(type,"DOUBLE PRECISION") ||
+		!charstring::compareIgnoringCase(type,"FLOAT4") ||
+		!charstring::compareIgnoringCase(type,"FLOAT8") ||
+		!charstring::compareIgnoringCase(type,"_NUMERIC"));
+}
+#endif
+
+#ifdef NEED_IS_NONSCALE_FLOAT_TYPE_CHAR
+static bool isNonScaleFloatTypeChar(const char *type) {
+	return (!charstring::compareIgnoringCase(type,"REAL") ||
+		!charstring::compareIgnoringCase(type,"FLOAT") ||
+		!charstring::compareIgnoringCase(type,"DOUBLE") ||
+		!charstring::compareIgnoringCase(type,"D_FLOAT") ||
+		!charstring::compareIgnoringCase(type,"DOUBLE PRECISION") ||
+		!charstring::compareIgnoringCase(type,"FLOAT4") ||
+		!charstring::compareIgnoringCase(type,"FLOAT8"));
+}
+#endif
+
+#ifdef NEED_IS_FLOAT_TYPE_INT
+static bool isFloatTypeInt(int16_t type) {
+	return (type==NUMERIC_DATATYPE ||
+		type==REAL_DATATYPE ||
+		type==FLOAT_DATATYPE ||
+		type==DOUBLE_DATATYPE ||
+		type==D_FLOAT_DATATYPE ||
+		type==DECIMAL_DATATYPE ||
+		type==MONEY_DATATYPE ||
+		type==SMALLMONEY_DATATYPE ||
+		type==DOUBLE_PRECISION_DATATYPE ||
+		type==FLOAT4_DATATYPE ||
+		type==FLOAT8_DATATYPE ||
+		type==_NUMERIC_DATATYPE);
 }
 #endif
 
@@ -445,7 +516,7 @@ static int32_t bitStringToLong(const char *str) {
 #endif
 
 #ifdef NEED_IS_NUMBER_TYPE_CHAR
-static bool isNumberTypeChar(const char *type) { 
+static bool isNumberTypeChar(const char *type) {
 	return (!charstring::compareIgnoringCase(type,"NUMBER") ||
 		!charstring::compareIgnoringCase(type,"INT") ||
 		!charstring::compareIgnoringCase(type,"SMALLINT") ||
@@ -491,7 +562,59 @@ static bool isNumberTypeChar(const char *type) {
 		!charstring::compareIgnoringCase(type,"_FLOAT8") ||
 		!charstring::compareIgnoringCase(type,"_TINTERVAL") ||
 		!charstring::compareIgnoringCase(type,"INTERVAL") ||
-		!charstring::compareIgnoringCase(type,"_INTERVAL"));
+		!charstring::compareIgnoringCase(type,"_INTERVAL") ||
+		!charstring::compareIgnoringCase(type,"NUMERIC"));
+}
+#endif
+
+#ifdef NEED_IS_NUMBER_TYPE_INT
+static bool isNumberTypeInt(int16_t type) {
+	return (type==NUMBER_DATATYPE ||
+		type==INT_DATATYPE ||
+		type==SMALLINT_DATATYPE ||
+		type==TINYINT_DATATYPE ||
+		type==BIT_DATATYPE ||
+		type==REAL_DATATYPE ||
+		type==FLOAT_DATATYPE ||
+		type==USHORT_DATATYPE ||
+		type==DOUBLE_DATATYPE ||
+		type==UINT_DATATYPE ||
+		type==LASTREAL_DATATYPE ||
+		type==TINY_DATATYPE ||
+		type==SHORT_DATATYPE ||
+		type==LONGLONG_DATATYPE ||
+		type==MEDIUMINT_DATATYPE ||
+		type==YEAR_DATATYPE ||
+		type==BIGINT_DATATYPE ||
+		type==INTEGER_DATATYPE ||
+		type==D_FLOAT_DATATYPE || 
+		type==DECIMAL_DATATYPE ||
+		type==INT64_DATATYPE ||
+		type==MONEY_DATATYPE ||
+		type==SMALLMONEY_DATATYPE ||
+		type==DOUBLE_PRECISION_DATATYPE ||
+		type==INT8_DATATYPE ||
+		type==INT2_DATATYPE ||
+		type==INT4_DATATYPE ||
+		type==TID_DATATYPE ||
+		type==XID_DATATYPE ||
+		type==CID_DATATYPE ||
+		type==FLOAT4_DATATYPE ||
+		type==FLOAT8_DATATYPE ||
+		type==TINTERVAL_DATATYPE ||
+		type==_MONEY_DATATYPE ||
+		type==_INT2_DATATYPE ||
+		type==_INT4_DATATYPE ||
+		type==_TID_DATATYPE ||
+		type==_XID_DATATYPE ||
+		type==_CID_DATATYPE ||
+		type==_INT8_DATATYPE ||
+		type==_FLOAT4_DATATYPE ||
+		type==_FLOAT8_DATATYPE ||
+		type==_TINTERVAL_DATATYPE ||
+		type==INTERVAL_DATATYPE ||
+		type==_INTERVAL_DATATYPE ||
+		type==NUMERIC_DATATYPE);
 }
 #endif
 
@@ -507,18 +630,69 @@ static bool isBlobTypeChar(const char *type) {
 		!charstring::compareIgnoringCase(type,"MEDIUMBLOB") ||
 		!charstring::compareIgnoringCase(type,"LONGBLOB") ||
 		!charstring::compareIgnoringCase(type,"BLOB") ||
+		!charstring::compareIgnoringCase(type,"LONGVARBINARY") ||
+		!charstring::compareIgnoringCase(type,"LONGVARCHAR") ||
 		!charstring::compareIgnoringCase(type,"RAW") ||
 		!charstring::compareIgnoringCase(type,"LONG_RAW") ||
 		!charstring::compareIgnoringCase(type,"CLOB") ||
 		!charstring::compareIgnoringCase(type,"BFILE") ||
+		!charstring::compareIgnoringCase(type,"DBCLOB") ||
+		!charstring::compareIgnoringCase(type,"TINYTEXT") ||
+		!charstring::compareIgnoringCase(type,"MEDIUMTEXT") ||
+		!charstring::compareIgnoringCase(type,"LONGTEXT") ||
+		!charstring::compareIgnoringCase(type,"JSON") ||
+		!charstring::compareIgnoringCase(type,"GEOMETRY") ||
+		!charstring::compareIgnoringCase(type,"SDO_GEOMETRY") ||
+		!charstring::compareIgnoringCase(type,"NTEXT") ||
+		!charstring::compareIgnoringCase(type,"XML") ||
+		!charstring::compareIgnoringCase(type,"GRAPHIC") ||
+		!charstring::compareIgnoringCase(type,"VARGRAPHIC") ||
+		!charstring::compareIgnoringCase(type,"LONGVARGRAPHIC") ||
 		!charstring::compareIgnoringCase(type,"DBCLOB"));
 }
 #endif
 
+#ifdef NEED_IS_BLOB_TYPE_INT
+static bool isBlobTypeInt(int16_t type) { 
+	return (type==IMAGE_DATATYPE ||
+		type==BINARY_DATATYPE ||
+		type==VARBINARY_DATATYPE ||
+		type==LONGCHAR_DATATYPE ||
+		type==LONGBINARY_DATATYPE ||
+		type==LONG_DATATYPE ||
+		type==TINY_BLOB_DATATYPE ||
+		type==MEDIUM_BLOB_DATATYPE ||
+		type==LONG_BLOB_DATATYPE ||
+		type==BLOB_DATATYPE ||
+		type==RAW_DATATYPE ||
+		type==LONG_RAW_DATATYPE ||
+		type==CLOB_DATATYPE ||
+		type==BFILE_DATATYPE ||
+		type==DBCLOB_DATATYPE ||
+		type==TINYTEXT_DATATYPE ||
+		type==MEDIUMTEXT_DATATYPE ||
+		type==LONGTEXT_DATATYPE ||
+		type==JSON_DATATYPE ||
+		type==GEOMETRY_DATATYPE ||
+		type==SDO_GEOMETRY_DATATYPE);
+}
+#endif
+
 #ifdef NEED_IS_UNSIGNED_TYPE_CHAR
 static bool isUnsignedTypeChar(const char *type) { 
 	return (!charstring::compareIgnoringCase(type,"USHORT") ||
-		!charstring::compareIgnoringCase(type,"UINT"));
+		!charstring::compareIgnoringCase(type,"UINT")||
+		!charstring::compareIgnoringCase(type,"YEAR") ||
+		!charstring::compareIgnoringCase(type,"TIMESTAMP"));
+}
+#endif
+
+#ifdef NEED_IS_UNSIGNED_TYPE_INT
+static bool isUnsignedTypeInt(int16_t type) { 
+	return (type==USHORT_DATATYPE ||
+		type==UINT_DATATYPE ||
+		type==YEAR_DATATYPE ||
+		type==TIMESTAMP_DATATYPE);
 }
 #endif
 
@@ -540,7 +714,39 @@ static bool isBinaryTypeChar(const char *type) {
 		!charstring::compareIgnoringCase(type,"OID") ||
 		!charstring::compareIgnoringCase(type,"_OID") ||
 		!charstring::compareIgnoringCase(type,"OIDVECTOR") ||
-		!charstring::compareIgnoringCase(type,"_BYTEA"));
+		!charstring::compareIgnoringCase(type,"_BYTEA") ||
+		!charstring::compareIgnoringCase(type,"TIMESTAMP") ||
+		!charstring::compareIgnoringCase(type,"DATE") ||
+		!charstring::compareIgnoringCase(type,"TIME") ||
+		!charstring::compareIgnoringCase(type,"DATETIME") ||
+		!charstring::compareIgnoringCase(type,"NEWDATE"));
+}
+#endif
+
+#ifdef NEED_IS_BINARY_TYPE_INT
+static bool isBinaryTypeInt(int16_t type) { 
+	return (type==IMAGE_DATATYPE ||
+		type==BINARY_DATATYPE ||
+		type==VARBINARY_DATATYPE ||
+		type==LONGBINARY_DATATYPE ||
+		type==TINY_BLOB_DATATYPE ||
+		type==MEDIUM_BLOB_DATATYPE ||
+		type==LONG_BLOB_DATATYPE ||
+		type==BLOB_DATATYPE ||
+		type==BFILE_DATATYPE ||
+		type==LONGVARBINARY_DATATYPE ||
+		type==GRAPHIC_DATATYPE ||
+		type==VARGRAPHIC_DATATYPE ||
+		type==LONGVARGRAPHIC_DATATYPE ||
+		type==OID_DATATYPE ||
+		type==_OID_DATATYPE ||
+		type==OIDVECTOR_DATATYPE ||
+		type==_BYTEA_DATATYPE ||
+		type==TIMESTAMP_DATATYPE ||
+		type==DATE_DATATYPE ||
+		type==TIME_DATATYPE ||
+		type==DATETIME_DATATYPE ||
+		type==NEWDATE_DATATYPE);
 }
 #endif
 
@@ -551,36 +757,8 @@ static bool isDateTimeTypeChar(const char *type) {
 		!charstring::compareIgnoringCase(type,"DATE") ||
 		!charstring::compareIgnoringCase(type,"TIME") ||
 		!charstring::compareIgnoringCase(type,"TIMESTAMP") ||
-		!charstring::compareIgnoringCase(type,"NEWDATE"));
-}
-#endif
-
-#ifdef NEED_IS_NUMBER_TYPE_INT
-static bool isNumberTypeInt(int16_t type) {
-	return (type==NUMBER_DATATYPE || type==INT_DATATYPE ||
-		type==SMALLINT_DATATYPE || type==TINYINT_DATATYPE ||
-		type==BIT_DATATYPE ||
-		type==REAL_DATATYPE || type==FLOAT_DATATYPE ||
-		type==USHORT_DATATYPE || type==DOUBLE_DATATYPE ||
-		type==UINT_DATATYPE || type==LASTREAL_DATATYPE ||
-		type==TINY_DATATYPE || type==SHORT_DATATYPE ||
-		type==LONGLONG_DATATYPE || type==MEDIUMINT_DATATYPE ||
-		type==YEAR_DATATYPE || type==BIGINT_DATATYPE ||
-		type==INTEGER_DATATYPE || type==D_FLOAT_DATATYPE || 
-		type==DECIMAL_DATATYPE || type==INT64_DATATYPE ||
-		type==MONEY_DATATYPE || type==SMALLMONEY_DATATYPE ||
-		type==DOUBLE_PRECISION_DATATYPE || type==INT8_DATATYPE ||
-		type==INT2_DATATYPE || type==INT4_DATATYPE ||
-		type==TID_DATATYPE ||
-		type==XID_DATATYPE || type==CID_DATATYPE ||
-		type==FLOAT4_DATATYPE || type==FLOAT8_DATATYPE ||
-		type==TINTERVAL_DATATYPE || type==_MONEY_DATATYPE ||
-		type==_INT2_DATATYPE || type==_INT4_DATATYPE ||
-		type==_TID_DATATYPE ||
-		type==_XID_DATATYPE || type==_CID_DATATYPE ||
-		type==_INT8_DATATYPE || type==_FLOAT4_DATATYPE ||
-		type==_FLOAT8_DATATYPE || type==_TINTERVAL_DATATYPE ||
-		type==INTERVAL_DATATYPE || type==_INTERVAL_DATATYPE);
+		!charstring::compareIgnoringCase(type,"NEWDATE") ||
+		!charstring::compareIgnoringCase(type,"DATETIMEOFFSET"));
 }
 #endif
 
