@@ -1,4 +1,4 @@
-// Copyright (c) 1999-2015  David Muse
+// Copyright (c) 1999-2018 David Muse
 // See the file COPYING for more information
 
 #include <sqlrelay/sqlrserver.h>
@@ -8,11 +8,12 @@
 #include <defines.h>
 #include <config.h>
 
-#include <sqlcli1.h>
+#ifdef DB2_AT_RUNTIME
+	#include "db2atruntime.cpp"
+#else
+	#include <sqlcli1.h>
+#endif
 
-#define FETCH_AT_ONCE		10
-#define MAX_SELECT_LIST_SIZE	256
-#define MAX_ITEM_BUFFER_SIZE	32768	
 #define MAX_OUT_BIND_LOB_SIZE	2097152
 
 #define MAX_LOB_CHUNK_SIZE	2147483647
@@ -33,6 +34,8 @@ struct db2column {
 	uint16_t	zerofill;
 	uint16_t	binary;
 	uint16_t	autoincrement;
+	char		table[4096];
+	uint16_t	tablelength;
 };
 
 struct datebind {
@@ -55,9 +58,10 @@ class SQLRSERVER_DLLSPEC db2cursor : public sqlrservercursor {
 			db2cursor(sqlrserverconnection *conn, uint16_t id);
 			~db2cursor();
 	private:
-		void		allocateResultSetBuffers(
-						int32_t selectlistsize);
+		void		allocateResultSetBuffers(int32_t columncount);
 		void		deallocateResultSetBuffers();
+		bool		open();
+		bool		close();
 		bool		prepareQuery(const char *query,
 						uint32_t length);
 		void		encodeBlob(stringbuffer *buffer,
@@ -86,6 +90,7 @@ class SQLRSERVER_DLLSPEC db2cursor : public sqlrservercursor {
 						int16_t second,
 						int32_t microsecond,
 						const char *tz,
+						bool isnegative,
 						char *buffer,
 						uint16_t buffersize,
 						int16_t *isnull);
@@ -104,7 +109,7 @@ class SQLRSERVER_DLLSPEC db2cursor : public sqlrservercursor {
 		bool		outputBind(const char *variable, 
 						uint16_t variablesize,
 						char *value, 
-						uint16_t valuesize,
+						uint32_t valuesize,
 						int16_t *isnull);
 		bool		outputBind(const char *variable,
 						uint16_t variablesize,
@@ -126,6 +131,7 @@ class SQLRSERVER_DLLSPEC db2cursor : public sqlrservercursor {
 						int16_t *second,
 						int32_t *microsecond,
 						const char **tz,
+						bool *isnegative,
 						char *buffer,
 						uint16_t buffersize,
 						int16_t *isnull);
@@ -164,9 +170,11 @@ class SQLRSERVER_DLLSPEC db2cursor : public sqlrservercursor {
 		uint16_t	getColumnIsUnsigned(uint32_t i);
 		uint16_t	getColumnIsBinary(uint32_t i);
 		uint16_t	getColumnIsAutoIncrement(uint32_t i);
+		const char	*getColumnTable(uint32_t i);
+		uint16_t	getColumnTableLength(uint32_t i);
 		bool		noRowsToReturn();
-		bool		skipRow();
-		bool		fetchRow();
+		bool		skipRow(bool *error);
+		bool		fetchRow(bool *error);
 		void		getField(uint32_t col,
 					const char **fld,
 					uint64_t *fldlength,
@@ -187,7 +195,7 @@ class SQLRSERVER_DLLSPEC db2cursor : public sqlrservercursor {
 		SQLSMALLINT	ncols;
 		SQLINTEGER 	affectedrows;
 
-		int32_t		selectlistsize;
+		int32_t		columncount;
 		char		**field;
 		SQLINTEGER	**loblocator;
 		SQLINTEGER	**loblength;
@@ -202,6 +210,8 @@ class SQLRSERVER_DLLSPEC db2cursor : public sqlrservercursor {
 		datebind	**outdatebind;
 		char		**outlobbind;
 		SQLINTEGER 	*outlobbindlen;
+		int16_t		**outisnullptr;
+		SQLINTEGER	*outisnull;
 		SQLINTEGER	sqlnulldata;
 
 		uint64_t	rowgroupindex;
@@ -209,6 +219,8 @@ class SQLRSERVER_DLLSPEC db2cursor : public sqlrservercursor {
 		uint64_t	totalrows;
 		uint64_t	rownumber;
 
+		bool		bindformaterror;
+
 		stringbuffer	errormsg;
 
 		db2connection	*db2conn;
@@ -232,6 +244,7 @@ class SQLRSERVER_DLLSPEC db2connection : public sqlrserverconnection {
 		bool	autoCommitOn();
 		bool	autoCommitOff();
 		bool	supportsTransactionBlocks();
+		bool	supportsAutoCommit();
 		bool	commit();
 		bool	rollback();
 		void	errorMessage(char *errorbuffer,
@@ -247,28 +260,27 @@ class SQLRSERVER_DLLSPEC db2connection : public sqlrserverconnection {
 		const char	*dbVersion();
 		const char	*dbHostNameQuery();
 		const char	*getDatabaseListQuery(bool wild);
-		const char	*getTableListQuery(bool wild);
+		const char	*getTableListQuery(bool wild,
+						uint16_t objecttypes);
 		const char	*getColumnListQuery(
 					const char *table, bool wild);
 		const char	*selectDatabaseQuery();
 		const char	*getCurrentDatabaseQuery();
 		const char	*getLastInsertIdQuery();
 		const char	*setIsolationLevelQuery();
+		const char	*noopQuery();
 		const char	*bindFormat();
 
 		SQLHENV		env;
 		SQLRETURN	erg;
 		SQLHDBC		dbc;
 
+		const char	*db2path;
 		const char	*server;
 		const char	*lang;
-		uint32_t	timeout;
 
 		stringbuffer	errormessage;
 
-		uint32_t	fetchatonce;
-		int32_t		maxselectlistsize;
-		int32_t		maxitembuffersize;
 		int32_t		maxoutbindlobsize;
 
 		const char	*identity;
@@ -286,15 +298,16 @@ class SQLRSERVER_DLLSPEC db2connection : public sqlrserverconnection {
 db2connection::db2connection(sqlrservercontroller *cont) :
 					sqlrserverconnection(cont) {
 
-	fetchatonce=FETCH_AT_ONCE;
-	maxselectlistsize=MAX_SELECT_LIST_SIZE;
-	maxitembuffersize=MAX_ITEM_BUFFER_SIZE;
 	maxoutbindlobsize=MAX_OUT_BIND_LOB_SIZE;
 	identity=NULL;
 }
 
 void db2connection::handleConnectString() {
 
+	sqlrserverconnection::handleConnectString();
+
+	db2path=cont->getConnectStringValue("db2path");
+
 	// override legacy "server" parameter with modern "db" parameter
 	server=cont->getConnectStringValue("server");
 	const char	*tmp=cont->getConnectStringValue("db");
@@ -302,50 +315,15 @@ void db2connection::handleConnectString() {
 		server=tmp;
 	}
 
-	cont->setUser(cont->getConnectStringValue("user"));
-	cont->setPassword(cont->getConnectStringValue("password"));
-	const char	*autocom=cont->getConnectStringValue("autocommit");
-	cont->setAutoCommitBehavior((autocom &&
-		!charstring::compareIgnoringCase(autocom,"yes")));
+	identity=cont->getConnectStringValue("identity");
+
 	lang=cont->getConnectStringValue("lang");
-	cont->setFakeTransactionBlocksBehavior(
-		!charstring::compare(
-			cont->getConnectStringValue("faketransactionblocks"),
-			"yes"));
-	if (!charstring::compare(
-			cont->getConnectStringValue("fakebinds"),"yes")) {
-		cont->fakeInputBinds();
-	}
 
-	const char	*to=cont->getConnectStringValue("timeout");
-	if (!charstring::length(to)) {
-		// for back-compatibility
-		timeout=5;
-	} else {
-		timeout=charstring::toInteger(to);
-	}
-
-	fetchatonce=charstring::toUnsignedInteger(
-				cont->getConnectStringValue("fetchatonce"));
-	if (fetchatonce<1) {
-		fetchatonce=FETCH_AT_ONCE;
-	}
-	maxselectlistsize=charstring::toInteger(
-			cont->getConnectStringValue("maxselectlistsize"));
-	if (!maxselectlistsize || maxselectlistsize<-1) {
-		maxselectlistsize=MAX_SELECT_LIST_SIZE;
-	}
-	maxitembuffersize=charstring::toInteger(
-			cont->getConnectStringValue("maxitembuffersize"));
-	if (maxitembuffersize<1) {
-		maxitembuffersize=MAX_ITEM_BUFFER_SIZE;
-	}
 	maxoutbindlobsize=charstring::toInteger(
 			cont->getConnectStringValue("maxoutbindlobsize"));
 	if (maxoutbindlobsize<1) {
 		maxoutbindlobsize=MAX_OUT_BIND_LOB_SIZE;
 	}
-	identity=cont->getConnectStringValue("identity");
 }
 
 bool db2connection::mustDetachBeforeLogIn() {
@@ -364,6 +342,13 @@ bool db2connection::logIn(const char **error, const char **warning) {
 		return false;
 	}
 
+	#ifdef DB2_AT_RUNTIME
+	if (!loadLibraries(&errormessage,db2path)) {
+		*error=errormessage.getString();
+		return false;
+	}
+	#endif
+
 	// allocate environment handle
 	erg=SQLAllocHandle(SQL_HANDLE_ENV,SQL_NULL_HANDLE,&env);
 	if (erg!=SQL_SUCCESS && erg!=SQL_SUCCESS_WITH_INFO) {
@@ -382,16 +367,17 @@ bool db2connection::logIn(const char **error, const char **warning) {
 	}
 
 	// set the connect timeout
-	if (timeout) {
+	uint32_t	connecttimeout=cont->getConnectTimeout();
+	if (connecttimeout) {
 		erg=SQLSetConnectAttr(dbc,
 				#ifdef SQL_ATTR_LOGIN_TIMEOUT
 				SQL_ATTR_LOGIN_TIMEOUT,
 				#else
 				SQL_LOGIN_TIMEOUT,
 				#endif
-				(SQLPOINTER)timeout,0);
+				(SQLPOINTER)connecttimeout,0);
 		if (erg!=SQL_SUCCESS && erg!=SQL_SUCCESS_WITH_INFO) {
-			*error="Failed to set timeout";
+			*error="Failed to set connect timeout";
 			SQLFreeHandle(SQL_HANDLE_DBC,dbc);
 			SQLFreeHandle(SQL_HANDLE_ENV,env);
 			return false;
@@ -450,8 +436,12 @@ void db2connection::dbVersionSpecificTasks() {
 
 		gettablelistquery=
 			"select distinct "
-			"	tabname, "
-			"	NULL "
+			"	NULL as table_cat, "
+			"	tabschema as table_schem, "
+			"	tabname as table_name, "
+			"	'TABLE' as table_type, "
+			"	NULL as remarks, "
+			"	NULL as extra "
 			"from "
 			"	syscat.tables "
 			"where "
@@ -463,12 +453,17 @@ void db2connection::dbVersionSpecificTasks() {
 			"	and "
 			"	tabname like '%s' "
 			"order by "
+			"	tabschema, "
 			"	tabname";
 
 		gettablelistquerywild=
 			"select distinct "
-			"	tabname, "
-			"	NULL "
+			"	NULL as table_cat, "
+			"	tabschema as table_schem, "
+			"	tabname as table_name, "
+			"	'TABLE' as table_type, "
+			"	NULL as remarks, "
+			"	NULL as extra "
 			"from "
 			"	syscat.tables "
 			"where "
@@ -478,6 +473,7 @@ void db2connection::dbVersionSpecificTasks() {
 			"	and "
 			"	type in ('T','U','V','W') "
 			"order by "
+			"	tabschema, "
 			"	tabname";
 
 		dbhostnamequery=
@@ -489,8 +485,12 @@ void db2connection::dbVersionSpecificTasks() {
 
 		gettablelistquery=
 			"select distinct "
-			"	tabname, "
-			"	NULL "
+			"	NULL as table_cat, "
+			"	tabschema as table_schem, "
+			"	tabname as table_name, "
+			"	'TABLE' as table_type, "
+			"	NULL as remarks, "
+			"	NULL as extra "
 			"from "
 			"	syscat.tables "
 			"where "
@@ -502,12 +502,17 @@ void db2connection::dbVersionSpecificTasks() {
 			"	and "
 			"	tabname like '%s' "
 			"order by "
+			"	tabschema, "
 			"	tabname";
 
 		gettablelistquerywild=
 			"select distinct "
-			"	tabname, "
-			"	NULL "
+			"	NULL as table_cat, "
+			"	tabschema as table_schem, "
+			"	tabname as table_name, "
+			"	'TABLE' as table_type, "
+			"	NULL as remarks, "
+			"	NULL as extra "
 			"from "
 			"	syscat.tables "
 			"where "
@@ -517,6 +522,7 @@ void db2connection::dbVersionSpecificTasks() {
 			"	and "
 			"	type in ('T','U','V','W') "
 			"order by "
+			"	tabschema, "
 			"	tabname";
 
 		// there is no obvious way to get this prior to 8.0
@@ -569,6 +575,10 @@ bool db2connection::supportsTransactionBlocks() {
 	return false;
 }
 
+bool db2connection::supportsAutoCommit() {
+	return true;
+}
+
 bool db2connection::commit() {
 	return (SQLEndTran(SQL_HANDLE_ENV,env,SQL_COMMIT)==SQL_SUCCESS);
 }
@@ -665,7 +675,7 @@ const char *db2connection::getDatabaseListQuery(bool wild) {
 		"	syscat.schemata ";
 }
 
-const char *db2connection::getTableListQuery(bool wild) {
+const char *db2connection::getTableListQuery(bool wild, uint16_t objecttypes) {
 	return (wild)?gettablelistquery:gettablelistquerywild;
 }
 
@@ -730,23 +740,32 @@ const char *db2connection::setIsolationLevelQuery() {
         return "set current isolation %s";
 }
 
+const char *db2connection::noopQuery() {
+	return "begin end;";
+}
+
 db2cursor::db2cursor(sqlrserverconnection *conn, uint16_t id) :
 						sqlrservercursor(conn,id) {
 	db2conn=(db2connection *)conn;
 	stmt=0;
 	lobstmt=0;
-	maxbindcount=conn->cont->cfg->getMaxBindCount();
+	maxbindcount=conn->cont->getConfig()->getMaxBindCount();
 	blobbindsize=new SQLINTEGER[maxbindcount];
 	outdatebind=new datebind *[maxbindcount];
 	outlobbind=new char *[maxbindcount];
 	outlobbindlen=new SQLINTEGER[maxbindcount];
+	outisnullptr=new int16_t *[maxbindcount];
+	outisnull=new SQLINTEGER[maxbindcount];
 	for (uint16_t i=0; i<maxbindcount; i++) {
 		outdatebind[i]=NULL;
 		outlobbind[i]=NULL;
 		outlobbindlen[i]=0;
+		outisnullptr[i]=NULL;
+		outisnull[i]=0;
 	}
 	sqlnulldata=SQL_NULL_DATA;
-	allocateResultSetBuffers(db2conn->maxselectlistsize);
+	bindformaterror=false;
+	allocateResultSetBuffers(conn->cont->getMaxColumnCount());
 }
 
 db2cursor::~db2cursor() {
@@ -754,13 +773,15 @@ db2cursor::~db2cursor() {
 	delete[] outdatebind;
 	delete[] outlobbind;
 	delete[] outlobbindlen;
+	delete[] outisnullptr;
+	delete[] outisnull;
 	deallocateResultSetBuffers();
 }
 
-void db2cursor::allocateResultSetBuffers(int32_t selectlistsize) {
+void db2cursor::allocateResultSetBuffers(int32_t columncount) {
 
-	if (selectlistsize==-1) {
-		this->selectlistsize=0;
+	if (!columncount) {
+		this->columncount=0;
 		field=NULL;
 		loblocator=NULL;
 		loblength=NULL;
@@ -770,29 +791,30 @@ void db2cursor::allocateResultSetBuffers(int32_t selectlistsize) {
 		#endif
 		column=NULL;
 	} else {
-		this->selectlistsize=selectlistsize;
-		field=new char *[selectlistsize];
-		loblocator=new SQLINTEGER *[selectlistsize];
-		loblength=new SQLINTEGER *[selectlistsize];
-		indicator=new SQLINTEGER *[selectlistsize];
+		this->columncount=columncount;
+		field=new char *[columncount];
+		loblocator=new SQLINTEGER *[columncount];
+		loblength=new SQLINTEGER *[columncount];
+		indicator=new SQLINTEGER *[columncount];
+		uint32_t	fetchatonce=conn->cont->getFetchAtOnce();
+		uint32_t	maxfieldlength=conn->cont->getMaxFieldLength();
 		#if (DB2VERSION>7)
-		rowstat=new SQLUSMALLINT[db2conn->fetchatonce];
+		rowstat=new SQLUSMALLINT[fetchatonce];
 		#endif
-		column=new db2column[selectlistsize];
-		for (int32_t i=0; i<selectlistsize; i++) {
+		column=new db2column[columncount];
+		for (int32_t i=0; i<columncount; i++) {
 			column[i].name=new char[4096];
-			field[i]=new char[db2conn->fetchatonce*
-						db2conn->maxitembuffersize];
-			loblocator[i]=new SQLINTEGER[db2conn->fetchatonce];
-			loblength[i]=new SQLINTEGER[db2conn->fetchatonce];
-			indicator[i]=new SQLINTEGER[db2conn->fetchatonce];
+			field[i]=new char[fetchatonce*maxfieldlength];
+			loblocator[i]=new SQLINTEGER[fetchatonce];
+			loblength[i]=new SQLINTEGER[fetchatonce];
+			indicator[i]=new SQLINTEGER[fetchatonce];
 		}
 	}
 }
 
 void db2cursor::deallocateResultSetBuffers() {
-	if (selectlistsize) {
-		for (int32_t i=0; i<selectlistsize; i++) {
+	if (columncount) {
+		for (int32_t i=0; i<columncount; i++) {
 			delete[] column[i].name;
 			delete[] field[i];
 			delete[] loblocator[i];
@@ -807,53 +829,81 @@ void db2cursor::deallocateResultSetBuffers() {
 		#if (DB2VERSION>7)
 		delete[] rowstat;
 		#endif
-		selectlistsize=0;
+		columncount=0;
 	}
 }
 
-bool db2cursor::prepareQuery(const char *query, uint32_t length) {
+bool db2cursor::open() {
 
-	if (stmt) {
-		SQLFreeHandle(SQL_HANDLE_STMT,stmt);
-	}
-	if (lobstmt) {
-		SQLFreeHandle(SQL_HANDLE_STMT,lobstmt);
-		lobstmt=0;
+	if (!stmt) {
+
+		// allocate the cursor
+		erg=SQLAllocHandle(SQL_HANDLE_STMT,db2conn->dbc,&stmt);
+		if (erg!=SQL_SUCCESS && erg!=SQL_SUCCESS_WITH_INFO) {
+			return false;
+		}
+
+		// set the row array size
+		erg=SQLSetStmtAttr(stmt,SQL_ATTR_ROW_ARRAY_SIZE,
+				(SQLPOINTER)conn->cont->getFetchAtOnce(),0);
+		if (erg!=SQL_SUCCESS && erg!=SQL_SUCCESS_WITH_INFO) {
+			return false;
+		}
+
+		#if (DB2VERSION>7)
+		if (conn->cont->getMaxColumnCount()) {
+
+			// set the row status ptr
+			// (only do this here if we're not
+			// dynamically allocating row buffers)
+			erg=SQLSetStmtAttr(stmt,SQL_ATTR_ROW_STATUS_PTR,
+						(SQLPOINTER)rowstat,0);
+			if (erg!=SQL_SUCCESS && erg!=SQL_SUCCESS_WITH_INFO) {
+				return false;
+			}
+		}
+		#endif
 	}
 
-	// allocate the cursor
-	erg=SQLAllocHandle(SQL_HANDLE_STMT,db2conn->dbc,&stmt);
-	if (erg!=SQL_SUCCESS && erg!=SQL_SUCCESS_WITH_INFO) {
-		return false;
-	}
+	if (!lobstmt) {
 
-	// set the row array size
-	erg=SQLSetStmtAttr(stmt,SQL_ATTR_ROW_ARRAY_SIZE,
-				(SQLPOINTER)db2conn->fetchatonce,0);
-	if (erg!=SQL_SUCCESS && erg!=SQL_SUCCESS_WITH_INFO) {
-		return false;
-	}
-
-	#if (DB2VERSION>7)
-	if (db2conn->maxselectlistsize!=-1) {
-
-		// set the row status ptr
-		// (only do this here if we're not
-		// dynamically allocating row buffers)
-		erg=SQLSetStmtAttr(stmt,SQL_ATTR_ROW_STATUS_PTR,
-					(SQLPOINTER)rowstat,0);
+		// allocate a lob handle, in case we need it
+		erg=SQLAllocHandle(SQL_HANDLE_STMT,db2conn->dbc,&lobstmt);
 		if (erg!=SQL_SUCCESS && erg!=SQL_SUCCESS_WITH_INFO) {
 			return false;
 		}
 	}
-	#endif
+
+	return true;
+}
+
+bool db2cursor::close() {
+
+	if (stmt) {
+		// free stmt handle
+		SQLFreeHandle(SQL_HANDLE_STMT,stmt);
+		stmt=0;
+	}
+
+	if (lobstmt) {
+		// free lob handle
+		SQLFreeHandle(SQL_HANDLE_STMT,lobstmt);
+		lobstmt=0;
+	}
+
+	return true;
+}
+
+bool db2cursor::prepareQuery(const char *query, uint32_t length) {
+
+	bindformaterror=false;
+
+	// initialize column count
+	ncols=0;
 
 	// prepare the query
 	erg=SQLPrepare(stmt,(SQLCHAR *)query,length);
-	if (erg!=SQL_SUCCESS && erg!=SQL_SUCCESS_WITH_INFO) {
-		return false;
-	}
-	return true;
+	return (erg==SQL_SUCCESS || erg==SQL_SUCCESS_WITH_INFO);
 }
 
 void db2cursor::encodeBlob(stringbuffer *buffer,
@@ -878,11 +928,17 @@ bool db2cursor::inputBind(const char *variable,
 					uint32_t valuesize,
 					int16_t *isnull) {
 
+	uint16_t	pos=charstring::toInteger(variable+1);
+	if (!pos || pos>maxbindcount) {
+		bindformaterror=true;
+		return false;
+	}
+
 	if (*isnull==SQL_NULL_DATA) {
 		// the 4th parameter (ValueType) must by
 		// SQL_C_BINARY for this to work with blobs
 		erg=SQLBindParameter(stmt,
-				charstring::toInteger(variable+1),
+				pos,
 				SQL_PARAM_INPUT,
 				SQL_C_BINARY,
 				SQL_CHAR,
@@ -890,10 +946,10 @@ bool db2cursor::inputBind(const char *variable,
 				0,
 				(SQLPOINTER)value,
 				valuesize,
-				(SQLINTEGER *)&sqlnulldata);
+				&sqlnulldata);
 	} else {
 		erg=SQLBindParameter(stmt,
-				charstring::toInteger(variable+1),
+				pos,
 				SQL_PARAM_INPUT,
 				SQL_C_CHAR,
 				SQL_CHAR,
@@ -901,20 +957,23 @@ bool db2cursor::inputBind(const char *variable,
 				0,
 				(SQLPOINTER)value,
 				valuesize,
-				(SQLINTEGER *)NULL);
+				NULL);
 	}
-	if (erg!=SQL_SUCCESS && erg!=SQL_SUCCESS_WITH_INFO) {
-		return false;
-	}
-	return true;
+	return (erg==SQL_SUCCESS || erg==SQL_SUCCESS_WITH_INFO);
 }
 
 bool db2cursor::inputBind(const char *variable,
 					uint16_t variablesize,
 					int64_t *value) {
 
+	uint16_t	pos=charstring::toInteger(variable+1);
+	if (!pos || pos>maxbindcount) {
+		bindformaterror=true;
+		return false;
+	}
+
 	erg=SQLBindParameter(stmt,
-				charstring::toInteger(variable+1),
+				pos,
 				SQL_PARAM_INPUT,
 				SQL_C_LONG,
 				SQL_INTEGER,
@@ -922,11 +981,8 @@ bool db2cursor::inputBind(const char *variable,
 				0,
 				value,
 				sizeof(int64_t),
-				(SQLINTEGER *)NULL);
-	if (erg!=SQL_SUCCESS && erg!=SQL_SUCCESS_WITH_INFO) {
-		return false;
-	}
-	return true;
+				NULL);
+	return (erg==SQL_SUCCESS || erg==SQL_SUCCESS_WITH_INFO);
 }
 
 bool db2cursor::inputBind(const char *variable,
@@ -935,8 +991,14 @@ bool db2cursor::inputBind(const char *variable,
 					uint32_t precision,
 					uint32_t scale) {
 
+	uint16_t	pos=charstring::toInteger(variable+1);
+	if (!pos || pos>maxbindcount) {
+		bindformaterror=true;
+		return false;
+	}
+
 	erg=SQLBindParameter(stmt,
-				charstring::toInteger(variable+1),
+				pos,
 				SQL_PARAM_INPUT,
 				SQL_C_DOUBLE,
 				SQL_DOUBLE,
@@ -944,11 +1006,8 @@ bool db2cursor::inputBind(const char *variable,
 				scale,
 				value,
 				sizeof(double),
-				(SQLINTEGER *)NULL);
-	if (erg!=SQL_SUCCESS && erg!=SQL_SUCCESS_WITH_INFO) {
-		return false;
-	}
-	return true;
+				NULL);
+	return (erg==SQL_SUCCESS || erg==SQL_SUCCESS_WITH_INFO);
 }
 
 bool db2cursor::inputBind(const char *variable,
@@ -961,21 +1020,51 @@ bool db2cursor::inputBind(const char *variable,
 					int16_t second,
 					int32_t microsecond,
 					const char *tz,
+					bool isnegative,
 					char *buffer,
 					uint16_t buffersize,
 					int16_t *isnull) {
 
-	SQL_TIMESTAMP_STRUCT	*ts=(SQL_TIMESTAMP_STRUCT *)buffer;
-	ts->year=year;
-	ts->month=month;
-	ts->day=day;
-	ts->hour=hour;
-	ts->minute=minute;
-	ts->second=second;
-	ts->fraction=microsecond*1000;
+	uint16_t	pos=charstring::toInteger(variable+1);
+	if (!pos || pos>maxbindcount) {
+		bindformaterror=true;
+		return false;
+	}
 
-	erg=SQLBindParameter(stmt,
-				charstring::toInteger(variable+1),
+	bool	validdate=(year>=0 && month>=0 && day>=0);
+	bool	validtime=(hour>=0 && minute>=0 && second>=0 && microsecond>=0);
+
+	if (validdate && !validtime) {
+
+		SQL_DATE_STRUCT	*ts=(SQL_DATE_STRUCT *)buffer;
+		ts->year=year;
+		ts->month=month;
+		ts->day=day;
+
+		erg=SQLBindParameter(stmt,
+				pos,
+				SQL_PARAM_INPUT,
+				SQL_C_DATE,
+				SQL_DATE,
+				0,
+				0,
+				buffer,
+				0,
+				NULL);
+
+	} else {
+
+		SQL_TIMESTAMP_STRUCT	*ts=(SQL_TIMESTAMP_STRUCT *)buffer;
+		ts->year=year;
+		ts->month=month;
+		ts->day=day;
+		ts->hour=hour;
+		ts->minute=minute;
+		ts->second=second;
+		ts->fraction=microsecond*1000;
+
+		erg=SQLBindParameter(stmt,
+				pos,
 				SQL_PARAM_INPUT,
 				SQL_C_TIMESTAMP,
 				SQL_TIMESTAMP,
@@ -983,11 +1072,9 @@ bool db2cursor::inputBind(const char *variable,
 				0,
 				buffer,
 				0,
-				(SQLINTEGER *)NULL);
-	if (erg!=SQL_SUCCESS && erg!=SQL_SUCCESS_WITH_INFO) {
-		return false;
+				NULL);
 	}
-	return true;
+	return (erg==SQL_SUCCESS || erg==SQL_SUCCESS_WITH_INFO);
 }
 
 bool db2cursor::inputBindBlob(const char *variable,
@@ -996,9 +1083,15 @@ bool db2cursor::inputBindBlob(const char *variable,
 					uint32_t valuesize,
 					int16_t *isnull) {
 
-	blobbindsize[inbindcount]=valuesize;
+	uint16_t	pos=charstring::toInteger(variable+1);
+	if (!pos || pos>maxbindcount) {
+		bindformaterror=true;
+		return false;
+	}
+
+	blobbindsize[pos-1]=valuesize;
 	erg=SQLBindParameter(stmt,
-				charstring::toInteger(variable+1),
+				pos,
 				SQL_PARAM_INPUT,
 				SQL_C_BINARY,
 				SQL_BLOB,
@@ -1006,11 +1099,8 @@ bool db2cursor::inputBindBlob(const char *variable,
 				0,
 				(SQLPOINTER)value,
 				valuesize,
-				&(blobbindsize[inbindcount]));
-	if (erg!=SQL_SUCCESS && erg!=SQL_SUCCESS_WITH_INFO) {
-		return false;
-	}
-	return true;
+				&(blobbindsize[pos-1]));
+	return (erg==SQL_SUCCESS || erg==SQL_SUCCESS_WITH_INFO);
 }
 
 #if (DB2VERSION<=7)
@@ -1024,8 +1114,14 @@ bool db2cursor::inputBindClob(const char *variable,
 					uint32_t valuesize,
 					int16_t *isnull) {
 
+	uint16_t	pos=charstring::toInteger(variable+1);
+	if (!pos || pos>maxbindcount) {
+		bindformaterror=true;
+		return false;
+	}
+
 	erg=SQLBindParameter(stmt,
-				charstring::toInteger(variable+1),
+				pos,
 				SQL_PARAM_INPUT,
 				SQL_C_CHAR,
 				SQL_CLOB,
@@ -1033,24 +1129,28 @@ bool db2cursor::inputBindClob(const char *variable,
 				0,
 				(SQLPOINTER)value,
 				valuesize,
-				(SQLINTEGER *)NULL);
-	if (erg!=SQL_SUCCESS && erg!=SQL_SUCCESS_WITH_INFO) {
-		return false;
-	}
-	return true;
+				NULL);
+	return (erg==SQL_SUCCESS || erg==SQL_SUCCESS_WITH_INFO);
 }
 #endif
 
 bool db2cursor::outputBind(const char *variable, 
 					uint16_t variablesize,
 					char *value, 
-					uint16_t valuesize, 
+					uint32_t valuesize, 
 					int16_t *isnull) {
 
-	outdatebind[outbindcount]=NULL;
+	uint16_t	pos=charstring::toInteger(variable+1);
+	if (!pos || pos>maxbindcount) {
+		bindformaterror=true;
+		return false;
+	}
+
+	outdatebind[pos-1]=NULL;
+	outisnullptr[pos-1]=isnull;
 
 	erg=SQLBindParameter(stmt,
-				charstring::toInteger(variable+1),
+				pos,
 				SQL_PARAM_OUTPUT,
 				SQL_C_CHAR,
 				SQL_CHAR,
@@ -1058,11 +1158,9 @@ bool db2cursor::outputBind(const char *variable,
 				0,
 				value,
 				valuesize,
-				(SQLINTEGER *)isnull);
-	if (erg!=SQL_SUCCESS && erg!=SQL_SUCCESS_WITH_INFO) {
-		return false;
-	}
-	return true;
+				&(outisnull[pos-1])
+				);
+	return (erg==SQL_SUCCESS || erg==SQL_SUCCESS_WITH_INFO);
 }
 
 bool db2cursor::outputBind(const char *variable,
@@ -1070,12 +1168,19 @@ bool db2cursor::outputBind(const char *variable,
 					int64_t *value,
 					int16_t *isnull) {
 
-	outdatebind[outbindcount]=NULL;
+	uint16_t	pos=charstring::toInteger(variable+1);
+	if (!pos || pos>maxbindcount) {
+		bindformaterror=true;
+		return false;
+	}
+
+	outdatebind[pos-1]=NULL;
+	outisnullptr[pos-1]=isnull;
 
 	*value=0;
 
 	erg=SQLBindParameter(stmt,
-				charstring::toInteger(variable+1),
+				pos,
 				SQL_PARAM_OUTPUT,
 				SQL_C_LONG,
 				SQL_INTEGER,
@@ -1083,11 +1188,9 @@ bool db2cursor::outputBind(const char *variable,
 				0,
 				value,
 				sizeof(int64_t),
-				(SQLINTEGER *)isnull);
-	if (erg!=SQL_SUCCESS && erg!=SQL_SUCCESS_WITH_INFO) {
-		return false;
-	}
-	return true;
+				&(outisnull[pos-1])
+				);
+	return (erg==SQL_SUCCESS || erg==SQL_SUCCESS_WITH_INFO);
 }
 
 bool db2cursor::outputBind(const char *variable,
@@ -1097,12 +1200,19 @@ bool db2cursor::outputBind(const char *variable,
 					uint32_t *scale,
 					int16_t *isnull) {
 
-	outdatebind[outbindcount]=NULL;
+	uint16_t	pos=charstring::toInteger(variable+1);
+	if (!pos || pos>maxbindcount) {
+		bindformaterror=true;
+		return false;
+	}
+
+	outdatebind[pos-1]=NULL;
+	outisnullptr[pos-1]=isnull;
 
 	*value=0.0;
 
 	erg=SQLBindParameter(stmt,
-				charstring::toInteger(variable+1),
+				pos,
 				SQL_PARAM_OUTPUT,
 				SQL_C_DOUBLE,
 				SQL_DOUBLE,
@@ -1110,11 +1220,9 @@ bool db2cursor::outputBind(const char *variable,
 				0,
 				value,
 				sizeof(double),
-				(SQLINTEGER *)isnull);
-	if (erg!=SQL_SUCCESS && erg!=SQL_SUCCESS_WITH_INFO) {
-		return false;
-	}
-	return true;
+				&(outisnull[pos-1])
+				);
+	return (erg==SQL_SUCCESS || erg==SQL_SUCCESS_WITH_INFO);
 }
 
 bool db2cursor::outputBind(const char *variable,
@@ -1127,10 +1235,17 @@ bool db2cursor::outputBind(const char *variable,
 					int16_t *second,
 					int32_t *microsecond,
 					const char **tz,
+					bool *isnegative,
 					char *buffer,
 					uint16_t buffersize,
 					int16_t *isnull) {
 
+	uint16_t	pos=charstring::toInteger(variable+1);
+	if (!pos || pos>maxbindcount) {
+		bindformaterror=true;
+		return false;
+	}
+
 	datebind	*db=new datebind;
 	db->year=year;
 	db->month=month;
@@ -1140,11 +1255,13 @@ bool db2cursor::outputBind(const char *variable,
 	db->second=second;
 	db->microsecond=microsecond;
 	db->tz=tz;
+	*isnegative=false;
 	db->buffer=buffer;
-	outdatebind[outbindcount]=db;
+	outdatebind[pos-1]=db;
+	outisnullptr[pos-1]=isnull;
 
 	erg=SQLBindParameter(stmt,
-				charstring::toInteger(variable+1),
+				pos,
 				SQL_PARAM_OUTPUT,
 				SQL_C_TIMESTAMP,
 				SQL_TIMESTAMP,
@@ -1152,11 +1269,9 @@ bool db2cursor::outputBind(const char *variable,
 				0,
 				buffer,
 				0,
-				(SQLINTEGER *)isnull);
-	if (erg!=SQL_SUCCESS && erg!=SQL_SUCCESS_WITH_INFO) {
-		return false;
-	}
-	return true;
+				&(outisnull[pos-1])
+				);
+	return (erg==SQL_SUCCESS || erg==SQL_SUCCESS_WITH_INFO);
 }
 
 bool db2cursor::outputBindBlob(const char *variable, 
@@ -1164,12 +1279,18 @@ bool db2cursor::outputBindBlob(const char *variable,
 					uint16_t index,
 					int16_t *isnull) {
 
+	uint16_t	pos=charstring::toInteger(variable+1);
+	if (!pos || pos>maxbindcount) {
+		bindformaterror=true;
+		return false;
+	}
+
 	outlobbind[index]=new char[db2conn->maxoutbindlobsize];
 
 	// FIXME: Ideally we'd bind a lob locator like we are for columns,
 	// but I can't seem to get that working.
 	erg=SQLBindParameter(stmt,
-				charstring::toInteger(variable+1),
+				pos,
 				SQL_PARAM_OUTPUT,
 				SQL_C_BINARY,
 				SQL_BLOB,
@@ -1178,10 +1299,7 @@ bool db2cursor::outputBindBlob(const char *variable,
 				outlobbind[index],
 				db2conn->maxoutbindlobsize,
 				&outlobbindlen[index]);
-	if (erg!=SQL_SUCCESS && erg!=SQL_SUCCESS_WITH_INFO) {
-		return false;
-	}
-	return true;
+	return (erg==SQL_SUCCESS || erg==SQL_SUCCESS_WITH_INFO);
 }
 
 bool db2cursor::outputBindClob(const char *variable, 
@@ -1189,6 +1307,12 @@ bool db2cursor::outputBindClob(const char *variable,
 					uint16_t index,
 					int16_t *isnull) {
 
+	uint16_t	pos=charstring::toInteger(variable+1);
+	if (!pos || pos>maxbindcount) {
+		bindformaterror=true;
+		return false;
+	}
+
 	outlobbind[index]=new char[db2conn->maxoutbindlobsize];
 
 	// FIXME: Ideally we'd bind a lob locator like we are for columns,
@@ -1198,7 +1322,7 @@ bool db2cursor::outputBindClob(const char *variable,
 	// Some versions of DB2 don't have SQL_CLOB, but all have SQL_CHAR.
 	// SQL_CHAR works on versions > 7 but does not work on versions <= 7
 	erg=SQLBindParameter(stmt,
-				charstring::toInteger(variable+1),
+				pos,
 				SQL_PARAM_OUTPUT,
 				SQL_C_CHAR,
 				#if (DB2VERSION>7)
@@ -1211,10 +1335,7 @@ bool db2cursor::outputBindClob(const char *variable,
 				outlobbind[index],
 				db2conn->maxoutbindlobsize,
 				&outlobbindlen[index]);
-	if (erg!=SQL_SUCCESS && erg!=SQL_SUCCESS_WITH_INFO) {
-		return false;
-	}
-	return true;
+	return (erg==SQL_SUCCESS || erg==SQL_SUCCESS_WITH_INFO);
 }
 
 bool db2cursor::getLobOutputBindLength(uint16_t index, uint64_t *length) {
@@ -1243,8 +1364,7 @@ bool db2cursor::getLobOutputBindSegment(uint16_t index,
 
 bool db2cursor::executeQuery(const char *query, uint32_t length) {
 
-	// initialize counts
-	ncols=0;
+	// initialize row counts
 	rowgroupindex=0;
 	totalinrowgroup=0;
 	totalrows=0;
@@ -1266,7 +1386,7 @@ bool db2cursor::executeQuery(const char *query, uint32_t length) {
 	}
 
 	// allocate buffers and limit column count if necessary
-	if (db2conn->maxselectlistsize==-1) {
+	if (!conn->cont->getMaxColumnCount()) {
 
 		allocateResultSetBuffers(ncols);
 
@@ -1281,8 +1401,8 @@ bool db2cursor::executeQuery(const char *query, uint32_t length) {
 		}
 		#endif
 
-	} else if (ncols>db2conn->maxselectlistsize) {
-		ncols=db2conn->maxselectlistsize;
+	} else if ((uint32_t)ncols>conn->cont->getMaxColumnCount()) {
+		ncols=conn->cont->getMaxColumnCount();
 	}
 
 	// run through the columns
@@ -1358,21 +1478,38 @@ bool db2cursor::executeQuery(const char *query, uint32_t length) {
 			if (erg!=SQL_SUCCESS && erg!=SQL_SUCCESS_WITH_INFO) {
 				return false;
 			}
+
+			// table name
+			erg=SQLColAttribute(stmt,i+1,
+				SQL_COLUMN_TABLE_NAME,
+				column[i].table,4096,
+				(SQLSMALLINT *)&(column[i].tablelength),
+				NULL);
+			if (erg!=SQL_SUCCESS && erg!=SQL_SUCCESS_WITH_INFO) {
+				return false;
+			}
+			column[i].tablelength=
+				charstring::length(column[i].table);
 		}
 
 		// bind the column to a lob locator or buffer
-		if (column[i].type==SQL_CLOB) {
-			erg=SQLBindCol(stmt,i+1,SQL_C_CLOB_LOCATOR,
-					loblocator[i],0,
-					(SQLINTEGER *)indicator[i]);
-		} else if (column[i].type==SQL_BLOB) {
-			erg=SQLBindCol(stmt,i+1,SQL_C_BLOB_LOCATOR,
-					loblocator[i],0,
-					(SQLINTEGER *)indicator[i]);
-		} else {
-			erg=SQLBindCol(stmt,i+1,SQL_C_CHAR,
-					field[i],db2conn->maxitembuffersize,
-					(SQLINTEGER *)indicator[i]);
+		switch (column[i].type) {
+			case SQL_CLOB:
+				erg=SQLBindCol(stmt,i+1,SQL_C_CLOB_LOCATOR,
+						loblocator[i],0,
+						indicator[i]);
+				break;
+			case SQL_BLOB:
+				erg=SQLBindCol(stmt,i+1,SQL_C_BLOB_LOCATOR,
+						loblocator[i],0,
+						indicator[i]);
+				break;
+			default:
+				erg=SQLBindCol(stmt,i+1,SQL_C_CHAR,
+					field[i],
+					conn->cont->getMaxFieldLength(),
+					indicator[i]);
+				break;
 		}
 		if (erg!=SQL_SUCCESS && erg!=SQL_SUCCESS_WITH_INFO) {
 			return false;
@@ -1385,8 +1522,8 @@ bool db2cursor::executeQuery(const char *query, uint32_t length) {
 		return false;
 	}
 
-	// convert date output binds
-	for (uint16_t i=0; i<maxbindcount; i++) {
+	// convert date output binds and copy out isnulls
+	for (uint16_t i=0; i<getOutputBindCount(); i++) {
 		if (outdatebind[i]) {
 			datebind	*db=outdatebind[i];
 			SQL_TIMESTAMP_STRUCT	*ts=
@@ -1400,6 +1537,9 @@ bool db2cursor::executeQuery(const char *query, uint32_t length) {
 			*(db->microsecond)=ts->fraction/1000;
 			*(db->tz)=NULL;
 		}
+		if (outisnullptr[i]) {
+			*(outisnullptr[i])=outisnull[i];
+		}
 	}
 	
 	return true;
@@ -1410,6 +1550,19 @@ void db2cursor::errorMessage(char *errorbuffer,
 					uint32_t *errorlength,
 					int64_t *errorcode,
 					bool *liveconnection) {
+	if (bindformaterror) {
+		// handle bind format errors
+		*errorlength=charstring::length(
+				SQLR_ERROR_INVALIDBINDVARIABLEFORMAT_STRING);
+		charstring::safeCopy(errorbuffer,
+				errorbufferlength,
+				SQLR_ERROR_INVALIDBINDVARIABLEFORMAT_STRING,
+				*errorlength);
+		*errorcode=SQLR_ERROR_INVALIDBINDVARIABLEFORMAT;
+		*liveconnection=true;
+		return;
+	}
+
 	SQLCHAR		state[10];
 	SQLINTEGER	nativeerrnum;
 	SQLSMALLINT	errlength;
@@ -1538,22 +1691,32 @@ uint16_t db2cursor::getColumnIsAutoIncrement(uint32_t i) {
 	return column[i].autoincrement;
 }
 
+const char *db2cursor::getColumnTable(uint32_t i) {
+	return column[i].table;
+}
+
+uint16_t db2cursor::getColumnTableLength(uint32_t i) {
+	return column[i].tablelength;
+}
+
 bool db2cursor::noRowsToReturn() {
 	// if there are no columns, then there can't be any rows either
 	return (ncols)?false:true;
 }
 
-bool db2cursor::skipRow() {
-	if (fetchRow()) {
+bool db2cursor::skipRow(bool *error) {
+	if (fetchRow(error)) {
 		rowgroupindex++;
 		return true;
 	}
 	return false;
 }
 
-bool db2cursor::fetchRow() {
+bool db2cursor::fetchRow(bool *error) {
 
-	if (rowgroupindex==db2conn->fetchatonce) {
+	*error=false;
+
+	if (rowgroupindex==conn->cont->getFetchAtOnce()) {
 		rowgroupindex=0;
 	}
 	if (rowgroupindex>0 && rowgroupindex==totalinrowgroup) {
@@ -1566,6 +1729,10 @@ bool db2cursor::fetchRow() {
 		// rows, otherwise we're at the end of the result and there are
 		// no more rows to fetch.
 		SQLRETURN	result=SQLFetchScroll(stmt,SQL_FETCH_NEXT,0);
+		if (result==SQL_ERROR) {
+			*error=true;
+			return false;
+		}
 		if (result!=SQL_SUCCESS && result!=SQL_SUCCESS_WITH_INFO) {
 			// there are no more rows to be fetched
 			return false;
@@ -1577,7 +1744,7 @@ bool db2cursor::fetchRow() {
 		// SQL_ATTR_ROW_NUMBER to always be 1, running through
 		// the row status buffer appears to work though.
 		uint32_t	index=0;
-		while (index<db2conn->fetchatonce &&
+		while (index<conn->cont->getFetchAtOnce() &&
 			(rowstat[index]==SQL_ROW_SUCCESS ||
 			rowstat[index]==SQL_ROW_SUCCESS_WITH_INFO)) {
 			index++;
@@ -1619,7 +1786,7 @@ void db2cursor::getField(uint32_t col,
 	}
 
 	// handle normal datatypes
-	*fld=&field[col][rowgroupindex*db2conn->maxitembuffersize];
+	*fld=&field[col][rowgroupindex*conn->cont->getMaxFieldLength()];
 	*fldlength=indicator[col][rowgroupindex];
 }
 
@@ -1629,14 +1796,6 @@ void db2cursor::nextRow() {
 
 bool db2cursor::getLobFieldLength(uint32_t col, uint64_t *length) {
 
-	// create a new handle if necessary
-	if (!lobstmt) {
-		erg=SQLAllocHandle(SQL_HANDLE_STMT,db2conn->dbc,&lobstmt);
-		if (erg!=SQL_SUCCESS && erg!=SQL_SUCCESS_WITH_INFO) {
-			return false;
-		}
-	}
-
 	// get the length of the lob
 	SQLINTEGER	ind;
 	SQLSMALLINT	locatortype=(column[col].type==SQL_CLOB)?
@@ -1672,14 +1831,6 @@ bool db2cursor::getLobFieldSegment(uint32_t col,
 		return false;
 	}
 
-	// create a new handle if necessary
-	if (!lobstmt) {
-		erg=SQLAllocHandle(SQL_HANDLE_STMT,db2conn->dbc,&lobstmt);
-		if (erg!=SQL_SUCCESS && erg!=SQL_SUCCESS_WITH_INFO) {
-			return false;
-		}
-	}
-
 	// prevent attempts to read past the end
 	if (offset+charstoread>(uint64_t)loblength[col][rowgroupindex]) {
 		charstoread=charstoread-
@@ -1739,17 +1890,39 @@ bool db2cursor::getLobFieldSegment(uint32_t col,
 void db2cursor::closeResultSet() {
 	SQLCloseCursor(stmt);
 
-	for (uint16_t i=0; i<maxbindcount; i++) {
+	for (uint16_t i=0; i<getOutputBindCount(); i++) {
 		delete outdatebind[i];
 		outdatebind[i]=NULL;
 		delete outlobbind[i];
 		outlobbind[i]=NULL;
 		outlobbindlen[i]=0;
+		outisnullptr[i]=NULL;
+		outisnull[i]=0;
 	}
 
-	if (db2conn->maxselectlistsize==-1) {
+	if (!conn->cont->getMaxColumnCount()) {
 		deallocateResultSetBuffers();
 	}
+
+	// NOTE: this is a bit of a kludge.
+	//
+	// ncols is reset at the beginning of prepareQuery, and other methods,
+	// but, since we rely on it to decide whether there are rows to return,
+	// it really needs to be reset here.
+	//
+	// If sqlrservercontroller intercepts the query (eg. if it's a begin,
+	// commit, rollback, etc.) then prepareQuery() will never be called,
+	// and this won't be reset.  If it was > 0 from the previous query,
+	// then a begin (for example) will think that it has rows to return,
+	// and the subsequent SQLFetch will fail with a
+	// "function sequence error".  We can avoid that by setting ncols=0
+	// here, which will cause noRowsToReturn() to return false by default,
+	// and avoid the fetch.
+	//
+	// Arguably, other things should be reset here too (eg. various row
+	// counts) but this is the critical one for now, so we'll sort that
+	// out later.
+	ncols=0;
 }
 
 extern "C" {
