@@ -1,4 +1,4 @@
-// Copyright (c) 1999-2015  David Muse
+// Copyright (c) 1999-2018 David Muse
 // See the file COPYING for more information
 
 #include <sqlrelay/sqlrserver.h>
@@ -53,6 +53,7 @@ struct datebind {
         int16_t         *minute;
         int16_t         *second;
         const char      **tz;
+	bool		*isnegative;
 };
 
 class firebirdconnection;
@@ -63,8 +64,7 @@ class SQLRSERVER_DLLSPEC firebirdcursor : public sqlrservercursor {
 				firebirdcursor(sqlrserverconnection *conn,
 								uint16_t id);
 				~firebirdcursor();
-		void		allocateResultSetBuffers(int32_t selectlistsize,
-							int32_t itembuffersize);
+		void		allocateResultSetBuffers(int32_t columncount);
 		void		deallocateResultSetBuffers();
 		bool		prepareQuery(const char *query,
 						uint32_t length);
@@ -91,6 +91,7 @@ class SQLRSERVER_DLLSPEC firebirdcursor : public sqlrservercursor {
                                         	int16_t second,
                                         	int32_t microsecond,
                                         	const char *tz,
+						bool isnegative,
                                         	char *buffer,
                                         	uint16_t buffersize,
                                         	int16_t *isnull);
@@ -107,7 +108,7 @@ class SQLRSERVER_DLLSPEC firebirdcursor : public sqlrservercursor {
 		bool		outputBind(const char *variable, 
 						uint16_t variablesize,
 						char *value, 
-						uint16_t valuesize,
+						uint32_t valuesize,
 						short *isnull);
 		bool		outputBind(const char *variable,
 						uint16_t variablesize,
@@ -129,6 +130,7 @@ class SQLRSERVER_DLLSPEC firebirdcursor : public sqlrservercursor {
 						int16_t *second,
 						int32_t *microsecond,
 						const char **tz,
+						bool *isnegative,
 						char *buffer,
 						uint16_t buffersize,
 						int16_t *isnull);
@@ -168,8 +170,10 @@ class SQLRSERVER_DLLSPEC firebirdcursor : public sqlrservercursor {
 		uint32_t	getColumnLength(uint32_t col);
 		uint32_t	getColumnPrecision(uint32_t col);
 		uint32_t	getColumnScale(uint32_t col);
+		const char	*getColumnTable(uint32_t col);
+		uint16_t	getColumnTableLength(uint32_t col);
 		bool		noRowsToReturn();
-		bool		fetchRow();
+		bool		fetchRow(bool *error);
 		void		getField(uint32_t col,
 					const char **field,
 					uint64_t *fieldlength,
@@ -202,7 +206,6 @@ class SQLRSERVER_DLLSPEC firebirdcursor : public sqlrservercursor {
 		
 		XSQLDA	ISC_FAR	*outsqlda;
 		fieldstruct	*field;
-		stringbuffer	fieldbuffer;
 
 		ISC_LONG	querytype;
 
@@ -235,23 +238,27 @@ class SQLRSERVER_DLLSPEC firebirdconnection : public sqlrserverconnection {
 					uint32_t *errorlength,
 					int64_t	*errorcode,
 					bool *liveconnection);
+		bool		selectDatabase(const char *database);
+		char		*getCurrentDatabase();
 		const char	*identify();
 		const char	*dbVersion();
 		const char	*dbHostName();
 		const char	*getDatabaseListQuery(bool wild);
-		const char	*getTableListQuery(bool wild);
+		const char	*getTableListQuery(bool wild,
+						uint16_t objecttypes);
 		const char	*getGlobalTempTableListQuery();
 		const char	*getColumnListQuery(
 						const char *table, bool wild);
 		const char	*bindFormat();
 		const char	*getLastInsertIdQuery();
+		const char	*noopQuery();
 
 		char		dpb[256];
 		short		dpblength;
 		isc_db_handle	db;
 		isc_tr_handle	tr;
 
-		const char	*database;
+		char		*database;
 		char		*host;
 		unsigned short	dialect;
 
@@ -259,9 +266,6 @@ class SQLRSERVER_DLLSPEC firebirdconnection : public sqlrserverconnection {
 
 		bool		droptemptables;
 
-		int32_t		maxselectlistsize;
-		int32_t		maxitembuffersize;
-
 		const char	*identity;
 
 		char		*dbversion;
@@ -286,6 +290,7 @@ firebirdconnection::firebirdconnection(sqlrservercontroller *cont) :
 						sqlrserverconnection(cont) {
 	dbversion=NULL;
 	lastinsertidquery=NULL;
+	database=NULL;
 	host=NULL;
 	identity=NULL;
 }
@@ -293,25 +298,20 @@ firebirdconnection::firebirdconnection(sqlrservercontroller *cont) :
 firebirdconnection::~firebirdconnection() {
 	delete dbversion;
 	delete[] lastinsertidquery;
+	delete[] database;
 	delete[] host;
 }
 
 void firebirdconnection::handleConnectString() {
 
-	// override legacy "database" parameter with modern "db" parameter
-	database=cont->getConnectStringValue("database");
-	const char	*tmp=cont->getConnectStringValue("db");
-	if (!charstring::isNullOrEmpty(tmp)) {
-		database=tmp;
-	}
+	sqlrserverconnection::handleConnectString();
 
-	// parse the host name from the database
-	const char	*colon=charstring::findFirst(database,':');
-	if (colon) {
-		host=charstring::duplicate(database,colon-database);
-	} else {
-		host=sys::getHostName();
+	// override legacy "database" parameter with modern "db" parameter
+	const char	*dbtmp=cont->getConnectStringValue("db");
+	if (charstring::isNullOrEmpty(dbtmp)) {
+		dbtmp=cont->getConnectStringValue("database");
 	}
+	database=charstring::duplicate(dbtmp);
 
 	const char	*dialectstr=cont->getConnectStringValue("dialect");
 	if (dialectstr) {
@@ -325,21 +325,11 @@ void firebirdconnection::handleConnectString() {
 	} else {
 		dialect=3;
 	}
-	cont->setUser(cont->getConnectStringValue("user"));
-	cont->setPassword(cont->getConnectStringValue("password"));
-	const char	*autocom=cont->getConnectStringValue("autocommit");
-	cont->setAutoCommitBehavior((autocom &&
-		!charstring::compareIgnoringCase(autocom,"yes")));
 
 	charset=cont->getConnectStringValue("charset");
 
-	cont->setFakeTransactionBlocksBehavior(
-		!charstring::compare(
-			cont->getConnectStringValue("faketransactionblocks"),
-			"yes"));
-
-	droptemptables=!charstring::compare(
-			cont->getConnectStringValue("droptemptables"),"yes");
+	droptemptables=charstring::isYes(
+			cont->getConnectStringValue("droptemptables"));
 
 	cont->addGlobalTempTables(
 			cont->getConnectStringValue("globaltemptables"));
@@ -353,28 +343,23 @@ void firebirdconnection::handleConnectString() {
 		lastinsertidquery=liiquery.detachString();
 	}
 
-	if (!charstring::compare(
-			cont->getConnectStringValue("fakebinds"),"yes")) {
-		cont->fakeInputBinds();
-	}
-
-	maxselectlistsize=charstring::toInteger(
-			cont->getConnectStringValue("maxselectlistsize"));
-	if (!maxselectlistsize || maxselectlistsize<-1) {
-		maxselectlistsize=MAX_SELECT_LIST_SIZE;
-	}
-
-	maxitembuffersize=charstring::toInteger(
-			cont->getConnectStringValue("maxitembuffersize"));
-	if (maxitembuffersize<1) {
-		maxitembuffersize=MAX_ITEM_BUFFER_SIZE;
-	}
-
 	identity=cont->getConnectStringValue("identity");
+
+	// firebird doesn't support multi-row fetches
+	cont->setFetchAtOnce(1);
 }
 
 bool firebirdconnection::logIn(const char **err, const char **warning) {
 
+	// parse the host name from the database
+	const char	*colon=charstring::findFirst(database,':');
+	delete[] host;
+	if (colon) {
+		host=charstring::duplicate(database,colon-database);
+	} else {
+		host=sys::getHostName();
+	}
+
 	// initialize a parameter buffer
 	char	*dpbptr=dpb;
 
@@ -420,6 +405,20 @@ bool firebirdconnection::logIn(const char **err, const char **warning) {
 					const_cast<char *>(database),&db,
 					dpblength,dpb)) {
 		db=0L;
+
+		errormsg.clear();
+
+		char		msg[512];
+		ISC_STATUS	*errstatus=error;
+		bool		first=false;
+		while (isc_interprete(msg,&errstatus)) {
+			if (first) {
+				errormsg.append(": ");
+			}
+			errormsg.append(msg);
+			first=true;
+		}
+		*err=errormsg.getString();
 		return false;
 	}
 
@@ -520,6 +519,50 @@ bool firebirdconnection::ping() {
 	return !(status[0]==1 && status[1]);
 }
 
+bool firebirdconnection::selectDatabase(const char *database) {
+
+	// keep track of the original db and host
+	char	*originaldb=this->database;
+	char	*originalhost=this->host;
+
+	// reset the db/host
+	this->database=charstring::duplicate(database);
+	this->host=NULL;
+
+	cont->clearError();
+
+	// log out and log back in to the specified database
+	logOut();
+	const char	*error=NULL;
+	const char	*warning=NULL;
+	if (!logIn(&error,&warning)) {
+
+		// Set the error, but don't use the error that was returned
+		// from logIn() because it will be confusing.  So, we'll
+		// just return the generic SQL Relay error for these kinds of
+		// things.
+		cont->setError(SQLR_ERROR_DBNOTFOUND_STRING,
+				SQLR_ERROR_DBNOTFOUND,true);
+
+		// log back in to the original database, we'll assume that works
+		delete[] this->database;
+		this->database=originaldb;
+		this->host=originalhost;
+		logOut();
+		logIn(&error,&warning);
+		return false;
+	}
+
+	// clean up
+	delete[] originaldb;
+	delete[] originalhost;
+	return true;
+}
+
+char *firebirdconnection::getCurrentDatabase() {
+	return charstring::duplicate(database);
+}
+
 const char *firebirdconnection::identify() {
 	return (identity)?identity:"firebird";
 }
@@ -573,10 +616,16 @@ const char *firebirdconnection::getDatabaseListQuery(bool wild) {
 	return "select '',NULL from rdb$database";
 }
 
-const char *firebirdconnection::getTableListQuery(bool wild) {
+const char *firebirdconnection::getTableListQuery(bool wild,
+						uint16_t objecttypes) {
 	return (wild)?
 		"select "
-		"	rdb$relation_name, NULL "
+		"	NULL as table_cat, "
+		"	rdb$owner_name as table_schem, "
+		"	rdb$relation_name as table_name, "
+		"	'TABLE' as table_type, "
+		"	NULL as remarks, "
+		"	NULL as extra "
 		"from "
 		"	rdb$relations "
 		"where "
@@ -584,15 +633,22 @@ const char *firebirdconnection::getTableListQuery(bool wild) {
 		"	and "
 		"	rdb$relation_name like '%s' "
 		"order by "
+		"	rdb$owner_name, "
 		"	rdb$relation_name":
 
 		"select "
-		"	rdb$relation_name, NULL "
+		"	NULL as table_cat, "
+		"	rdb$owner_name as table_schem, "
+		"	rdb$relation_name as table_name, "
+		"	'TABLE' as table_type, "
+		"	NULL as remarks, "
+		"	NULL as extra "
 		"from "
 		"	rdb$relations "
 		"where "
 		"	rdb$system_flag=0 "
 		"order by "
+		"	rdb$owner_name, "
 		"	rdb$relation_name";
 }
 
@@ -697,15 +753,19 @@ const char *firebirdconnection::getLastInsertIdQuery() {
 	return lastinsertidquery;
 }
 
+const char *firebirdconnection::noopQuery() {
+	return "execute block as begin end";
+}
+
 firebirdcursor::firebirdcursor(sqlrserverconnection *conn, uint16_t id) :
 						sqlrservercursor(conn,id) {
 
 	firebirdconn=(firebirdconnection *)conn;
 
-	allocateResultSetBuffers(firebirdconn->maxselectlistsize,
-					firebirdconn->maxitembuffersize);
+	outsqlda=NULL;
+	allocateResultSetBuffers(conn->cont->getMaxColumnCount());
 
-	maxbindcount=conn->cont->cfg->getMaxBindCount();
+	maxbindcount=conn->cont->getConfig()->getMaxBindCount();
 	outbindcount=0;
 
 	// set up input binds
@@ -728,16 +788,15 @@ firebirdcursor::firebirdcursor(sqlrserverconnection *conn, uint16_t id) :
 	outdatebind=new datebind[maxbindcount];
 
 	querytype=0;
-	stmt=NULL;
+	stmt=0;
 
 	queryisexecsp=false;
 	bindformaterror=false;
 
-	createtemp.compile("(create|CREATE)[ 	\\n\\r]+(global|GLOBAL)[ 	\\n\\r]+(temporary|TEMPORARY)[ 	\\n\\r]+(table|TABLE)[ 	\\n\\r]+");
-	createtemp.study();
-	preserverows.compile("(on|ON)[ 	\\n\\r]+(commit|COMMIT)[ 	\\n\\r]+(preserve|PRESERVE)[ 	\\n\\r]+(rows|ROWS)");
+	setCreateTempTablePattern("(create|CREATE)[ 	\n\r]+(global|GLOBAL)[ 	\n\r]+(temporary|TEMPORARY)[ 	\n\r]+(table|TABLE)[ 	\n\r]+");
+	preserverows.setPattern("(on|ON)[ 	\n\r]+(commit|COMMIT)[ 	\n\r]+(preserve|PRESERVE)[ 	\n\r]+(rows|ROWS)");
 	preserverows.study();
-	executeprocedure.compile("(execute|EXECUTE)[ 	\\n\\r]+(procedure|PROCEDURE)");
+	executeprocedure.setPattern("(execute|EXECUTE)[ 	\n\r]+(procedure|PROCEDURE)");
 	executeprocedure.study();
 }
 
@@ -755,10 +814,9 @@ firebirdcursor::~firebirdcursor() {
 	deallocateResultSetBuffers();
 }
 
-void firebirdcursor::allocateResultSetBuffers(int32_t selectlistsize,
-						int32_t itembuffersize) {
+void firebirdcursor::allocateResultSetBuffers(int32_t columncount) {
 
-	if (selectlistsize==-1) {
+	if (!columncount) {
 		outsqlda=(XSQLDA ISC_FAR *)new unsigned char[XSQLDA_LENGTH(1)];
 		outsqlda->version=SQLDA_VERSION1;
 		outsqlda->sqln=1;
@@ -768,12 +826,13 @@ void firebirdcursor::allocateResultSetBuffers(int32_t selectlistsize,
 			delete[] outsqlda;
 		}
 		outsqlda=(XSQLDA ISC_FAR *)new unsigned char[
-						XSQLDA_LENGTH(selectlistsize)];
+						XSQLDA_LENGTH(columncount)];
 		outsqlda->version=SQLDA_VERSION1;
-		outsqlda->sqln=selectlistsize;
-		field=new fieldstruct[selectlistsize];
-		for (int32_t i=0; i<selectlistsize; i++) {
-			field[i].textbuffer=new char[itembuffersize+1];
+		outsqlda->sqln=columncount;
+		field=new fieldstruct[columncount];
+		for (int32_t i=0; i<columncount; i++) {
+			field[i].textbuffer=new char[
+					conn->cont->getMaxFieldLength()+1];
 		}
 	}
 }
@@ -791,6 +850,9 @@ void firebirdcursor::deallocateResultSetBuffers() {
 
 bool firebirdcursor::prepareQuery(const char *query, uint32_t length) {
 
+	// initialize column count
+	outsqlda->sqld=0;
+
 	// are we executing a stored procedure
 	queryisexecsp=executeprocedure.match(query);
 
@@ -804,7 +866,7 @@ bool firebirdcursor::prepareQuery(const char *query, uint32_t length) {
 	}
 
 	// allocate a cursor handle
-	stmt=NULL;
+	stmt=0;
 	if (isc_dsql_allocate_statement(firebirdconn->error,
 					&firebirdconn->db,&stmt)) {
 		return false;
@@ -938,6 +1000,7 @@ bool firebirdcursor::inputBind(const char *variable,
 					int16_t second,
 					int32_t microsecond,
 					const char *tz,
+					bool isnegative,
 					char *buffer,
 					uint16_t buffersize,
 					int16_t *isnull) {
@@ -999,7 +1062,7 @@ bool firebirdcursor::inputBindBlob(const char *variable,
 	}
 
 	// write the value to the blob, MAX_LOB_CHUNK_SIZE bytes at a time
-	uint16_t	bytesput=0;
+	uint32_t	bytesput=0;
 	while (bytesput<valuesize) {
 		uint16_t	bytestoput=0;
 		if (valuesize-bytesput<MAX_LOB_CHUNK_SIZE) {
@@ -1050,7 +1113,7 @@ bool firebirdcursor::inputBindClob(const char *variable,
 bool firebirdcursor::outputBind(const char *variable, 
 				uint16_t variablesize,
 				char *value, 
-				uint16_t valuesize, 
+				uint32_t valuesize, 
 				int16_t *isnull) {
 
 	outbindcount++;
@@ -1150,6 +1213,7 @@ bool firebirdcursor::outputBind(const char *variable,
 				int16_t *second,
 				int32_t *microsecond,
 				const char **tz,
+				bool *isnegative,
 				char *buffer,
 				uint16_t buffersize,
 				int16_t *isnull) {
@@ -1162,6 +1226,7 @@ bool firebirdcursor::outputBind(const char *variable,
 	outdatebind[outbindcount].minute=minute;
 	outdatebind[outbindcount].second=second;
 	outdatebind[outbindcount].tz=tz;
+	outdatebind[outbindcount].isnegative=isnegative;
 
 	outbindcount++;
 
@@ -1231,7 +1296,7 @@ bool firebirdcursor::outputBindClob(const char *variable,
 bool firebirdcursor::getLobOutputBindLength(uint16_t index, uint64_t *length) {
 
 	// open the blob
-	outbindblobhandle[index]=NULL;
+	outbindblobhandle[index]=0;
 	if (isc_open_blob2(firebirdconn->error,
 				&firebirdconn->db,
 				&firebirdconn->tr,
@@ -1293,7 +1358,7 @@ bool firebirdcursor::getLobOutputBindSegment(uint16_t index,
 
 	// open the blob, if necessary
 	if (!outbindblobisopen[index]) {
-		outbindblobhandle[index]=NULL;
+		outbindblobhandle[index]=0;
 		if (isc_open_blob2(firebirdconn->error,
 					&firebirdconn->db,
 					&firebirdconn->tr,
@@ -1398,6 +1463,7 @@ bool firebirdcursor::executeQuery(const char *query, uint32_t length) {
 				*(outdatebind[i].minute)=t.tm_min;
 				*(outdatebind[i].second)=t.tm_sec;
 				*(outdatebind[i].tz)=NULL;
+				*(outdatebind[i].isnegative)=false;
 			}
 		}
 		return retval;
@@ -1405,24 +1471,25 @@ bool firebirdcursor::executeQuery(const char *query, uint32_t length) {
 
 	// handle non-stored procedures...
 
+	// get the max column count and field length
+	uint32_t	maxcolumncount=conn->cont->getMaxColumnCount();
+	uint32_t	maxfieldlength=conn->cont->getMaxFieldLength();
+
 	// check for create temp table query
 	if (querytype==isc_info_sql_stmt_ddl) {
 		checkForTempTable(query,length);
 	}
 
-	if (firebirdconn->maxselectlistsize==-1) {
-		allocateResultSetBuffers(outsqlda->sqld,
-					firebirdconn->maxitembuffersize);
+	if (!maxcolumncount) {
+		allocateResultSetBuffers(outsqlda->sqld);
 	}
 
 	// describe the cursor
-	outsqlda->sqld=0;
 	if (isc_dsql_describe(firebirdconn->error,&stmt,1,outsqlda)) {
 		return false;
 	}
-	if (firebirdconn->maxselectlistsize>-1 &&
-		outsqlda->sqld>firebirdconn->maxselectlistsize) {
-		outsqlda->sqld=firebirdconn->maxselectlistsize;
+	if (maxcolumncount && (uint32_t)outsqlda->sqld>maxcolumncount) {
+		outsqlda->sqld=maxcolumncount;
 	}
 
 	for (uint16_t i=0; i<outsqlda->sqld; i++) {
@@ -1438,20 +1505,17 @@ bool firebirdcursor::executeQuery(const char *query, uint32_t length) {
 				outsqlda->sqlvar[i].sqltype==SQL_TEXT+1) {
 			outsqlda->sqlvar[i].sqldata=field[i].textbuffer;
 			field[i].sqlrtype=CHAR_DATATYPE;
-			if (outsqlda->sqlvar[i].sqllen>
-				firebirdconn->maxitembuffersize) {
-				outsqlda->sqlvar[i].sqllen=
-					firebirdconn->maxitembuffersize;
+			if ((uint32_t)outsqlda->sqlvar[i].sqllen>
+							maxfieldlength) {
+				outsqlda->sqlvar[i].sqllen=maxfieldlength;
 			}
 		} else if (outsqlda->sqlvar[i].sqltype==SQL_VARYING ||
-				outsqlda->sqlvar[i].
-					sqltype==SQL_VARYING+1) {
+				outsqlda->sqlvar[i].sqltype==SQL_VARYING+1) {
 			outsqlda->sqlvar[i].sqldata=field[i].textbuffer;
 			field[i].sqlrtype=VARCHAR_DATATYPE;
-			if (outsqlda->sqlvar[i].sqllen>
-				firebirdconn->maxitembuffersize) {
-				outsqlda->sqlvar[i].sqllen=
-					firebirdconn->maxitembuffersize;
+			if ((uint32_t)outsqlda->sqlvar[i].sqllen>
+							maxfieldlength) {
+				outsqlda->sqlvar[i].sqllen=maxfieldlength;
 			}
 		} else if (outsqlda->sqlvar[i].sqltype==SQL_SHORT ||
 				outsqlda->sqlvar[i].sqltype==SQL_SHORT+1) {
@@ -1545,10 +1609,9 @@ bool firebirdcursor::executeQuery(const char *query, uint32_t length) {
 			outsqlda->sqlvar[i].sqltype=SQL_VARYING;
 			outsqlda->sqlvar[i].sqldata=field[i].textbuffer;
 			field[i].sqlrtype=UNKNOWN_DATATYPE;
-			if (outsqlda->sqlvar[i].sqllen>
-				firebirdconn->maxitembuffersize) {
-				outsqlda->sqlvar[i].sqllen=
-					firebirdconn->maxitembuffersize;
+			if ((uint32_t)outsqlda->sqlvar[i].sqllen>
+							maxfieldlength) {
+				outsqlda->sqlvar[i].sqllen=maxfieldlength;
 			}
 		}
 	}
@@ -1587,24 +1650,16 @@ void firebirdcursor::errorMessage(char *errorbuffer,
 
 void firebirdcursor::checkForTempTable(const char *query, uint32_t length) {
 
-	const char	*ptr=query;
-	const char	*endptr=query+length;
-
-	// skip any leading whitespace and comments
-	ptr=conn->cont->skipWhitespaceAndComments(query);
-	if (!(*ptr)) {
-		return;
-	}
-
-	// look for "create global temporary table "
-	if (createtemp.match(ptr)) {
-		ptr=createtemp.getSubstringEnd(0);
-	} else {
+	// see if the query matches the pattern for a temporary query that
+	// creates a temporary table
+	const char	*ptr=skipCreateTempTableClause(query);
+	if (!ptr) {
 		return;
 	}
 
 	// get the table name
 	stringbuffer	tablename;
+	const char	*endptr=query+length;
 	while (ptr && *ptr && *ptr!=' ' &&
 		*ptr!='\n' && *ptr!='	' && ptr<endptr) {
 		tablename.append(*ptr);
@@ -1714,30 +1769,40 @@ uint32_t firebirdcursor::getColumnScale(uint32_t col) {
 	return -outsqlda->sqlvar[col].sqlscale;
 }
 
+const char *firebirdcursor::getColumnTable(uint32_t col) {
+	return outsqlda->sqlvar[col].relname;
+}
+
+uint16_t firebirdcursor::getColumnTableLength(uint32_t col) {
+	return outsqlda->sqlvar[col].relname_length;
+}
+
 bool firebirdcursor::noRowsToReturn() {
 	// for exec procedure queries, outsqlda contains output bind values
 	// rather than a result set and there is no result set
 	return (queryisexecsp)?true:!outsqlda->sqld;
 }
 
-bool firebirdcursor::fetchRow() {
+bool firebirdcursor::fetchRow(bool *error) {
+
+	*error=false;
 
 	ISC_STATUS	retcode=isc_dsql_fetch(firebirdconn->error,
 							&stmt,1,outsqlda);
+
+	// success
+	if (!retcode) {
+		return true;
+	}
+
+	// no more rows
 	if (retcode==100) {
-		// no more rows
-		return false;
-	} else if (retcode==335544364) {
-		// Request synchronization error.  This usually occurs because
-		// maxitembuffer was too small and a field was truncated.  When
-		// it happens, the fetch fails, the cursor still points to the
-		// same row, and subsequent fetches will attempt to return the
-		// same row again.  There's no known way to recover and continue
-		// fetching rows, so we have to bail here.  Maybe a future
-		// version of firebird will have a fix for this.
 		return false;
 	}
-	return true;
+
+	// error
+	*error=true;
+	return false;
 }
 
 void firebirdcursor::getField(uint32_t col,
@@ -1747,14 +1812,15 @@ void firebirdcursor::getField(uint32_t col,
 	// handle a null field
 	if ((outsqlda->sqlvar[col].sqltype & 1) && 
 			field[col].nullindicator==-1) {
-		*null=true;
-		return;
-	}
 
+		*null=true;
+
+	} else
 
 	// handle a non-null field
 	if (outsqlda->sqlvar[col].sqltype==SQL_TEXT ||
 			outsqlda->sqlvar[col].sqltype==SQL_TEXT+1) {
+
 		size_t	maxlen=outsqlda->sqlvar[col].sqllen;
 		size_t	reallen=charstring::length(field[col].textbuffer);
 		if (reallen>maxlen) {
@@ -1762,19 +1828,27 @@ void firebirdcursor::getField(uint32_t col,
 		}
 		*fld=field[col].textbuffer;
 		*fldlength=reallen;
-		return;
+
 	} else if (outsqlda->sqlvar[col].
 				sqltype==SQL_SHORT ||
 			outsqlda->sqlvar[col].
 				sqltype==SQL_SHORT+1) {
-		fieldbuffer.clear();
-		fieldbuffer.append(field[col].shortbuffer);
+
+		*fldlength=charstring::printf(field[col].textbuffer,
+						conn->cont->getMaxFieldLength(),
+						"%hd",field[col].shortbuffer);
+		*fld=field[col].textbuffer;
+
 	} else if (outsqlda->sqlvar[col].
 				sqltype==SQL_FLOAT ||
 			outsqlda->sqlvar[col].
 				sqltype==SQL_FLOAT+1) {
-		fieldbuffer.clear();
-		fieldbuffer.append((double)field[col].floatbuffer);
+
+		*fldlength=charstring::printf(field[col].textbuffer,
+					conn->cont->getMaxFieldLength(),
+					"%.4f",(double)field[col].floatbuffer);
+		*fld=field[col].textbuffer;
+
 	} else if (outsqlda->sqlvar[col].
 				sqltype==SQL_DOUBLE ||
 			outsqlda->sqlvar[col].
@@ -1783,12 +1857,17 @@ void firebirdcursor::getField(uint32_t col,
 				sqltype==SQL_D_FLOAT ||
 			outsqlda->sqlvar[col].
 				sqltype==SQL_D_FLOAT+1) {
-		fieldbuffer.clear();
-		fieldbuffer.append((double)field[col].doublebuffer);
+
+		*fldlength=charstring::printf(field[col].textbuffer,
+					conn->cont->getMaxFieldLength(),
+					"%.4f",field[col].doublebuffer);
+		*fld=field[col].textbuffer;
+
 	} else if (outsqlda->sqlvar[col].
 				sqltype==SQL_VARYING ||
 			outsqlda->sqlvar[col].
 				sqltype==SQL_VARYING+1) {
+
 		// the first 2 bytes are the length in 
 		// an SQL_VARYING field
 		int16_t	size;
@@ -1797,7 +1876,6 @@ void firebirdcursor::getField(uint32_t col,
 				sizeof(int16_t));
 		*fld=field[col].textbuffer+sizeof(int16_t);
 		*fldlength=size;
-		return;
 
 	// Looks like sometimes firebird returns INT64's as
 	// SQL_LONG type.  These can be identified because
@@ -1808,8 +1886,12 @@ void firebirdcursor::getField(uint32_t col,
 			outsqlda->sqlvar[col].
 				sqltype==SQL_LONG+1) &&
 			!outsqlda->sqlvar[col].sqlscale) {
-		fieldbuffer.clear();
-		fieldbuffer.append((int32_t)field[col].longbuffer);
+
+		*fldlength=charstring::printf(field[col].textbuffer,
+					conn->cont->getMaxFieldLength(),
+					"%d",field[col].longbuffer);
+		*fld=field[col].textbuffer;
+
 	} else if (
 	#ifdef SQL_INT64
 			(outsqlda->sqlvar[col].
@@ -1822,39 +1904,39 @@ void firebirdcursor::getField(uint32_t col,
 			outsqlda->sqlvar[col].
 				sqltype==SQL_LONG+1) &&
 			outsqlda->sqlvar[col].sqlscale)) {
+
 		// int64's are weird.  To the left of the decimal
 		// point is the value/10^scale, to the right is
 		// value%10^scale
-		fieldbuffer.clear();
+		ISC_INT64	v=field[col].int64buffer;
 		if (outsqlda->sqlvar[col].sqlscale) {
-
-			fieldbuffer.append((int64_t)(field[col].int64buffer/(int)pow(10.0,(double)-outsqlda->sqlvar[col].sqlscale)))->append(".");
-
-			stringbuffer	decimal;
-			decimal.append((int64_t)(field[col].int64buffer%(int)pow(10.0,(double)-outsqlda->sqlvar[col].sqlscale)));
-		
-			// gotta get the right number
-			// of decimal places
-			for (int32_t i=charstring::length(
-					decimal.getString());
-				i<-outsqlda->sqlvar[col].sqlscale;
-				i++) {
-				decimal.append("0");
-			}
-			fieldbuffer.append(decimal.getString());
+			ISC_SHORT	scale=-outsqlda->sqlvar[col].sqlscale;
+			int		p=(int)pow(10.0,(double)scale);
+			*fldlength=charstring::printf(
+					field[col].textbuffer,
+					conn->cont->getMaxFieldLength(),
+					"%lld.%0*lld",
+					(int64_t)(v/p),scale,(int64_t)(v%p));
 		} else {
-			fieldbuffer.append((int64_t)field[col].int64buffer);
+			*fldlength=charstring::printf(
+					field[col].textbuffer,
+					conn->cont->getMaxFieldLength(),
+					"%lld",(int64_t)v);
 		}
+		*fld=field[col].textbuffer;
+
 	} else if (outsqlda->sqlvar[col].sqltype==SQL_ARRAY ||
 		outsqlda->sqlvar[col].sqltype==SQL_ARRAY+1 ||
 		outsqlda->sqlvar[col].sqltype==SQL_QUAD ||
 		outsqlda->sqlvar[col].sqltype==SQL_QUAD+1) {
+
 		// FIXME: handle arrays for real here...
 		*null=true;
-		return;
+
 	#ifdef SQL_TIMESTAMP
 	} else if (outsqlda->sqlvar[col].sqltype==SQL_TIMESTAMP ||
 		outsqlda->sqlvar[col].sqltype==SQL_TIMESTAMP+1) {
+
 		// decode the timestamp
 		tm	entry_timestamp;
 		isc_decode_timestamp(&field[col].timestampbuffer,
@@ -1868,9 +1950,10 @@ void firebirdcursor::getField(uint32_t col,
 		isc_decode_date(&field[col].timestampbuffer,
 						&entry_timestamp);
 	#endif
+
 		// build a string of "yyyy-mm-dd hh:mm:ss" format
-		char	buffer[20];
-		charstring::printf(buffer,20,
+		*fldlength=charstring::printf(field[col].textbuffer,
+					conn->cont->getMaxFieldLength(),
 					"%d-%02d-%02d %02d:%02d:%02d",
 					entry_timestamp.tm_year+1900,
 					entry_timestamp.tm_mon+1,
@@ -1878,49 +1961,46 @@ void firebirdcursor::getField(uint32_t col,
 					entry_timestamp.tm_hour,
 					entry_timestamp.tm_min,
 					entry_timestamp.tm_sec);
-		fieldbuffer.clear();
-		fieldbuffer.append(buffer);
+		*fld=field[col].textbuffer;
+
 	#ifdef SQL_TIMESTAMP
 	} else if (outsqlda->sqlvar[col].sqltype==SQL_TYPE_TIME ||
 		outsqlda->sqlvar[col].sqltype==SQL_TYPE_TIME+1) {
+
 		// decode the time
 		tm	entry_time;
 		isc_decode_sql_time(&field[col].timebuffer,
 						&entry_time);
 		// build a string of "hh:mm:ss" format
-		char	buffer[9];
-		charstring::printf(buffer,9,
+		*fldlength=charstring::printf(field[col].textbuffer,
+					conn->cont->getMaxFieldLength(),
 					"%02d:%02d:%02d",
 					entry_time.tm_hour,
 					entry_time.tm_min,
 					entry_time.tm_sec);
-		fieldbuffer.clear();
-		fieldbuffer.append(buffer);
+		*fld=field[col].textbuffer;
+
 	} else if (outsqlda->sqlvar[col].sqltype==SQL_TYPE_DATE ||
 		outsqlda->sqlvar[col].sqltype==SQL_TYPE_DATE+1) {
+
 		// decode the date
 		tm	entry_date;
 		isc_decode_sql_date(&field[col].datebuffer,
 						&entry_date);
 		// build a string of "yyyy-mm-dd" format
-		char	buffer[11];
-		charstring::printf(buffer,11,
+		*fldlength=charstring::printf(field[col].textbuffer,
+					conn->cont->getMaxFieldLength(),
 					"%d:%02d:%02d",
 					entry_date.tm_year+1900,
 					entry_date.tm_mon+1,
 					entry_date.tm_mday);
-		fieldbuffer.clear();
-		fieldbuffer.append(buffer);
+		*fld=field[col].textbuffer;
+
 	#endif
 	} else if (outsqlda->sqlvar[col].sqltype==SQL_BLOB ||
 			outsqlda->sqlvar[col].sqltype==SQL_BLOB+1) {
 		*blob=true;
-		return;
 	}
-
-	// for any case that didn't return already, we need to do this...
-	*fld=fieldbuffer.getString();
-	*fldlength=fieldbuffer.getStringLength();
 }
 
 bool firebirdcursor::getLobFieldLength(uint32_t col, uint64_t *length) {
@@ -1931,7 +2011,7 @@ bool firebirdcursor::getLobFieldLength(uint32_t col, uint64_t *length) {
 	}
 
 	// open the blob
-	field[col].blobhandle=NULL;
+	field[col].blobhandle=0;
 	if (isc_open_blob2(firebirdconn->error,
 				&firebirdconn->db,
 				&firebirdconn->tr,
@@ -1998,7 +2078,7 @@ bool firebirdcursor::getLobFieldSegment(uint32_t col,
 
 	// open the blob, if necessary
 	if (!field[col].blobisopen) {
-		field[col].blobhandle=NULL;
+		field[col].blobhandle=0;
 		if (isc_open_blob2(firebirdconn->error,
 					&firebirdconn->db,
 					&firebirdconn->tr,
@@ -2068,7 +2148,7 @@ void firebirdcursor::closeLobField(uint32_t col) {
 
 void firebirdcursor::closeResultSet() {
 	outbindcount=0;
-	if (firebirdconn->maxselectlistsize==-1) {
+	if (!conn->cont->getMaxColumnCount()) {
 		deallocateResultSetBuffers();
 	}
 }
