@@ -1,10 +1,11 @@
-// Copyright (c) 1999-2015  David Muse
+// Copyright (c) 1999-2018 David Muse
 // See the file COPYING for more information
 
 #include <sqlrelay/sqlrserver.h>
 #include <rudiments/environment.h>
 #include <rudiments/stringbuffer.h>
 #include <rudiments/charstring.h>
+#include <rudiments/character.h>
 #include <rudiments/bytestring.h>
 #include <rudiments/stdio.h>
 #include <rudiments/snooze.h>
@@ -57,12 +58,6 @@ extern	CS_INT	ct_dynamic(CS_COMMAND *,CS_INT,CS_CHAR *,CS_INT,CS_CHAR *,CS_INT);
 }
 #endif
 
-// this is here in case freetds ever supports array fetches
-//#define FETCH_AT_ONCE		10
-#define FETCH_AT_ONCE		1
-#define MAX_SELECT_LIST_SIZE	256
-#define MAX_ITEM_BUFFER_SIZE	32768
-
 // this is here in case freetds ever supports cursors
 //#define FREETDS_SUPPORTS_CURSORS
 
@@ -80,6 +75,7 @@ struct datebind {
         int16_t         *second;
         int32_t         *microsecond;
         const char      **tz;
+	bool		*isnegative;
 };
 
 class freetdsconnection;
@@ -90,8 +86,7 @@ class SQLRSERVER_DLLSPEC freetdscursor : public sqlrservercursor {
 				freetdscursor(sqlrserverconnection *conn,
 								uint16_t id);
 				~freetdscursor();
-		void		allocateResultSetBuffers(
-					int32_t selectlistsize);
+		void		allocateResultSetBuffers(int32_t columncount);
 		void		deallocateResultSetBuffers();
 		bool		open();
 		bool		close();
@@ -126,13 +121,14 @@ class SQLRSERVER_DLLSPEC freetdscursor : public sqlrservercursor {
 						int16_t second,
 						int32_t microsecond,
 						const char *tz,
+						bool isnegative,
 						char *buffer,
 						uint16_t buffersize,
 						int16_t *isnull);
 		bool		outputBind(const char *variable, 
 						uint16_t variablesize,
 						char *value, 
-						uint16_t valuesize, 
+						uint32_t valuesize, 
 						int16_t *isnull);
 		bool		outputBind(const char *variable,
 						uint16_t variablesize,
@@ -154,6 +150,7 @@ class SQLRSERVER_DLLSPEC freetdscursor : public sqlrservercursor {
 						int16_t *second,
 						int32_t *microsecond,
 						const char **tz,
+						bool *isnegative,
 						char *buffer,
 						uint16_t buffersize,
 						int16_t *isnull);
@@ -177,8 +174,8 @@ class SQLRSERVER_DLLSPEC freetdscursor : public sqlrservercursor {
 						const char *data,
 						uint32_t size);
 		bool		noRowsToReturn();
-		bool		skipRow();
-		bool		fetchRow();
+		bool		skipRow(bool *error);
+		bool		fetchRow(bool *error);
 		void		getField(uint32_t col,
 					const char **field,
 					uint64_t *fieldlength,
@@ -216,13 +213,14 @@ class SQLRSERVER_DLLSPEC freetdscursor : public sqlrservercursor {
 		uint16_t	paramindex;
 		CS_INT		*outbindtype;
 		char		**outbindstrings;
-		uint16_t	*outbindstringlengths;
+		uint32_t	*outbindstringlengths;
 		int64_t		**outbindints;
 		double		**outbinddoubles;
 		datebind	*outbinddates;
 		uint16_t	outbindindex;
 
-		int32_t		selectlistsize;
+		int32_t		columncount;
+		CS_DATAFMT	templatecolumn;
 		CS_DATAFMT	*column;
 		char		**data;
 		CS_INT		**datalength;
@@ -233,10 +231,6 @@ class SQLRSERVER_DLLSPEC freetdscursor : public sqlrservercursor {
 		bool		prepared;
 		bool		clean;
 
-		regularexpression	cursorquery;
-		regularexpression	rpcquery;
-		bool			isrpcquery;
-
 		freetdsconnection	*freetdsconn;
 };
 
@@ -257,15 +251,16 @@ class SQLRSERVER_DLLSPEC freetdsconnection : public sqlrserverconnection {
 		const char	*dbVersion();
 		const char	*dbHostNameQuery();
 		const char	*getDatabaseListQuery(bool wild);
-		const char	*getTableListQuery(bool wild);
+		const char	*getTableListQuery(bool wild,
+						uint16_t objecttypes);
 		const char	*getColumnListQuery(
 						const char *table, bool wild);
 		const char	*selectDatabaseQuery();
 		const char	*getCurrentDatabaseQuery();
 		const char	*getLastInsertIdQuery();
+		const char	*getNoopQuery();
 		const char	*bindFormat();
 		const char	*beginTransactionQuery();
-		char	bindVariablePrefix();
 		const char	*tempTableDropPrefix();
 		bool		commit();
 		bool		rollback();
@@ -280,6 +275,7 @@ class SQLRSERVER_DLLSPEC freetdsconnection : public sqlrserverconnection {
 		CS_CONNECTION	*dbconn;
 
 		const char	*sybase;
+		const char	*freetds;
 		const char	*lang;
 		const char	*server;
 		const char	*db;
@@ -288,10 +284,6 @@ class SQLRSERVER_DLLSPEC freetdsconnection : public sqlrserverconnection {
 		const char	*hostname;
 		const char	*packetsize;
 
-		int32_t		fetchatonce;
-		int32_t		maxselectlistsize;
-		int32_t		maxitembuffersize;
-
 		const char	*identity;
 
 		bool		dbused;
@@ -326,10 +318,6 @@ freetdsconnection::freetdsconnection(sqlrservercontroller *cont) :
 	dbversion=NULL;
 	sybasedb=true;
 
-	fetchatonce=FETCH_AT_ONCE;
-	maxselectlistsize=MAX_SELECT_LIST_SIZE;
-	maxitembuffersize=MAX_ITEM_BUFFER_SIZE;
-
 	identity=NULL;
 }
 
@@ -338,39 +326,26 @@ freetdsconnection::~freetdsconnection() {
 }
 
 void freetdsconnection::handleConnectString() {
+
+	sqlrserverconnection::handleConnectString();
+
 	sybase=cont->getConnectStringValue("sybase");
+	freetds=cont->getConnectStringValue("freetds");
 	lang=cont->getConnectStringValue("lang");
-	cont->setUser(cont->getConnectStringValue("user"));
-	cont->setPassword(cont->getConnectStringValue("password"));
 	server=cont->getConnectStringValue("server");
 	db=cont->getConnectStringValue("db");
 	charset=cont->getConnectStringValue("charset");
 	language=cont->getConnectStringValue("language");
 	hostname=cont->getConnectStringValue("hostname");
 	packetsize=cont->getConnectStringValue("packetsize");
-	if (!charstring::compare(
-			cont->getConnectStringValue("fakebinds"),"yes")) {
-		cont->fakeInputBinds();
-	}
-	// this is here in case freetds ever supports array fetches
-	/*fetchatonce=charstring::toInteger(
-				cont->getConnectStringValue("fetchatonce"));
-	if (fetchatonce<1) {
-		fetchatonce=FETCH_AT_ONCE;
-	}*/
-	maxselectlistsize=charstring::toInteger(
-			cont->getConnectStringValue("maxselectlistsize"));
-	if (!maxselectlistsize || maxselectlistsize<-1) {
-		maxselectlistsize=MAX_SELECT_LIST_SIZE;
-	} else if (maxselectlistsize==1) {
-		// if maxselectlistsize is set to 1 then force it
+
+	// freetds doesn't currently support array fetches
+	cont->setFetchAtOnce(1);
+
+	if (cont->getMaxColumnCount()==1) {
+		// if max column count is set to 1 then force it
 		// to 2 so the db version detection doesn't crash
-		maxselectlistsize=2;
-	}
-	maxitembuffersize=charstring::toInteger(
-			cont->getConnectStringValue("maxitembuffersize"));
-	if (maxitembuffersize<1) {
-		maxitembuffersize=MAX_ITEM_BUFFER_SIZE;
+		cont->setMaxColumnCount(2);
 	}
 
 	identity=cont->getConnectStringValue("identity");
@@ -386,6 +361,22 @@ bool freetdsconnection::logIn(const char **error, const char **warning) {
 		return false;
 	}
 
+	// set freetds
+	if (!charstring::isNullOrEmpty(freetds)) {
+		if (!environment::setValue("FREETDS",freetds)) {
+			*error=logInError(
+				"Failed to set FREETDS "
+				"environment variable.",1);
+			return false;
+		}
+		if (!environment::setValue("FREETDSCONF",freetds)) {
+			*error=logInError(
+				"Failed to set FREETDSCONF "
+				"environment variable.",1);
+			return false;
+		}
+	}
+
 	// set lang
 	if (!charstring::isNullOrEmpty(lang) &&
 			!environment::setValue("LANG",lang)) {
@@ -501,7 +492,7 @@ bool freetdsconnection::logIn(const char **error, const char **warning) {
 	if (ct_con_props(dbconn,CS_SET,CS_SEC_ENCRYPTION,
 			(CS_VOID *)&enc,CS_UNUSED,
 			(CS_INT *)NULL)!=CS_SUCCEED) {
-		*error=logInError("Failed to set the encryption",5);
+		*error=logInError("Failed to enable password encryption",5);
 		return false;
 	}
 	#endif
@@ -648,12 +639,17 @@ const char *freetdsconnection::getDatabaseListQuery(bool wild) {
 	}
 }
 
-const char *freetdsconnection::getTableListQuery(bool wild) {
+const char *freetdsconnection::getTableListQuery(bool wild,
+						uint16_t objecttypes) {
 	if (sybasedb) {
 		return (wild)?
 			"select "
-			"	name, "
-			"	NULL "
+			"	NULL as table_cat, "
+			"	NULL as table_schem, "
+			"	name as table_name, "
+			"	'TABLE' as table_type, "
+			"	NULL as remarks, "
+			"	NULL as extra "
 			"from "
 			"	sysobjects "
 			"where "
@@ -666,7 +662,10 @@ const char *freetdsconnection::getTableListQuery(bool wild) {
 			"	name":
 	
 			"select "
+			"	NULL, "
+			"	NULL, "
 			"	name, "
+			"	'TABLE', "
 			"	NULL "
 			"from "
 			"	sysobjects "
@@ -677,24 +676,8 @@ const char *freetdsconnection::getTableListQuery(bool wild) {
 			"order by "
 			"	name";
 	} else {
-		return (wild)?
-			"select "
-			"	table_name, "
-			"	NULL "
-			"from "
-			"	information_schema.tables "
-			"where "
-			"	table_name like '%s' "
-			"order by "
-			"	table_name":
-	
-			"select "
-			"	table_name, "
-			"	NULL "
-			"from "
-			"	information_schema.tables "
-			"order by "
-			"	table_name";
+		return sqlrserverconnection::getTableListQuery(
+						wild,objecttypes);
 	}
 }
 
@@ -856,6 +839,10 @@ const char *freetdsconnection::getLastInsertIdQuery() {
 	return "select @@identity";
 }
 
+const char *freetdsconnection::getNoopQuery() {
+	return "waitfor delay '0:0'";
+}
+
 const char *freetdsconnection::bindFormat() {
 	return "@*";
 }
@@ -864,10 +851,6 @@ const char *freetdsconnection::beginTransactionQuery() {
 	return "BEGIN TRANSACTION";
 }
 
-char freetdsconnection::bindVariablePrefix() {
-	return '@';
-}
-
 freetdscursor::freetdscursor(sqlrserverconnection *conn, uint16_t id) :
 						sqlrservercursor(conn,id) {
 
@@ -915,7 +898,7 @@ freetdscursor::freetdscursor(sqlrserverconnection *conn, uint16_t id) :
 
 	// Affected row count is generally supported in versions >= 0.53 but
 	// appears to be broken in 0.61.
-	knowsaffectedrows=(majorversion>=0 ||
+	knowsaffectedrows=(majorversion>0 ||
 				(minorversion>=53 && minorversion!=61));
 
 	prepared=false;
@@ -927,27 +910,34 @@ freetdscursor::freetdscursor(sqlrserverconnection *conn, uint16_t id) :
 	cursornamelength=charstring::integerLength(id);
 	cursorname=charstring::parseNumber(id);
 
-	uint16_t	maxbindcount=conn->cont->cfg->getMaxBindCount();
+	uint16_t	maxbindcount=conn->cont->getConfig()->getMaxBindCount();
 	parameter=new CS_DATAFMT[maxbindcount];
 	outbindtype=new CS_INT[maxbindcount];
 	outbindstrings=new char *[maxbindcount];
-	outbindstringlengths=new uint16_t[maxbindcount];
+	outbindstringlengths=new uint32_t[maxbindcount];
 	outbindints=new int64_t *[maxbindcount];
 	outbinddoubles=new double *[maxbindcount];
 	outbinddates=new datebind[maxbindcount];
 
 	// replace the regular expressions used to detect creation of a
 	// temporary table
-	createtemp.compile("(create|CREATE)[ 	\\r\\n]+(table|TABLE)[ 	\\r\\n]+#");
-	createtemp.study();
+	setCreateTempTablePattern("^(create|CREATE)[ 	\r\n]"
+					"+(table|TABLE)[ 	\r\n]+#");
 
-	cursorquery.compile("^(select|SELECT)[ 	\\r\\n]+");
-	cursorquery.study();
+	allocateResultSetBuffers(conn->cont->getMaxColumnCount());
 
-	rpcquery.compile("^(execute|EXECUTE|exec|EXEC)[ 	\\r\\n]+");
-	rpcquery.study();
-
-	allocateResultSetBuffers(freetdsconn->maxselectlistsize);
+	// define a template column-bind definition...
+	// get the field as a null terminated character string
+	// no longer than MAX_ITEM_BUFFER_SIZE, override some
+	templatecolumn.datatype=CS_CHAR_TYPE;
+	templatecolumn.format=CS_FMT_NULLTERM;
+	templatecolumn.maxlength=conn->cont->getMaxFieldLength();
+	templatecolumn.scale=CS_UNUSED;
+	templatecolumn.precision=CS_UNUSED;
+	templatecolumn.status=CS_UNUSED;
+	templatecolumn.count=conn->cont->getFetchAtOnce();
+	templatecolumn.usertype=CS_UNUSED;
+	templatecolumn.locale=NULL;
 }
 
 freetdscursor::~freetdscursor() {
@@ -964,35 +954,34 @@ freetdscursor::~freetdscursor() {
 	deallocateResultSetBuffers();
 }
 
-void freetdscursor::allocateResultSetBuffers(int32_t selectlistsize) {
+void freetdscursor::allocateResultSetBuffers(int32_t columncount) {
 
-	if (selectlistsize==-1) {
-		this->selectlistsize=0;
+	if (!columncount) {
+		this->columncount=0;
 		column=NULL;
 		data=NULL;
 		datalength=NULL;
 		nullindicator=NULL;
 	} else {
-		this->selectlistsize=selectlistsize;
-		column=new CS_DATAFMT[selectlistsize];
-		data=new char *[selectlistsize];
-		datalength=new CS_INT *[selectlistsize];
-		nullindicator=new CS_SMALLINT *[selectlistsize];
-		for (int32_t i=0; i<selectlistsize; i++) {
-			data[i]=new char[freetdsconn->fetchatonce*
-					freetdsconn->maxitembuffersize];
-			datalength[i]=
-				new CS_INT[freetdsconn->fetchatonce];
-			nullindicator[i]=
-				new CS_SMALLINT[freetdsconn->fetchatonce];
+		this->columncount=columncount;
+		column=new CS_DATAFMT[columncount];
+		data=new char *[columncount];
+		datalength=new CS_INT *[columncount];
+		nullindicator=new CS_SMALLINT *[columncount];
+		uint32_t	fetchatonce=conn->cont->getFetchAtOnce();
+		uint32_t	maxfieldlength=conn->cont->getMaxFieldLength();
+		for (int32_t i=0; i<columncount; i++) {
+			data[i]=new char[fetchatonce*maxfieldlength];
+			datalength[i]=new CS_INT[fetchatonce];
+			nullindicator[i]=new CS_SMALLINT[fetchatonce];
 		}
 	}
 }
 
 void freetdscursor::deallocateResultSetBuffers() {
-	if (selectlistsize) {
+	if (columncount) {
 		delete[] column;
-		for (int32_t i=0; i<selectlistsize; i++) {
+		for (int32_t i=0; i<columncount; i++) {
 			delete[] data[i];
 			delete[] datalength[i];
 			delete[] nullindicator[i];
@@ -1000,7 +989,7 @@ void freetdscursor::deallocateResultSetBuffers() {
 		delete[] data;
 		delete[] datalength;
 		delete[] nullindicator;
-		selectlistsize=0;
+		columncount=0;
 	}
 }
 
@@ -1055,10 +1044,11 @@ bool freetdscursor::open() {
 
 			const char	*q=query[i];
 			int32_t		len=charstring::length(q);
+			bool		error=false;
 
 			if (prepareQuery(q,len) &&
 					executeQuery(q,len) &&
-					fetchRow()) {
+					fetchRow(&error)) {
 				freetdsconn->dbversion=
 					charstring::duplicate(data[index[i]]);
 			}
@@ -1103,6 +1093,9 @@ bool freetdscursor::prepareQuery(const char *query, uint32_t length) {
 	// it here
 	closeResultSet();
 
+	// initialize column count
+	ncols=0;
+
 	clean=true;
 
 	this->query=(char *)query;
@@ -1111,33 +1104,53 @@ bool freetdscursor::prepareQuery(const char *query, uint32_t length) {
 	paramindex=0;
 	outbindindex=0;
 
-	isrpcquery=false;
-
-	if (cursorquery.match(query)) {
+	if ((!charstring::compare(query,"select",6) ||
+		!charstring::compare(query,"SELECT",6)) &&
+		character::isWhitespace(query[6])) {
 
 		// initiate a cursor command
 		cmd=cursorcmd;
 		#ifdef FREETDS_SUPPORTS_CURSORS
-		if (ct_cursor(cursorcmd,CS_CURSOR_DECLARE,
+		if (ct_cursor(cursorcmd,
+				CS_CURSOR_DECLARE,
 				(CS_CHAR *)cursorname,
 				(CS_INT)cursornamelength,
-				(CS_CHAR *)query,length,
+				(CS_CHAR *)query,
+				length,
 				//CS_READ_ONLY)!=CS_SUCCEED) {
 				CS_UNUSED)!=CS_SUCCEED) {
 			return false;
 		}
 		#endif
 
-	} else if (rpcquery.match(query)) {
+	} else if ((!charstring::compare(query,"exec",4) ||
+			!charstring::compare(query,"EXEC",4)) &&
+					character::isWhitespace(query[4])) {
 
 		// initiate an rpc command
-		isrpcquery=true;
 		cmd=languagecmd;
 		#ifdef FREETDS_SUPPORTS_CURSORS
-		if (ct_command(languagecmd,CS_RPC_CMD,
-			(CS_CHAR *)rpcquery.getSubstringEnd(0),
-			length-rpcquery.getSubstringEndOffset(0),
-			CS_UNUSED)!=CS_SUCCEED) {
+		if (ct_command(languagecmd,
+				CS_RPC_CMD,
+				(CS_CHAR *)query+5,
+				length-5,
+				CS_UNUSED)!=CS_SUCCEED) {
+			return false;
+		}
+		#endif
+
+	} else if ((!charstring::compare(query,"execute",7) ||
+			!charstring::compare(query,"EXECUTE",7)) &&
+					character::isWhitespace(query[7])) {
+
+		// initiate an rpc command
+		cmd=languagecmd;
+		#ifdef FREETDS_SUPPORTS_CURSORS
+		if (ct_command(languagecmd,
+				CS_RPC_CMD,
+				(CS_CHAR *)query+8,
+				length-8,
+				CS_UNUSED)!=CS_SUCCEED) {
 			return false;
 		}
 		#endif
@@ -1147,8 +1160,10 @@ bool freetdscursor::prepareQuery(const char *query, uint32_t length) {
 		// initiate a language command
 		cmd=languagecmd;
 		#ifdef FREETDS_SUPPORTS_CURSORS
-		if (ct_command(languagecmd,CS_LANG_CMD,
-				(CS_CHAR *)query,length,
+		if (ct_command(languagecmd,
+				CS_LANG_CMD,
+				(CS_CHAR *)query,
+				length,
 				CS_UNUSED)!=CS_SUCCEED) {
 			return false;
 		}
@@ -1295,6 +1310,7 @@ bool freetdscursor::inputBind(const char *variable,
 				int16_t second,
 				int32_t microsecond,
 				const char *tz,
+				bool isnegative,
 				char *buffer,
 				uint16_t buffersize,
 				int16_t *isnull) {
@@ -1338,7 +1354,7 @@ bool freetdscursor::inputBind(const char *variable,
 bool freetdscursor::outputBind(const char *variable, 
 				uint16_t variablesize,
 				char *value, 
-				uint16_t valuesize, 
+				uint32_t valuesize, 
 				int16_t *isnull) {
 
 	checkRePrepare();
@@ -1448,9 +1464,11 @@ bool freetdscursor::outputBind(const char *variable,
 				int16_t *second,
 				int32_t *microsecond,
 				const char **tz,
+				bool *isnegative,
 				char *buffer,
 				uint16_t buffersize,
 				int16_t *isnull) {
+
 	checkRePrepare();
 
 	outbindtype[outbindindex]=CS_DATETIME_TYPE;
@@ -1462,6 +1480,7 @@ bool freetdscursor::outputBind(const char *variable,
 	outbinddates[outbindindex].second=second;
 	outbinddates[outbindindex].microsecond=microsecond;
 	outbinddates[outbindindex].tz=tz;
+	outbinddates[outbindindex].isnegative=isnegative;
 	outbindindex++;
 
 	bytestring::zero(&parameter[paramindex],sizeof(parameter[paramindex]));
@@ -1494,7 +1513,6 @@ bool freetdscursor::executeQuery(const char *query, uint32_t length) {
 	results=CS_UNSUPPORTED;
 
 	// clear out any errors
-	freetdsconn->errorstring.clear();
 	freetdsconn->errorcode=0;
 	freetdsconn->liveconnection=true;
 
@@ -1505,8 +1523,7 @@ bool freetdscursor::executeQuery(const char *query, uint32_t length) {
 	}
 	clean=false;
 
-	// initialize return values
-	ncols=0;
+	// initialize row counts
 	affectedrows=0;
 	row=0;
 	maxrow=0;
@@ -1517,7 +1534,7 @@ bool freetdscursor::executeQuery(const char *query, uint32_t length) {
 		if (ct_cursor(cursorcmd,CS_CURSOR_ROWS,
 					NULL,CS_UNUSED,
 					NULL,CS_UNUSED,
-					(CS_INT)freetdsconn->fetchatonce)!=
+					(CS_INT)conn->cont->getFetchAtOnce())!=
 					CS_SUCCEED) {
 			return false;
 		}
@@ -1600,7 +1617,7 @@ bool freetdscursor::executeQuery(const char *query, uint32_t length) {
 		// the result set was a type that we want to ignore
 		if (ct_cancel(NULL,cmd,CS_CANCEL_CURRENT)==CS_FAIL) {
 			freetdsconn->liveconnection=false;
-			// FIXME: call ct_close(CS_FORCE_CLOSE)
+			// FIXME: call ct_close(CS_FORCE_CLOSE)?
 			return false;
 		}
 	}
@@ -1625,10 +1642,14 @@ bool freetdscursor::executeQuery(const char *query, uint32_t length) {
 		}
 
 		// allocate buffers and limit column count if necessary
-		if (freetdsconn->maxselectlistsize==-1) {
+		uint32_t	maxcolumncount=conn->cont->getMaxColumnCount();
+		if (!maxcolumncount) {
+			// see note in discardResults for
+			// why we're doing this here
+			deallocateResultSetBuffers();
 			allocateResultSetBuffers(ncols);
-		} else if (ncols>freetdsconn->maxselectlistsize) {
-			ncols=freetdsconn->maxselectlistsize;
+		} else if ((uint32_t)ncols>maxcolumncount) {
+			ncols=maxcolumncount;
 		}
 
 		// bind columns
@@ -1645,55 +1666,42 @@ bool freetdscursor::executeQuery(const char *query, uint32_t length) {
 					moneycolumn=true;
 					freetdsconn->errorstring.clear();
 					freetdsconn->errorstring.append(
-						"FreeTDS versions prior to ");
-					freetdsconn->errorstring.append( 
-						"0.53 do not support MONEY ");
-					freetdsconn->errorstring.append( 
-						"or SMALLMONEY datatypes. ");
-					freetdsconn->errorstring.append( 
-						"Please upgrade SQL Relay to ");
-					freetdsconn->errorstring.append( 
-						"a version compiled against ");
-					freetdsconn->errorstring.append( 
+						"FreeTDS versions prior to "
+						"0.53 do not support MONEY "
+						"or SMALLMONEY datatypes. "
+						"Please upgrade SQL Relay to "
+						"a version compiled against "
 						"FreeTDS >= 0.53 ");
 				}
 			}
 
-			// get the field as a null terminated character string
-			// no longer than MAX_ITEM_BUFFER_SIZE, override some
-			// other values that might have been set also...
-			//
-			// however, if we're getting the output bind variables
-			// of a stored procedure that returns dates, then use
-			// the datetime type instead...
+			// reset the column-bind
+			column[i]=templatecolumn;
+
+			// actually...
+			// if we're getting the output bind variables of a
+			// stored procedure that returns dates, then use the
+			// datetime type instead...
 			if (resultstype==CS_PARAM_RESULT &&
 				outbindtype[i]==CS_DATETIME_TYPE) {
 				column[i].datatype=CS_DATETIME_TYPE;
 				column[i].format=CS_FMT_UNUSED;
 				column[i].maxlength=sizeof(CS_DATETIME);
-			} else {
-				column[i].datatype=CS_CHAR_TYPE;
-				column[i].format=CS_FMT_NULLTERM;
-				column[i].maxlength=
-					freetdsconn->maxitembuffersize;
 			}
-			column[i].scale=CS_UNUSED;
-			column[i].precision=CS_UNUSED;
-			column[i].status=CS_UNUSED;
-			column[i].count=freetdsconn->fetchatonce;
-			column[i].usertype=CS_UNUSED;
-			column[i].locale=NULL;
 	
 			// bind the columns for the fetches
-			if (ct_bind(cmd,i+1,&column[i],(CS_VOID *)data[i],
-				datalength[i],nullindicator[i])!=CS_SUCCEED) {
+			if (ct_bind(cmd,i+1,
+					&column[i],
+					(CS_VOID *)data[i],
+					datalength[i],
+					nullindicator[i])!=CS_SUCCEED) {
 				break;
 			}
 
 			// describe the columns
 			if (conn->cont->getSendColumnInfo()==SEND_COLUMN_INFO) {
-				if (ct_describe(cmd,i+1,&column[i])!=
-								CS_SUCCEED) {
+				if (ct_describe(cmd,i+1,
+						&column[i])!=CS_SUCCEED) {
 					break;
 				}
 			}
@@ -1707,7 +1715,7 @@ bool freetdscursor::executeQuery(const char *query, uint32_t length) {
 	if (moneycolumn) {
 		if (ct_cancel(NULL,cmd,CS_CANCEL_CURRENT)==CS_FAIL) {
 			freetdsconn->liveconnection=false;
-			// FIXME: call ct_close(CS_FORCE_CLOSE)
+			// FIXME: call ct_close(CS_FORCE_CLOSE)?
 			return false;
 		}
 		return false;
@@ -1719,8 +1727,11 @@ bool freetdscursor::executeQuery(const char *query, uint32_t length) {
 	// bind variables...
 	if (resultstype==CS_PARAM_RESULT) {
 
-		if (ct_fetch(cmd,CS_UNUSED,CS_UNUSED,CS_UNUSED,
-				&rowsread)!=CS_SUCCEED && !rowsread) {
+		if (ct_fetch(cmd,
+				CS_UNUSED,
+				CS_UNUSED,
+				CS_UNUSED,
+				&rowsread)!=CS_SUCCEED || !rowsread) {
 			return false;
 		}
 		
@@ -1739,9 +1750,11 @@ bool freetdscursor::executeQuery(const char *query, uint32_t length) {
 				bytestring::copy(outbindstrings[i],
 						data[i],length);
 			} else if (outbindtype[i]==CS_INT_TYPE) {
-				*outbindints[i]=charstring::toInteger(data[i]);
+				*outbindints[i]=
+					charstring::toInteger(data[i]);
 			} else if (outbindtype[i]==CS_FLOAT_TYPE) {
-				*outbinddoubles[i]=charstring::toFloat(data[i]);
+				*outbinddoubles[i]=
+					charstring::toFloatC(data[i]);
 			} else if (outbindtype[i]==CS_DATETIME_TYPE) {
 
 				// convert to a CS_DATEREC
@@ -1759,6 +1772,7 @@ bool freetdscursor::executeQuery(const char *query, uint32_t length) {
 				*(db->second)=dr.datesecond;
 				*(db->microsecond)=dr.datemsecond;
 				*(db->tz)=NULL;
+				*(db->isnegative)=false;
 			}
 		}
 
@@ -1768,10 +1782,7 @@ bool freetdscursor::executeQuery(const char *query, uint32_t length) {
 	}
 
 	// return success only if no error was generated
-	if (freetdsconn->errorstring.getStringLength()) {
-		return false;
-	}
-	return true;
+	return (!freetdsconn->errorcode);
 }
 
 bool freetdscursor::knowsAffectedRows() {
@@ -1863,8 +1874,9 @@ uint16_t freetdscursor::getColumnType(uint32_t col) {
 
 uint32_t freetdscursor::getColumnLength(uint32_t col) {
 	// limit the column size
-	if (column[col].maxlength>freetdsconn->maxitembuffersize) {
-		column[col].maxlength=freetdsconn->maxitembuffersize;
+	uint32_t	maxfieldlength=conn->cont->getMaxFieldLength();
+	if ((uint32_t)column[col].maxlength>maxfieldlength) {
+		column[col].maxlength=maxfieldlength;
 	}
 	return column[col].maxlength;
 }
@@ -1953,16 +1965,20 @@ bool freetdscursor::noRowsToReturn() {
 			resultstype!=CS_COMPUTE_RESULT);
 }
 
-bool freetdscursor::skipRow() {
-	if (fetchRow()) {
+bool freetdscursor::skipRow(bool *error) {
+	if (fetchRow(error)) {
 		row++;
 		return true;
 	}
 	return false;
 }
 
-bool freetdscursor::fetchRow() {
-	if (row==freetdsconn->fetchatonce) {
+bool freetdscursor::fetchRow(bool *error) {
+
+	*error=false;
+	// FIXME: set error if an error occurs
+
+	if (row==(CS_INT)conn->cont->getFetchAtOnce()) {
 		row=0;
 	}
 	if (row>0 && row==maxrow) {
@@ -1970,7 +1986,9 @@ bool freetdscursor::fetchRow() {
 	}
 	if (!row) {
 		CS_RETCODE	fetchresult=ct_fetch(cmd,CS_UNUSED,
-						CS_UNUSED,CS_UNUSED,&rowsread);
+							CS_UNUSED,
+							CS_UNUSED,
+							&rowsread);
 
 		// This is essential with freetds.
 		// http://www.freetds.org/faq.html#pending
@@ -1995,6 +2013,9 @@ bool freetdscursor::fetchRow() {
 		}
 
 		if (fetchresult!=CS_SUCCEED || !rowsread) {
+			if (fetchresult==CS_FAIL || fetchresult==CS_ROW_FAIL) {
+				*error=true;
+			}
 			return false;
 		}
 		maxrow=rowsread;
@@ -2013,15 +2034,17 @@ void freetdscursor::getField(uint32_t col,
 		return;
 	}
 
+	uint32_t	maxfieldlength=conn->cont->getMaxFieldLength();
+
 	// Empty TEXT fields don't get properly converted
 	// to null-terminated strings.  Handle them.
 	if (column[col].datatype==CS_TEXT_TYPE && !datalength[col][row]) {
-		data[col][row*freetdsconn->maxitembuffersize]='\0';
+		data[col][row*maxfieldlength]='\0';
 		datalength[col][row]=1;
 	}
 
 	// handle normal datatypes
-	*field=&data[col][row*freetdsconn->maxitembuffersize];
+	*field=&data[col][row*maxfieldlength];
 	*fieldlength=datalength[col][row]-1;
 }
 
@@ -2048,8 +2071,7 @@ void freetdscursor::discardResults() {
 		do {
 			if (ct_cancel(NULL,cmd,CS_CANCEL_CURRENT)==CS_FAIL) {
 				freetdsconn->liveconnection=false;
-				// FIXME: call ct_close(CS_FORCE_CLOSE)
-				// maybe return false
+				// FIXME: call ct_close(CS_FORCE_CLOSE)?
 			}
 			results=ct_results(cmd,&resultstype);
 		} while (results==CS_SUCCEED);
@@ -2058,14 +2080,21 @@ void freetdscursor::discardResults() {
 	if (results==CS_FAIL) {
 		if (ct_cancel(NULL,cmd,CS_CANCEL_ALL)==CS_FAIL) {
 			freetdsconn->liveconnection=false;
-			// FIXME: call ct_close(CS_FORCE_CLOSE)
-			// maybe return false
+			// FIXME: call ct_close(CS_FORCE_CLOSE)?
 		}
 	}
 
-	if (freetdsconn->maxselectlistsize==-1) {
+	// Deallocating the result set buffers here causes a problem, but only
+	// in the freetds connection.
+	// When using freetds, we have to call discardResults() when we hit
+	// the end of the result set (see note in fetchRow()) but if we
+	// deallocate the result set buffers at that point, then subsequent
+	// attempts to fetch column info, will result in a reference-after-free.
+	// So, unlike the in the sybase/sap connection code we defer the
+	// deallocate until right before the next allocate, in prepareQuery().
+	/*if (!conn->cont->getMaxColumnCount()) {
 		deallocateResultSetBuffers();
-	}
+	}*/
 }
 
 
@@ -2073,8 +2102,10 @@ void freetdscursor::discardCursor() {
 
 	#ifdef FREETDS_SUPPORTS_CURSORS
 	if (cmd==cursorcmd) {
-		if (ct_cursor(cursorcmd,CS_CURSOR_CLOSE,NULL,CS_UNUSED,
-				NULL,CS_UNUSED,CS_DEALLOC)==CS_SUCCEED) {
+		if (ct_cursor(cursorcmd,CS_CURSOR_CLOSE,
+					NULL,CS_UNUSED,
+					NULL,CS_UNUSED,
+					CS_DEALLOC)==CS_SUCCEED) {
 			if (ct_send(cursorcmd)==CS_SUCCEED) {
 				results=ct_results(cmd,&resultstype);
 				discardResults();
@@ -2086,12 +2117,13 @@ void freetdscursor::discardCursor() {
 
 CS_RETCODE freetdsconnection::csMessageCallback(CS_CONTEXT *ctxt, 
 						CS_CLIENTMSG *msgp) {
-	if (errorstring.getStringLength()) {
+	if (errorcode) {
 		return CS_SUCCEED;
 	}
 
 	errorcode=msgp->msgnumber;
 
+	errorstring.clear();
 	errorstring.append("Client Library error: ")->append(msgp->msgstring);
 	errorstring.append(" severity(")->
 		append((int32_t)CS_SEVERITY(msgp->msgnumber))->append(")");
@@ -2132,12 +2164,13 @@ CS_RETCODE freetdsconnection::csMessageCallback(CS_CONTEXT *ctxt,
 CS_RETCODE freetdsconnection::clientMessageCallback(CS_CONTEXT *ctxt, 
 						CS_CONNECTION *cnn,
 						CS_CLIENTMSG *msgp) {
-	if (errorstring.getStringLength()) {
+	if (errorcode) {
 		return CS_SUCCEED;
 	}
 
 	errorcode=msgp->msgnumber;
 
+	errorstring.clear();
 	errorstring.append("Client Library error: ")->append(msgp->msgstring);
 	errorstring.append(" severity(")->
 		append((int32_t)CS_SEVERITY(msgp->msgnumber))->append(")");
@@ -2189,12 +2222,13 @@ CS_RETCODE freetdsconnection::serverMessageCallback(CS_CONTEXT *ctxt,
 		return CS_SUCCEED;
 	}
 
-	if (errorstring.getStringLength()) {
+	if (errorcode) {
 		return CS_SUCCEED;
 	}
 
 	errorcode=msgp->msgnumber;
 
+	errorstring.clear();
 	errorstring.append("Server message: ")->append(msgp->text);
 	errorstring.append(" severity(")->
 		append((int32_t)CS_SEVERITY(msgp->msgnumber))->append(")");
