@@ -1,4 +1,4 @@
-// Copyright (c) 1999-2015  David Muse
+// Copyright (c) 1999-2018 David Muse
 // See the file COPYING for more information
 
 #include <sqlrelay/sqlrserver.h>
@@ -8,14 +8,12 @@
 #include <defines.h>
 #include <config.h>
 
-#include <infxcli.h>
+#ifdef INFORMIX_AT_RUNTIME
+	#include "informixatruntime.cpp"
+#else
+	#include <infxcli.h>
+#endif
 
-// multi-row fetch doesn't work with clobs/blobs because you're already on a
-// different row when SQLGetData is called to get the data for the clob/blob
-// on the first row
-#define FETCH_AT_ONCE		1
-#define MAX_SELECT_LIST_SIZE	256
-#define MAX_ITEM_BUFFER_SIZE	32768	
 #define MAX_OUT_BIND_LOB_SIZE	2097152
 
 #define MAX_LOB_CHUNK_SIZE	2147483647
@@ -34,6 +32,8 @@ struct informixcolumn {
 	SQLLEN		zerofill;
 	SQLLEN		binary;
 	SQLLEN		autoincrement;
+	char		table[4096];
+	uint16_t	tablelength;
 };
 
 struct datebind {
@@ -56,9 +56,10 @@ class SQLRSERVER_DLLSPEC informixcursor : public sqlrservercursor {
 			informixcursor(sqlrserverconnection *conn, uint16_t id);
 			~informixcursor();
 	private:
-		void		allocateResultSetBuffers(
-						int32_t selectlistsize);
+		void		allocateResultSetBuffers(int32_t columncount);
 		void		deallocateResultSetBuffers();
+		bool		open();
+		bool		close();
 		bool		prepareQuery(const char *query,
 						uint32_t length);
 		bool		inputBind(const char *variable, 
@@ -84,6 +85,7 @@ class SQLRSERVER_DLLSPEC informixcursor : public sqlrservercursor {
 						int16_t second,
 						int32_t microsecond,
 						const char *tz,
+						bool isnegative,
 						char *buffer,
 						uint16_t buffersize,
 						int16_t *isnull);
@@ -100,7 +102,7 @@ class SQLRSERVER_DLLSPEC informixcursor : public sqlrservercursor {
 		bool		outputBind(const char *variable, 
 						uint16_t variablesize,
 						char *value, 
-						uint16_t valuesize,
+						uint32_t valuesize,
 						int16_t *isnull);
 		bool		outputBind(const char *variable,
 						uint16_t variablesize,
@@ -122,6 +124,7 @@ class SQLRSERVER_DLLSPEC informixcursor : public sqlrservercursor {
 						int16_t *second,
 						int32_t *microsecond,
 						const char **tz,
+						bool *isnegative,
 						char *buffer,
 						uint16_t buffersize,
 						int16_t *isnull);
@@ -160,9 +163,11 @@ class SQLRSERVER_DLLSPEC informixcursor : public sqlrservercursor {
 		uint16_t	getColumnIsUnsigned(uint32_t i);
 		uint16_t	getColumnIsBinary(uint32_t i);
 		uint16_t	getColumnIsAutoIncrement(uint32_t i);
+		const char	*getColumnTable(uint32_t i);
+		uint16_t	getColumnTableLength(uint32_t i);
 		bool		noRowsToReturn();
-		bool		skipRow();
-		bool		fetchRow();
+		bool		skipRow(bool *error);
+		bool		fetchRow(bool *error);
 		void		getField(uint32_t col,
 					const char **fld,
 					uint64_t *fldlength,
@@ -182,7 +187,7 @@ class SQLRSERVER_DLLSPEC informixcursor : public sqlrservercursor {
 		SQLSMALLINT	ncols;
 		SQLLEN 		affectedrows;
 
-		int32_t		selectlistsize;
+		int32_t		columncount;
 		char		**field;
 		SQLLEN		**loblength;
 		SQLLEN		**indicator;
@@ -193,6 +198,8 @@ class SQLRSERVER_DLLSPEC informixcursor : public sqlrservercursor {
 		datebind	**outdatebind;
 		char		**outlobbind;
 		SQLLEN 		*outlobbindlen;
+		int16_t		**outisnullptr;
+		SQLLEN		*outisnull;
 		SQLLEN		sqlnulldata;
 		BOOL		truevalue;
 
@@ -201,6 +208,10 @@ class SQLRSERVER_DLLSPEC informixcursor : public sqlrservercursor {
 		uint64_t	totalrows;
 		uint64_t	rownumber;
 
+		bool		noop;
+
+		bool		bindformaterror;
+
 		stringbuffer	errormsg;
 
 		informixconnection	*informixconn;
@@ -222,6 +233,7 @@ class SQLRSERVER_DLLSPEC informixconnection : public sqlrserverconnection {
 		bool	autoCommitOn();
 		bool	autoCommitOff();
 		bool	supportsTransactionBlocks();
+		bool	supportsAutoCommit();
 		bool	commit();
 		bool	rollback();
 		void	errorMessage(char *errorbuffer,
@@ -237,13 +249,15 @@ class SQLRSERVER_DLLSPEC informixconnection : public sqlrserverconnection {
 		const char	*dbVersion();
 		const char	*dbHostNameQuery();
 		const char	*getDatabaseListQuery(bool wild);
-		const char	*getTableListQuery(bool wild);
+		const char	*getTableListQuery(bool wild,
+						uint16_t objecttypes);
 		const char	*getColumnListQuery(
 					const char *table, bool wild);
 		const char	*selectDatabaseQuery();
 		const char	*getCurrentDatabaseQuery();
 		const char	*getLastInsertIdQuery();
 		const char	*setIsolationLevelQuery();
+		const char	*noopQuery();
 		const char	*bindFormat();
 
 		SQLHENV		env;
@@ -254,14 +268,10 @@ class SQLRSERVER_DLLSPEC informixconnection : public sqlrserverconnection {
 		const char	*servername;
 		const char	*db;
 		const char	*lang;
-		uint32_t	timeout;
 		stringbuffer	dsn;
 
 		stringbuffer	errormessage;
 
-		uint32_t	fetchatonce;
-		int32_t		maxselectlistsize;
-		int32_t		maxitembuffersize;
 		int32_t		maxoutbindlobsize;
 
 		const char	*identity;
@@ -274,15 +284,14 @@ class SQLRSERVER_DLLSPEC informixconnection : public sqlrserverconnection {
 informixconnection::informixconnection(sqlrservercontroller *cont) :
 					sqlrserverconnection(cont) {
 
-	fetchatonce=FETCH_AT_ONCE;
-	maxselectlistsize=MAX_SELECT_LIST_SIZE;
-	maxitembuffersize=MAX_ITEM_BUFFER_SIZE;
 	maxoutbindlobsize=MAX_OUT_BIND_LOB_SIZE;
 	identity=NULL;
 }
 
 void informixconnection::handleConnectString() {
 
+	sqlrserverconnection::handleConnectString();
+
 	// get informix dir
 	informixdir=cont->getConnectStringValue("informixdir");
 
@@ -292,8 +301,6 @@ void informixconnection::handleConnectString() {
 		servername=environment::getValue("INFORMIXSERVER");
 	}
 	db=cont->getConnectStringValue("db");
-	cont->setUser(cont->getConnectStringValue("user"));
-	cont->setPassword(cont->getConnectStringValue("password"));
 
 	// build dsn
 	dsn.clear();
@@ -322,40 +329,13 @@ void informixconnection::handleConnectString() {
 	}
 
 	// get other parameters
-	const char	*autocom=cont->getConnectStringValue("autocommit");
-	cont->setAutoCommitBehavior((autocom &&
-		!charstring::compareIgnoringCase(autocom,"yes")));
 	lang=cont->getConnectStringValue("lang");
-	cont->setFakeTransactionBlocksBehavior(
-		!charstring::compare(
-			cont->getConnectStringValue("faketransactionblocks"),
-			"yes"));
-	if (!charstring::compare(
-			cont->getConnectStringValue("fakebinds"),"yes")) {
-		cont->fakeInputBinds();
-	}
-
-	timeout=charstring::toInteger(cont->getConnectStringValue("timeout"));
 
 	// multi-row fetch doesn't work with clobs/blobs because you're already
 	// on a different row when SQLGetData is called to get the data for the
-	// clob/blob on the first row
-	/*fetchatonce=charstring::toUnsignedInteger(
-				cont->getConnectStringValue("fetchatonce"));
-	if (fetchatonce<1) {
-		fetchatonce=FETCH_AT_ONCE;
-	}*/
+	// clob/blob on the first row, so override it to 1
+	cont->setFetchAtOnce(1);
 
-	maxselectlistsize=charstring::toInteger(
-			cont->getConnectStringValue("maxselectlistsize"));
-	if (!maxselectlistsize || maxselectlistsize<-1) {
-		maxselectlistsize=MAX_SELECT_LIST_SIZE;
-	}
-	maxitembuffersize=charstring::toInteger(
-			cont->getConnectStringValue("maxitembuffersize"));
-	if (maxitembuffersize<1) {
-		maxitembuffersize=MAX_ITEM_BUFFER_SIZE;
-	}
 	maxoutbindlobsize=charstring::toInteger(
 			cont->getConnectStringValue("maxoutbindlobsize"));
 	if (maxoutbindlobsize<1) {
@@ -380,6 +360,13 @@ bool informixconnection::logIn(const char **error, const char **warning) {
 		return false;
 	}
 
+	#ifdef INFORMIX_AT_RUNTIME
+	if (!loadLibraries(&errormessage)) {
+		*error=errormessage.getString();
+		return NULL;
+	}
+	#endif
+
 	// allocate environment handle
 	erg=SQLAllocHandle(SQL_HANDLE_ENV,SQL_NULL_HANDLE,&env);
 	if (erg!=SQL_SUCCESS && erg!=SQL_SUCCESS_WITH_INFO) {
@@ -398,16 +385,17 @@ bool informixconnection::logIn(const char **error, const char **warning) {
 	}
 
 	// set the connect timeout
-	if (timeout) {
+	uint32_t	connecttimeout=cont->getConnectTimeout();
+	if (connecttimeout) {
 		erg=SQLSetConnectAttr(dbc,
 				#ifdef SQL_ATTR_LOGIN_TIMEOUT
 				SQL_ATTR_LOGIN_TIMEOUT,
 				#else
 				SQL_LOGIN_TIMEOUT,
 				#endif
-				(SQLPOINTER)timeout,0);
+				(SQLPOINTER)connecttimeout,0);
 		if (erg!=SQL_SUCCESS && erg!=SQL_SUCCESS_WITH_INFO) {
-			*error="Failed to set timeout";
+			*error="Failed to set connect timeout";
 			SQLFreeHandle(SQL_HANDLE_DBC,dbc);
 			SQLFreeHandle(SQL_HANDLE_ENV,env);
 			return false;
@@ -499,6 +487,10 @@ bool informixconnection::supportsTransactionBlocks() {
 	return false;
 }
 
+bool informixconnection::supportsAutoCommit() {
+	return true;
+}
+
 bool informixconnection::commit() {
 	return (SQLEndTran(SQL_HANDLE_ENV,env,SQL_COMMIT)==SQL_SUCCESS);
 }
@@ -571,10 +563,15 @@ const char *informixconnection::getDatabaseListQuery(bool wild) {
 		"	sysmaster:sysdatabases ";
 }
 
-const char *informixconnection::getTableListQuery(bool wild) {
+const char *informixconnection::getTableListQuery(bool wild,
+						uint16_t objecttypes) {
 	return (wild)?
 		"select distinct "
-		"	tabname, "
+		"	dbname as table_cat, "
+		"	owner as table_schem, "
+		"	tabname as table_name, "
+		"	'TABLE' as table_type, "
+		"	'' as remarks, "
 		"	'' as extra "
 		"from "
 		"	systables "
@@ -585,10 +582,16 @@ const char *informixconnection::getTableListQuery(bool wild) {
 		"	and "
 		"	tabtype in ('T','S','P','V') "
 		"order by "
+		"	dbname, "
+		"	owner, "
 		"	tabname":
 
 		"select distinct "
-		"	tabname, "
+		"	dbname as table_cat, "
+		"	owner as table_schem, "
+		"	tabname as table_name, "
+		"	'TABLE' as table_type, "
+		"	'' as remarks, "
 		"	'' as extra "
 		"from "
 		"	systables "
@@ -597,6 +600,8 @@ const char *informixconnection::getTableListQuery(bool wild) {
 		"	and "
 		"	tabtype in ('T','S','P','V') "
 		"order by "
+		"	dbname, "
+		"	owner, "
 		"	tabname";
 }
 
@@ -774,22 +779,31 @@ const char *informixconnection::setIsolationLevelQuery() {
         return "set isolation %s";
 }
 
+const char *informixconnection::noopQuery() {
+        return "noop";
+}
+
 informixcursor::informixcursor(sqlrserverconnection *conn, uint16_t id) :
 						sqlrservercursor(conn,id) {
 	informixconn=(informixconnection *)conn;
 	stmt=0;
-	maxbindcount=conn->cont->cfg->getMaxBindCount();
+	maxbindcount=conn->cont->getConfig()->getMaxBindCount();
 	lobbindsize=new SQLLEN[maxbindcount];
 	outdatebind=new datebind *[maxbindcount];
 	outlobbind=new char *[maxbindcount];
 	outlobbindlen=new SQLLEN[maxbindcount];
+	outisnullptr=new int16_t *[maxbindcount];
+	outisnull=new SQLLEN[maxbindcount];
 	for (uint16_t i=0; i<maxbindcount; i++) {
 		outdatebind[i]=NULL;
 		outlobbind[i]=NULL;
 		outlobbindlen[i]=0;
+		outisnullptr[i]=NULL;
+		outisnull[i]=0;
 	}
 	sqlnulldata=SQL_NULL_DATA;
-	allocateResultSetBuffers(informixconn->maxselectlistsize);
+	bindformaterror=false;
+	allocateResultSetBuffers(conn->cont->getMaxColumnCount());
 	truevalue=SQL_TRUE;
 }
 
@@ -798,36 +812,39 @@ informixcursor::~informixcursor() {
 	delete[] outdatebind;
 	delete[] outlobbind;
 	delete[] outlobbindlen;
+	delete[] outisnullptr;
+	delete[] outisnull;
 	deallocateResultSetBuffers();
 }
 
-void informixcursor::allocateResultSetBuffers(int32_t selectlistsize) {
+void informixcursor::allocateResultSetBuffers(int32_t columncount) {
 
-	if (selectlistsize==-1) {
-		this->selectlistsize=0;
+	if (!columncount) {
+		this->columncount=0;
 		field=NULL;
 		loblength=NULL;
 		indicator=NULL;
 		column=NULL;
 	} else {
-		this->selectlistsize=selectlistsize;
-		field=new char *[selectlistsize];
-		loblength=new SQLLEN *[selectlistsize];
-		indicator=new SQLLEN *[selectlistsize];
-		column=new informixcolumn[selectlistsize];
-		for (int32_t i=0; i<selectlistsize; i++) {
+		this->columncount=columncount;
+		field=new char *[columncount];
+		loblength=new SQLLEN *[columncount];
+		indicator=new SQLLEN *[columncount];
+		column=new informixcolumn[columncount];
+		uint32_t	fetchatonce=conn->cont->getFetchAtOnce();
+		int32_t		maxfieldlength=conn->cont->getMaxFieldLength();
+		for (int32_t i=0; i<columncount; i++) {
 			column[i].name=new char[4096];
-			field[i]=new char[informixconn->fetchatonce*
-					informixconn->maxitembuffersize];
-			loblength[i]=new SQLLEN[informixconn->fetchatonce];
-			indicator[i]=new SQLLEN[informixconn->fetchatonce];
+			field[i]=new char[fetchatonce*maxfieldlength];
+			loblength[i]=new SQLLEN[fetchatonce];
+			indicator[i]=new SQLLEN[fetchatonce];
 		}
 	}
 }
 
 void informixcursor::deallocateResultSetBuffers() {
-	if (selectlistsize) {
-		for (int32_t i=0; i<selectlistsize; i++) {
+	if (columncount) {
+		for (int32_t i=0; i<columncount; i++) {
 			delete[] column[i].name;
 			delete[] field[i];
 			delete[] loblength[i];
@@ -837,42 +854,68 @@ void informixcursor::deallocateResultSetBuffers() {
 		delete[] field;
 		delete[] loblength;
 		delete[] indicator;
-		selectlistsize=0;
+		columncount=0;
 	}
 }
 
+bool informixcursor::open() {
+
+	if (!stmt) {
+
+		// allocate the cursor
+		erg=SQLAllocHandle(SQL_HANDLE_STMT,informixconn->dbc,&stmt);
+		if (erg!=SQL_SUCCESS && erg!=SQL_SUCCESS_WITH_INFO) {
+			return false;
+		}
+
+		// set the row array size
+		erg=SQLSetStmtAttr(stmt,SQL_ATTR_ROW_ARRAY_SIZE,
+				(SQLPOINTER)conn->cont->getFetchAtOnce(),0);
+		if (erg!=SQL_SUCCESS && erg!=SQL_SUCCESS_WITH_INFO) {
+			return false;
+		}
+
+		// enable smart-large-object automation for non-selects
+		erg=SQLSetStmtAttr(stmt,SQL_INFX_ATTR_LO_AUTOMATIC,
+						(SQLPOINTER)truevalue,0);
+		if (erg!=SQL_SUCCESS && erg!=SQL_SUCCESS_WITH_INFO) {
+			return false;
+		}
+	}
+	return true;
+}
+
+bool informixcursor::close() {
+
+	if (stmt) {
+		SQLFreeHandle(SQL_HANDLE_STMT,stmt);
+		stmt=0;
+	}
+	return true;
+}
+
 bool informixcursor::prepareQuery(const char *query, uint32_t length) {
 
-	if (stmt) {
-		SQLFreeHandle(SQL_HANDLE_STMT,stmt);
-	}
+	bindformaterror=false;
 
-	// allocate the cursor
-	erg=SQLAllocHandle(SQL_HANDLE_STMT,informixconn->dbc,&stmt);
-	if (erg!=SQL_SUCCESS && erg!=SQL_SUCCESS_WITH_INFO) {
+	// FIXME: we shouldn't have to do this, but the tests crash in
+	// multiple locations if we don't...
+	if (!close() || !open()) {
 		return false;
 	}
 
-	// set the row array size
-	erg=SQLSetStmtAttr(stmt,SQL_ATTR_ROW_ARRAY_SIZE,
-				(SQLPOINTER)informixconn->fetchatonce,0);
-	if (erg!=SQL_SUCCESS && erg!=SQL_SUCCESS_WITH_INFO) {
-		return false;
-	}
+	// initialize column count
+	ncols=0;
 
-	// enable smart-large-object automation for non-selects
-	erg=SQLSetStmtAttr(stmt,SQL_INFX_ATTR_LO_AUTOMATIC,
-					(SQLPOINTER)truevalue,0);
-	if (erg!=SQL_SUCCESS && erg!=SQL_SUCCESS_WITH_INFO) {
-		return false;
+	// handle noops
+	noop=!charstring::compare(query,"noop");
+	if (noop) {
+		return true;
 	}
 
 	// prepare the query
 	erg=SQLPrepare(stmt,(SQLCHAR *)query,length);
-	if (erg!=SQL_SUCCESS && erg!=SQL_SUCCESS_WITH_INFO) {
-		return false;
-	}
-	return true;
+	return (erg==SQL_SUCCESS || erg==SQL_SUCCESS_WITH_INFO);
 }
 
 bool informixcursor::inputBind(const char *variable,
@@ -881,11 +924,17 @@ bool informixcursor::inputBind(const char *variable,
 					uint32_t valuesize,
 					int16_t *isnull) {
 
+	uint16_t	pos=charstring::toInteger(variable+1);
+	if (!pos || pos>maxbindcount) {
+		bindformaterror=true;
+		return false;
+	}
+
 	if (*isnull==SQL_NULL_DATA) {
 		// the 4th parameter (ValueType) must by
 		// SQL_C_BINARY for this to work with blobs
 		erg=SQLBindParameter(stmt,
-				charstring::toInteger(variable+1),
+				pos,
 				SQL_PARAM_INPUT,
 				SQL_C_BINARY,
 				SQL_CHAR,
@@ -896,7 +945,7 @@ bool informixcursor::inputBind(const char *variable,
 				&sqlnulldata);
 	} else {
 		erg=SQLBindParameter(stmt,
-				charstring::toInteger(variable+1),
+				pos,
 				SQL_PARAM_INPUT,
 				SQL_C_CHAR,
 				SQL_CHAR,
@@ -906,20 +955,23 @@ bool informixcursor::inputBind(const char *variable,
 				0,
 				(SQLPOINTER)value,
 				valuesize,
-				(SQLLEN *)NULL);
+				NULL);
 	}
-	if (erg!=SQL_SUCCESS && erg!=SQL_SUCCESS_WITH_INFO) {
-		return false;
-	}
-	return true;
+	return (erg==SQL_SUCCESS || erg==SQL_SUCCESS_WITH_INFO);
 }
 
 bool informixcursor::inputBind(const char *variable,
 					uint16_t variablesize,
 					int64_t *value) {
 
+	uint16_t	pos=charstring::toInteger(variable+1);
+	if (!pos || pos>maxbindcount) {
+		bindformaterror=true;
+		return false;
+	}
+
 	erg=SQLBindParameter(stmt,
-				charstring::toInteger(variable+1),
+				pos,
 				SQL_PARAM_INPUT,
 				SQL_C_LONG,
 				SQL_INTEGER,
@@ -927,11 +979,8 @@ bool informixcursor::inputBind(const char *variable,
 				0,
 				value,
 				sizeof(int64_t),
-				(SQLLEN *)NULL);
-	if (erg!=SQL_SUCCESS && erg!=SQL_SUCCESS_WITH_INFO) {
-		return false;
-	}
-	return true;
+				NULL);
+	return (erg==SQL_SUCCESS || erg==SQL_SUCCESS_WITH_INFO);
 }
 
 bool informixcursor::inputBind(const char *variable,
@@ -940,8 +989,14 @@ bool informixcursor::inputBind(const char *variable,
 					uint32_t precision,
 					uint32_t scale) {
 
+	uint16_t	pos=charstring::toInteger(variable+1);
+	if (!pos || pos>maxbindcount) {
+		bindformaterror=true;
+		return false;
+	}
+
 	erg=SQLBindParameter(stmt,
-				charstring::toInteger(variable+1),
+				pos,
 				SQL_PARAM_INPUT,
 				SQL_C_DOUBLE,
 				SQL_DOUBLE,
@@ -949,11 +1004,8 @@ bool informixcursor::inputBind(const char *variable,
 				scale,
 				value,
 				sizeof(double),
-				(SQLLEN *)NULL);
-	if (erg!=SQL_SUCCESS && erg!=SQL_SUCCESS_WITH_INFO) {
-		return false;
-	}
-	return true;
+				NULL);
+	return (erg==SQL_SUCCESS || erg==SQL_SUCCESS_WITH_INFO);
 }
 
 bool informixcursor::inputBind(const char *variable,
@@ -966,21 +1018,51 @@ bool informixcursor::inputBind(const char *variable,
 					int16_t second,
 					int32_t microsecond,
 					const char *tz,
+					bool isnegative,
 					char *buffer,
 					uint16_t buffersize,
 					int16_t *isnull) {
 
-	SQL_TIMESTAMP_STRUCT	*ts=(SQL_TIMESTAMP_STRUCT *)buffer;
-	ts->year=year;
-	ts->month=month;
-	ts->day=day;
-	ts->hour=hour;
-	ts->minute=minute;
-	ts->second=second;
-	ts->fraction=microsecond*1000;
+	uint16_t	pos=charstring::toInteger(variable+1);
+	if (!pos || pos>maxbindcount) {
+		bindformaterror=true;
+		return false;
+	}
 
-	erg=SQLBindParameter(stmt,
-				charstring::toInteger(variable+1),
+	bool	validdate=(year>=0 && month>=0 && day>=0);
+	bool	validtime=(hour>=0 && minute>=0 && second>=0 && microsecond>=0);
+
+	if (validdate && !validtime) {
+
+		SQL_DATE_STRUCT	*ts=(SQL_DATE_STRUCT *)buffer;
+		ts->year=year;
+		ts->month=month;
+		ts->day=day;
+
+		erg=SQLBindParameter(stmt,
+				pos,
+				SQL_PARAM_INPUT,
+				SQL_C_DATE,
+				SQL_DATE,
+				0,
+				0,
+				buffer,
+				0,
+				NULL);
+
+	} else {
+
+		SQL_TIMESTAMP_STRUCT	*ts=(SQL_TIMESTAMP_STRUCT *)buffer;
+		ts->year=year;
+		ts->month=month;
+		ts->day=day;
+		ts->hour=hour;
+		ts->minute=minute;
+		ts->second=second;
+		ts->fraction=microsecond*1000;
+
+		erg=SQLBindParameter(stmt,
+				pos,
 				SQL_PARAM_INPUT,
 				SQL_C_TIMESTAMP,
 				SQL_TIMESTAMP,
@@ -988,11 +1070,9 @@ bool informixcursor::inputBind(const char *variable,
 				0,
 				buffer,
 				0,
-				(SQLLEN *)NULL);
-	if (erg!=SQL_SUCCESS && erg!=SQL_SUCCESS_WITH_INFO) {
-		return false;
+				NULL);
 	}
-	return true;
+	return (erg==SQL_SUCCESS || erg==SQL_SUCCESS_WITH_INFO);
 }
 
 bool informixcursor::inputBindBlob(const char *variable,
@@ -1001,9 +1081,15 @@ bool informixcursor::inputBindBlob(const char *variable,
 					uint32_t valuesize,
 					int16_t *isnull) {
 
-	lobbindsize[inbindcount]=valuesize;
+	uint16_t	pos=charstring::toInteger(variable+1);
+	if (!pos || pos>maxbindcount) {
+		bindformaterror=true;
+		return false;
+	}
+
+	lobbindsize[pos-1]=valuesize;
 	erg=SQLBindParameter(stmt,
-				charstring::toInteger(variable+1),
+				pos,
 				SQL_PARAM_INPUT,
 				SQL_C_BINARY,
 				SQL_LONGVARBINARY,
@@ -1011,11 +1097,8 @@ bool informixcursor::inputBindBlob(const char *variable,
 				0,
 				(SQLPOINTER)value,
 				valuesize,
-				&(lobbindsize[inbindcount]));
-	if (erg!=SQL_SUCCESS && erg!=SQL_SUCCESS_WITH_INFO) {
-		return false;
-	}
-	return true;
+				&(lobbindsize[pos-1]));
+	return (erg==SQL_SUCCESS || erg==SQL_SUCCESS_WITH_INFO);
 }
 
 bool informixcursor::inputBindClob(const char *variable,
@@ -1024,9 +1107,15 @@ bool informixcursor::inputBindClob(const char *variable,
 					uint32_t valuesize,
 					int16_t *isnull) {
 
-	lobbindsize[inbindcount]=valuesize;
+	uint16_t	pos=charstring::toInteger(variable+1);
+	if (!pos || pos>maxbindcount) {
+		bindformaterror=true;
+		return false;
+	}
+
+	lobbindsize[pos-1]=valuesize;
 	erg=SQLBindParameter(stmt,
-				charstring::toInteger(variable+1),
+				pos,
 				SQL_PARAM_INPUT,
 				// SQL_C_CHAR works as expected with TEXT
 				// columns, but when used with clobs it ends up
@@ -1038,23 +1127,27 @@ bool informixcursor::inputBindClob(const char *variable,
 				0,
 				(SQLPOINTER)value,
 				valuesize,
-				&(lobbindsize[inbindcount]));
-	if (erg!=SQL_SUCCESS && erg!=SQL_SUCCESS_WITH_INFO) {
-		return false;
-	}
-	return true;
+				&(lobbindsize[pos-1]));
+	return (erg==SQL_SUCCESS || erg==SQL_SUCCESS_WITH_INFO);
 }
 
 bool informixcursor::outputBind(const char *variable, 
 					uint16_t variablesize,
 					char *value, 
-					uint16_t valuesize, 
+					uint32_t valuesize, 
 					int16_t *isnull) {
 
-	outdatebind[outbindcount]=NULL;
+	uint16_t	pos=charstring::toInteger(variable+1);
+	if (!pos || pos>maxbindcount) {
+		bindformaterror=true;
+		return false;
+	}
+
+	outdatebind[pos-1]=NULL;
+	outisnullptr[pos-1]=isnull;
 
 	erg=SQLBindParameter(stmt,
-				charstring::toInteger(variable+1),
+				pos,
 				SQL_PARAM_OUTPUT,
 				SQL_C_CHAR,
 				SQL_CHAR,
@@ -1062,11 +1155,9 @@ bool informixcursor::outputBind(const char *variable,
 				0,
 				value,
 				valuesize,
-				(SQLLEN *)isnull);
-	if (erg!=SQL_SUCCESS && erg!=SQL_SUCCESS_WITH_INFO) {
-		return false;
-	}
-	return true;
+				&(outisnull[pos-1])
+				);
+	return (erg==SQL_SUCCESS || erg==SQL_SUCCESS_WITH_INFO);
 }
 
 bool informixcursor::outputBind(const char *variable,
@@ -1074,12 +1165,19 @@ bool informixcursor::outputBind(const char *variable,
 					int64_t *value,
 					int16_t *isnull) {
 
-	outdatebind[outbindcount]=NULL;
+	uint16_t	pos=charstring::toInteger(variable+1);
+	if (!pos || pos>maxbindcount) {
+		bindformaterror=true;
+		return false;
+	}
+
+	outdatebind[pos-1]=NULL;
+	outisnullptr[pos-1]=isnull;
 
 	*value=0;
 
 	erg=SQLBindParameter(stmt,
-				charstring::toInteger(variable+1),
+				pos,
 				SQL_PARAM_OUTPUT,
 				SQL_C_LONG,
 				SQL_INTEGER,
@@ -1087,11 +1185,9 @@ bool informixcursor::outputBind(const char *variable,
 				0,
 				value,
 				sizeof(int64_t),
-				(SQLLEN *)isnull);
-	if (erg!=SQL_SUCCESS && erg!=SQL_SUCCESS_WITH_INFO) {
-		return false;
-	}
-	return true;
+				&(outisnull[pos-1])
+				);
+	return (erg==SQL_SUCCESS || erg==SQL_SUCCESS_WITH_INFO);
 }
 
 bool informixcursor::outputBind(const char *variable,
@@ -1101,12 +1197,19 @@ bool informixcursor::outputBind(const char *variable,
 					uint32_t *scale,
 					int16_t *isnull) {
 
-	outdatebind[outbindcount]=NULL;
+	uint16_t	pos=charstring::toInteger(variable+1);
+	if (!pos || pos>maxbindcount) {
+		bindformaterror=true;
+		return false;
+	}
+
+	outdatebind[pos-1]=NULL;
+	outisnullptr[pos-1]=isnull;
 
 	*value=0.0;
 
 	erg=SQLBindParameter(stmt,
-				charstring::toInteger(variable+1),
+				pos,
 				SQL_PARAM_OUTPUT,
 				SQL_C_DOUBLE,
 				SQL_DOUBLE,
@@ -1114,11 +1217,9 @@ bool informixcursor::outputBind(const char *variable,
 				0,
 				value,
 				sizeof(double),
-				(SQLLEN *)isnull);
-	if (erg!=SQL_SUCCESS && erg!=SQL_SUCCESS_WITH_INFO) {
-		return false;
-	}
-	return true;
+				&(outisnull[pos-1])
+				);
+	return (erg==SQL_SUCCESS || erg==SQL_SUCCESS_WITH_INFO);
 }
 
 bool informixcursor::outputBind(const char *variable,
@@ -1131,10 +1232,17 @@ bool informixcursor::outputBind(const char *variable,
 					int16_t *second,
 					int32_t *microsecond,
 					const char **tz,
+					bool *isnegative,
 					char *buffer,
 					uint16_t buffersize,
 					int16_t *isnull) {
 
+	uint16_t	pos=charstring::toInteger(variable+1);
+	if (!pos || pos>maxbindcount) {
+		bindformaterror=true;
+		return false;
+	}
+
 	datebind	*db=new datebind;
 	db->year=year;
 	db->month=month;
@@ -1144,11 +1252,13 @@ bool informixcursor::outputBind(const char *variable,
 	db->second=second;
 	db->microsecond=microsecond;
 	db->tz=tz;
+	*isnegative=false;
 	db->buffer=buffer;
-	outdatebind[outbindcount]=db;
+	outdatebind[pos-1]=db;
+	outisnullptr[pos-1]=isnull;
 
 	erg=SQLBindParameter(stmt,
-				charstring::toInteger(variable+1),
+				pos,
 				SQL_PARAM_OUTPUT,
 				SQL_C_TIMESTAMP,
 				SQL_TIMESTAMP,
@@ -1156,11 +1266,9 @@ bool informixcursor::outputBind(const char *variable,
 				0,
 				buffer,
 				0,
-				(SQLLEN *)isnull);
-	if (erg!=SQL_SUCCESS && erg!=SQL_SUCCESS_WITH_INFO) {
-		return false;
-	}
-	return true;
+				&(outisnull[pos-1])
+				);
+	return (erg==SQL_SUCCESS || erg==SQL_SUCCESS_WITH_INFO);
 }
 
 bool informixcursor::outputBindBlob(const char *variable, 
@@ -1168,11 +1276,17 @@ bool informixcursor::outputBindBlob(const char *variable,
 					uint16_t index,
 					int16_t *isnull) {
 
+	uint16_t	pos=charstring::toInteger(variable+1);
+	if (!pos || pos>maxbindcount) {
+		bindformaterror=true;
+		return false;
+	}
+
 	outlobbind[index]=new char[informixconn->maxoutbindlobsize];
 	outlobbindlen[index]=SQL_NULL_DATA;
 
 	erg=SQLBindParameter(stmt,
-				charstring::toInteger(variable+1),
+				pos,
 				SQL_PARAM_OUTPUT,
 				SQL_C_BINARY,
 				SQL_LONGVARBINARY,
@@ -1181,10 +1295,7 @@ bool informixcursor::outputBindBlob(const char *variable,
 				outlobbind[index],
 				informixconn->maxoutbindlobsize,
 				&outlobbindlen[index]);
-	if (erg!=SQL_SUCCESS && erg!=SQL_SUCCESS_WITH_INFO) {
-		return false;
-	}
-	return true;
+	return (erg==SQL_SUCCESS || erg==SQL_SUCCESS_WITH_INFO);
 }
 
 bool informixcursor::outputBindClob(const char *variable, 
@@ -1192,11 +1303,17 @@ bool informixcursor::outputBindClob(const char *variable,
 					uint16_t index,
 					int16_t *isnull) {
 
+	uint16_t	pos=charstring::toInteger(variable+1);
+	if (!pos || pos>maxbindcount) {
+		bindformaterror=true;
+		return false;
+	}
+
 	outlobbind[index]=new char[informixconn->maxoutbindlobsize];
 	outlobbindlen[index]=SQL_NULL_DATA;
 
 	erg=SQLBindParameter(stmt,
-				charstring::toInteger(variable+1),
+				pos,
 				SQL_PARAM_OUTPUT,
 				SQL_C_CHAR,
 				SQL_LONGVARCHAR,
@@ -1205,10 +1322,7 @@ bool informixcursor::outputBindClob(const char *variable,
 				outlobbind[index],
 				informixconn->maxoutbindlobsize,
 				&outlobbindlen[index]);
-	if (erg!=SQL_SUCCESS && erg!=SQL_SUCCESS_WITH_INFO) {
-		return false;
-	}
-	return true;
+	return (erg==SQL_SUCCESS || erg==SQL_SUCCESS_WITH_INFO);
 }
 
 bool informixcursor::getLobOutputBindLength(uint16_t index, uint64_t *length) {
@@ -1237,12 +1351,16 @@ bool informixcursor::getLobOutputBindSegment(uint16_t index,
 
 bool informixcursor::executeQuery(const char *query, uint32_t length) {
 
-	// initialize counts
-	ncols=0;
+	// initialize row counts
 	rowgroupindex=0;
 	totalinrowgroup=0;
 	totalrows=0;
 
+	// handle noops
+	if (noop) {
+		return true;
+	}
+
 	// execute the query
 	erg=SQLExecute(stmt);
 	if (erg!=SQL_SUCCESS &&
@@ -1260,10 +1378,11 @@ bool informixcursor::executeQuery(const char *query, uint32_t length) {
 	}
 
 	// allocate buffers and limit column count if necessary
-	if (informixconn->maxselectlistsize==-1) {
+	int32_t	maxcolumncount=conn->cont->getMaxColumnCount();
+	if (!maxcolumncount) {
 		allocateResultSetBuffers(ncols);
-	} else if (ncols>informixconn->maxselectlistsize) {
-		ncols=informixconn->maxselectlistsize;
+	} else if (ncols>maxcolumncount) {
+		ncols=maxcolumncount;
 	}
 
 	// run through the columns
@@ -1342,18 +1461,30 @@ bool informixcursor::executeQuery(const char *query, uint32_t length) {
 			if (erg!=SQL_SUCCESS && erg!=SQL_SUCCESS_WITH_INFO) {
 				return false;
 			}
+
+			// table name
+			erg=SQLColAttribute(stmt,i+1,
+				SQL_COLUMN_TABLE_NAME,
+				column[i].table,4096,
+				(SQLSMALLINT *)&(column[i].tablelength),
+				NULL);
+			if (erg!=SQL_SUCCESS && erg!=SQL_SUCCESS_WITH_INFO) {
+				return false;
+			}
+			column[i].tablelength=
+				charstring::length(column[i].table);
 		}
 
 		if (column[i].type==SQL_LONGVARBINARY ||
 			column[i].type==SQL_INFX_UDT_BLOB) {
 			erg=SQLBindCol(stmt,i+1,SQL_C_BINARY,
 					field[i],
-					informixconn->maxitembuffersize,
+					conn->cont->getMaxFieldLength(),
 					indicator[i]);
 		} else {
 			erg=SQLBindCol(stmt,i+1,SQL_C_CHAR,
 					field[i],
-					informixconn->maxitembuffersize,
+					conn->cont->getMaxFieldLength(),
 					indicator[i]);
 		}
 		if (erg!=SQL_SUCCESS && erg!=SQL_SUCCESS_WITH_INFO) {
@@ -1370,8 +1501,8 @@ bool informixcursor::executeQuery(const char *query, uint32_t length) {
 		affectedrows=0;
 	}
 
-	// convert date output binds
-	for (uint16_t i=0; i<maxbindcount; i++) {
+	// convert date output binds and copy out isnulls
+	for (uint16_t i=0; i<getOutputBindCount(); i++) {
 		if (outdatebind[i]) {
 			datebind	*db=outdatebind[i];
 			SQL_TIMESTAMP_STRUCT	*ts=
@@ -1385,6 +1516,9 @@ bool informixcursor::executeQuery(const char *query, uint32_t length) {
 			*(db->microsecond)=ts->fraction/1000;
 			*(db->tz)=NULL;
 		}
+		if (outisnullptr[i]) {
+			*(outisnullptr[i])=outisnull[i];
+		}
 	}
 	
 	return true;
@@ -1395,6 +1529,19 @@ void informixcursor::errorMessage(char *errorbuffer,
 					uint32_t *errorlength,
 					int64_t *errorcode,
 					bool *liveconnection) {
+	if (bindformaterror) {
+		// handle bind format errors
+		*errorlength=charstring::length(
+				SQLR_ERROR_INVALIDBINDVARIABLEFORMAT_STRING);
+		charstring::safeCopy(errorbuffer,
+				errorbufferlength,
+				SQLR_ERROR_INVALIDBINDVARIABLEFORMAT_STRING,
+				*errorlength);
+		*errorcode=SQLR_ERROR_INVALIDBINDVARIABLEFORMAT;
+		*liveconnection=true;
+		return;
+	}
+
 	SQLCHAR		state[10];
 	SQLINTEGER	nativeerrnum;
 	SQLSMALLINT	errlength;
@@ -1563,22 +1710,36 @@ uint16_t informixcursor::getColumnIsAutoIncrement(uint32_t i) {
 	return column[i].autoincrement;
 }
 
+const char *informixcursor::getColumnTable(uint32_t i) {
+	return column[i].table;
+}
+
+uint16_t informixcursor::getColumnTableLength(uint32_t i) {
+	return column[i].tablelength;
+}
+
 bool informixcursor::noRowsToReturn() {
 	// if there are no columns, then there can't be any rows either
 	return (ncols)?false:true;
 }
 
-bool informixcursor::skipRow() {
-	if (fetchRow()) {
+bool informixcursor::skipRow(bool *error) {
+	if (fetchRow(error)) {
 		rowgroupindex++;
 		return true;
 	}
 	return false;
 }
 
-bool informixcursor::fetchRow() {
+bool informixcursor::fetchRow(bool *error) {
 
-	if (rowgroupindex==informixconn->fetchatonce) {
+	*error=false;
+
+	if (noop) {
+		return false;
+	}
+
+	if (rowgroupindex==conn->cont->getFetchAtOnce()) {
 		rowgroupindex=0;
 	}
 	if (rowgroupindex>0 && rowgroupindex==totalinrowgroup) {
@@ -1591,6 +1752,10 @@ bool informixcursor::fetchRow() {
 		// rows, otherwise we're at the end of the result and there are
 		// no more rows to fetch.
 		SQLRETURN	result=SQLFetchScroll(stmt,SQL_FETCH_NEXT,0);
+		if (result==SQL_ERROR) {
+			*error=true;
+			return false;
+		}
 		if (result!=SQL_SUCCESS && result!=SQL_SUCCESS_WITH_INFO) {
 			// there are no more rows to be fetched
 			return false;
@@ -1632,7 +1797,7 @@ void informixcursor::getField(uint32_t col,
 	}
 
 	// handle normal datatypes
-	*fld=&field[col][rowgroupindex*informixconn->maxitembuffersize];
+	*fld=&field[col][rowgroupindex*conn->cont->getMaxFieldLength()];
 	*fldlength=indicator[col][rowgroupindex];
 }
 
@@ -1725,17 +1890,39 @@ void informixcursor::closeResultSet() {
 		SQLCloseCursor(stmt);
 	}
 
-	for (uint16_t i=0; i<maxbindcount; i++) {
+	for (uint16_t i=0; i<getOutputBindCount(); i++) {
 		delete outdatebind[i];
 		outdatebind[i]=NULL;
 		delete outlobbind[i];
 		outlobbind[i]=NULL;
 		outlobbindlen[i]=0;
+		outisnullptr[i]=NULL;
+		outisnull[i]=0;
 	}
 
-	if (informixconn->maxselectlistsize==-1) {
+	if (!conn->cont->getMaxColumnCount()) {
 		deallocateResultSetBuffers();
 	}
+
+	// NOTE: this is a bit of a kludge.
+	//
+	// ncols is reset at the beginning of prepareQuery, and other methods,
+	// but, since we rely on it to decide whether there are rows to return,
+	// it really needs to be reset here.
+	//
+	// If sqlrservercontroller intercepts the query (eg. if it's a begin,
+	// commit, rollback, etc.) then prepareQuery() will never be called,
+	// and this won't be reset.  If it was > 0 from the previous query,
+	// then a begin (for example) will think that it has rows to return,
+	// and the subsequent SQLFetch will fail with a
+	// "function sequence error".  We can avoid that by setting ncols=0
+	// here, which will cause noRowsToReturn() to return false by default,
+	// and avoid the fetch.
+	//
+	// Arguably, other things should be reset here too (eg. various row
+	// counts), but this is the critical one for now, so we'll sort that
+	// out later.
+	ncols=0;
 }
 
 extern "C" {
