@@ -1,4 +1,4 @@
-// Copyright (c) 1999-2015  David Muse
+// Copyright (c) 1999-2018 David Muse
 // See the file COPYING for more information
 
 #include <sqlrelay/sqlrserver.h>
@@ -14,6 +14,8 @@
 
 #include <libpq-fe.h>
 
+//#undef HAVE_POSTGRESQL_PQSENDQUERYPREPARED
+
 class SQLRSERVER_DLLSPEC postgresqlconnection : public sqlrserverconnection {
 	friend class postgresqlcursor;
 	public:
@@ -22,6 +24,9 @@ class SQLRSERVER_DLLSPEC postgresqlconnection : public sqlrserverconnection {
 	private:
 		void		handleConnectString();
 		bool		logIn(const char **error, const char **warning);
+		bool		logIn(const char **error,
+					const char **warning,
+					const char *database);
 		const char	*logInError(const char *errmsg);
 		sqlrservercursor	*newCursor(uint16_t id);
 		void		deleteCursor(sqlrservercursor *curs);
@@ -37,18 +42,19 @@ class SQLRSERVER_DLLSPEC postgresqlconnection : public sqlrserverconnection {
 		const char	*dbIpAddressQuery();
 		const char	*dbIpAddress();
 		const char	*getDatabaseListQuery(bool wild);
-		const char	*getTableListQuery(bool wild);
+		const char	*getTableListQuery(bool wild,
+						uint16_t objecttypes);
 		const char	*getColumnListQuery(
 					const char *table, bool wild);
-		const char	*selectDatabaseQuery();
+		bool		selectDatabase(const char *database);
 		const char	*getCurrentDatabaseQuery();
 		bool		getLastInsertId(uint64_t *id);
 		const char	*getLastInsertIdQuery();
+		const char	*noopQuery();
 		const char	*bindFormat();
 
-		int	datatypecount;
-		int32_t	*datatypeids;
-		char	**datatypenames;
+		dictionary< int32_t, char *>	datatypes;
+		dictionary< int32_t, char *>	tables;
 
 		PGconn	*pgconn;
 
@@ -58,6 +64,7 @@ class SQLRSERVER_DLLSPEC postgresqlconnection : public sqlrserverconnection {
 		const char	*db;
 		const char	*sslmode;
 		uint16_t	typemangling;
+		uint16_t	tablemangling;
 		const char	*charset;
 		char		*dbversion;
 		char		*hostname;
@@ -87,19 +94,22 @@ class SQLRSERVER_DLLSPEC postgresqlcursor : public sqlrservercursor {
 				postgresqlcursor(sqlrserverconnection *conn,
 								uint16_t id);
 				~postgresqlcursor();
-#if defined(HAVE_POSTGRESQL_PQEXECPREPARED) && \
-		defined(HAVE_POSTGRESQL_PQPREPARE)
+#if (defined(HAVE_POSTGRESQL_PQEXECPREPARED) && \
+		defined(HAVE_POSTGRESQL_PQPREPARE)) || \
+		(defined(HAVE_POSTGRESQL_PQSENDQUERYPREPARED) && \
+		defined(HAVE_POSTGRESQL_PQSETSINGLEROWMODE))
 		bool		prepareQuery(const char *query,
 						uint32_t length);
-		bool		deallocateStatement();
 #endif
 		bool		supportsNativeBinds(const char *query,
 							uint32_t length);
 		void		encodeBlob(stringbuffer *buffer,
 							const char *data,
 							uint32_t datasize);
-#if defined(HAVE_POSTGRESQL_PQEXECPREPARED) && \
-		defined(HAVE_POSTGRESQL_PQPREPARE)
+#if (defined(HAVE_POSTGRESQL_PQEXECPREPARED) && \
+		defined(HAVE_POSTGRESQL_PQPREPARE)) || \
+		(defined(HAVE_POSTGRESQL_PQSENDQUERYPREPARED) && \
+		defined(HAVE_POSTGRESQL_PQSETSINGLEROWMODE))
 		bool		inputBind(const char *variable, 
 						uint16_t variablesize,
 						const char *value, 
@@ -126,8 +136,10 @@ class SQLRSERVER_DLLSPEC postgresqlcursor : public sqlrservercursor {
 #endif
 		bool		executeQuery(const char *query,
 						uint32_t length);
-#if defined(HAVE_POSTGRESQL_PQEXECPREPARED) && \
-		defined(HAVE_POSTGRESQL_PQPREPARE)
+#if (defined(HAVE_POSTGRESQL_PQEXECPREPARED) && \
+		defined(HAVE_POSTGRESQL_PQPREPARE)) || \
+		(defined(HAVE_POSTGRESQL_PQSENDQUERYPREPARED) && \
+		defined(HAVE_POSTGRESQL_PQSETSINGLEROWMODE))
 		void		errorMessage(char *errorbuffer,
 					uint32_t errorbufferlength,
 					uint32_t *errorlength,
@@ -144,8 +156,11 @@ class SQLRSERVER_DLLSPEC postgresqlcursor : public sqlrservercursor {
 		const char	*getColumnTypeName(uint32_t col);
 		uint32_t	getColumnLength(uint32_t col);
 		uint16_t	getColumnIsBinary(uint32_t col);
+#ifdef HAVE_POSTGRESQL_PQFTABLE
+		const char	*getColumnTable(uint32_t col);
+#endif
 		bool		noRowsToReturn();
-		bool		fetchRow();
+		bool		fetchRow(bool *error);
 		void		getField(uint32_t col,
 					const char **field,
 					uint64_t *fieldlength,
@@ -153,6 +168,20 @@ class SQLRSERVER_DLLSPEC postgresqlcursor : public sqlrservercursor {
 					bool *null);
 		void		closeResultSet();
 
+#if (defined(HAVE_POSTGRESQL_PQEXECPREPARED) && \
+		defined(HAVE_POSTGRESQL_PQPREPARE)) || \
+		(defined(HAVE_POSTGRESQL_PQSENDQUERYPREPARED) && \
+		defined(HAVE_POSTGRESQL_PQSETSINGLEROWMODE))
+		void		deallocateNamedStatement();
+#endif
+#if ((defined(HAVE_POSTGRESQL_PQEXECPREPARED) && \
+		defined(HAVE_POSTGRESQL_PQPREPARE)) || \
+		(defined(HAVE_POSTGRESQL_PQSENDQUERYPREPARED) && \
+		defined(HAVE_POSTGRESQL_PQSETSINGLEROWMODE))) && \
+		defined(HAVE_POSTGRESQL_PQDESCRIBEPREPARED)
+		bool		columnInfoIsValidAfterPrepare();
+#endif
+
 		PGresult	*pgresult;
 		ExecStatusType	pgstatus;
 		int		ncols;
@@ -160,22 +189,31 @@ class SQLRSERVER_DLLSPEC postgresqlcursor : public sqlrservercursor {
 		uint64_t	affectedrows;
 		int		currentrow;
 
-		char		typenamebuffer[6];
+		char		**typenamebuffer;
+		char		tablenamebuffer[32];
 
 		postgresqlconnection	*postgresqlconn;
 
-#if defined(HAVE_POSTGRESQL_PQEXECPREPARED) && \
-		defined(HAVE_POSTGRESQL_PQPREPARE)
-		bool		deallocatestatement;
-		int		bindcount;
-		int		bindcounter;
+#if (defined(HAVE_POSTGRESQL_PQEXECPREPARED) && \
+		defined(HAVE_POSTGRESQL_PQPREPARE)) || \
+		(defined(HAVE_POSTGRESQL_PQSENDQUERYPREPARED) && \
+		defined(HAVE_POSTGRESQL_PQSETSINGLEROWMODE))
+		char		*cursorid;
+		stringbuffer	deallocatecursorid;
+		bool		allocated;
+		uint16_t	maxbindcount;
 		char		**bindvalues;
 		int		*bindlengths;
 		int		*bindformats;
-		char		*cursorname;
+		int		bindcounter;
 
 		bool		bindformaterror;
 #endif
+
+#if defined(HAVE_POSTGRESQL_PQSENDQUERYPREPARED) && \
+		defined(HAVE_POSTGRESQL_PQSETSINGLEROWMODE)
+		bool		justexecuted;
+#endif
 };
 
 #ifdef HAVE_POSTGRESQL_PQSETNOTICEPROCESSOR
@@ -186,9 +224,8 @@ static void nullNoticeProcessor(void *arg, const char *message) {
 postgresqlconnection::postgresqlconnection(sqlrservercontroller *cont) :
 						sqlrserverconnection(cont) {
 	dbversion=NULL;
-	datatypecount=0;
-	datatypeids=NULL;
-	datatypenames=NULL;
+	datatypes.setTrackInsertionOrder(false);
+	tables.setTrackInsertionOrder(false);
 	pgconn=NULL;
 #ifdef HAVE_POSTGRESQL_PQOIDVALUE
 	currentoid=InvalidOid;
@@ -208,21 +245,28 @@ postgresqlconnection::~postgresqlconnection() {
 }
 
 void postgresqlconnection::handleConnectString() {
+
+	sqlrserverconnection::handleConnectString();
+
 	host=cont->getConnectStringValue("host");
 	port=cont->getConnectStringValue("port");
 	options=cont->getConnectStringValue("options");
 	db=cont->getConnectStringValue("db");
-	cont->setUser(cont->getConnectStringValue("user"));
-	cont->setPassword(cont->getConnectStringValue("password"));
 	sslmode=cont->getConnectStringValue("sslmode");
 	const char	*typemang=cont->getConnectStringValue("typemangling");
-	if (!typemang ||!charstring::compareIgnoringCase(typemang,"no")) {
+	if (!typemang || charstring::isNo(typemang)) {
 		typemangling=0;
-	} else if (!charstring::compareIgnoringCase(typemang,"yes")) {
+	} else if (charstring::isYes(typemang)) {
 		typemangling=1;
 	} else {
 		typemangling=2;
 	}
+	const char	*tablemang=cont->getConnectStringValue("tablemangling");
+	if (!tablemang || charstring::isNo(tablemang)) {
+		tablemangling=0;
+	} else {
+		tablemangling=2;
+	}
 	charset=cont->getConnectStringValue("charset");
 	const char	*lastinsertidfunc=
 			cont->getConnectStringValue("lastinsertidfunction");
@@ -232,20 +276,29 @@ void postgresqlconnection::handleConnectString() {
 		liiquery.append(lastinsertidfunc);
 		lastinsertidquery=liiquery.detachString();
 	}
-	if (!charstring::compare(
-			cont->getConnectStringValue("fakebinds"),"yes")) {
-		cont->fakeInputBinds();
-	}
 	identity=cont->getConnectStringValue("identity");
+
+	// postgresql doesn't support multi-row fetches
+	cont->setFetchAtOnce(1);
+	cont->setMaxFieldLength(0);
 }
 
 bool postgresqlconnection::logIn(const char **error, const char **warning) {
+	return logIn(error,warning,db);
+}
 
-	// initialize the datatype storage buffers
+bool postgresqlconnection::logIn(const char **error,
+					const char **warning,
+					const char *database) {
+
+	// clear the datatype dictionary
 	if (typemangling==2) {
-		datatypecount=0;
-		datatypeids=NULL;
-		datatypenames=NULL;
+		datatypes.clearAndArrayDeleteValues();
+	}
+
+	// clear the table dictionary
+	if (tablemangling==2) {
+		tables.clearAndArrayDeleteValues();
 	}
 
 	// log in
@@ -262,8 +315,8 @@ bool postgresqlconnection::logIn(const char **error, const char **warning) {
 	if (!charstring::isNullOrEmpty(options)) {
 		conninfo.append(" options=")->append(options);
 	}
-	if (!charstring::isNullOrEmpty(db)) {
-		conninfo.append(" dbname=")->append(db);
+	if (!charstring::isNullOrEmpty(database)) {
+		conninfo.append(" dbname=")->append(database);
 	}
 	// sslmode isn't supported by older versions of postgresql, and
 	// including it at all will cause PQconnectdb to fail.  Remove it
@@ -274,7 +327,7 @@ bool postgresqlconnection::logIn(const char **error, const char **warning) {
 	}
 	pgconn=PQconnectdb(conninfo.getString());
 #else
-	pgconn=PQsetdbLogin(host,port,options,NULL,db,
+	pgconn=PQsetdbLogin(host,port,options,NULL,database,
 				cont->getUser(),cont->getPassword());
 #endif
 
@@ -301,7 +354,7 @@ bool postgresqlconnection::logIn(const char **error, const char **warning) {
 	}
 #endif
 
-	// get the datatypes
+	// build the datatype dictionary
 	if (typemangling==2) {
 		PGresult	*result=PQexec(pgconn,
 					"select oid,typname from pg_type");
@@ -309,29 +362,37 @@ bool postgresqlconnection::logIn(const char **error, const char **warning) {
 			*error=logInError("Get datatypes failed");
 			return false;
 		}
-
-		// create the datatype storage buffers
-		datatypecount=PQntuples(result);
-		datatypeids=new int32_t[datatypecount];
-		datatypenames=new char *[datatypecount];
-
-		// copy the datatype ids/names into the buffers
-		for (int i=0; i<datatypecount; i++) {
-			datatypeids[i]=
-				charstring::toInteger(PQgetvalue(result,i,0));
-			datatypenames[i]=
-				charstring::duplicate(PQgetvalue(result,i,1));
+		for (int i=0; i<PQntuples(result); i++) {
+			datatypes.setValue(
+				charstring::toInteger(PQgetvalue(result,i,0)),
+				charstring::duplicate(PQgetvalue(result,i,1)));
 		}
-	
-		// clean up
 		PQclear(result);
 	}
 
-#if defined(HAVE_POSTGRESQL_PQEXECPREPARED) && \
-		defined(HAVE_POSTGRESQL_PQPREPARE)
+	// build the table dictionary
+	if (tablemangling==2) {
+		PGresult	*result=PQexec(pgconn,
+					"select oid,relname from pg_class");
+		if (!result) {
+			*error=logInError("Get tables failed");
+			return false;
+		}
+		for (int i=0; i<PQntuples(result); i++) {
+			tables.setValue(
+				charstring::toInteger(PQgetvalue(result,i,0)),
+				charstring::duplicate(PQgetvalue(result,i,1)));
+		}
+		PQclear(result);
+	}
+
+#if (defined(HAVE_POSTGRESQL_PQEXECPREPARED) && \
+		defined(HAVE_POSTGRESQL_PQPREPARE)) || \
+		(defined(HAVE_POSTGRESQL_PQSENDQUERYPREPARED) && \
+		defined(HAVE_POSTGRESQL_PQSETSINGLEROWMODE))
 	// don't use bind variables against older servers
 	if (PQprotocolVersion(pgconn)<3) {
-		cont->fakeInputBinds();
+		cont->setFakeInputBinds(true);
 	}
 #endif
 
@@ -369,19 +430,24 @@ void postgresqlconnection::logOut() {
 		pgconn=NULL;
 	}
 
+	// clear the datatype dictionary
 	if (typemangling==2) {
-
-		// delete the datatype storage buffers
-		for (int i=0; i<datatypecount; i++) {
-			delete[] datatypenames[i];
+		for (avltreenode< dictionarynode<int32_t,char *> *>
+					*node=datatypes.getTree()->getFirst();
+					node; node=node->getNext()) {
+			delete[] node->getValue()->getValue();
 		}
-		delete[] datatypeids;
-		delete[] datatypenames;
+		datatypes.clear();
+	}
 
-		// re-initialize the datatype storage buffers
-		datatypecount=0;
-		datatypeids=NULL;
-		datatypenames=NULL;
+	// clear the table dictionary
+	if (typemangling==2) {
+		for (avltreenode< dictionarynode<int32_t,char *> *>
+					*node=tables.getTree()->getFirst();
+					node; node=node->getNext()) {
+			delete[] node->getValue()->getValue();
+		}
+		tables.clear();
 	}
 }
 
@@ -497,48 +563,53 @@ const char *postgresqlconnection::getDatabaseListQuery(bool wild) {
 		"	datname";
 }
 
-const char *postgresqlconnection::getTableListQuery(bool wild) {
-	return (wild)?
-		"select "
-		"	table_name, "
-		"	NULL "
-		"from "
-		"	information_schema.tables "
-		"where "
-		"	table_schema = 'public' "
-		"	and "
-		"	table_name like '%s' "
-		"order by "
-		"	table_name":
-
-		"select "
-		"	table_name, "
-		"	NULL "
-		"from "
-		"	information_schema.tables "
-		"where "
-		"	table_schema = 'public' "
-		"order by "
-		"	table_name";
+const char *postgresqlconnection::getTableListQuery(bool wild,
+						uint16_t objecttypes) {
+	return sqlrserverconnection::getTableListQuery(wild,objecttypes,
+					" and table_schema = 'public' ");
 }
 
 const char *postgresqlconnection::getColumnListQuery(
 					const char *table, bool wild) {
 	return (wild)?
 		"select "
+		"	table_catalog as table_cat, "
+		"	table_schema as table_schem, "
+		"	table_name as table_name, "
 		"	column_name, "
-		"	data_type, "
-		"	character_maximum_length, "
-		"	numeric_precision, "
-		"	numeric_scale, "
-		"	is_nullable, "
-		"	'' as key, "
+		"	null as data_type, " // case this...
+		"	data_type as type_name, "
+		"	case "
+		"		when numeric_scale is null "
+		"			then character_maximum_length "
+		"		else numeric_precision "
+		"	end as column_size, "
+		"	null as buffer_length, "
+			// length in bytes of data transferred during fetch
+		"	numeric_scale as decimal_digits, "
+		"	numeric_precision_radix as num_prec_radix, "
+		"	case "
+		"		when is_nullable = 'NO' "
+		"			then 0 "
+		"		when is_nullable = 'YES' "
+		"			then 1 "
+		"		else 2 "
+		"	end as nullable, "
+		"	null as remarks, "
 		"	column_default, "
-		"	'' as extra, "
-		"	NULL "
+		"	null as sql_data_type, "
+			// type (int)
+		"	null as sql_datetime_sub, "
+			// subtype (int) for datetime/interval, otherwise null
+		"	character_octet_length as char_octet_length, "
+		"	ordinal_position, "
+		"	is_nullable, "
+		"	null as extra "
 		"from "
 		"	information_schema.columns "
 		"where "
+		"	table_schema='public' "
+		"	and "
 		"	table_name='%s' "
 		"	and "
 		"	column_name like '%s' "
@@ -546,26 +617,71 @@ const char *postgresqlconnection::getColumnListQuery(
 		"	ordinal_position":
 
 		"select "
+		"	table_catalog as table_cat, "
+		"	table_schema as table_schem, "
+		"	table_name as table_name, "
 		"	column_name, "
-		"	data_type, "
-		"	character_maximum_length, "
-		"	numeric_precision, "
-		"	numeric_scale, "
-		"	is_nullable, "
-		"	'' as key, "
+		"	null as data_type, " // case this...
+		"	data_type as type_name, "
+		"	case "
+		"		when numeric_scale is null "
+		"			then character_maximum_length "
+		"		else numeric_precision "
+		"	end as column_size, "
+		"	null as buffer_length, "
+		"	numeric_scale as decimal_digits, "
+		"	numeric_precision_radix as num_prec_radix, "
+		"	case "
+		"		when is_nullable = 'NO' "
+		"			then 0 "
+		"		when is_nullable = 'YES' "
+		"			then 1 "
+		"		else 2 "
+		"	end as nullable, "
+		"	null as remarks, "
 		"	column_default, "
-		"	'' as extra, "
-		"	NULL "
+		"	null as sql_data_type, "
+		"	null as sql_datetime_sub, "
+		"	character_octet_length as char_octet_length, "
+		"	ordinal_position, "
+		"	is_nullable, "
+		"	null as extra "
 		"from "
 		"	information_schema.columns "
 		"where "
+		"	table_schema='public' "
+		"	and "
 		"	table_name='%s' "
 		"order by "
 		"	ordinal_position";
 }
 
-const char *postgresqlconnection::selectDatabaseQuery() {
-	return "use %s";
+bool postgresqlconnection::selectDatabase(const char *database) {
+
+	cont->clearError();
+
+	// log out and log back in to the specified database
+	logOut();
+	const char	*error=NULL;
+	const char	*warning=NULL;
+	if (!logIn(&error,&warning,database)) {
+
+		// Set the error, but don't use the error that was returned
+		// from logIn() because it will have a message prepended to it.
+		// Also, we can't get the message from PQerrorMessage, because
+		// if PQconnect fails then pgconn will be NULL and
+		// PQerrorMessage will just return a message saying that it's
+		// NULL.  So, we'll just return the generic SQL Relay error
+		// for these kinds of things.
+		cont->setError(SQLR_ERROR_DBNOTFOUND_STRING,
+				SQLR_ERROR_DBNOTFOUND,true);
+
+		// log back in to the original database, we'll assume that works
+		logOut();
+		logIn(&error,&warning);
+		return false;
+	}
+	return true;
 }
 
 const char *postgresqlconnection::getCurrentDatabaseQuery() {
@@ -588,9 +704,15 @@ const char *postgresqlconnection::getLastInsertIdQuery() {
 	return lastinsertidquery;
 }
 
+const char *postgresqlconnection::noopQuery() {
+	return "do language plpgsql $$declare dummy int; begin end$$";
+}
+
 const char *postgresqlconnection::bindFormat() {
-#if defined(HAVE_POSTGRESQL_PQEXECPREPARED) && \
-		defined(HAVE_POSTGRESQL_PQPREPARE)
+#if (defined(HAVE_POSTGRESQL_PQEXECPREPARED) && \
+		defined(HAVE_POSTGRESQL_PQPREPARE)) || \
+		(defined(HAVE_POSTGRESQL_PQSENDQUERYPREPARED) && \
+		defined(HAVE_POSTGRESQL_PQSETSINGLEROWMODE))
 	return "$1";
 #else
 	return sqlrserverconnection::bindFormat();
@@ -601,93 +723,78 @@ postgresqlcursor::postgresqlcursor(sqlrserverconnection *conn, uint16_t id) :
 						sqlrservercursor(conn,id) {
 	postgresqlconn=(postgresqlconnection *)conn;
 	pgresult=NULL;
-#if defined(HAVE_POSTGRESQL_PQEXECPREPARED) && \
-		defined(HAVE_POSTGRESQL_PQPREPARE)
-	deallocatestatement=false;
-	size_t	cursornamelen=6+charstring::integerLength(id)+1;
-	cursorname=new char[cursornamelen];
-	charstring::printf(cursorname,cursornamelen,"cursor%d",id);
+#if (defined(HAVE_POSTGRESQL_PQEXECPREPARED) && \
+		defined(HAVE_POSTGRESQL_PQPREPARE)) || \
+		(defined(HAVE_POSTGRESQL_PQSENDQUERYPREPARED) && \
+		defined(HAVE_POSTGRESQL_PQSETSINGLEROWMODE))
+	if (id) {
+		charstring::printf(&cursorid,"%s-%d",
+					conn->cont->getConnectionId(),id);
+		charstring::replace(cursorid,'-','_');
+	} else {
+		cursorid=charstring::duplicate("");
+	}
+	deallocatecursorid.append("deallocate ")->append(cursorid);
+	allocated=false;
+	maxbindcount=conn->cont->getConfig()->getMaxBindCount();
+	bindvalues=new char *[maxbindcount];
+	bytestring::zero(bindvalues,maxbindcount*sizeof(char *));
+	bindlengths=new int[maxbindcount];
+	bindformats=new int[maxbindcount];
 	bindcounter=0;
-	bindcount=0;
-	bindvalues=NULL;
-	bindlengths=NULL;
-	bindformats=NULL;
 	bindformaterror=false;
 #endif
+#if defined(HAVE_POSTGRESQL_PQSENDQUERYPREPARED) && \
+		defined(HAVE_POSTGRESQL_PQSETSINGLEROWMODE)
+	justexecuted=false;
+#endif
+	typenamebuffer=new char *[conn->cont->getMaxColumnCount()];
+	for (uint32_t i=0; i<conn->cont->getMaxColumnCount(); i++) {
+		typenamebuffer[i]=new char[32];
+	}
 }
 
 postgresqlcursor::~postgresqlcursor() {
-#if defined(HAVE_POSTGRESQL_PQEXECPREPARED) && \
-		defined(HAVE_POSTGRESQL_PQPREPARE)
-	deallocateStatement();
-	delete[] cursorname;
-
+#if (defined(HAVE_POSTGRESQL_PQEXECPREPARED) && \
+		defined(HAVE_POSTGRESQL_PQPREPARE)) || \
+		(defined(HAVE_POSTGRESQL_PQSENDQUERYPREPARED) && \
+		defined(HAVE_POSTGRESQL_PQSETSINGLEROWMODE))
 	for (uint16_t i=0; i<bindcounter; i++) {
 		delete[] bindvalues[i];
 	}
 	delete[] bindvalues;
 	delete[] bindlengths;
 	delete[] bindformats;
+	deallocateNamedStatement();
+	delete[] cursorid;
 #endif
-}
-
-#if defined(HAVE_POSTGRESQL_PQEXECPREPARED) && \
-		defined(HAVE_POSTGRESQL_PQPREPARE)
-bool postgresqlcursor::deallocateStatement() {
-	if (deallocatestatement) {
-		stringbuffer	rmquery;
-		rmquery.append("deallocate ")->append(cursorname);
-		pgresult=PQexec(postgresqlconn->pgconn,rmquery.getString());
-		if (!pgresult) {
-			return false;
-		}
-		PQclear(pgresult);
-		deallocatestatement=true;
+	for (uint32_t i=0; i<conn->cont->getMaxColumnCount(); i++) {
+		delete[] typenamebuffer[i];
 	}
-	return true;
+	delete[] typenamebuffer;
 }
 
+#if (defined(HAVE_POSTGRESQL_PQEXECPREPARED) && \
+		defined(HAVE_POSTGRESQL_PQPREPARE)) || \
+		(defined(HAVE_POSTGRESQL_PQSENDQUERYPREPARED) && \
+		defined(HAVE_POSTGRESQL_PQSETSINGLEROWMODE))
 bool postgresqlcursor::prepareQuery(const char *query, uint32_t length) {
 
-	// store inbindcount here, otherwise if rebinding/reexecution occurs and
-	// the client tries to bind more variables than were defined when the
-	// query was prepared, it would cause the inputBind methods to attempt
-	// to address beyond the end of the various arrays
-	bindcount=inbindcount;
+	// initialize the column count
+	ncols=0;
 
 	// reset bind counter
 	bindcounter=0;
 
-	if (bindcount) {
-
-		// clear bind arrays
-		delete[] bindvalues;
-		delete[] bindlengths;
-		delete[] bindformats;
-
-		// create new bind arrays
-		bindvalues=new char *[bindcount];
-		bindlengths=new int[bindcount];
-		bindformats=new int[bindcount];
-
-		// initialize bind arrays
-		for (int i=0; i<bindcount; i++) {
-			bindvalues[i]=NULL;
-			bindlengths[i]=0;
-			bindformats[i]=0;
-		}
-	}
-
 	// reset the bind format error flag
 	bindformaterror=false;
 
-	// remove this named statement, if it exists already
-	if (!deallocateStatement()) {
-		return false;
-	}
+	// deallocate named statement
+	deallocateNamedStatement();
 
 	// prepare the query
-	pgresult=PQprepare(postgresqlconn->pgconn,cursorname,query,0,NULL);
+	pgresult=PQprepare(postgresqlconn->pgconn,cursorid,query,0,NULL);
+	allocated=true;
 
 	// handle some kind of outright failure
 	if (!pgresult) {
@@ -701,14 +808,40 @@ bool postgresqlcursor::prepareQuery(const char *query, uint32_t length) {
 		pgstatus==PGRES_NONFATAL_ERROR ||
 		pgstatus==PGRES_FATAL_ERROR) {
 		result=false;
-	} else {
-		deallocatestatement=true;
 	}
 
+#if defined(HAVE_POSTGRESQL_PQDESCRIBEPREPARED)
+
 	// clean up
 	PQclear(pgresult);
 	pgresult=NULL;
 
+	// bail, if necessary
+	if (!result) {
+		return false;
+	}
+	
+	// describe the query (get column info)
+	pgresult=PQdescribePrepared(postgresqlconn->pgconn,cursorid);
+
+	// handle some kind of outright failure
+	if (!pgresult) {
+		return false;
+	}
+
+	// handle errors
+	result=true;
+	pgstatus=PQresultStatus(pgresult);
+	if (pgstatus==PGRES_BAD_RESPONSE ||
+		pgstatus==PGRES_NONFATAL_ERROR ||
+		pgstatus==PGRES_FATAL_ERROR) {
+		result=false;
+	}
+
+	// get the col count
+	ncols=PQnfields(pgresult);
+#endif
+
 	return result;
 }
 
@@ -718,12 +851,14 @@ bool postgresqlcursor::inputBind(const char *variable,
 					uint32_t valuesize,
 					int16_t *isnull) {
 
-	int32_t	pos=charstring::toInteger(variable+1)-1;
+	// "variable" should be something like ?1,?2,?3, etc.
+	// If it's something like ?var1,?var2,?var3, etc. then it'll be
+	// converted to 0.  1 will be subtracted and after the cast it will
+	// be converted to 65535 and will cause the if below to fail.
+	uint16_t	pos=charstring::toInteger(variable+1)-1;
 
-	// ignore attempts to bind beyond the number of
-	// variables defined when the query was prepared
-	// or below 0
-	if (pos>=bindcount || bindcounter>=bindcount || pos<0) {
+	// validate bind index
+	if (pos>=maxbindcount) {
 		bindformaterror=true;
 		return true;
 	}
@@ -744,12 +879,14 @@ bool postgresqlcursor::inputBind(const char *variable,
 					uint16_t variablesize,
 					int64_t *value) {
 
-	int32_t	pos=charstring::toInteger(variable+1)-1;
+	// "variable" should be something like ?1,?2,?3, etc.
+	// If it's something like ?var1,?var2,?var3, etc. then it'll be
+	// converted to 0.  1 will be subtracted and after the cast it will
+	// be converted to 65535 and will cause the if below to fail.
+	uint16_t	pos=charstring::toInteger(variable+1)-1;
 
-	// ignore attempts to bind beyond the number of
-	// variables defined when the query was prepared
-	// or below 0
-	if (pos>=bindcount || bindcounter>=bindcount || pos<0) {
+	// validate bind index
+	if (pos>=maxbindcount) {
 		bindformaterror=true;
 		return true;
 	}
@@ -767,12 +904,14 @@ bool postgresqlcursor::inputBind(const char *variable,
 					uint32_t precision,
 					uint32_t scale) {
 
-	int32_t	pos=charstring::toInteger(variable+1)-1;
+	// "variable" should be something like ?1,?2,?3, etc.
+	// If it's something like ?var1,?var2,?var3, etc. then it'll be
+	// converted to 0.  1 will be subtracted and after the cast it will
+	// be converted to 65535 and will cause the if below to fail.
+	uint16_t	pos=charstring::toInteger(variable+1)-1;
 
-	// ignore attempts to bind beyond the number of
-	// variables defined when the query was prepared
-	// or below 0
-	if (pos>=bindcount || bindcounter>=bindcount || pos<0) {
+	// validate bind index
+	if (pos>=maxbindcount) {
 		bindformaterror=true;
 		return true;
 	}
@@ -790,22 +929,18 @@ bool postgresqlcursor::inputBindBlob(const char *variable,
 					uint32_t valuesize,
 					int16_t *isnull) {
 
-	int32_t	pos=charstring::toInteger(variable+1)-1;
+	// "variable" should be something like ?1,?2,?3, etc.
+	// If it's something like ?var1,?var2,?var3, etc. then it'll be
+	// converted to 0.  1 will be subtracted and after the cast it will
+	// be converted to 65535 and will cause the if below to fail.
+	uint16_t	pos=charstring::toInteger(variable+1)-1;
 
-	// ignore attempts to bind beyond the number of
-	// variables defined when the query was prepared
-	// or below 0
-	if (pos>=bindcount || bindcounter>=bindcount || pos<0) {
+	// validate bind index
+	if (pos>=maxbindcount) {
 		bindformaterror=true;
 		return true;
 	}
 
-	// ignore attempts to bind beyond the number of
-	// variables defined when the query was prepared
-	if (pos>=bindcount || bindcounter>=bindcount) {
-		return true;
-	}
-
 	if (*isnull) {
 		bindvalues[pos]=NULL;
 		bindlengths[pos]=0;
@@ -825,22 +960,18 @@ bool postgresqlcursor::inputBindClob(const char *variable,
 					uint32_t valuesize,
 					int16_t *isnull) {
 
-	int32_t	pos=charstring::toInteger(variable+1)-1;
+	// "variable" should be something like ?1,?2,?3, etc.
+	// If it's something like ?var1,?var2,?var3, etc. then it'll be
+	// converted to 0.  1 will be subtracted and after the cast it will
+	// be converted to 65535 and will cause the if below to fail.
+	uint16_t	pos=charstring::toInteger(variable+1)-1;
 
-	// ignore attempts to bind beyond the number of
-	// variables defined when the query was prepared
-	// or below 0
-	if (pos>=bindcount || bindcounter>=bindcount || pos<0) {
+	// validate bind index
+	if (pos>=maxbindcount) {
 		bindformaterror=true;
 		return true;
 	}
 
-	// ignore attempts to bind beyond the number of
-	// variables defined when the query was prepared
-	if (pos>=bindcount || bindcounter>=bindcount) {
-		return true;
-	}
-
 	if (*isnull) {
 		bindvalues[pos]=NULL;
 		bindlengths[pos]=0;
@@ -855,8 +986,10 @@ bool postgresqlcursor::inputBindClob(const char *variable,
 #endif
 
 bool postgresqlcursor::supportsNativeBinds(const char *query, uint32_t length) {
-#if defined(HAVE_POSTGRESQL_PQEXECPREPARED) && \
-		defined(HAVE_POSTGRESQL_PQPREPARE)
+#if (defined(HAVE_POSTGRESQL_PQEXECPREPARED) && \
+		defined(HAVE_POSTGRESQL_PQPREPARE)) || \
+		(defined(HAVE_POSTGRESQL_PQSENDQUERYPREPARED) && \
+		defined(HAVE_POSTGRESQL_PQSETSINGLEROWMODE))
 	return true;
 #else
 	return false;
@@ -885,20 +1018,49 @@ void postgresqlcursor::encodeBlob(stringbuffer *buffer,
 
 bool postgresqlcursor::executeQuery(const char *query, uint32_t length) {
 
-	// initialize the counts
-	ncols=0;
+	// initialize the row counts
 	nrows=0;
 	currentrow=-1;
 
-#if defined(HAVE_POSTGRESQL_PQEXECPREPARED) && \
+	// clean up any result that might be lying around (eg. from a prepare)
+	if (pgresult) {
+		PQclear(pgresult);
+		pgresult=NULL;
+	}
+
+#if defined(HAVE_POSTGRESQL_PQSENDQUERYPREPARED) && \
+		defined(HAVE_POSTGRESQL_PQSETSINGLEROWMODE)
+	int	result=1;
+	if (bindcounter) {
+		result=PQsendQueryPrepared(postgresqlconn->pgconn,cursorid,
+						bindcounter,bindvalues,
+						bindlengths,bindformats,0);
+		bindcounter=0;
+	} else {
+		result=PQsendQuery(postgresqlconn->pgconn,query);
+	}
+
+	// handle some kind of outright failure
+	if (!result) {
+		return false;
+	}
+
+	// set single-row mode
+	if (!PQsetSingleRowMode(postgresqlconn->pgconn)) {
+		return false;
+	}
+
+	// get the result (and the first row)
+	pgresult=PQgetResult(postgresqlconn->pgconn);
+
+	justexecuted=true;
+	currentrow=0;
+#elif defined(HAVE_POSTGRESQL_PQEXECPREPARED) && \
 		defined(HAVE_POSTGRESQL_PQPREPARE)
 	if (bindcounter) {
-		// execute the query
-		pgresult=PQexecPrepared(postgresqlconn->pgconn,
-					cursorname,
+		pgresult=PQexecPrepared(postgresqlconn->pgconn,cursorid,
 					bindcounter,bindvalues,
 					bindlengths,bindformats,0);
-		// reset bind counter
 		bindcounter=0;
 	} else {
 		pgresult=PQexec(postgresqlconn->pgconn,query);
@@ -920,13 +1082,42 @@ bool postgresqlcursor::executeQuery(const char *query, uint32_t length) {
 		return false;
 	}
 
-	checkForTempTable(query,length);
-
+	// NOTE: this is a bit of a kludge.
+	//
+	// As this is set in prepareQuery(), originally, we only did this here
+	// if we don't support prepared queries.  However, since it's set to 0
+	// in closeResultSet() (see long note there as to why), we must reset
+	// it to the correct count here so that ncols will be correct for
+	// reexecuted queries.
+/*#if !((defined(HAVE_POSTGRESQL_PQEXECPREPARED) && \
+		defined(HAVE_POSTGRESQL_PQPREPARE)) || \
+		(defined(HAVE_POSTGRESQL_PQSENDQUERYPREPARED) && \
+		defined(HAVE_POSTGRESQL_PQSETSINGLEROWMODE))) || \
+		!(defined(HAVE_POSTGRESQL_PQDESCRIBEPREPARED))*/
 	// get the col count
 	ncols=PQnfields(pgresult);
+//#endif
 
+	// validate column count
+	uint32_t	maxcolumncount=conn->cont->getMaxColumnCount();
+	if (maxcolumncount && (uint32_t)ncols>maxcolumncount) {
+		stringbuffer	err;
+		err.append(SQLR_ERROR_MAXSELECTLIST_STRING);
+		err.append(" (")->append(ncols)->append('>');
+		err.append(maxcolumncount);
+		err.append(')');
+		conn->cont->setError(this,err.getString(),
+					SQLR_ERROR_MAXSELECTLIST,true);
+		return false;
+	}
+
+	checkForTempTable(query,length);
+
+#if !(defined(HAVE_POSTGRESQL_PQSENDQUERYPREPARED) && \
+		defined(HAVE_POSTGRESQL_PQSETSINGLEROWMODE))
 	// get the row count
 	nrows=PQntuples(pgresult);
+#endif
 
 	// get the affected row count
 	const char	*affrows=PQcmdTuples(pgresult);
@@ -943,11 +1134,16 @@ bool postgresqlcursor::executeQuery(const char *query, uint32_t length) {
 	}
 #endif
 
+	// force re-fetch of column info
+	setResultSetHeaderHasBeenHandled(false);
+
 	return true;
 }
 
-#if defined(HAVE_POSTGRESQL_PQEXECPREPARED) && \
-		defined(HAVE_POSTGRESQL_PQPREPARE)
+#if (defined(HAVE_POSTGRESQL_PQEXECPREPARED) && \
+		defined(HAVE_POSTGRESQL_PQPREPARE)) || \
+		(defined(HAVE_POSTGRESQL_PQSENDQUERYPREPARED) && \
+		defined(HAVE_POSTGRESQL_PQSETSINGLEROWMODE))
 void postgresqlcursor::errorMessage(char *errorbuffer,
 					uint32_t errorbufferlength,
 					uint32_t *errorlength,
@@ -971,7 +1167,12 @@ void postgresqlcursor::errorMessage(char *errorbuffer,
 #endif
 
 bool postgresqlcursor::knowsRowCount() {
+#if defined(HAVE_POSTGRESQL_PQSENDQUERYPREPARED) && \
+		defined(HAVE_POSTGRESQL_PQSETSINGLEROWMODE)
+	return false;
+#else
 	return true;
+#endif
 }
 
 uint64_t postgresqlcursor::rowCount() {
@@ -1250,18 +1451,12 @@ const char *postgresqlcursor::getColumnTypeName(uint32_t col) {
 	// typemangling=2 means return the name as a string
 	Oid	pgfieldtype=PQftype(pgresult,col);
 	if (!postgresqlconn->typemangling) {
-		charstring::printf(typenamebuffer,sizeof(typenamebuffer),
+		charstring::printf(typenamebuffer[col],
+						sizeof(typenamebuffer[col]),
 						"%d",(int32_t)pgfieldtype);
-		return typenamebuffer;
-	} else {
-		for (int i=0; i<postgresqlconn->datatypecount; i++) {
-			if ((int32_t)pgfieldtype==
-				postgresqlconn->datatypeids[i]) {
-				return postgresqlconn->datatypenames[i];
-			}
-		}
+		return typenamebuffer[col];
 	}
-	return NULL;
+	return postgresqlconn->datatypes.getValue((int32_t)pgfieldtype);
 }
 
 uint32_t postgresqlcursor::getColumnLength(uint32_t col) {
@@ -1286,16 +1481,60 @@ uint16_t postgresqlcursor::getColumnIsBinary(uint32_t col) {
 	return binary;
 }
 
+#ifdef HAVE_POSTGRESQL_PQFTABLE
+const char *postgresqlcursor::getColumnTable(uint32_t col) {
+	// PQftable returns an oid rather than a table name, so we have to map
+	// it to a table name.
+	// tablemangling=0 means return the internal number as a string
+	// tablemangling=2 means return the name as a string
+	Oid	pgfieldtable=PQftable(pgresult,col);
+	if (!postgresqlconn->tablemangling) {
+		charstring::printf(tablenamebuffer,sizeof(tablenamebuffer),
+						"%d",(int32_t)pgfieldtable);
+		return tablenamebuffer;
+	}
+	return postgresqlconn->tables.getValue((int32_t)pgfieldtable);
+}
+#endif
+
 bool postgresqlcursor::noRowsToReturn() {
+#if defined(HAVE_POSTGRESQL_PQSENDQUERYPREPARED) && \
+		defined(HAVE_POSTGRESQL_PQSETSINGLEROWMODE)
+	// if there are no columns, then there can't be any rows either
+	return (ncols)?false:true;
+#else
 	return (!nrows);
+#endif
 }
 
-bool postgresqlcursor::fetchRow() {
+bool postgresqlcursor::fetchRow(bool *error) {
+
+	*error=false;
+	// FIXME: set error if an error occurs
+
+#if defined(HAVE_POSTGRESQL_PQSENDQUERYPREPARED) && \
+		defined(HAVE_POSTGRESQL_PQSETSINGLEROWMODE)
+	if (!justexecuted) {
+		PQclear(pgresult);
+		pgresult=PQgetResult(postgresqlconn->pgconn);
+	} else {
+		justexecuted=false;
+	}
+	// The docs say call PQgetResult until it returns null, but it will
+	// actually return non-null one time when called after the end of the
+	// result set.  Fortunately, we can detect the true end with
+	// PQresultStatus.
+	if (PQresultStatus(pgresult)==PGRES_SINGLE_TUPLE && pgresult) {
+		return true;
+	}
+	return false;
+#else
 	if (currentrow<nrows-1) {
 		currentrow++;
 		return true;
 	}
 	return false;
+#endif
 }
 
 void postgresqlcursor::getField(uint32_t col,
@@ -1315,20 +1554,82 @@ void postgresqlcursor::getField(uint32_t col,
 
 void postgresqlcursor::closeResultSet() {
 
-#if defined(HAVE_POSTGRESQL_PQEXECPREPARED) && \
-		defined(HAVE_POSTGRESQL_PQPREPARE)
+#if (defined(HAVE_POSTGRESQL_PQEXECPREPARED) && \
+		defined(HAVE_POSTGRESQL_PQPREPARE)) || \
+		(defined(HAVE_POSTGRESQL_PQSENDQUERYPREPARED) && \
+		defined(HAVE_POSTGRESQL_PQSETSINGLEROWMODE))
 	for (uint16_t i=0; i<bindcounter; i++) {
 		delete[] bindvalues[i];
 		bindvalues[i]=NULL;
 	}
 #endif
 
+#if defined(HAVE_POSTGRESQL_PQSENDQUERYPREPARED) && \
+		defined(HAVE_POSTGRESQL_PQSETSINGLEROWMODE)
+	for (;;) {
+		if (pgresult) {
+			PQclear(pgresult);
+		} else {
+			break;
+		}
+		pgresult=PQgetResult(postgresqlconn->pgconn);
+	}
+	justexecuted=false;
+#else
 	if (pgresult) {
 		PQclear(pgresult);
 		pgresult=NULL;
 	}
+#endif
+
+	// NOTE: this is a bit of a kludge.
+	//
+	// ncols is reset at the beginning of prepareQuery, and other methods,
+	// but, since we rely on it to decide whether there are rows to return,
+	// it really needs to be reset here.
+	//
+	// If sqlrservercontroller intercepts the query (eg. if it's a begin,
+	// commit, rollback, etc.) then prepareQuery() will never be called,
+	// and this won't be reset.  If it was > 0 from the previous query,
+	// then a begin (for example) will think that it has rows to return,
+	// and the subsequent SQLFetch will fail with a
+	// "function sequence error".  We can avoid that by setting ncols=0
+	// here, which will cause noRowsToReturn() to return false by default,
+	// and avoid the fetch.
+	//
+	// Arguably, other things should be reset here too (eg. various row
+	// counts), but this is the critical one for now, so we'll sort that
+	// out later.
+	ncols=0;
 }
 
+#if (defined(HAVE_POSTGRESQL_PQEXECPREPARED) && \
+		defined(HAVE_POSTGRESQL_PQPREPARE)) || \
+		(defined(HAVE_POSTGRESQL_PQSENDQUERYPREPARED) && \
+		defined(HAVE_POSTGRESQL_PQSETSINGLEROWMODE))
+void postgresqlcursor::deallocateNamedStatement() {
+	if (allocated) {
+		if (cursorid[0]) {
+			pgresult=PQexec(postgresqlconn->pgconn,
+					deallocatecursorid.getString());
+			PQclear(pgresult);
+			pgresult=NULL;
+		}
+		allocated=false;
+	}
+}
+#endif
+
+#if ((defined(HAVE_POSTGRESQL_PQEXECPREPARED) && \
+		defined(HAVE_POSTGRESQL_PQPREPARE)) || \
+		(defined(HAVE_POSTGRESQL_PQSENDQUERYPREPARED) && \
+		defined(HAVE_POSTGRESQL_PQSETSINGLEROWMODE))) && \
+		defined(HAVE_POSTGRESQL_PQDESCRIBEPREPARED)
+bool postgresqlcursor::columnInfoIsValidAfterPrepare() {
+	return true;
+}
+#endif
+
 extern "C" {
 	SQLRSERVER_DLLSPEC sqlrserverconnection *new_postgresqlconnection(
 						sqlrservercontroller *cont) {
