@@ -1,24 +1,26 @@
-// Copyright (c) 1999-2015  David Muse
+// Copyright (c) 1999-2018 David Muse
 // See the file COPYING for more information
 
 #include <sqlrelay/sqlrserver.h>
 #include <rudiments/environment.h>
 #include <rudiments/stringbuffer.h>
 #include <rudiments/charstring.h>
+#include <rudiments/character.h>
 #include <rudiments/bytestring.h>
 #include <rudiments/stdio.h>
+#include <rudiments/process.h>
 
 #include <config.h>
 #include <datatypes.h>
 #include <defines.h>
 
-extern "C" {
-	#include <ctpublic.h>
-}
-
-#define FETCH_AT_ONCE		10
-#define MAX_SELECT_LIST_SIZE	256
-#define MAX_ITEM_BUFFER_SIZE	32768
+#ifdef SYBASE_AT_RUNTIME
+	#include "sapatruntime.cpp"
+#else
+	extern "C" {
+		#include <ctpublic.h>
+	}
+#endif
 
 class SQLRSERVER_DLLSPEC sapconnection : public sqlrserverconnection {
 	friend class sapcursor;
@@ -36,15 +38,16 @@ class SQLRSERVER_DLLSPEC sapconnection : public sqlrserverconnection {
 		const char	*dbVersion();
 		const char	*dbHostNameQuery();
 		const char	*getDatabaseListQuery(bool wild);
-		const char	*getTableListQuery(bool wild);
+		const char	*getTableListQuery(bool wild,
+						uint16_t objecttypes);
 		const char	*getColumnListQuery(
 						const char *table, bool wild);
 		const char	*selectDatabaseQuery();
 		const char	*getCurrentDatabaseQuery();
 		const char	*getLastInsertIdQuery();
+		const char	*noopQuery();
 		const char	*bindFormat();
 		const char	*beginTransactionQuery();
-		char		bindVariablePrefix();
 		const char	*tempTableDropPrefix();
 		bool		commit();
 		bool		rollback();
@@ -67,10 +70,6 @@ class SQLRSERVER_DLLSPEC sapconnection : public sqlrserverconnection {
 		const char	*hostname;
 		const char	*packetsize;
 
-		int32_t		fetchatonce;
-		int32_t		maxselectlistsize;
-		int32_t		maxitembuffersize;
-
 		const char	*identity;
 
 		bool		dbused;
@@ -102,6 +101,7 @@ struct datebind {
         int16_t         *second;
         int32_t         *microsecond;
         const char      **tz;
+	bool		*isnegative;
 };
 
 class SQLRSERVER_DLLSPEC sapcursor : public sqlrservercursor {
@@ -110,8 +110,7 @@ class SQLRSERVER_DLLSPEC sapcursor : public sqlrservercursor {
 				sapcursor(sqlrserverconnection *conn,
 								uint16_t id);
 				~sapcursor();
-		void		allocateResultSetBuffers(
-					int32_t selectlistsize);
+		void		allocateResultSetBuffers(int32_t columncount);
 		void		deallocateResultSetBuffers();
 		bool		open();
 		bool		close();
@@ -143,13 +142,14 @@ class SQLRSERVER_DLLSPEC sapcursor : public sqlrservercursor {
 						int16_t second,
 						int32_t microsecond,
 						const char *tz,
+						bool isnegative,
 						char *buffer,
 						uint16_t buffersize,
 						int16_t *isnull);
 		bool		outputBind(const char *variable, 
 						uint16_t variablesize,
 						char *value, 
-						uint16_t valuesize, 
+						uint32_t valuesize, 
 						int16_t *isnull);
 		bool		outputBind(const char *variable,
 						uint16_t variablesize,
@@ -171,6 +171,7 @@ class SQLRSERVER_DLLSPEC sapcursor : public sqlrservercursor {
 						int16_t *second,
 						int32_t *microsecond,
 						const char **tz,
+						bool *isnegative,
 						char *buffer,
 						uint16_t buffersize,
 						int16_t *isnull);
@@ -189,8 +190,8 @@ class SQLRSERVER_DLLSPEC sapcursor : public sqlrservercursor {
 		uint16_t	getColumnIsBinary(uint32_t col);
 		uint16_t	getColumnIsAutoIncrement(uint32_t col);
 		bool		noRowsToReturn();
-		bool		skipRow();
-		bool		fetchRow();
+		bool		skipRow(bool *error);
+		bool		fetchRow(bool *error);
 		void		getField(uint32_t col,
 					const char **field,
 					uint64_t *fieldlength,
@@ -223,13 +224,14 @@ class SQLRSERVER_DLLSPEC sapcursor : public sqlrservercursor {
 		uint16_t	paramindex;
 		CS_INT		*outbindtype;
 		char		**outbindstrings;
-		uint16_t	*outbindstringlengths;
+		uint32_t	*outbindstringlengths;
 		int64_t		**outbindints;
 		double		**outbinddoubles;
 		datebind	*outbinddates;
 		uint16_t	outbindindex;
 
-		int32_t		selectlistsize;
+		int32_t		columncount;
+		CS_DATAFMT	templatecolumn;
 		CS_DATAFMT	*column;
 		char		**data;
 		CS_INT		**datalength;
@@ -240,11 +242,6 @@ class SQLRSERVER_DLLSPEC sapcursor : public sqlrservercursor {
 		bool		prepared;
 		bool		clean;
 
-		regularexpression	cursorquery;
-		regularexpression	rpcquery;
-
-		bool			isrpcquery;
-
 		sapconnection	*sapconn;
 };
 
@@ -259,10 +256,6 @@ sapconnection::sapconnection(sqlrservercontroller *cont) :
 	dbused=false;
 	dbversion=NULL;
 
-	fetchatonce=FETCH_AT_ONCE;
-	maxselectlistsize=MAX_SELECT_LIST_SIZE;
-	maxitembuffersize=MAX_ITEM_BUFFER_SIZE;
-
 	identity=NULL;
 }
 
@@ -271,39 +264,24 @@ sapconnection::~sapconnection() {
 }
 
 void sapconnection::handleConnectString() {
+
+	sqlrserverconnection::handleConnectString();
+
 	sybase=cont->getConnectStringValue("sybase");
 	lang=cont->getConnectStringValue("lang");
-	cont->setUser(cont->getConnectStringValue("user"));
-	cont->setPassword(cont->getConnectStringValue("password"));
 	server=cont->getConnectStringValue("server");
 	db=cont->getConnectStringValue("db");
 	charset=cont->getConnectStringValue("charset");
 	language=cont->getConnectStringValue("language");
 	hostname=cont->getConnectStringValue("hostname");
 	packetsize=cont->getConnectStringValue("packetsize");
-	if (!charstring::compare(
-			cont->getConnectStringValue("fakebinds"),"yes")) {
-		cont->fakeInputBinds();
-	}
-	fetchatonce=charstring::toInteger(
-				cont->getConnectStringValue("fetchatonce"));
-	if (fetchatonce<1) {
-		fetchatonce=FETCH_AT_ONCE;
-	}
-	maxselectlistsize=charstring::toInteger(
-			cont->getConnectStringValue("maxselectlistsize"));
-	if (!maxselectlistsize || maxselectlistsize<-1) {
-		maxselectlistsize=MAX_SELECT_LIST_SIZE;
-	} else if (maxselectlistsize==1) {
-		// if maxselectlistsize is set to 1 then force it
+
+	if (cont->getMaxColumnCount()==1) {
+		// if max column count is set to 1 then force it
 		// to 2 so the db version detection doesn't crash
-		maxselectlistsize=2;
-	}
-	maxitembuffersize=charstring::toInteger(
-			cont->getConnectStringValue("maxitembuffersize"));
-	if (maxitembuffersize<1) {
-		maxitembuffersize=MAX_ITEM_BUFFER_SIZE;
+		cont->setMaxColumnCount(2);
 	}
+
 	identity=cont->getConnectStringValue("identity");
 }
 
@@ -333,6 +311,13 @@ bool sapconnection::logIn(const char **error, const char **warning) {
 		return false;
 	}
 
+	#ifdef SYBASE_AT_RUNTIME
+	if (!loadLibraries(&loginerror)) {
+		*error=loginerror.getString();
+		return false;
+	}
+	#endif
+
 	// allocate a context
 	context=(CS_CONTEXT *)NULL;
 	if (cs_ctx_alloc(CS_VERSION_100,&context)!=CS_SUCCEED) {
@@ -340,6 +325,7 @@ bool sapconnection::logIn(const char **error, const char **warning) {
 			"Failed to allocate a context structure",2);
 		return false;
 	}
+
 	// init the context
 	if (ct_init(context,CS_VERSION_100)!=CS_SUCCEED) {
 		*error=logInError(
@@ -573,11 +559,16 @@ const char *sapconnection::getDatabaseListQuery(bool wild) {
 	return "select '',NULL as db";
 }
 
-const char *sapconnection::getTableListQuery(bool wild) {
+const char *sapconnection::getTableListQuery(bool wild,
+						uint16_t objecttypes) {
 	return (wild)?
 		"select "
-		"	name, "
-		"	NULL "
+		"	NULL as table_cat, "
+		"	NULL as table_schem, "
+		"	name as table_name, "
+		"	'TABLE' as table_type, "
+		"	NULL as remarks, "
+		"	NULL as extra "
 		"from "
 		"	sysobjects "
 		"where "
@@ -590,8 +581,12 @@ const char *sapconnection::getTableListQuery(bool wild) {
 		"	name":
 
 		"select "
-		"	name, "
-		"	NULL "
+		"	NULL as table_cat, "
+		"	NULL as table_schem, "
+		"	name as table_name, "
+		"	'TABLE' as table_type, "
+		"	NULL as remarks, "
+		"	NULL as extra "
 		"from "
 		"	sysobjects "
 		"where "
@@ -672,6 +667,10 @@ const char *sapconnection::getLastInsertIdQuery() {
 	return "select @@identity";
 }
 
+const char *sapconnection::noopQuery() {
+	return "waitfor delay '0:0'";
+}
+
 const char *sapconnection::bindFormat() {
 	return "@*";
 }
@@ -680,10 +679,6 @@ const char *sapconnection::beginTransactionQuery() {
 	return "BEGIN TRANSACTION";
 }
 
-char sapconnection::bindVariablePrefix() {
-	return '@';
-}
-
 sapcursor::sapcursor(sqlrserverconnection *conn, uint16_t id) :
 						sqlrservercursor(conn,id) {
 	prepared=false;
@@ -695,28 +690,35 @@ sapcursor::sapcursor(sqlrserverconnection *conn, uint16_t id) :
 	cursornamelength=charstring::integerLength(id);
 	cursorname=charstring::parseNumber(id);
 
-	uint16_t	maxbindcount=conn->cont->cfg->getMaxBindCount();
+	uint16_t	maxbindcount=conn->cont->getConfig()->getMaxBindCount();
 	parameter=new CS_DATAFMT[maxbindcount];
 	outbindtype=new CS_INT[maxbindcount];
 	outbindstrings=new char *[maxbindcount];
-	outbindstringlengths=new uint16_t[maxbindcount];
+	outbindstringlengths=new uint32_t[maxbindcount];
 	outbindints=new int64_t *[maxbindcount];
 	outbinddoubles=new double *[maxbindcount];
 	outbinddates=new datebind[maxbindcount];
 
 	// replace the regular expression used to detect creation of a
 	// temporary table
-	createtemp.compile("(create|CREATE)[ 	\\r\\n]+(table|TABLE)[ 	\\r\\n]+#");
-	createtemp.study();
+	setCreateTempTablePattern("^(create|CREATE)[ 	\r\n]+"
+					"(table|TABLE)[ 	\r\n]+#");
 
-	cursorquery.compile("^(select|SELECT)[ 	\\r\\n]+");
-	cursorquery.study();
+	columncount=0;
+	allocateResultSetBuffers(conn->cont->getMaxColumnCount());
 
-	rpcquery.compile("^(execute|exec|EXECUTE|EXEC)[ 	\\r\\n]+");
-	rpcquery.study();
-
-	selectlistsize=0;
-	allocateResultSetBuffers(sapconn->maxselectlistsize);
+	// define a template column-bind definition...
+	// get the field as a null terminated character string
+	// no longer than MAX_ITEM_BUFFER_SIZE, override some
+	templatecolumn.datatype=CS_CHAR_TYPE;
+	templatecolumn.format=CS_FMT_NULLTERM;
+	templatecolumn.maxlength=conn->cont->getMaxFieldLength();
+	templatecolumn.scale=CS_UNUSED;
+	templatecolumn.precision=CS_UNUSED;
+	templatecolumn.status=CS_UNUSED;
+	templatecolumn.count=conn->cont->getFetchAtOnce();
+	templatecolumn.usertype=CS_UNUSED;
+	templatecolumn.locale=NULL;
 }
 
 sapcursor::~sapcursor() {
@@ -733,35 +735,34 @@ sapcursor::~sapcursor() {
 	deallocateResultSetBuffers();
 }
 
-void sapcursor::allocateResultSetBuffers(int32_t selectlistsize) {
+void sapcursor::allocateResultSetBuffers(int32_t columncount) {
 
-	if (selectlistsize==-1) {
-		this->selectlistsize=0;
+	if (!columncount) {
+		this->columncount=0;
 		column=NULL;
 		data=NULL;
 		datalength=NULL;
 		nullindicator=NULL;
 	} else {
-		this->selectlistsize=selectlistsize;
-		column=new CS_DATAFMT[selectlistsize];
-		data=new char *[selectlistsize];
-		datalength=new CS_INT *[selectlistsize];
-		nullindicator=new CS_SMALLINT *[selectlistsize];
-		for (int32_t i=0; i<selectlistsize; i++) {
-			data[i]=new char[sapconn->fetchatonce*
-					sapconn->maxitembuffersize];
-			datalength[i]=
-				new CS_INT[sapconn->fetchatonce];
-			nullindicator[i]=
-				new CS_SMALLINT[sapconn->fetchatonce];
+		this->columncount=columncount;
+		column=new CS_DATAFMT[columncount];
+		data=new char *[columncount];
+		datalength=new CS_INT *[columncount];
+		nullindicator=new CS_SMALLINT *[columncount];
+		uint32_t	fetchatonce=conn->cont->getFetchAtOnce();
+		uint32_t	maxfieldlength=conn->cont->getMaxFieldLength();
+		for (int32_t i=0; i<columncount; i++) {
+			data[i]=new char[fetchatonce*maxfieldlength];
+			datalength[i]=new CS_INT[fetchatonce];
+			nullindicator[i]=new CS_SMALLINT[fetchatonce];
 		}
 	}
 }
 
 void sapcursor::deallocateResultSetBuffers() {
-	if (selectlistsize) {
+	if (columncount) {
 		delete[] column;
-		for (int32_t i=0; i<selectlistsize; i++) {
+		for (int32_t i=0; i<columncount; i++) {
 			delete[] data[i];
 			delete[] datalength[i];
 			delete[] nullindicator[i];
@@ -769,7 +770,7 @@ void sapcursor::deallocateResultSetBuffers() {
 		delete[] data;
 		delete[] datalength;
 		delete[] nullindicator;
-		selectlistsize=0;
+		columncount=0;
 	}
 }
 
@@ -823,10 +824,11 @@ bool sapcursor::open() {
 
 			const char	*q=query[i];
 			int32_t		len=charstring::length(q);
+			bool		error=false;
 
 			if (prepareQuery(q,len) &&
 					executeQuery(q,len) &&
-					fetchRow()) {
+					fetchRow(&error)) {
 				sapconn->dbversion=
 					charstring::duplicate(data[index[i]]);
 			}
@@ -860,6 +862,9 @@ bool sapcursor::close() {
 
 bool sapcursor::prepareQuery(const char *query, uint32_t length) {
 
+	// initialize column count
+	ncols=0;
+
 	clean=true;
 
 	this->query=(char *)query;
@@ -868,30 +873,48 @@ bool sapcursor::prepareQuery(const char *query, uint32_t length) {
 	paramindex=0;
 	outbindindex=0;
 
-	isrpcquery=false;
-
-	if (cursorquery.match(query)) {
+	if ((!charstring::compare(query,"select",6) ||
+		!charstring::compare(query,"SELECT",6)) &&
+		character::isWhitespace(query[6])) {
 
 		// initiate a cursor command
 		// (don't use CS_NULLTERM for the 4th parameter, it randomly
 		// causes weird things to happen)
 		cmd=cursorcmd;
-		if (ct_cursor(cursorcmd,CS_CURSOR_DECLARE,
-					(CS_CHAR *)cursorname,
-					(CS_INT)cursornamelength,
-					(CS_CHAR *)query,length,
-					CS_READ_ONLY)!=CS_SUCCEED) {
+		if (ct_cursor(cursorcmd,
+				CS_CURSOR_DECLARE,
+				(CS_CHAR *)cursorname,
+				(CS_INT)cursornamelength,
+				(CS_CHAR *)query,
+				length,
+				CS_READ_ONLY)!=CS_SUCCEED) {
 			return false;
 		}
 
-	} else if (rpcquery.match(query)) {
+	} else if ((!charstring::compare(query,"exec",4) ||
+			!charstring::compare(query,"EXEC",4)) &&
+					character::isWhitespace(query[4])) {
 
 		// initiate an rpc command
-		isrpcquery=true;
 		cmd=languagecmd;
-		if (ct_command(languagecmd,CS_RPC_CMD,
-				(CS_CHAR *)rpcquery.getSubstringEnd(0),
-				length-rpcquery.getSubstringEndOffset(0),
+		if (ct_command(languagecmd,
+				CS_RPC_CMD,
+				(CS_CHAR *)query+5,
+				length-5,
+				CS_UNUSED)!=CS_SUCCEED) {
+			return false;
+		}
+
+	} else if ((!charstring::compare(query,"execute",7) ||
+			!charstring::compare(query,"EXECUTE",7)) &&
+					character::isWhitespace(query[7])) {
+
+		// initiate an rpc command
+		cmd=languagecmd;
+		if (ct_command(languagecmd,
+				CS_RPC_CMD,
+				(CS_CHAR *)query+8,
+				length-8,
 				CS_UNUSED)!=CS_SUCCEED) {
 			return false;
 		}
@@ -900,9 +923,11 @@ bool sapcursor::prepareQuery(const char *query, uint32_t length) {
 
 		// initiate a language command
 		cmd=languagecmd;
-		if (ct_command(languagecmd,CS_LANG_CMD,
-					(CS_CHAR *)query,length,
-					CS_UNUSED)!=CS_SUCCEED) {
+		if (ct_command(languagecmd,
+				CS_LANG_CMD,
+				(CS_CHAR *)query,
+				length,
+				CS_UNUSED)!=CS_SUCCEED) {
 			return false;
 		}
 	}
@@ -930,6 +955,7 @@ void sapcursor::checkRePrepare() {
 	// Sybase doesn't allow you to rebind and re-execute when using 
 	// ct_command.  You have to re-prepare too.  I'll make this transparent
 	// to the user.
+	// FIXME: skip if cmd==cursorcmd?
 	if (!prepared) {
 		prepareQuery(query,length);
 	}
@@ -1035,6 +1061,7 @@ bool sapcursor::inputBind(const char *variable,
 				int16_t second,
 				int32_t microsecond,
 				const char *tz,
+				bool isnegative,
 				char *buffer,
 				uint16_t buffersize,
 				int16_t *isnull) {
@@ -1078,7 +1105,7 @@ bool sapcursor::inputBind(const char *variable,
 bool sapcursor::outputBind(const char *variable, 
 				uint16_t variablesize,
 				char *value, 
-				uint16_t valuesize, 
+				uint32_t valuesize, 
 				int16_t *isnull) {
 
 	checkRePrepare();
@@ -1185,6 +1212,7 @@ bool sapcursor::outputBind(const char *variable,
 				int16_t *second,
 				int32_t *microsecond,
 				const char **tz,
+				bool *isnegative,
 				char *buffer,
 				uint16_t buffersize,
 				int16_t *isnull) {
@@ -1199,6 +1227,7 @@ bool sapcursor::outputBind(const char *variable,
 	outbinddates[outbindindex].second=second;
 	outbinddates[outbindindex].microsecond=microsecond;
 	outbinddates[outbindindex].tz=tz;
+	outbinddates[outbindindex].isnegative=isnegative;
 	outbindindex++;
 
 	bytestring::zero(&parameter[paramindex],sizeof(parameter[paramindex]));
@@ -1225,12 +1254,10 @@ bool sapcursor::outputBind(const char *variable,
 bool sapcursor::executeQuery(const char *query, uint32_t length) {
 
 	// clear out any errors
-	sapconn->errorstring.clear();
 	sapconn->errorcode=0;
 	sapconn->liveconnection=true;
 
-	// initialize return values
-	ncols=0;
+	// initialize row counts
 	affectedrows=0;
 	row=0;
 	maxrow=0;
@@ -1240,7 +1267,7 @@ bool sapcursor::executeQuery(const char *query, uint32_t length) {
 		if (ct_cursor(cursorcmd,CS_CURSOR_ROWS,
 					NULL,CS_UNUSED,
 					NULL,CS_UNUSED,
-					(CS_INT)sapconn->fetchatonce)!=
+					(CS_INT)conn->cont->getFetchAtOnce())!=
 					CS_SUCCEED) {
 			return false;
 		}
@@ -1344,50 +1371,43 @@ bool sapcursor::executeQuery(const char *query, uint32_t length) {
 		}
 
 		// allocate buffers and limit column count if necessary
-		if (sapconn->maxselectlistsize==-1) {
+		uint32_t	maxcolumncount=conn->cont->getMaxColumnCount();
+		if (!maxcolumncount) {
 			allocateResultSetBuffers(ncols);
-		} else if (ncols>sapconn->maxselectlistsize) {
-			ncols=sapconn->maxselectlistsize;
+		} else if ((uint32_t)ncols>maxcolumncount) {
+			ncols=maxcolumncount;
 		}
 
 		// bind columns
 		for (CS_INT i=0; i<ncols; i++) {
 
-			// get the field as a null terminated character string
-			// no longer than MAX_ITEM_BUFFER_SIZE, override some
-			// other values that might have been set also...
-			//
-			// however, if we're getting the output bind variables
-			// of a stored procedure that returns dates, then use
+			// reset the column-bind
+			column[i]=templatecolumn;
+
+			// actually...
+			// if we're getting the output bind variables of a
+			// stored procedure that returns dates, then use
 			// the datetime type instead...
 			if (resultstype==CS_PARAM_RESULT &&
 				outbindtype[i]==CS_DATETIME_TYPE) {
 				column[i].datatype=CS_DATETIME_TYPE;
 				column[i].format=CS_FMT_UNUSED;
 				column[i].maxlength=sizeof(CS_DATETIME);
-			} else {
-				column[i].datatype=CS_CHAR_TYPE;
-				column[i].format=CS_FMT_NULLTERM;
-				column[i].maxlength=
-					sapconn->maxitembuffersize;
 			}
-			column[i].scale=CS_UNUSED;
-			column[i].precision=CS_UNUSED;
-			column[i].status=CS_UNUSED;
-			column[i].count=sapconn->fetchatonce;
-			column[i].usertype=CS_UNUSED;
-			column[i].locale=NULL;
 	
 			// bind the columns for the fetches
-			if (ct_bind(cmd,i+1,&column[i],(CS_VOID *)data[i],
-				datalength[i],nullindicator[i])!=CS_SUCCEED) {
+			if (ct_bind(cmd,i+1,
+					&column[i],
+					(CS_VOID *)data[i],
+					datalength[i],
+					nullindicator[i])!=CS_SUCCEED) {
 				break;
 			}
 
 			// describe the columns
 			if (conn->cont->getSendColumnInfo()==SEND_COLUMN_INFO) {
-				if (ct_describe(cmd,i+1,&column[i])!=
-								CS_SUCCEED) {
+				if (ct_describe(cmd,i+1,
+						&column[i])!=CS_SUCCEED) {
 					break;
 				}
 			}
@@ -1400,8 +1420,10 @@ bool sapcursor::executeQuery(const char *query, uint32_t length) {
 	// bind variables...
 	if (resultstype==CS_PARAM_RESULT) {
 
-		if (ct_fetch(cmd,CS_UNUSED,CS_UNUSED,CS_UNUSED,
-				&rowsread)!=CS_SUCCEED && !rowsread) {
+		if (ct_fetch(cmd,CS_UNUSED,
+					CS_UNUSED,
+					CS_UNUSED,
+					&rowsread)!=CS_SUCCEED || !rowsread) {
 			return false;
 		}
 		
@@ -1418,11 +1440,13 @@ bool sapcursor::executeQuery(const char *query, uint32_t length) {
 					length=datalength[i][0];
 				}
 				bytestring::copy(outbindstrings[i],
-						data[i],length);
+							data[i],length);
 			} else if (outbindtype[i]==CS_INT_TYPE) {
-				*outbindints[i]=charstring::toInteger(data[i]);
+				*outbindints[i]=
+					charstring::toInteger(data[i]);
 			} else if (outbindtype[i]==CS_FLOAT_TYPE) {
-				*outbinddoubles[i]=charstring::toFloat(data[i]);
+				*outbinddoubles[i]=
+					charstring::toFloatC(data[i]);
 			} else if (outbindtype[i]==CS_DATETIME_TYPE) {
 
 				// convert to a CS_DATEREC
@@ -1441,6 +1465,7 @@ bool sapcursor::executeQuery(const char *query, uint32_t length) {
 				*(db->second)=dr.datesecond;
 				*(db->microsecond)=dr.datesecfrac;
 				*(db->tz)=NULL;
+				*(db->isnegative)=false;
 			}
 		}
 
@@ -1449,10 +1474,7 @@ bool sapcursor::executeQuery(const char *query, uint32_t length) {
 	}
 
 	// return success only if no error was generated
-	if (sapconn->errorstring.getStringLength()) {
-		return false;
-	}
-	return true;
+	return (!sapconn->errorcode);
 }
 
 uint64_t sapcursor::affectedRows() {
@@ -1536,8 +1558,9 @@ uint16_t sapcursor::getColumnType(uint32_t col) {
 
 uint32_t sapcursor::getColumnLength(uint32_t col) {
 	// limit the column size
-	if (column[col].maxlength>sapconn->maxitembuffersize) {
-		column[col].maxlength=sapconn->maxitembuffersize;
+	uint32_t	maxfieldlength=conn->cont->getMaxFieldLength();
+	if ((uint32_t)column[col].maxlength>maxfieldlength) {
+		column[col].maxlength=maxfieldlength;
 	}
 	return column[col].maxlength;
 }
@@ -1577,24 +1600,34 @@ bool sapcursor::noRowsToReturn() {
 			resultstype!=CS_COMPUTE_RESULT);
 }
 
-bool sapcursor::skipRow() {
-	if (fetchRow()) {
+bool sapcursor::skipRow(bool *error) {
+	if (fetchRow(error)) {
 		row++;
 		return true;
 	}
 	return false;
 }
 
-bool sapcursor::fetchRow() {
-	if (row==sapconn->fetchatonce) {
+bool sapcursor::fetchRow(bool *error) {
+
+	*error=false;
+	// FIXME: set error if an error occurs
+
+	if (row==(CS_INT)conn->cont->getFetchAtOnce()) {
 		row=0;
 	}
 	if (row>0 && row==maxrow) {
 		return false;
 	}
 	if (!row) {
-		if (ct_fetch(cmd,CS_UNUSED,CS_UNUSED,CS_UNUSED,
-				&rowsread)!=CS_SUCCEED || !rowsread) {
+		CS_RETCODE	result=ct_fetch(cmd,CS_UNUSED,
+							CS_UNUSED,
+							CS_UNUSED,
+							&rowsread);
+		if (result!=CS_SUCCEED || !rowsread) {
+			if (result==CS_FAIL || result==CS_ROW_FAIL) {
+				*error=true;
+			}
 			return false;
 		}
 		maxrow=rowsread;
@@ -1614,7 +1647,7 @@ void sapcursor::getField(uint32_t col,
 	}
 
 	// handle normal datatypes
-	*field=&data[col][row*sapconn->maxitembuffersize];
+	*field=&data[col][row*conn->cont->getMaxFieldLength()];
 	*fieldlength=datalength[col][row]-1;
 }
 
@@ -1641,8 +1674,7 @@ void sapcursor::discardResults() {
 		do {
 			if (ct_cancel(NULL,cmd,CS_CANCEL_CURRENT)==CS_FAIL) {
 				sapconn->liveconnection=false;
-				// FIXME: call ct_close(CS_FORCE_CLOSE)
-				// maybe return false
+				// FIXME: call ct_close(CS_FORCE_CLOSE)?
 			}
 			results=ct_results(cmd,&resultstype);
 		} while (results==CS_SUCCEED);
@@ -1651,22 +1683,22 @@ void sapcursor::discardResults() {
 	if (results==CS_FAIL) {
 		if (ct_cancel(NULL,cmd,CS_CANCEL_ALL)==CS_FAIL) {
 			sapconn->liveconnection=false;
-			// FIXME: call ct_close(CS_FORCE_CLOSE)
-			// maybe return false
+			// FIXME: call ct_close(CS_FORCE_CLOSE)?
 		}
 	}
 
-	if (sapconn->maxselectlistsize==-1) {
+	if (!conn->cont->getMaxColumnCount()) {
 		deallocateResultSetBuffers();
 	}
 }
 
 
 void sapcursor::discardCursor() {
-
 	if (cmd==cursorcmd) {
-		if (ct_cursor(cursorcmd,CS_CURSOR_CLOSE,NULL,CS_UNUSED,
-				NULL,CS_UNUSED,CS_DEALLOC)==CS_SUCCEED) {
+		if (ct_cursor(cursorcmd,CS_CURSOR_CLOSE,
+					NULL,CS_UNUSED,
+					NULL,CS_UNUSED,
+					CS_DEALLOC)==CS_SUCCEED) {
 			if (ct_send(cursorcmd)==CS_SUCCEED) {
 				results=ct_results(cmd,&resultstype);
 				discardResults();
@@ -1677,12 +1709,13 @@ void sapcursor::discardCursor() {
 
 CS_RETCODE sapconnection::csMessageCallback(CS_CONTEXT *ctxt, 
 						CS_CLIENTMSG *msgp) {
-	if (errorstring.getStringLength()) {
+	if (errorcode) {
 		return CS_SUCCEED;
 	}
 
 	errorcode=msgp->msgnumber;
 
+	errorstring.clear();
 	errorstring.append("Client Library error: ")->append(msgp->msgstring);
 	errorstring.append(" severity(")->
 		append((int32_t)CS_SEVERITY(msgp->msgnumber))->append(")");
@@ -1722,12 +1755,13 @@ CS_RETCODE sapconnection::csMessageCallback(CS_CONTEXT *ctxt,
 CS_RETCODE sapconnection::clientMessageCallback(CS_CONTEXT *ctxt, 
 						CS_CONNECTION *cnn,
 						CS_CLIENTMSG *msgp) {
-	if (errorstring.getStringLength()) {
+	if (errorcode) {
 		return CS_SUCCEED;
 	}
 
 	errorcode=msgp->msgnumber;
 
+	errorstring.clear();
 	errorstring.append("Client Library error: ")->append(msgp->msgstring);
 	errorstring.append(" severity(")->
 		append((int32_t)CS_SEVERITY(msgp->msgnumber))->append(")");
@@ -1776,12 +1810,13 @@ CS_RETCODE sapconnection::serverMessageCallback(CS_CONTEXT *ctxt,
 		return CS_SUCCEED;
 	}
 
-	if (errorstring.getStringLength()) {
+	if (errorcode) {
 		return CS_SUCCEED;
 	}
 
 	errorcode=msgp->msgnumber;
 
+	errorstring.clear();
 	errorstring.append("Server message: ")->append(msgp->text);
 	errorstring.append(" severity(")->
 		append((int32_t)CS_SEVERITY(msgp->msgnumber))->append(")");
