@@ -1,4 +1,4 @@
-// Copyright (c) 1999-2015  David Muse
+// Copyright (c) 1999-2018 David Muse
 // See the file COPYING for more information
 
 #include <sqlrelay/sqlrserver.h>
@@ -6,6 +6,7 @@
 #include <rudiments/sys.h>
 
 #include <datatypes.h>
+#include <defines.h>
 #include <config.h>
 
 extern "C" {
@@ -47,13 +48,17 @@ class SQLRSERVER_DLLSPEC sqliteconnection : public sqlrserverconnection {
 		const char	*dbVersion();
 		const char	*dbHostName();
 		const char	*getDatabaseListQuery(bool wild);
-		const char	*getTableListQuery(bool wild);
+		const char	*getTableListQuery(bool wild,
+						uint16_t objecttypes);
 		const char	*getColumnListQuery(
 						const char *table, bool wild);
 		#ifdef SQLITE_TRANSACTIONAL
 		const char	*setIsolationLevelQuery();
 		#endif
+		bool		selectDatabase(const char *database);
+		char		*getCurrentDatabase();
 		bool		getLastInsertId(uint64_t *id);
+		const char	*noopQuery();
 		#ifdef SQLITE3
 		char		*duplicate(const char *str);
 		#endif
@@ -70,7 +75,7 @@ class SQLRSERVER_DLLSPEC sqliteconnection : public sqlrserverconnection {
 
 		void		clearErrors();
 
-		const char	*db;
+		char		*db;
 
 		const char	*identity;
 
@@ -131,10 +136,11 @@ class SQLRSERVER_DLLSPEC sqlitecursor : public sqlrservercursor {
 		const char	*getColumnName(uint32_t col);
 		#ifdef HAVE_SQLITE3_STMT
 		uint16_t	getColumnType(uint32_t col);
+		const char	*getColumnTable(uint32_t col);
 		#endif
 		bool		noRowsToReturn();
-		bool		skipRow();
-		bool		fetchRow();
+		bool		skipRow(bool *error);
+		bool		fetchRow(bool *error);
 		void		getField(uint32_t col,
 					const char **field,
 					uint64_t *fieldlength,
@@ -148,6 +154,7 @@ class SQLRSERVER_DLLSPEC sqlitecursor : public sqlrservercursor {
 		bool		lastinsertrowid;
 
 		#ifdef HAVE_SQLITE3_STMT
+		char		**columntables;
 		int		*columntypes;
 		sqlite3_stmt	*stmt;
 		bool		justexecuted;
@@ -170,16 +177,22 @@ sqliteconnection::sqliteconnection(sqlrservercontroller *cont) :
 	errmesg=NULL;
 	errcode=0;
 	hostname=NULL;
+	db=NULL;
 }
 
 sqliteconnection::~sqliteconnection() {
 	clearErrors();
 	delete[] hostname;
+	delete[] db;
 }
 
 void sqliteconnection::handleConnectString() {
-	db=cont->getConnectStringValue("db");
+	db=charstring::duplicate(cont->getConnectStringValue("db"));
 	identity=cont->getConnectStringValue("identity");
+
+	cont->setFetchAtOnce(1);
+	cont->setMaxColumnCount(0);
+	cont->setMaxFieldLength(0);
 }
 
 bool sqliteconnection::logIn(const char **error, const char **warning) {
@@ -249,11 +262,16 @@ const char *sqliteconnection::getDatabaseListQuery(bool wild) {
 	return "select '',NULL";
 }
 
-const char *sqliteconnection::getTableListQuery(bool wild) {
+const char *sqliteconnection::getTableListQuery(bool wild,
+						uint16_t objecttypes) {
 	return (wild)?
 		"select "
-		"	tbl_name, "
-		"	NULL "
+		"	NULL as table_cat, "
+		"	NULL as table_schem, "
+		"	tbl_name as table_name, "
+		"	'TABLE' as table_type, "
+		"	NULL as remarks, "
+		"	NULL as extra "
 		"from "
 		"(select "
 		"	tbl_name "
@@ -261,23 +279,25 @@ const char *sqliteconnection::getTableListQuery(bool wild) {
 		"	sqlite_master "
 		"where "
 		"	type in ('table','view') "
-		"	and "
-		"	tbl_name like '%s' "
 		"union all "
 		"select "
 		"	tbl_name "
 		"from "
 		"	sqlite_temp_master "
 		"where "
-		"	type in ('table','view') "
-		"	and "
-		"	tbl_name like '%s') "
+		"	type in ('table','view')) "
+		"where "
+		"	tbl_name like '%s' "
 		"order by "
 		"	tbl_name":
 
 		"select "
-		"	tbl_name, "
-		"	NULL "
+		"	NULL as table_cat, "
+		"	NULL as table_schem, "
+		"	tbl_name as table_name, "
+		"	'TABLE' as table_type, "
+		"	NULL as remarks, "
+		"	NULL as extra "
 		"from "
 		"(select "
 		"	tbl_name "
@@ -317,11 +337,54 @@ const char *sqliteconnection::setIsolationLevelQuery() {
 }
 #endif
 
+bool sqliteconnection::selectDatabase(const char *database) {
+
+	// keep track of the original db and host
+	char	*originaldb=db;
+
+	// reset the db/host
+	db=charstring::duplicate(database);
+
+	cont->clearError();
+
+	// log out and log back in to the specified database
+	logOut();
+	const char	*error;
+	const char	*warning;
+	if (!logIn(&error,&warning)) {
+
+		// Set the error.  We can't get the message from sqlite3_errmsg,
+		// because sqliteptr will be NULL.  So, we'll just return the
+		// generic SQL Relay error for these kinds of things.
+		cont->setError(SQLR_ERROR_DBNOTFOUND_STRING,
+				SQLR_ERROR_DBNOTFOUND,true);
+
+		// log back in to the original database, we'll assume that works
+		delete[] db;
+		db=originaldb;
+		logOut();
+		logIn(&error,&warning);
+		return false;
+	}
+
+	// clean up
+	delete[] originaldb;
+	return true;
+}
+
+char *sqliteconnection::getCurrentDatabase() {
+	return charstring::duplicate(db);
+}
+
 bool sqliteconnection::getLastInsertId(uint64_t *id) {
 	*id=sqlite3_last_insert_rowid(sqliteptr);
 	return true;
 }
 
+const char *sqliteconnection::noopQuery() {
+	return "pragma noop";
+}
+
 #ifndef SQLITE_TRANSACTIONAL
 bool sqliteconnection::isTransactional() {
 	return false;
@@ -374,6 +437,7 @@ sqlitecursor::sqlitecursor(sqlrserverconnection *conn, uint16_t id) :
 	nrow=0;
 	lastinsertrowid=false;
 	#ifdef HAVE_SQLITE3_STMT
+	columntables=NULL;
 	columntypes=NULL;
 	stmt=NULL;
 	justexecuted=false;
@@ -385,8 +449,8 @@ sqlitecursor::sqlitecursor(sqlrserverconnection *conn, uint16_t id) :
 
 	sqliteconn=(sqliteconnection *)conn;
 
-	selectlastinsertrowid.compile("^\\s*(select|SELECT)\\s+"
-				"(last|LAST)\\s+(insert|INSERT)\\s+"
+	selectlastinsertrowid.setPattern("^[ 	\r\n]*(select|SELECT)[ 	\r\n]+"
+				"(last|LAST)[ 	\r\n]+(insert|INSERT)[ 	\r\n]+"
 				"(rowid|ROWID)");
 	selectlastinsertrowid.study();
 }
@@ -402,6 +466,14 @@ sqlitecursor::~sqlitecursor() {
 	}
 
 	#ifdef HAVE_SQLITE3_STMT
+	// clean up old column tables
+	if (columntables) {
+		for (int i=0; i<ncolumn; i++) {
+			delete[] columntables[i];
+		}
+		delete[] columntables;
+	}
+
 	// clean up old column types
 	if (columntypes) {
 		delete[] columntypes;
@@ -426,6 +498,12 @@ bool sqlitecursor::supportsNativeBinds(const char *query, uint32_t length) {
 #ifdef HAVE_SQLITE3_STMT
 bool sqlitecursor::prepareQuery(const char *query, uint32_t length) {
 
+	// reinit justexecuted flag
+	justexecuted=false;
+
+	// initialize column count
+	ncolumn=0;
+
 	// clear any errors
 	sqliteconn->clearErrors();
 
@@ -587,20 +665,30 @@ bool sqlitecursor::executeQuery(const char *query, uint32_t length) {
 	// cache off the columns so they can be returned later if the result
 	// set is suspended/resumed
 	#ifdef HAVE_SQLITE3_STMT
-	columnnames=new char * [ncolumn];
+	columntables=new char *[ncolumn];
+	columnnames=new char *[ncolumn];
 	columntypes=new int[ncolumn];
 	if (lastinsertrowid) {
+		columntables[0]=charstring::duplicate("");
 		columnnames[0]=charstring::duplicate("LASTINSERTROWID");
 		columntypes[0]=INTEGER_DATATYPE;
 	} else {
 		for (int i=0; i<ncolumn; i++) {
+			columntables[i]=
+				charstring::duplicate(
+					#ifdef HAVE_SQLITE3_COLUMN_TABLE_NAME
+					sqlite3_column_table_name(stmt,i)
+					#else
+					""
+					#endif
+					);
 			columnnames[i]=charstring::duplicate(
-						sqlite3_column_name(stmt,i));
+					sqlite3_column_name(stmt,i));
 			columntypes[i]=sqlite3_column_type(stmt,i);
 		}
 	}
 	#else
-	columnnames=new char * [ncolumn];
+	columnnames=new char *[ncolumn];
 	for (int i=0; i<ncolumn; i++) {
 		columnnames[i]=charstring::duplicate(result[i]);
 	}
@@ -625,6 +713,15 @@ int sqlitecursor::runQuery(const char *query) {
 	}
 
 	#ifdef HAVE_SQLITE3_STMT
+	// clean up old column tables
+	if (columntables) {
+		for (int i=0; i<ncolumn; i++) {
+			delete[] columntables[i];
+		}
+		delete[] columntables;
+		columntables=NULL;
+	}
+
 	// clean up old column types
 	if (columntypes) {
 		delete[] columntypes;
@@ -633,9 +730,9 @@ int sqlitecursor::runQuery(const char *query) {
 	#endif
 
 	// reset counters and flags
-	ncolumn=0;
 	nrow=0;
 	#ifndef HAVE_SQLITE3_STMT
+	ncolumn=0;
 	rowindex=0;
 	#endif
 	lastinsertrowid=false;
@@ -643,6 +740,9 @@ int sqlitecursor::runQuery(const char *query) {
 	// handle special case of selecting the last row id
 	if (selectlastinsertrowid.match(query)) {
 		lastinsertrowid=true;
+		#ifdef HAVE_SQLITE3_STMT
+		justexecuted=true;
+		#endif
 		selectLastInsertRowId();
 		return SQLITE_OK;
 	}
@@ -705,7 +805,7 @@ void sqlitecursor::selectLastInsertRowId() {
 					(int64_t)sqlite3_last_insert_rowid(
 							sqliteconn->sqliteptr));
 	#else
-	result=new char * [2];
+	result=new char *[2];
 	result[0]=charstring::duplicate("LASTINSERTROWID");
 	result[1]=charstring::parseNumber((int64_t)sqlite3_last_insert_rowid(
 							sqliteconn->sqliteptr));
@@ -741,6 +841,10 @@ const char *sqlitecursor::getColumnName(uint32_t col) {
 }
 
 #ifdef HAVE_SQLITE3_STMT
+const char *sqlitecursor::getColumnTable(uint32_t col) {
+	return columntables[col];
+}
+
 uint16_t sqlitecursor::getColumnType(uint32_t col) {
 	switch (columntypes[col]) {
 		case SQLITE_INTEGER:
@@ -763,16 +867,19 @@ bool sqlitecursor::noRowsToReturn() {
 	return (!nrow);
 }
 
-bool sqlitecursor::skipRow() {
+bool sqlitecursor::skipRow(bool *error) {
 	#ifdef HAVE_SQLITE3_STMT
-	return fetchRow();
+	return fetchRow(error);
 	#else
 	rowindex=rowindex+ncolumn;
 	return true;
 	#endif
 }
 
-bool sqlitecursor::fetchRow() {
+bool sqlitecursor::fetchRow(bool *error) {
+
+	*error=false;
+
 	#ifdef HAVE_SQLITE3_STMT
 	if (justexecuted) {
 		justexecuted=false;
@@ -781,7 +888,11 @@ bool sqlitecursor::fetchRow() {
 	if (lastinsertrowid) {
 		return false;
 	}
-	return (sqlite3_step(stmt)==SQLITE_ROW);
+	int	result=sqlite3_step(stmt);
+	if (result==SQLITE_ERROR) {
+		*error=true;
+	}
+	return (result==SQLITE_ROW);
 	#else
 	// have to check for nrow+1 because the 
 	// first row is actually the column names
