@@ -1,4 +1,4 @@
-// Copyright (c) 2015  David Muse
+// Copyright (c) 1999-2018 David Muse
 // See the file COPYING for more information
 
 #include <sqlrelay/sqlrserver.h>
@@ -8,9 +8,9 @@
 
 class SQLRSERVER_DLLSPEC sqlrfilter_regex : public sqlrfilter {
 	public:
-			sqlrfilter_regex(sqlrfilters *sqlrfs,
-					xmldomnode *parameters,
-					bool debug);
+			sqlrfilter_regex(sqlrservercontroller *cont,
+						sqlrfilters *fs,
+						domnode *parameters);
 		bool	run(sqlrserverconnection *sqlrcon,
 					sqlrservercursor *sqlrcur,
 					const char *query);
@@ -19,22 +19,25 @@ class SQLRSERVER_DLLSPEC sqlrfilter_regex : public sqlrfilter {
 		const char		*pattern;
 
 		bool	enabled;
+
+		bool	debug;
 };
 
-sqlrfilter_regex::sqlrfilter_regex(sqlrfilters *sqlrfs,
-					xmldomnode *parameters,
-					bool debug) :
-					sqlrfilter(sqlrfs,parameters,debug) {
+sqlrfilter_regex::sqlrfilter_regex(sqlrservercontroller *cont,
+						sqlrfilters *fs,
+						domnode *parameters) :
+						sqlrfilter(cont,fs,parameters) {
 	debugFunction();
 
-	enabled=charstring::compareIgnoringCase(
-			parameters->getAttributeValue("enabled"),"no");
+	debug=cont->getConfig()->getDebugFilters();
+
+	enabled=!charstring::isNo(parameters->getAttributeValue("enabled"));
 	if (!enabled) {
 		return;
 	}
 
 	pattern=parameters->getAttributeValue("pattern");
-	re.compile(pattern);
+	re.setPattern(pattern);
 	re.study();
 }
 
@@ -58,9 +61,10 @@ bool sqlrfilter_regex::run(sqlrserverconnection *sqlrcon,
 }
 
 extern "C" {
-	SQLRSERVER_DLLSPEC sqlrfilter *new_sqlrfilter_regex(sqlrfilters *sqlrfs,
-							xmldomnode *parameters,
-							bool debug) {
-		return new sqlrfilter_regex(sqlrfs,parameters,debug);
+	SQLRSERVER_DLLSPEC sqlrfilter *new_sqlrfilter_regex(
+						sqlrservercontroller *cont,
+						sqlrfilters *fs,
+						domnode *parameters) {
+		return new sqlrfilter_regex(cont,fs,parameters);
 	}
 }
