@@ -1,4 +1,4 @@
-// Copyright (c) 2012  David Muse
+// Copyright (c) 1999-2018 David Muse
 // See the file COPYING for more information
 
 #include <sqlrelay/sqlrserver.h>
@@ -7,13 +7,13 @@
 
 class SQLRSERVER_DLLSPEC sqlrpwdenc_crypt : public sqlrpwdenc {
 	public:
-			sqlrpwdenc_crypt(xmldomnode *parameters);
+			sqlrpwdenc_crypt(domnode *parameters, bool debug);
 		bool	oneWay();
 		char	*encrypt(const char *value);
 };
 
-sqlrpwdenc_crypt::sqlrpwdenc_crypt(xmldomnode *parameters) :
-					sqlrpwdenc(parameters) {
+sqlrpwdenc_crypt::sqlrpwdenc_crypt(domnode *parameters, bool debug) :
+						sqlrpwdenc(parameters,debug) {
 }
 
 bool sqlrpwdenc_crypt::oneWay() {
@@ -24,8 +24,8 @@ char *sqlrpwdenc_crypt::encrypt(const char *value) {
 
 	// the first two characters of the result string
 	// are the salt, so don't include them, if possible
-	char	*encrypted=crypt::encrypt(value,
-					parameters->getAttributeValue("salt"));
+	char	*encrypted=crypt::encrypt(value,getParameters()->
+						getAttributeValue("salt"));
 	if (charstring::length(encrypted)<2) {
 		return encrypted;
 	}
@@ -36,7 +36,8 @@ char *sqlrpwdenc_crypt::encrypt(const char *value) {
 
 extern "C" {
 	SQLRSERVER_DLLSPEC sqlrpwdenc *new_sqlrpwdenc_crypt(
-						xmldomnode *parameters) {
-		return new sqlrpwdenc_crypt(parameters);
+						domnode *parameters,
+						bool debug) {
+		return new sqlrpwdenc_crypt(parameters,debug);
 	}
 }
