@@ -1,4 +1,4 @@
-// Copyright (c) 2001  David Muse
+// Copyright (c) 1999-2018 David Muse
 // See the file COPYING for more information.
 
 #include <sqlrelay/sqlrclient.h>
@@ -111,7 +111,7 @@ int	main(int argc, char **argv) {
 	uint32_t	*fieldlens;
 
 	// instantiation
-	con=new sqlrconnection("sqlrserver",9000,"/tmp/test.socket",
+	con=new sqlrconnection("sqlrelay",9000,"/tmp/test.socket",
 							"test","test",0,1);
 	cur=new sqlrcursor(con);
 
@@ -147,14 +147,14 @@ int	main(int argc, char **argv) {
 	cur->inputBind("1",2);
 	cur->inputBind("2","testchar2");
 	cur->inputBind("3","testvarchar2");
-	cur->inputBind("4",2,1,1,0,0,0,0,NULL);
+	cur->inputBind("4",2,1,1,0,0,0,0,NULL,false);
 	cur->inputBind("5","testlong2");
 	checkSuccess(cur->executeQuery(),1);
 	cur->clearBinds();
 	cur->inputBind("1",3);
 	cur->inputBind("2","testchar3");
 	cur->inputBind("3","testvarchar3");
-	cur->inputBind("4",3,1,1,0,0,0,0,NULL);
+	cur->inputBind("4",3,1,1,0,0,0,0,NULL,false);
 	cur->inputBind("5","testlong3");
 	checkSuccess(cur->executeQuery(),1);
 	stdoutput.printf("\n");
@@ -170,14 +170,14 @@ int	main(int argc, char **argv) {
 	cur->inputBind("var1",5);
 	cur->inputBind("var2","testchar5");
 	cur->inputBind("var3","testvarchar5");
-	cur->inputBind("var4",5,1,1,0,0,0,0,NULL);
+	cur->inputBind("var4",5,1,1,0,0,0,0,NULL,false);
 	cur->inputBind("var5","testlong5");
 	checkSuccess(cur->executeQuery(),1);
 	cur->clearBinds();
 	cur->inputBind("var1",6);
 	cur->inputBind("var2","testchar6");
 	cur->inputBind("var3","testvarchar6");
-	cur->inputBind("var4",6,1,1,0,0,0,0,NULL);
+	cur->inputBind("var4",6,1,1,0,0,0,0,NULL,false);
 	cur->inputBind("var5","testlong6");
 	checkSuccess(cur->executeQuery(),1);
 	stdoutput.printf("\n");
@@ -193,7 +193,7 @@ int	main(int argc, char **argv) {
 	cur->inputBind("var1",8);
 	cur->inputBind("var2","testchar8");
 	cur->inputBind("var3","testvarchar8");
-	cur->inputBind("var4",8,1,1,0,0,0,0,NULL);
+	cur->inputBind("var4",8,1,1,0,0,0,0,NULL,false);
 	cur->inputBind("var5","testlong8");
 	cur->inputBind("var9","junkvalue");
 	cur->validateBinds();
@@ -218,8 +218,10 @@ int	main(int argc, char **argv) {
 	int16_t	second=0;
 	int32_t	microsecond=0;
 	const char	*tz=NULL;
+	bool	isnegative=false;
 	cur->getOutputBindDate("datevar",&year,&month,&day,
-					&hour,&minute,&second,&microsecond,&tz);
+					&hour,&minute,&second,&microsecond,&tz,
+					&isnegative);
 	checkSuccess(numvar,1);
 	checkSuccess(stringvar,"hello");
 	checkSuccess(floatvar,2.5);
@@ -244,7 +246,8 @@ int	main(int argc, char **argv) {
 	stringvar=cur->getOutputBindString("2");
 	floatvar=cur->getOutputBindDouble("3");
 	cur->getOutputBindDate("4",&year,&month,&day,
-					&hour,&minute,&second,&microsecond,&tz);
+					&hour,&minute,&second,&microsecond,&tz,
+					&isnegative);
 	checkSuccess(numvar,1);
 	checkSuccess(stringvar,"hello");
 	checkSuccess(floatvar,2.5);
@@ -271,7 +274,8 @@ int	main(int argc, char **argv) {
 	stringvar=cur->getOutputBindString("stringvar");
 	floatvar=cur->getOutputBindDouble("floatvar");
 	cur->getOutputBindDate("datevar",&year,&month,&day,
-					&hour,&minute,&second,&microsecond,&tz);
+					&hour,&minute,&second,&microsecond,&tz,
+					&isnegative);
 	checkSuccess(numvar,1);
 	checkSuccess(stringvar,"hello");
 	checkSuccess(floatvar,2.5);
@@ -391,31 +395,31 @@ int	main(int argc, char **argv) {
 	stdoutput.printf("\n");
 
 	stdoutput.printf("FIELDS BY NAME: \n");
-	checkSuccess(cur->getField(0,"testnumber"),"1");
-	checkSuccess(cur->getField(0,"testchar"),"testchar1                               ");
-	checkSuccess(cur->getField(0,"testvarchar"),"testvarchar1");
-	checkSuccess(cur->getField(0,"testdate"),"01-JAN-01");
-	checkSuccess(cur->getField(0,"testlong"),"testlong1");
+	checkSuccess(cur->getField(0,"TESTNUMBER"),"1");
+	checkSuccess(cur->getField(0,"TESTCHAR"),"testchar1                               ");
+	checkSuccess(cur->getField(0,"TESTVARCHAR"),"testvarchar1");
+	checkSuccess(cur->getField(0,"TESTDATE"),"01-JAN-01");
+	checkSuccess(cur->getField(0,"TESTLONG"),"testlong1");
 	stdoutput.printf("\n");
-	checkSuccess(cur->getField(7,"testnumber"),"8");
-	checkSuccess(cur->getField(7,"testchar"),"testchar8                               ");
-	checkSuccess(cur->getField(7,"testvarchar"),"testvarchar8");
-	checkSuccess(cur->getField(7,"testdate"),"01-JAN-08");
-	checkSuccess(cur->getField(7,"testlong"),"testlong8");
+	checkSuccess(cur->getField(7,"TESTNUMBER"),"8");
+	checkSuccess(cur->getField(7,"TESTCHAR"),"testchar8                               ");
+	checkSuccess(cur->getField(7,"TESTVARCHAR"),"testvarchar8");
+	checkSuccess(cur->getField(7,"TESTDATE"),"01-JAN-08");
+	checkSuccess(cur->getField(7,"TESTLONG"),"testlong8");
 	stdoutput.printf("\n");
 
 	stdoutput.printf("FIELD LENGTHS BY NAME: \n");
-	checkSuccess(cur->getFieldLength(0,"testnumber"),1);
-	checkSuccess(cur->getFieldLength(0,"testchar"),40);
-	checkSuccess(cur->getFieldLength(0,"testvarchar"),12);
-	checkSuccess(cur->getFieldLength(0,"testdate"),9);
-	checkSuccess(cur->getFieldLength(0,"testlong"),9);
+	checkSuccess(cur->getFieldLength(0,"TESTNUMBER"),1);
+	checkSuccess(cur->getFieldLength(0,"TESTCHAR"),40);
+	checkSuccess(cur->getFieldLength(0,"TESTVARCHAR"),12);
+	checkSuccess(cur->getFieldLength(0,"TESTDATE"),9);
+	checkSuccess(cur->getFieldLength(0,"TESTLONG"),9);
 	stdoutput.printf("\n");
-	checkSuccess(cur->getFieldLength(7,"testnumber"),1);
-	checkSuccess(cur->getFieldLength(7,"testchar"),40);
-	checkSuccess(cur->getFieldLength(7,"testvarchar"),12);
-	checkSuccess(cur->getFieldLength(7,"testdate"),9);
-	checkSuccess(cur->getFieldLength(7,"testlong"),9);
+	checkSuccess(cur->getFieldLength(7,"TESTNUMBER"),1);
+	checkSuccess(cur->getFieldLength(7,"TESTCHAR"),40);
+	checkSuccess(cur->getFieldLength(7,"TESTVARCHAR"),12);
+	checkSuccess(cur->getFieldLength(7,"TESTDATE"),9);
+	checkSuccess(cur->getFieldLength(7,"TESTLONG"),9);
 	stdoutput.printf("\n");
 
 	stdoutput.printf("FIELDS BY ARRAY: \n");
@@ -761,7 +765,7 @@ int	main(int argc, char **argv) {
 	cur->inputBind("testval",testval);
 	checkSuccess(cur->executeQuery(),1);
 	cur->sendQuery("select testval from testtable2");
-	checkSuccess(testval,cur->getField(0,"testval"));
+	checkSuccess(testval,cur->getField(0,"TESTVAL"));
 	char	query[2000+25];
 	charstring::printf(query,sizeof(query),
 				"begin :bindval:='%s'; end;",testval);
@@ -780,7 +784,7 @@ int	main(int argc, char **argv) {
 	cur->inputBind("testval",-1);
 	checkSuccess(cur->executeQuery(),1);
 	cur->sendQuery("select testval from testtable2");
-	checkSuccess(cur->getField(0,"testval"),"-1");
+	checkSuccess(cur->getField(0,"TESTVAL"),"-1");
 	cur->sendQuery("drop table testtable2");
 	stdoutput.printf("\n");
 
@@ -920,4 +924,6 @@ int	main(int argc, char **argv) {
 
 	delete cur;
 	delete con;
+
+	return 0;
 }
