@@ -1,4 +1,4 @@
-// Copyright (c) 2001  David Muse
+// Copyright (c) 1999-2018 David Muse
 // See the file COPYING for more information.
 
 #include <sqlrelay/sqlrclient.h>
@@ -113,7 +113,7 @@ int	main(int argc, char **argv) {
 	uint32_t	*fieldlens;
 
 	// instantiation
-	con=new sqlrconnection("sqlrserver",9000,"/tmp/test.socket",
+	con=new sqlrconnection("sqlrelay",9000,"/tmp/test.socket",
 							"test","test",0,1);
 	cur=new sqlrcursor(con);
 
@@ -149,14 +149,14 @@ int	main(int argc, char **argv) {
 	cur->inputBind("1",2);
 	cur->inputBind("2","testchar2");
 	cur->inputBind("3","testvarchar2");
-	cur->inputBind("4",2002,1,1,0,0,0,0,NULL);
+	cur->inputBind("4",2002,1,1,0,0,0,0,NULL,false);
 	cur->inputBind("5","testlong2");
 	checkSuccess(cur->executeQuery(),1);
 	cur->clearBinds();
 	cur->inputBind("1",3);
 	cur->inputBind("2","testchar3");
 	cur->inputBind("3","testvarchar3");
-	cur->inputBind("4",2003,1,1,0,0,0,0,NULL);
+	cur->inputBind("4",2003,1,1,0,0,0,0,NULL,false);
 	cur->inputBind("5","testlong3");
 	checkSuccess(cur->executeQuery(),1);
 	stdoutput.printf("\n");
@@ -172,14 +172,14 @@ int	main(int argc, char **argv) {
 	cur->inputBind("var1",5);
 	cur->inputBind("var2","testchar5");
 	cur->inputBind("var3","testvarchar5");
-	cur->inputBind("var4",2005,1,1,0,0,0,0,NULL);
+	cur->inputBind("var4",2005,1,1,0,0,0,0,NULL,false);
 	cur->inputBind("var5","testlong5");
 	checkSuccess(cur->executeQuery(),1);
 	cur->clearBinds();
 	cur->inputBind("var1",6);
 	cur->inputBind("var2","testchar6");
 	cur->inputBind("var3","testvarchar6");
-	cur->inputBind("var4",2006,1,1,0,0,0,0,NULL);
+	cur->inputBind("var4",2006,1,1,0,0,0,0,NULL,false);
 	cur->inputBind("var5","testlong6");
 	checkSuccess(cur->executeQuery(),1);
 	stdoutput.printf("\n");
@@ -195,7 +195,7 @@ int	main(int argc, char **argv) {
 	cur->inputBind("var1",8);
 	cur->inputBind("var2","testchar8");
 	cur->inputBind("var3","testvarchar8");
-	cur->inputBind("var4",2008,1,1,0,0,0,0,NULL);
+	cur->inputBind("var4",2008,1,1,0,0,0,0,NULL,false);
 	cur->inputBind("var5","testlong8");
 	cur->inputBind("var9","junkvalue");
 	cur->validateBinds();
@@ -220,8 +220,10 @@ int	main(int argc, char **argv) {
 	int16_t	second=0;
 	int32_t	microsecond=0;
 	const char	*tz=NULL;
+	bool	isnegative=false;
 	cur->getOutputBindDate("datevar",&year,&month,&day,
-					&hour,&minute,&second,&microsecond,&tz);
+					&hour,&minute,&second,&microsecond,&tz,
+					&isnegative);
 	checkSuccess(numvar,1);
 	checkSuccess(stringvar,"hello");
 	checkSuccess(floatvar,2.5);
@@ -246,7 +248,8 @@ int	main(int argc, char **argv) {
 	stringvar=cur->getOutputBindString("2");
 	floatvar=cur->getOutputBindDouble("3");
 	cur->getOutputBindDate("4",&year,&month,&day,
-					&hour,&minute,&second,&microsecond,&tz);
+					&hour,&minute,&second,&microsecond,&tz,
+					&isnegative);
 	checkSuccess(numvar,1);
 	checkSuccess(stringvar,"hello");
 	checkSuccess(floatvar,2.5);
@@ -273,7 +276,8 @@ int	main(int argc, char **argv) {
 	stringvar=cur->getOutputBindString("stringvar");
 	floatvar=cur->getOutputBindDouble("floatvar");
 	cur->getOutputBindDate("datevar",&year,&month,&day,
-					&hour,&minute,&second,&microsecond,&tz);
+					&hour,&minute,&second,&microsecond,&tz,
+					&isnegative);
 	checkSuccess(numvar,1);
 	checkSuccess(stringvar,"hello");
 	checkSuccess(floatvar,2.5);
@@ -311,41 +315,41 @@ int	main(int argc, char **argv) {
 
 	stdoutput.printf("COLUMN TYPES: \n");
 	checkSuccess(cur->getColumnType((uint32_t)0),"NUMBER");
-	checkSuccess(cur->getColumnType("testnumber"),"NUMBER");
+	checkSuccess(cur->getColumnType("TESTNUMBER"),"NUMBER");
 	checkSuccess(cur->getColumnType(1),"CHAR");
-	checkSuccess(cur->getColumnType("testchar"),"CHAR");
+	checkSuccess(cur->getColumnType("TESTCHAR"),"CHAR");
 	checkSuccess(cur->getColumnType(2),"VARCHAR2");
-	checkSuccess(cur->getColumnType("testvarchar"),"VARCHAR2");
+	checkSuccess(cur->getColumnType("TESTVARCHAR"),"VARCHAR2");
 	checkSuccess(cur->getColumnType(3),"DATE");
-	checkSuccess(cur->getColumnType("testdate"),"DATE");
+	checkSuccess(cur->getColumnType("TESTDATE"),"DATE");
 	checkSuccess(cur->getColumnType(4),"LONG");
-	checkSuccess(cur->getColumnType("testlong"),"LONG");
+	checkSuccess(cur->getColumnType("TESTLONG"),"LONG");
 	stdoutput.printf("\n");
 
 	stdoutput.printf("COLUMN LENGTH: \n");
 	checkSuccess(cur->getColumnLength((uint32_t)0),22);
-	checkSuccess(cur->getColumnLength("testnumber"),22);
+	checkSuccess(cur->getColumnLength("TESTNUMBER"),22);
 	checkSuccess(cur->getColumnLength(1),40);
-	checkSuccess(cur->getColumnLength("testchar"),40);
+	checkSuccess(cur->getColumnLength("TESTCHAR"),40);
 	checkSuccess(cur->getColumnLength(2),40);
-	checkSuccess(cur->getColumnLength("testvarchar"),40);
+	checkSuccess(cur->getColumnLength("TESTVARCHAR"),40);
 	checkSuccess(cur->getColumnLength(3),7);
-	checkSuccess(cur->getColumnLength("testdate"),7);
+	checkSuccess(cur->getColumnLength("TESTDATE"),7);
 	checkSuccess(cur->getColumnLength(4),0);
-	checkSuccess(cur->getColumnLength("testlong"),0);
+	checkSuccess(cur->getColumnLength("TESTLONG"),0);
 	stdoutput.printf("\n");
 
 	stdoutput.printf("LONGEST COLUMN: \n");
 	checkSuccess(cur->getLongest((uint32_t)0),1);
-	checkSuccess(cur->getLongest("testnumber"),1);
+	checkSuccess(cur->getLongest("TESTNUMBER"),1);
 	checkSuccess(cur->getLongest(1),40);
-	checkSuccess(cur->getLongest("testchar"),40);
+	checkSuccess(cur->getLongest("TESTCHAR"),40);
 	checkSuccess(cur->getLongest(2),12);
-	checkSuccess(cur->getLongest("testvarchar"),12);
+	checkSuccess(cur->getLongest("TESTVARCHAR"),12);
 	checkSuccess(cur->getLongest(3),9);
-	checkSuccess(cur->getLongest("testdate"),9);
+	checkSuccess(cur->getLongest("TESTDATE"),9);
 	checkSuccess(cur->getLongest(4),9);
-	checkSuccess(cur->getLongest("testlong"),9);
+	checkSuccess(cur->getLongest("TESTLONG"),9);
 	stdoutput.printf("\n");
 
 	stdoutput.printf("ROW COUNT: \n");
@@ -393,31 +397,31 @@ int	main(int argc, char **argv) {
 	stdoutput.printf("\n");
 
 	stdoutput.printf("FIELDS BY NAME: \n");
-	checkSuccess(cur->getField(0,"testnumber"),"1");
-	checkSuccess(cur->getField(0,"testchar"),"testchar1                               ");
-	checkSuccess(cur->getField(0,"testvarchar"),"testvarchar1");
-	checkSuccess(cur->getField(0,"testdate"),"01-JAN-01");
-	checkSuccess(cur->getField(0,"testlong"),"testlong1");
+	checkSuccess(cur->getField(0,"TESTNUMBER"),"1");
+	checkSuccess(cur->getField(0,"TESTCHAR"),"testchar1                               ");
+	checkSuccess(cur->getField(0,"TESTVARCHAR"),"testvarchar1");
+	checkSuccess(cur->getField(0,"TESTDATE"),"01-JAN-01");
+	checkSuccess(cur->getField(0,"TESTLONG"),"testlong1");
 	stdoutput.printf("\n");
-	checkSuccess(cur->getField(7,"testnumber"),"8");
-	checkSuccess(cur->getField(7,"testchar"),"testchar8                               ");
-	checkSuccess(cur->getField(7,"testvarchar"),"testvarchar8");
-	checkSuccess(cur->getField(7,"testdate"),"01-JAN-08");
-	checkSuccess(cur->getField(7,"testlong"),"testlong8");
+	checkSuccess(cur->getField(7,"TESTNUMBER"),"8");
+	checkSuccess(cur->getField(7,"TESTCHAR"),"testchar8                               ");
+	checkSuccess(cur->getField(7,"TESTVARCHAR"),"testvarchar8");
+	checkSuccess(cur->getField(7,"TESTDATE"),"01-JAN-08");
+	checkSuccess(cur->getField(7,"TESTLONG"),"testlong8");
 	stdoutput.printf("\n");
 
 	stdoutput.printf("FIELD LENGTHS BY NAME: \n");
-	checkSuccess(cur->getFieldLength(0,"testnumber"),1);
-	checkSuccess(cur->getFieldLength(0,"testchar"),40);
-	checkSuccess(cur->getFieldLength(0,"testvarchar"),12);
-	checkSuccess(cur->getFieldLength(0,"testdate"),9);
-	checkSuccess(cur->getFieldLength(0,"testlong"),9);
+	checkSuccess(cur->getFieldLength(0,"TESTNUMBER"),1);
+	checkSuccess(cur->getFieldLength(0,"TESTCHAR"),40);
+	checkSuccess(cur->getFieldLength(0,"TESTVARCHAR"),12);
+	checkSuccess(cur->getFieldLength(0,"TESTDATE"),9);
+	checkSuccess(cur->getFieldLength(0,"TESTLONG"),9);
 	stdoutput.printf("\n");
-	checkSuccess(cur->getFieldLength(7,"testnumber"),1);
-	checkSuccess(cur->getFieldLength(7,"testchar"),40);
-	checkSuccess(cur->getFieldLength(7,"testvarchar"),12);
-	checkSuccess(cur->getFieldLength(7,"testdate"),9);
-	checkSuccess(cur->getFieldLength(7,"testlong"),9);
+	checkSuccess(cur->getFieldLength(7,"TESTNUMBER"),1);
+	checkSuccess(cur->getFieldLength(7,"TESTCHAR"),40);
+	checkSuccess(cur->getFieldLength(7,"TESTVARCHAR"),12);
+	checkSuccess(cur->getFieldLength(7,"TESTDATE"),9);
+	checkSuccess(cur->getFieldLength(7,"TESTLONG"),9);
 	stdoutput.printf("\n");
 
 	stdoutput.printf("FIELDS BY ARRAY: \n");
@@ -733,7 +737,7 @@ int	main(int argc, char **argv) {
 	stdoutput.printf("\n");
 
 	stdoutput.printf("COMMIT AND ROLLBACK: \n");
-	secondcon=new sqlrconnection("sqlrserver",9000,"/tmp/test.socket",
+	secondcon=new sqlrconnection("sqlrelay",9000,"/tmp/test.socket",
 							"test","test",0,1);
 	secondcur=new sqlrcursor(secondcon);
 	checkSuccess(secondcur->sendQuery("select count(*) from testtable"),1);
@@ -802,7 +806,7 @@ int	main(int argc, char **argv) {
 	cur->inputBind("testval",testval);
 	checkSuccess(cur->executeQuery(),1);
 	cur->sendQuery("select testval from testtable2");
-	checkSuccess(testval,cur->getField(0,"testval"));
+	checkSuccess(testval,cur->getField(0,"TESTVAL"));
 	char	query[4000+25];
 	charstring::printf(query,sizeof(query),
 				"begin :bindval:='%s'; end;",testval);
@@ -821,7 +825,7 @@ int	main(int argc, char **argv) {
 	cur->inputBind("testval",-1);
 	checkSuccess(cur->executeQuery(),1);
 	cur->sendQuery("select testval from testtable2");
-	checkSuccess(cur->getField(0,"testval"),"-1");
+	checkSuccess(cur->getField(0,"TESTVAL"),"-1");
 	cur->sendQuery("drop table testtable2");
 	stdoutput.printf("\n");
 
@@ -961,4 +965,6 @@ int	main(int argc, char **argv) {
 
 	delete cur;
 	delete con;
+
+	return 0;
 }
