@@ -1,4 +1,4 @@
-// Copyright (c) 2001  David Muse
+// Copyright (c) 1999-2018 David Muse
 // See the file COPYING for more information.
 
 #include <sqlrelay/sqlrclient.h>
@@ -19,7 +19,7 @@ void checkSuccess(const char *value, const char *success) {
 			return;
 		} else {
 			stdoutput.printf("\"%s\"!=\"%s\"\n",value,success);
-			stdoutput.printf("failure ");
+			stdoutput.printf("failure: %s",cur->errorMessage());
 			delete cur;
 			delete con;
 			process::exit(1);
@@ -30,7 +30,7 @@ void checkSuccess(const char *value, const char *success) {
 		stdoutput.printf("success ");
 	} else {
 		stdoutput.printf("\"%s\"!=\"%s\"\n",value,success);
-		stdoutput.printf("failure ");
+		stdoutput.printf("failure: %s",cur->errorMessage());
 		delete cur;
 		delete con;
 		process::exit(1);
@@ -43,7 +43,7 @@ void checkSuccess(int value, int success) {
 		stdoutput.printf("success ");
 	} else {
 		stdoutput.printf("\"%d\"!=\"%d\"\n",value,success);
-		stdoutput.printf("failure ");
+		stdoutput.printf("failure: %s",cur->errorMessage());
 		delete cur;
 		delete con;
 		process::exit(1);
@@ -56,7 +56,7 @@ void checkSuccess(double value, double success) {
 		stdoutput.printf("success ");
 	} else {
 		stdoutput.printf("\"%f\"!=\"%f\"\n",value,success);
-		stdoutput.printf("failure ");
+		stdoutput.printf("failure: %s",cur->errorMessage());
 		delete cur;
 		delete con;
 		process::exit(1);
@@ -80,7 +80,7 @@ int	main(int argc, char **argv) {
 	uint32_t	*fieldlens;
 
 	// instantiation
-	con=new sqlrconnection("sqlrserver",9000,"/tmp/test.socket",
+	con=new sqlrconnection("sqlrelay",9000,"/tmp/test.socket",
 							"test","test",0,1);
 	cur=new sqlrcursor(con);
 
@@ -167,7 +167,6 @@ int	main(int argc, char **argv) {
 	cur->inputBind("8","08:00:00");
 	cur->inputBindClob("9","testtext8",9);
 	cur->inputBindClob("10","testbytea8",10);
-	cur->inputBind("11","junkvalue");
 	cur->validateBinds();
 	checkSuccess(cur->executeQuery(),1);
 	stdoutput.printf("\n");
@@ -283,9 +282,9 @@ int	main(int argc, char **argv) {
 	checkSuccess(cur->rowCount(),8);
 	stdoutput.printf("\n");
 
-	stdoutput.printf("TOTAL ROWS: \n");
+	/*stdoutput.printf("TOTAL ROWS: \n");
 	checkSuccess(cur->totalRows(),8);
-	stdoutput.printf("\n");
+	stdoutput.printf("\n");*/
 
 	stdoutput.printf("FIRST ROW INDEX: \n");
 	checkSuccess(cur->firstRowIndex(),0);
@@ -716,7 +715,7 @@ int	main(int argc, char **argv) {
 	stdoutput.printf("\n");
 
 	stdoutput.printf("COMMIT AND ROLLBACK: \n");
-	secondcon=new sqlrconnection("sqlrserver",9000,"/tmp/test.socket",
+	secondcon=new sqlrconnection("sqlrelay",9000,"/tmp/test.socket",
 							"test","test",0,1);
 	secondcur=new sqlrcursor(secondcon);
 	checkSuccess(secondcur->sendQuery("select count(*) from testtable"),1);
@@ -753,7 +752,11 @@ int	main(int argc, char **argv) {
 	// temporary tables
 	stdoutput.printf("TEMPORARY TABLES: \n");
 	cur->sendQuery("drop table temptable\n");
-	cur->sendQuery("create temporary table temptable (col1 int)");
+	cur->sendQuery("-- this should be skipped\n"
+			"-- so should this\n"
+			"-- and the whitespace below too\n"
+			"        				\n\n"
+			"create temporary table temptable (col1 int)");
 	checkSuccess(cur->sendQuery("insert into temptable values (1)"),1);
 	checkSuccess(cur->sendQuery("select count(*) from temptable"),1);
 	checkSuccess(cur->getField(0,(uint32_t)0),"1");
@@ -795,7 +798,7 @@ int	main(int argc, char **argv) {
 	cur->inputBind("3","hello");
 	checkSuccess(cur->executeQuery(),1);
 	checkSuccess(cur->getField(0,(uint32_t)0),"1");
-	checkSuccess(charstring::toFloat(cur->getField(0,1)),1.1);
+	checkSuccess(charstring::toFloatC(cur->getField(0,1)),1.1);
 	checkSuccess(cur->getField(0,2),"hello");
 	cur->sendQuery("drop function testfunc(int,float,char(20))");
 	stdoutput.printf("\n");
@@ -830,4 +833,6 @@ int	main(int argc, char **argv) {
 	checkSuccess(cur->sendQuery("create table testtable"),0);
 	checkSuccess(cur->sendQuery("create table testtable"),0);
 	stdoutput.printf("\n");
+
+	return 0;
 }
