@@ -1,4 +1,4 @@
-// Copyright (c) 2001  David Muse
+// Copyright (c) 1999-2018 David Muse
 // See the file COPYING for more information.
 
 #include "../../config.h"
@@ -65,7 +65,7 @@ int	main(int argc, char **argv) {
 	uint32_t	*fieldlens;
 
 	// instantiation
-	con=new sqlrconnection("sqlrserver",9000,"/tmp/test.socket",
+	con=new sqlrconnection("sqlrelay",9000,"/tmp/test.socket",
 							"test","test",0,1);
 	cur=new sqlrcursor(con);
 
@@ -604,7 +604,7 @@ int	main(int argc, char **argv) {
 	stdoutput.printf("\n");
 
 	stdoutput.printf("COMMIT AND ROLLBACK: \n");
-	secondcon=new sqlrconnection("sqlrserver",9000,"/tmp/test.socket",
+	secondcon=new sqlrconnection("sqlrelay",9000,"/tmp/test.socket",
 							"test","test",0,1);
 	secondcur=new sqlrcursor(secondcon);
 	checkSuccess(secondcur->sendQuery("select count(*) from testtable"),1);
@@ -678,4 +678,6 @@ int	main(int argc, char **argv) {
 	checkSuccess(cur->sendQuery("create table testtable"),0);
 	checkSuccess(cur->sendQuery("create table testtable"),0);
 	stdoutput.printf("\n");
+
+	return 0;
 }
