@@ -1,4 +1,4 @@
-// Copyright (c) 2001  David Muse
+// Copyright (c) 1999-2018 David Muse
 // See the file COPYING for more information.
 
 #include <sqlrelay/sqlrclientwrapper.h>
@@ -72,7 +72,7 @@ int	main(int argc, char **argv) {
 	uint32_t	*fieldlens;
 
 	// instantiation
-	con=sqlrcon_alloc("sqlrserver",9000,
+	con=sqlrcon_alloc("sqlrelay",9000,
 				"/tmp/test.socket","test","test",0,1);
 	cur=sqlrcur_alloc(con);
 
@@ -325,51 +325,51 @@ int	main(int argc, char **argv) {
 	printf("\n");
 
 	printf("FIELDS BY NAME: \n");
-	checkSuccessString(sqlrcur_getFieldByName(cur,0,"testsmallint"),"1");
-	checkSuccessString(sqlrcur_getFieldByName(cur,0,"testint"),"1");
-	checkSuccessString(sqlrcur_getFieldByName(cur,0,"testbigint"),"1");
-	checkSuccessString(sqlrcur_getFieldByName(cur,0,"testdecimal"),"1.10");
-	//checkSuccessString(sqlrcur_getFieldByName(cur,0,"testreal"),"1.1");
-	//checkSuccessString(sqlrcur_getFieldByName(cur,0,"testdouble"),"1.1");
-	checkSuccessString(sqlrcur_getFieldByName(cur,0,"testchar"),"testchar1                               ");
-	checkSuccessString(sqlrcur_getFieldByName(cur,0,"testvarchar"),"testvarchar1");
-	checkSuccessString(sqlrcur_getFieldByName(cur,0,"testdate"),"2001-01-01");
-	checkSuccessString(sqlrcur_getFieldByName(cur,0,"testtime"),"01:00:00");
+	checkSuccessString(sqlrcur_getFieldByName(cur,0,"TESTSMALLINT"),"1");
+	checkSuccessString(sqlrcur_getFieldByName(cur,0,"TESTINT"),"1");
+	checkSuccessString(sqlrcur_getFieldByName(cur,0,"TESTBIGINT"),"1");
+	checkSuccessString(sqlrcur_getFieldByName(cur,0,"TESTDECIMAL"),"1.10");
+	//checkSuccessString(sqlrcur_getFieldByName(cur,0,"TESTREAL"),"1.1");
+	//checkSuccessString(sqlrcur_getFieldByName(cur,0,"TESTDOUBLE"),"1.1");
+	checkSuccessString(sqlrcur_getFieldByName(cur,0,"TESTCHAR"),"testchar1                               ");
+	checkSuccessString(sqlrcur_getFieldByName(cur,0,"TESTVARCHAR"),"testvarchar1");
+	checkSuccessString(sqlrcur_getFieldByName(cur,0,"TESTDATE"),"2001-01-01");
+	checkSuccessString(sqlrcur_getFieldByName(cur,0,"TESTTIME"),"01:00:00");
 	printf("\n");
-	checkSuccessString(sqlrcur_getFieldByName(cur,7,"testsmallint"),"8");
-	checkSuccessString(sqlrcur_getFieldByName(cur,7,"testint"),"8");
-	checkSuccessString(sqlrcur_getFieldByName(cur,7,"testbigint"),"8");
-	checkSuccessString(sqlrcur_getFieldByName(cur,7,"testdecimal"),"8.80");
-	//checkSuccessString(sqlrcur_getFieldByName(cur,7,"testreal"),"8.8");
-	//checkSuccessString(sqlrcur_getFieldByName(cur,7,"testdouble"),"8.8");
-	checkSuccessString(sqlrcur_getFieldByName(cur,7,"testchar"),"testchar8                               ");
-	checkSuccessString(sqlrcur_getFieldByName(cur,7,"testvarchar"),"testvarchar8");
-	checkSuccessString(sqlrcur_getFieldByName(cur,7,"testdate"),"2008-01-01");
-	checkSuccessString(sqlrcur_getFieldByName(cur,7,"testtime"),"08:00:00");
+	checkSuccessString(sqlrcur_getFieldByName(cur,7,"TESTSMALLINT"),"8");
+	checkSuccessString(sqlrcur_getFieldByName(cur,7,"TESTINT"),"8");
+	checkSuccessString(sqlrcur_getFieldByName(cur,7,"TESTBIGINT"),"8");
+	checkSuccessString(sqlrcur_getFieldByName(cur,7,"TESTDECIMAL"),"8.80");
+	//checkSuccessString(sqlrcur_getFieldByName(cur,7,"TESTREAL"),"8.8");
+	//checkSuccessString(sqlrcur_getFieldByName(cur,7,"TESTDOUBLE"),"8.8");
+	checkSuccessString(sqlrcur_getFieldByName(cur,7,"TESTCHAR"),"testchar8                               ");
+	checkSuccessString(sqlrcur_getFieldByName(cur,7,"TESTVARCHAR"),"testvarchar8");
+	checkSuccessString(sqlrcur_getFieldByName(cur,7,"TESTDATE"),"2008-01-01");
+	checkSuccessString(sqlrcur_getFieldByName(cur,7,"TESTTIME"),"08:00:00");
 	printf("\n");
 
 	printf("FIELD LENGTHS BY NAME: \n");
-	checkSuccessInt(sqlrcur_getFieldLengthByName(cur,0,"testsmallint"),1);
-	checkSuccessInt(sqlrcur_getFieldLengthByName(cur,0,"testint"),1);
-	checkSuccessInt(sqlrcur_getFieldLengthByName(cur,0,"testbigint"),1);
-	checkSuccessInt(sqlrcur_getFieldLengthByName(cur,0,"testdecimal"),4);
-	//checkSuccessInt(sqlrcur_getFieldLengthByName(cur,0,"testreal"),3);
-	//checkSuccessInt(sqlrcur_getFieldLengthByName(cur,0,"testdouble"),3);
-	checkSuccessInt(sqlrcur_getFieldLengthByName(cur,0,"testchar"),40);
-	checkSuccessInt(sqlrcur_getFieldLengthByName(cur,0,"testvarchar"),12);
-	checkSuccessInt(sqlrcur_getFieldLengthByName(cur,0,"testdate"),10);
-	checkSuccessInt(sqlrcur_getFieldLengthByName(cur,0,"testtime"),8);
+	checkSuccessInt(sqlrcur_getFieldLengthByName(cur,0,"TESTSMALLINT"),1);
+	checkSuccessInt(sqlrcur_getFieldLengthByName(cur,0,"TESTINT"),1);
+	checkSuccessInt(sqlrcur_getFieldLengthByName(cur,0,"TESTBIGINT"),1);
+	checkSuccessInt(sqlrcur_getFieldLengthByName(cur,0,"TESTDECIMAL"),4);
+	//checkSuccessInt(sqlrcur_getFieldLengthByName(cur,0,"TESTREAL"),3);
+	//checkSuccessInt(sqlrcur_getFieldLengthByName(cur,0,"TESTDOUBLE"),3);
+	checkSuccessInt(sqlrcur_getFieldLengthByName(cur,0,"TESTCHAR"),40);
+	checkSuccessInt(sqlrcur_getFieldLengthByName(cur,0,"TESTVARCHAR"),12);
+	checkSuccessInt(sqlrcur_getFieldLengthByName(cur,0,"TESTDATE"),10);
+	checkSuccessInt(sqlrcur_getFieldLengthByName(cur,0,"TESTTIME"),8);
 	printf("\n");
-	checkSuccessInt(sqlrcur_getFieldLengthByName(cur,7,"testsmallint"),1);
-	checkSuccessInt(sqlrcur_getFieldLengthByName(cur,7,"testint"),1);
-	checkSuccessInt(sqlrcur_getFieldLengthByName(cur,7,"testbigint"),1);
-	checkSuccessInt(sqlrcur_getFieldLengthByName(cur,7,"testdecimal"),4);
-	//checkSuccessInt(sqlrcur_getFieldLengthByName(cur,7,"testreal"),3);
-	//checkSuccessInt(sqlrcur_getFieldLengthByName(cur,7,"testdouble"),3);
-	checkSuccessInt(sqlrcur_getFieldLengthByName(cur,7,"testchar"),40);
-	checkSuccessInt(sqlrcur_getFieldLengthByName(cur,7,"testvarchar"),12);
-	checkSuccessInt(sqlrcur_getFieldLengthByName(cur,7,"testdate"),10);
-	checkSuccessInt(sqlrcur_getFieldLengthByName(cur,7,"testtime"),8);
+	checkSuccessInt(sqlrcur_getFieldLengthByName(cur,7,"TESTSMALLINT"),1);
+	checkSuccessInt(sqlrcur_getFieldLengthByName(cur,7,"TESTINT"),1);
+	checkSuccessInt(sqlrcur_getFieldLengthByName(cur,7,"TESTBIGINT"),1);
+	checkSuccessInt(sqlrcur_getFieldLengthByName(cur,7,"TESTDECIMAL"),4);
+	//checkSuccessInt(sqlrcur_getFieldLengthByName(cur,7,"TESTREAL"),3);
+	//checkSuccessInt(sqlrcur_getFieldLengthByName(cur,7,"TESTDOUBLE"),3);
+	checkSuccessInt(sqlrcur_getFieldLengthByName(cur,7,"TESTCHAR"),40);
+	checkSuccessInt(sqlrcur_getFieldLengthByName(cur,7,"TESTVARCHAR"),12);
+	checkSuccessInt(sqlrcur_getFieldLengthByName(cur,7,"TESTDATE"),10);
+	checkSuccessInt(sqlrcur_getFieldLengthByName(cur,7,"TESTTIME"),8);
 	printf("\n");
 
 	printf("FIELDS BY ARRAY: \n");
@@ -745,4 +745,6 @@ int	main(int argc, char **argv) {
 	checkSuccessInt(sqlrcur_sendQuery(cur,"create table testtable"),0);
 	checkSuccessInt(sqlrcur_sendQuery(cur,"create table testtable"),0);
 	printf("\n");
+
+	return 0;
 }
