@@ -1,4 +1,4 @@
-// Copyright (c) 2001  David Muse
+// Copyright (c) 1999-2018 David Muse
 // See the file COPYING for more information.
 
 #include <sqlrelay/sqlrclientwrapper.h>
@@ -73,7 +73,7 @@ int	main(int argc, char **argv) {
 	uint32_t	*fieldlens;
 
 	// instantiation
-	con=sqlrcon_alloc("sqlrserver",9000,
+	con=sqlrcon_alloc("sqlrelay",9000,
 				"/tmp/test.socket","test","test",0,1);
 	cur=sqlrcur_alloc(con);
 
@@ -716,7 +716,7 @@ int	main(int argc, char **argv) {
 	printf("\n");
 
 	printf("COMMIT AND ROLLBACK: \n");
-	secondcon=sqlrcon_alloc("sqlrserver",9000,
+	secondcon=sqlrcon_alloc("sqlrelay",9000,
 				"/tmp/test.socket","test","test",0,1);
 	secondcur=sqlrcur_alloc(secondcon);
 	checkSuccessInt(sqlrcur_sendQuery(secondcur,"select count(*) from testtable"),1);
@@ -773,4 +773,6 @@ int	main(int argc, char **argv) {
 	checkSuccessInt(sqlrcur_sendQuery(cur,"create table testtable"),0);
 	checkSuccessInt(sqlrcur_sendQuery(cur,"create table testtable"),0);
 	printf("\n");
+
+	return 0;
 }
