@@ -1,4 +1,4 @@
-// Copyright (c) 2001  David Muse
+// Copyright (c) 1999-2018 David Muse
 // See the file COPYING for more information.
 
 #include <sqlrelay/sqlrclientwrapper.h>
@@ -68,7 +68,7 @@ int	main(int argc, char **argv) {
 	uint32_t	*fieldlens;
 
 	// instantiation
-	con=sqlrcon_alloc("sqlrserver",9000,
+	con=sqlrcon_alloc("sqlrelay",9000,
 				"/tmp/test.socket","test","test",0,1);
 	cur=sqlrcur_alloc(con);
 
@@ -147,7 +147,6 @@ int	main(int argc, char **argv) {
 	sqlrcur_inputBindString(cur,"6","testvarchar8");
 	sqlrcur_inputBindString(cur,"7","01/01/2008");
 	sqlrcur_inputBindString(cur,"8","08:00:00");
-	sqlrcur_inputBindString(cur,"9","junkvalue");
 	sqlrcur_validateBinds(cur);
 	checkSuccessInt(sqlrcur_executeQuery(cur),1);
 	printf("\n");
@@ -247,9 +246,9 @@ int	main(int argc, char **argv) {
 	checkSuccessInt(sqlrcur_rowCount(cur),8);
 	printf("\n");
 
-	printf("TOTAL ROWS: \n");
+	/*printf("TOTAL ROWS: \n");
 	checkSuccessInt(sqlrcur_totalRows(cur),8);
-	printf("\n");
+	printf("\n");*/
 
 	printf("FIRST ROW INDEX: \n");
 	checkSuccessInt(sqlrcur_firstRowIndex(cur),0);
@@ -660,7 +659,7 @@ int	main(int argc, char **argv) {
 	printf("\n");
 
 	printf("COMMIT AND ROLLBACK: \n");
-	secondcon=sqlrcon_alloc("sqlrserver",9000,
+	secondcon=sqlrcon_alloc("sqlrelay",9000,
 				"/tmp/test.socket","test","test",0,1);
 	secondcur=sqlrcur_alloc(secondcon);
 	checkSuccessInt(sqlrcur_sendQuery(secondcur,"select count(*) from testtable"),1);
@@ -774,4 +773,6 @@ int	main(int argc, char **argv) {
 	checkSuccessInt(sqlrcur_sendQuery(cur,"create table testtable"),0);
 	checkSuccessInt(sqlrcur_sendQuery(cur,"create table testtable"),0);
 	printf("\n");
+
+	return 0;
 }
