@@ -1,4 +1,4 @@
-// Copyright (c) 2001  David Muse
+// Copyright (c) 1999-2018 David Muse
 // See the file COPYING for more information.
 
 #include <sqlrelay/sqlrclientwrapper.h>
@@ -127,16 +127,16 @@ int	main(int argc, char **argv) {
 	char	query[4000+25];
 	const char	*clobbindvar;
 
-	const char	*cert="/usr/local/firstworks/etc/client.pem";
-	const char	*ca="/usr/local/firstworks/etc/ca.pem";
+	const char	*cert="/usr/local/firstworks/etc/sqlrelay.conf.d/client.pem";
+	const char	*ca="/usr/local/firstworks/etc/sqlrelay.conf.d/ca.pem";
 	#ifdef _WIN32
-		cert="C:\\Program Files\\Firstworks\\etc\\client.pfx";
-		ca="C:\\Program Files\\Firstworks\\etc\\ca.pfx";
+		cert="C:\\Program Files\\Firstworks\\etc\\sqlrelay.conf.d\\client.pfx";
+		ca="C:\\Program Files\\Firstworks\\etc\\sqlrelay.conf.d\\ca.pfx";
 	#endif
 
 
 	// instantiation
-	con=sqlrcon_alloc("sqlrserver",9000,"/tmp/test.socket",NULL,NULL,0,1);
+	con=sqlrcon_alloc("sqlrelay",9000,"/tmp/test.socket",NULL,NULL,0,1);
 	cur=sqlrcur_alloc(con);
 	sqlrcon_enableTls(con,NULL,cert,NULL,NULL,"ca",ca,0);
 
@@ -199,7 +199,7 @@ int	main(int argc, char **argv) {
 	sqlrcur_inputBindLong(cur,"1",2);
 	sqlrcur_inputBindString(cur,"2","testchar2");
 	sqlrcur_inputBindString(cur,"3","testvarchar2");
-	sqlrcur_inputBindDate(cur,"4",2002,1,1,-1,-1,-1,0,NULL);
+	sqlrcur_inputBindDate(cur,"4",2002,1,1,-1,-1,-1,0,NULL,0);
 	sqlrcur_inputBindString(cur,"5","testlong2");
 	sqlrcur_inputBindClob(cur,"6","testclob2",9);
 	sqlrcur_inputBindBlob(cur,"7","testblob2",9);
@@ -208,7 +208,7 @@ int	main(int argc, char **argv) {
 	sqlrcur_inputBindLong(cur,"1",3);
 	sqlrcur_inputBindString(cur,"2","testchar3");
 	sqlrcur_inputBindString(cur,"3","testvarchar3");
-	sqlrcur_inputBindDate(cur,"4",2003,1,1,-1,-1,-1,0,NULL);
+	sqlrcur_inputBindDate(cur,"4",2003,1,1,-1,-1,-1,0,NULL,0);
 	sqlrcur_inputBindString(cur,"5","testlong3");
 	sqlrcur_inputBindClob(cur,"6","testclob3",9);
 	sqlrcur_inputBindBlob(cur,"7","testblob3",9);
@@ -228,7 +228,7 @@ int	main(int argc, char **argv) {
 	sqlrcur_inputBindLong(cur,"var1",5);
 	sqlrcur_inputBindString(cur,"var2","testchar5");
 	sqlrcur_inputBindString(cur,"var3","testvarchar5");
-	sqlrcur_inputBindDate(cur,"var4",2005,1,1,-1,-1,-1,0,NULL);
+	sqlrcur_inputBindDate(cur,"var4",2005,1,1,-1,-1,-1,0,NULL,0);
 	sqlrcur_inputBindString(cur,"var5","testlong5");
 	sqlrcur_inputBindClob(cur,"var6","testclob5",9);
 	sqlrcur_inputBindBlob(cur,"var7","testblob5",9);
@@ -237,7 +237,7 @@ int	main(int argc, char **argv) {
 	sqlrcur_inputBindLong(cur,"var1",6);
 	sqlrcur_inputBindString(cur,"var2","testchar6");
 	sqlrcur_inputBindString(cur,"var3","testvarchar6");
-	sqlrcur_inputBindDate(cur,"var4",2006,1,1,-1,-1,-1,0,NULL);
+	sqlrcur_inputBindDate(cur,"var4",2006,1,1,-1,-1,-1,0,NULL,0);
 	sqlrcur_inputBindString(cur,"var5","testlong6");
 	sqlrcur_inputBindClob(cur,"var6","testclob6",9);
 	sqlrcur_inputBindBlob(cur,"var7","testblob6",9);
@@ -257,7 +257,7 @@ int	main(int argc, char **argv) {
 	sqlrcur_inputBindLong(cur,"var1",8);
 	sqlrcur_inputBindString(cur,"var2","testchar8");
 	sqlrcur_inputBindString(cur,"var3","testvarchar8");
-	sqlrcur_inputBindDate(cur,"var4",2008,1,1,-1,-1,-1,0,NULL);
+	sqlrcur_inputBindDate(cur,"var4",2008,1,1,-1,-1,-1,0,NULL,0);
 	sqlrcur_inputBindString(cur,"var5","testlong8");
 	sqlrcur_inputBindClob(cur,"var6","testclob8",9);
 	sqlrcur_inputBindBlob(cur,"var7","testblob8",9);
@@ -338,53 +338,53 @@ int	main(int argc, char **argv) {
 
 	printf("COLUMN TYPES: \n");
 	checkSuccessString(sqlrcur_getColumnTypeByIndex(cur,0),"NUMBER");
-	checkSuccessString(sqlrcur_getColumnTypeByName(cur,"testnumber"),"NUMBER");
+	checkSuccessString(sqlrcur_getColumnTypeByName(cur,"TESTNUMBER"),"NUMBER");
 	checkSuccessString(sqlrcur_getColumnTypeByIndex(cur,1),"CHAR");
-	checkSuccessString(sqlrcur_getColumnTypeByName(cur,"testchar"),"CHAR");
+	checkSuccessString(sqlrcur_getColumnTypeByName(cur,"TESTCHAR"),"CHAR");
 	checkSuccessString(sqlrcur_getColumnTypeByIndex(cur,2),"VARCHAR2");
-	checkSuccessString(sqlrcur_getColumnTypeByName(cur,"testvarchar"),"VARCHAR2");
+	checkSuccessString(sqlrcur_getColumnTypeByName(cur,"TESTVARCHAR"),"VARCHAR2");
 	checkSuccessString(sqlrcur_getColumnTypeByIndex(cur,3),"DATE");
-	checkSuccessString(sqlrcur_getColumnTypeByName(cur,"testdate"),"DATE");
+	checkSuccessString(sqlrcur_getColumnTypeByName(cur,"TESTDATE"),"DATE");
 	checkSuccessString(sqlrcur_getColumnTypeByIndex(cur,4),"LONG");
-	checkSuccessString(sqlrcur_getColumnTypeByName(cur,"testlong"),"LONG");
+	checkSuccessString(sqlrcur_getColumnTypeByName(cur,"TESTLONG"),"LONG");
 	checkSuccessString(sqlrcur_getColumnTypeByIndex(cur,5),"CLOB");
-	checkSuccessString(sqlrcur_getColumnTypeByName(cur,"testclob"),"CLOB");
+	checkSuccessString(sqlrcur_getColumnTypeByName(cur,"TESTCLOB"),"CLOB");
 	checkSuccessString(sqlrcur_getColumnTypeByIndex(cur,6),"BLOB");
-	checkSuccessString(sqlrcur_getColumnTypeByName(cur,"testblob"),"BLOB");
+	checkSuccessString(sqlrcur_getColumnTypeByName(cur,"TESTBLOB"),"BLOB");
 	printf("\n");
 
 	printf("COLUMN LENGTH: \n");
 	checkSuccessInt(sqlrcur_getColumnLengthByIndex(cur,0),22);
-	checkSuccessInt(sqlrcur_getColumnLengthByName(cur,"testnumber"),22);
+	checkSuccessInt(sqlrcur_getColumnLengthByName(cur,"TESTNUMBER"),22);
 	checkSuccessInt(sqlrcur_getColumnLengthByIndex(cur,1),40);
-	checkSuccessInt(sqlrcur_getColumnLengthByName(cur,"testchar"),40);
+	checkSuccessInt(sqlrcur_getColumnLengthByName(cur,"TESTCHAR"),40);
 	checkSuccessInt(sqlrcur_getColumnLengthByIndex(cur,2),40);
-	checkSuccessInt(sqlrcur_getColumnLengthByName(cur,"testvarchar"),40);
+	checkSuccessInt(sqlrcur_getColumnLengthByName(cur,"TESTVARCHAR"),40);
 	checkSuccessInt(sqlrcur_getColumnLengthByIndex(cur,3),7);
-	checkSuccessInt(sqlrcur_getColumnLengthByName(cur,"testdate"),7);
+	checkSuccessInt(sqlrcur_getColumnLengthByName(cur,"TESTDATE"),7);
 	checkSuccessInt(sqlrcur_getColumnLengthByIndex(cur,4),0);
-	checkSuccessInt(sqlrcur_getColumnLengthByName(cur,"testlong"),0);
+	checkSuccessInt(sqlrcur_getColumnLengthByName(cur,"TESTLONG"),0);
 	checkSuccessInt(sqlrcur_getColumnLengthByIndex(cur,5),0);
-	checkSuccessInt(sqlrcur_getColumnLengthByName(cur,"testclob"),0);
+	checkSuccessInt(sqlrcur_getColumnLengthByName(cur,"TESTCLOB"),0);
 	checkSuccessInt(sqlrcur_getColumnLengthByIndex(cur,6),0);
-	checkSuccessInt(sqlrcur_getColumnLengthByName(cur,"testblob"),0);
+	checkSuccessInt(sqlrcur_getColumnLengthByName(cur,"TESTBLOB"),0);
 	printf("\n");
 
 	printf("LONGEST COLUMN: \n");
 	checkSuccessInt(sqlrcur_getLongestByIndex(cur,0),1);
-	checkSuccessInt(sqlrcur_getLongestByName(cur,"testnumber"),1);
+	checkSuccessInt(sqlrcur_getLongestByName(cur,"TESTNUMBER"),1);
 	checkSuccessInt(sqlrcur_getLongestByIndex(cur,1),40);
-	checkSuccessInt(sqlrcur_getLongestByName(cur,"testchar"),40);
+	checkSuccessInt(sqlrcur_getLongestByName(cur,"TESTCHAR"),40);
 	checkSuccessInt(sqlrcur_getLongestByIndex(cur,2),12);
-	checkSuccessInt(sqlrcur_getLongestByName(cur,"testvarchar"),12);
+	checkSuccessInt(sqlrcur_getLongestByName(cur,"TESTVARCHAR"),12);
 	checkSuccessInt(sqlrcur_getLongestByIndex(cur,3),9);
-	checkSuccessInt(sqlrcur_getLongestByName(cur,"testdate"),9);
+	checkSuccessInt(sqlrcur_getLongestByName(cur,"TESTDATE"),9);
 	checkSuccessInt(sqlrcur_getLongestByIndex(cur,4),9);
-	checkSuccessInt(sqlrcur_getLongestByName(cur,"testlong"),9);
+	checkSuccessInt(sqlrcur_getLongestByName(cur,"TESTLONG"),9);
 	checkSuccessInt(sqlrcur_getLongestByIndex(cur,5),9);
-	checkSuccessInt(sqlrcur_getLongestByName(cur,"testclob"),9);
+	checkSuccessInt(sqlrcur_getLongestByName(cur,"TESTCLOB"),9);
 	checkSuccessInt(sqlrcur_getLongestByIndex(cur,6),9);
-	checkSuccessInt(sqlrcur_getLongestByName(cur,"testblob"),9);
+	checkSuccessInt(sqlrcur_getLongestByName(cur,"TESTBLOB"),9);
 	printf("\n");
 
 	printf("ROW COUNT: \n");
@@ -440,39 +440,39 @@ int	main(int argc, char **argv) {
 	printf("\n");
 
 	printf("FIELDS BY NAME: \n");
-	checkSuccessString(sqlrcur_getFieldByName(cur,0,"testnumber"),"1");
-	checkSuccessString(sqlrcur_getFieldByName(cur,0,"testchar"),"testchar1                               ");
-	checkSuccessString(sqlrcur_getFieldByName(cur,0,"testvarchar"),"testvarchar1");
-	checkSuccessString(sqlrcur_getFieldByName(cur,0,"testdate"),"01-JAN-01");
-	checkSuccessString(sqlrcur_getFieldByName(cur,0,"testlong"),"testlong1");
-	checkSuccessString(sqlrcur_getFieldByName(cur,0,"testclob"),"testclob1");
-	checkSuccessString(sqlrcur_getFieldByName(cur,0,"testblob"),"");
+	checkSuccessString(sqlrcur_getFieldByName(cur,0,"TESTNUMBER"),"1");
+	checkSuccessString(sqlrcur_getFieldByName(cur,0,"TESTCHAR"),"testchar1                               ");
+	checkSuccessString(sqlrcur_getFieldByName(cur,0,"TESTVARCHAR"),"testvarchar1");
+	checkSuccessString(sqlrcur_getFieldByName(cur,0,"TESTDATE"),"01-JAN-01");
+	checkSuccessString(sqlrcur_getFieldByName(cur,0,"TESTLONG"),"testlong1");
+	checkSuccessString(sqlrcur_getFieldByName(cur,0,"TESTCLOB"),"testclob1");
+	checkSuccessString(sqlrcur_getFieldByName(cur,0,"TESTBLOB"),"");
 	printf("\n");
-	checkSuccessString(sqlrcur_getFieldByName(cur,7,"testnumber"),"8");
-	checkSuccessString(sqlrcur_getFieldByName(cur,7,"testchar"),"testchar8                               ");
-	checkSuccessString(sqlrcur_getFieldByName(cur,7,"testvarchar"),"testvarchar8");
-	checkSuccessString(sqlrcur_getFieldByName(cur,7,"testdate"),"01-JAN-08");
-	checkSuccessString(sqlrcur_getFieldByName(cur,7,"testlong"),"testlong8");
-	checkSuccessString(sqlrcur_getFieldByName(cur,7,"testclob"),"testclob8");
-	checkSuccessString(sqlrcur_getFieldByName(cur,7,"testblob"),"testblob8");
+	checkSuccessString(sqlrcur_getFieldByName(cur,7,"TESTNUMBER"),"8");
+	checkSuccessString(sqlrcur_getFieldByName(cur,7,"TESTCHAR"),"testchar8                               ");
+	checkSuccessString(sqlrcur_getFieldByName(cur,7,"TESTVARCHAR"),"testvarchar8");
+	checkSuccessString(sqlrcur_getFieldByName(cur,7,"TESTDATE"),"01-JAN-08");
+	checkSuccessString(sqlrcur_getFieldByName(cur,7,"TESTLONG"),"testlong8");
+	checkSuccessString(sqlrcur_getFieldByName(cur,7,"TESTCLOB"),"testclob8");
+	checkSuccessString(sqlrcur_getFieldByName(cur,7,"TESTBLOB"),"testblob8");
 	printf("\n");
 
 	printf("FIELD LENGTHS BY NAME: \n");
-	checkSuccessInt(sqlrcur_getFieldLengthByName(cur,0,"testnumber"),1);
-	checkSuccessInt(sqlrcur_getFieldLengthByName(cur,0,"testchar"),40);
-	checkSuccessInt(sqlrcur_getFieldLengthByName(cur,0,"testvarchar"),12);
-	checkSuccessInt(sqlrcur_getFieldLengthByName(cur,0,"testdate"),9);
-	checkSuccessInt(sqlrcur_getFieldLengthByName(cur,0,"testlong"),9);
-	checkSuccessInt(sqlrcur_getFieldLengthByName(cur,0,"testclob"),9);
-	checkSuccessInt(sqlrcur_getFieldLengthByName(cur,0,"testblob"),0);
+	checkSuccessInt(sqlrcur_getFieldLengthByName(cur,0,"TESTNUMBER"),1);
+	checkSuccessInt(sqlrcur_getFieldLengthByName(cur,0,"TESTCHAR"),40);
+	checkSuccessInt(sqlrcur_getFieldLengthByName(cur,0,"TESTVARCHAR"),12);
+	checkSuccessInt(sqlrcur_getFieldLengthByName(cur,0,"TESTDATE"),9);
+	checkSuccessInt(sqlrcur_getFieldLengthByName(cur,0,"TESTLONG"),9);
+	checkSuccessInt(sqlrcur_getFieldLengthByName(cur,0,"TESTCLOB"),9);
+	checkSuccessInt(sqlrcur_getFieldLengthByName(cur,0,"TESTBLOB"),0);
 	printf("\n");
-	checkSuccessInt(sqlrcur_getFieldLengthByName(cur,7,"testnumber"),1);
-	checkSuccessInt(sqlrcur_getFieldLengthByName(cur,7,"testchar"),40);
-	checkSuccessInt(sqlrcur_getFieldLengthByName(cur,7,"testvarchar"),12);
-	checkSuccessInt(sqlrcur_getFieldLengthByName(cur,7,"testdate"),9);
-	checkSuccessInt(sqlrcur_getFieldLengthByName(cur,7,"testlong"),9);
-	checkSuccessInt(sqlrcur_getFieldLengthByName(cur,7,"testclob"),9);
-	checkSuccessInt(sqlrcur_getFieldLengthByName(cur,7,"testblob"),9);
+	checkSuccessInt(sqlrcur_getFieldLengthByName(cur,7,"TESTNUMBER"),1);
+	checkSuccessInt(sqlrcur_getFieldLengthByName(cur,7,"TESTCHAR"),40);
+	checkSuccessInt(sqlrcur_getFieldLengthByName(cur,7,"TESTVARCHAR"),12);
+	checkSuccessInt(sqlrcur_getFieldLengthByName(cur,7,"TESTDATE"),9);
+	checkSuccessInt(sqlrcur_getFieldLengthByName(cur,7,"TESTLONG"),9);
+	checkSuccessInt(sqlrcur_getFieldLengthByName(cur,7,"TESTCLOB"),9);
+	checkSuccessInt(sqlrcur_getFieldLengthByName(cur,7,"TESTBLOB"),9);
 	printf("\n");
 
 	printf("FIELDS BY ARRAY: \n");
@@ -797,8 +797,8 @@ int	main(int argc, char **argv) {
 	printf("\n");
 
 	printf("COMMIT AND ROLLBACK: \n");
-	secondcon=sqlrcon_alloc("sqlrserver",9000,"/tmp/test.socket",
-							NULL,NULL,0,1);
+	secondcon=sqlrcon_alloc("sqlrelay",9000,
+				"/tmp/test.socket",NULL,NULL,0,1);
 	secondcur=sqlrcur_alloc(secondcon);
 	sqlrcon_enableTls(secondcon,NULL,cert,NULL,NULL,"ca",ca,0);
 	checkSuccessInt(sqlrcur_sendQuery(secondcur,"select count(*) from testtable"),1);
@@ -881,7 +881,7 @@ int	main(int argc, char **argv) {
 	sqlrcur_inputBindClob(cur,"clobval",clobval,8*1024);
 	checkSuccessInt(sqlrcur_executeQuery(cur),1);
 	sqlrcur_sendQuery(cur,"select testclob from testtable2");
-	checkSuccessString(clobval,sqlrcur_getFieldByName(cur,0,"testclob"));
+	checkSuccessString(clobval,sqlrcur_getFieldByName(cur,0,"TESTCLOB"));
 	sqlrcur_prepareQuery(cur,"begin select testclob into :clobbindval from testtable2; end;");
 	sqlrcur_defineOutputBindClob(cur,"clobbindval");
 	checkSuccessInt(sqlrcur_executeQuery(cur),1);
@@ -903,7 +903,7 @@ int	main(int argc, char **argv) {
 	sqlrcur_inputBindString(cur,"testval",testval);
 	checkSuccessInt(sqlrcur_executeQuery(cur),1);
 	sqlrcur_sendQuery(cur,"select testval from testtable2");
-	checkSuccessString(testval,sqlrcur_getFieldByName(cur,0,"testval"));
+	checkSuccessString(testval,sqlrcur_getFieldByName(cur,0,"TESTVAL"));
 	sprintf(query,"begin :bindval:='%s'; end;",testval);
 	sqlrcur_prepareQuery(cur,query);
 	sqlrcur_defineOutputBindString(cur,"bindval",4000);
@@ -919,7 +919,7 @@ int	main(int argc, char **argv) {
 	sqlrcur_inputBindLong(cur,"testval",-1);
 	checkSuccessInt(sqlrcur_executeQuery(cur),1);
 	sqlrcur_sendQuery(cur,"select testval from testtable2");
-	checkSuccessString(sqlrcur_getFieldByName(cur,0,"testval"),"-1");
+	checkSuccessString(sqlrcur_getFieldByName(cur,0,"TESTVAL"),"-1");
 	sqlrcur_sendQuery(cur,"drop table testtable2");
 	printf("\n");
 
@@ -962,4 +962,6 @@ int	main(int argc, char **argv) {
 	checkSuccessInt(sqlrcur_sendQuery(cur,"create table testtable"),0);
 	checkSuccessInt(sqlrcur_sendQuery(cur,"create table testtable"),0);
 	printf("\n");
+
+	return 0;
 }
