@@ -1,4 +1,4 @@
-﻿// Copyright (c) 2012-2015  David Muse
+// Copyright (c) 1999-2018 David Muse
 // See the file COPYING for more information.
 
 using System;
@@ -141,7 +141,7 @@ namespace SQLRClientTest
         {
 
             // open connection and command
-            SQLRelayConnection sqlrcon = new SQLRelayConnection("Data Source=sqlrserver:9000;User ID=test;Password=test;Retry Time=0;Tries=1;Debug=false");
+            SQLRelayConnection sqlrcon = new SQLRelayConnection("Data Source=sqlrelay:9000:/tmp/test.socket;User ID=test;Password=test;Retry Time=0;Tries=1;Debug=false");
             sqlrcon.Open();
 
 
@@ -572,7 +572,7 @@ namespace SQLRClientTest
 
             // commit and rollback
             Console.WriteLine("COMMIT AND ROLLBACK:");
-            SQLRelayConnection sqlrcon2 = new SQLRelayConnection("Data Source=sqlrserver:9000;User ID=test;Password=test;Retry Time=0;Tries=1;Debug=false");
+            SQLRelayConnection sqlrcon2 = new SQLRelayConnection("Data Source=sqlrelay:9000:/tmp/test.socket;User ID=test;Password=test;Retry Time=0;Tries=1;Debug=false");
             sqlrcon2.Open();
             SQLRelayCommand sqlrcom2 = new SQLRelayCommand("select count(*) from testtable", sqlrcon2);
             checkSuccess(Convert.ToInt64(sqlrcom2.ExecuteScalar()), 0);
@@ -886,6 +886,8 @@ namespace SQLRClientTest
             // invalid queries
 
             sqlrcon.Close();
+
+            Environment.Exit(0);
         }
     }
 }
