@@ -1,4 +1,4 @@
-﻿// Copyright (c) 2012-2015  David Muse
+// Copyright (c) 1999-2018 David Muse
 // See the file COPYING for more information.
 
 using System;
@@ -142,16 +142,16 @@ namespace SQLRClientTest
         public static void Main(String[] args)
         {
 
-            tlscert = "/usr/local/firstworks/etc/client.pem";
-            tlsca = "/usr/local/firstworks/etc/ca.pem";
+            tlscert = "/usr/local/firstworks/etc/sqlrelay.conf.d/client.pem";
+            tlsca = "/usr/local/firstworks/etc/sqlrelay.conf.d/ca.pem";
             if (Environment.OSVersion.ToString().Contains("Windows"))
             {
-                tlscert = "C:\\Program Files\\Firstworks\\etc\\client.pfx";
-                tlsca = "C:\\Program Files\\Firstworks\\etc\\ca.pfx";
+                tlscert = "C:\\Program Files\\Firstworks\\etc\\sqlrelay.conf.d\\client.pfx";
+                tlsca = "C:\\Program Files\\Firstworks\\etc\\sqlrelay.conf.d\\ca.pfx";
             }
 
             // open connection and command
-            SQLRelayConnection sqlrcon = new SQLRelayConnection("Data Source=sqlrserver:9000;Retry Time=0;Tries=1;Tls=yes;Tlscert=" + tlscert + ";Tlsvalidate=ca;Tlsca=" + tlsca + ";Debug=false");
+            SQLRelayConnection sqlrcon = new SQLRelayConnection("Data Source=sqlrelay:9000:/tmp/test.socket;Retry Time=0;Tries=1;Tls=yes;Tlscert=" + tlscert + ";Tlsvalidate=ca;Tlsca=" + tlsca + ";Debug=false");
             sqlrcon.Open();
 
 
@@ -582,7 +582,7 @@ namespace SQLRClientTest
 
             // commit and rollback
             Console.WriteLine("COMMIT AND ROLLBACK:");
-            SQLRelayConnection sqlrcon2 = new SQLRelayConnection("Data Source=sqlrserver:9000;Retry Time=0;Tries=1;Tls=yes;Tlscert=" + tlscert + ";Tlsvalidate=ca;Tlsca=" + tlsca + ";Debug=false");
+            SQLRelayConnection sqlrcon2 = new SQLRelayConnection("Data Source=sqlrelay:9000:/tmp/test.socket;Retry Time=0;Tries=1;Tls=yes;Tlscert=" + tlscert + ";Tlsvalidate=ca;Tlsca=" + tlsca + ";Debug=false");
             sqlrcon2.Open();
             SQLRelayCommand sqlrcom2 = new SQLRelayCommand("select count(*) from testtable", sqlrcon2);
             checkSuccess(Convert.ToInt64(sqlrcom2.ExecuteScalar()), 0);
@@ -896,6 +896,8 @@ namespace SQLRClientTest
             // invalid queries
 
             sqlrcon.Close();
+
+            Environment.Exit(0);
         }
     }
 }
