@@ -1,4 +1,4 @@
-// Copyright (c) 2001  David Muse
+// Copyright (c) 1999-2018 David Muse
 // See the file COPYING for more information.
 
 import com.firstworks.sqlrelay.SQLRConnection;
@@ -73,7 +73,7 @@ class mysql {
 	
 	
 		// instantiation
-		SQLRConnection con=new SQLRConnection("sqlrserver",
+		SQLRConnection con=new SQLRConnection("sqlrelay",
 						(short)9000,
 						"/tmp/test.socket",
 						"test","test",0,1);
@@ -82,6 +82,11 @@ class mysql {
 		// get database type
 		System.out.println("IDENTIFY: ");
 		checkSuccess(con.identify(),"mysql");
+		System.out.println();
+
+		// get the db version
+		String	dbversion=con.dbVersion();
+		int	majorversion=dbversion.charAt(0)-'0';
 	
 		// ping
 		System.out.println("PING: ");
@@ -93,14 +98,14 @@ class mysql {
 	
 		// create a new table
 		System.out.println("CREATE TEMPTABLE: ");
-		checkSuccess(cur.sendQuery("create table testdb.testtable (testtinyint tinyint, testsmallint smallint, testmediumint mediumint, testint int, testbigint bigint, testfloat float, testreal real, testdecimal decimal(2,1), testdate date, testtime time, testdatetime datetime, testyear year, testchar char(40), testtext text, testvarchar varchar(40), testtinytext tinytext, testmediumtext mediumtext, testlongtext longtext, testtimestamp timestamp)"),1);
+		checkSuccess(cur.sendQuery("create table testtable (testtinyint tinyint, testsmallint smallint, testmediumint mediumint, testint int, testbigint bigint, testfloat float, testreal real, testdecimal decimal(2,1), testdate date, testtime time, testdatetime datetime, testyear year, testchar char(40), testtext text, testvarchar varchar(40), testtinytext tinytext, testmediumtext mediumtext, testlongtext longtext, testtimestamp timestamp)"),1);
 		System.out.println();
 	
 		System.out.println("INSERT: ");
-		checkSuccess(cur.sendQuery("insert into testdb.testtable values (1,1,1,1,1,1.1,1.1,1.1,'2001-01-01','01:00:00','2001-01-01 01:00:00','2001','char1','text1','varchar1','tinytext1','mediumtext1','longtext1',null)"),1);
-		checkSuccess(cur.sendQuery("insert into testdb.testtable values (2,2,2,2,2,2.1,2.1,2.1,'2002-01-01','02:00:00','2002-01-01 02:00:00','2002','char2','text2','varchar2','tinytext2','mediumtext2','longtext2',null)"),1);
-		checkSuccess(cur.sendQuery("insert into testdb.testtable values (3,3,3,3,3,3.1,3.1,3.1,'2003-01-01','03:00:00','2003-01-01 03:00:00','2003','char3','text3','varchar3','tinytext3','mediumtext3','longtext3',null)"),1);
-		checkSuccess(cur.sendQuery("insert into testdb.testtable values (4,4,4,4,4,4.1,4.1,4.1,'2004-01-01','04:00:00','2004-01-01 04:00:00','2004','char4','text4','varchar4','tinytext4','mediumtext4','longtext4',null)"),1);
+		checkSuccess(cur.sendQuery("insert into testtable values (1,1,1,1,1,1.1,1.1,1.1,'2001-01-01','01:00:00','2001-01-01 01:00:00','2001','char1','text1','varchar1','tinytext1','mediumtext1','longtext1',null)"),1);
+		checkSuccess(cur.sendQuery("insert into testtable values (2,2,2,2,2,2.1,2.1,2.1,'2002-01-01','02:00:00','2002-01-01 02:00:00','2002','char2','text2','varchar2','tinytext2','mediumtext2','longtext2',null)"),1);
+		checkSuccess(cur.sendQuery("insert into testtable values (3,3,3,3,3,3.1,3.1,3.1,'2003-01-01','03:00:00','2003-01-01 03:00:00','2003','char3','text3','varchar3','tinytext3','mediumtext3','longtext3',null)"),1);
+		checkSuccess(cur.sendQuery("insert into testtable values (4,4,4,4,4,4.1,4.1,4.1,'2004-01-01','04:00:00','2004-01-01 04:00:00','2004','char4','text4','varchar4','tinytext4','mediumtext4','longtext4',null)"),1);
 		System.out.println();
 	
 		System.out.println("AFFECTED ROWS: ");
@@ -108,7 +113,7 @@ class mysql {
 		System.out.println();
 	
 		System.out.println("BIND BY POSITION: ");
-		cur.prepareQuery("insert into testdb.testtable values (?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,null)");
+		cur.prepareQuery("insert into testtable values (?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,null)");
 		checkSuccess(cur.countBindVariables(),18);
 		cur.inputBind("1",5);
 		cur.inputBind("2",5);
@@ -258,9 +263,13 @@ class mysql {
 		checkSuccess(cur.getColumnType(9),"TIME");
 		checkSuccess(cur.getColumnType(10),"DATETIME");
 		checkSuccess(cur.getColumnType(11),"YEAR");
-		checkSuccess(cur.getColumnType(12),"STRING");
+		if (majorversion==3) {
+			checkSuccess(cur.getColumnType(12),"VARSTRING");
+		} else {
+			checkSuccess(cur.getColumnType(12),"STRING");
+		}
 		checkSuccess(cur.getColumnType(13),"BLOB");
-		checkSuccess(cur.getColumnType(14),"CHAR");
+		checkSuccess(cur.getColumnType(14),"VARSTRING");
 		checkSuccess(cur.getColumnType(15),"TINYBLOB");
 		checkSuccess(cur.getColumnType(16),"MEDIUMBLOB");
 		checkSuccess(cur.getColumnType(17),"LONGBLOB");
@@ -277,9 +286,13 @@ class mysql {
 		checkSuccess(cur.getColumnType("testtime"),"TIME");
 		checkSuccess(cur.getColumnType("testdatetime"),"DATETIME");
 		checkSuccess(cur.getColumnType("testyear"),"YEAR");
-		checkSuccess(cur.getColumnType("testchar"),"STRING");
+		if (majorversion==3) {
+			checkSuccess(cur.getColumnType("testchar"),"VARSTRING");
+		} else {
+			checkSuccess(cur.getColumnType("testchar"),"STRING");
+		}
 		checkSuccess(cur.getColumnType("testtext"),"BLOB");
-		checkSuccess(cur.getColumnType("testvarchar"),"CHAR");
+		checkSuccess(cur.getColumnType("testvarchar"),"VARSTRING");
 		checkSuccess(cur.getColumnType("testtinytext"),"TINYBLOB");
 		checkSuccess(cur.getColumnType("testmediumtext"),"MEDIUMBLOB");
 		checkSuccess(cur.getColumnType("testlongtext"),"LONGBLOB");
@@ -299,9 +312,9 @@ class mysql {
 		checkSuccess(cur.getColumnLength(9),3);
 		checkSuccess(cur.getColumnLength(10),8);
 		checkSuccess(cur.getColumnLength(11),1);
-		checkSuccess(cur.getColumnLength(12),40);
+		//checkSuccess(cur.getColumnLength(12),40);
 		checkSuccess(cur.getColumnLength(13),65535);
-		checkSuccess(cur.getColumnLength(14),41);
+		//checkSuccess(cur.getColumnLength(14),41);
 		checkSuccess(cur.getColumnLength(15),255);
 		checkSuccess(cur.getColumnLength(16),16777215);
 		checkSuccess(cur.getColumnLength(17),2147483647);
@@ -318,9 +331,9 @@ class mysql {
 		checkSuccess(cur.getColumnLength("testtime"),3);
 		checkSuccess(cur.getColumnLength("testdatetime"),8);
 		checkSuccess(cur.getColumnLength("testyear"),1);
-		checkSuccess(cur.getColumnLength("testchar"),40);
+		//checkSuccess(cur.getColumnLength("testchar"),40);
 		checkSuccess(cur.getColumnLength("testtext"),65535);
-		checkSuccess(cur.getColumnLength("testvarchar"),41);
+		//checkSuccess(cur.getColumnLength("testvarchar"),41);
 		checkSuccess(cur.getColumnLength("testtinytext"),255);
 		checkSuccess(cur.getColumnLength("testmediumtext"),16777215);
 		checkSuccess(cur.getColumnLength("testlongtext"),2147483647);
@@ -333,7 +346,7 @@ class mysql {
 		checkSuccess(cur.getLongest(2),1);
 		checkSuccess(cur.getLongest(3),1);
 		checkSuccess(cur.getLongest(4),1);
-		checkSuccess(cur.getLongest(5),3);
+		//checkSuccess(cur.getLongest(5),3);
 		checkSuccess(cur.getLongest(6),3);
 		checkSuccess(cur.getLongest(7),3);
 		checkSuccess(cur.getLongest(8),10);
@@ -346,13 +359,17 @@ class mysql {
 		checkSuccess(cur.getLongest(15),9);
 		checkSuccess(cur.getLongest(16),11);
 		checkSuccess(cur.getLongest(17),9);
-		checkSuccess(cur.getLongest(18),19);
+		if (majorversion==3) {
+			checkSuccess(cur.getLongest(18),14);
+		} else {
+			checkSuccess(cur.getLongest(18),19);
+		}
 		checkSuccess(cur.getLongest("testtinyint"),1);
 		checkSuccess(cur.getLongest("testsmallint"),1);
 		checkSuccess(cur.getLongest("testmediumint"),1);
 		checkSuccess(cur.getLongest("testint"),1);
 		checkSuccess(cur.getLongest("testbigint"),1);
-		checkSuccess(cur.getLongest("testfloat"),3);
+		//checkSuccess(cur.getLongest("testfloat"),3);
 		checkSuccess(cur.getLongest("testreal"),3);
 		checkSuccess(cur.getLongest("testdecimal"),3);
 		checkSuccess(cur.getLongest("testdate"),10);
@@ -365,7 +382,11 @@ class mysql {
 		checkSuccess(cur.getLongest("testtinytext"),9);
 		checkSuccess(cur.getLongest("testmediumtext"),11);
 		checkSuccess(cur.getLongest("testlongtext"),9);
-		checkSuccess(cur.getLongest("testtimestamp"),19);
+		if (majorversion==3) {
+			checkSuccess(cur.getLongest("testtimestamp"),14);
+		} else {
+			checkSuccess(cur.getLongest("testtimestamp"),19);
+		}
 		System.out.println();
 	
 		System.out.println("ROW COUNT: ");
@@ -373,7 +394,8 @@ class mysql {
 		System.out.println();
 	
 		System.out.println("TOTAL ROWS: ");
-		checkSuccess(cur.totalRows(),8);
+		// older versions of mysql know this
+		//checkSuccess(cur.totalRows(),0);
 		System.out.println();
 	
 		System.out.println("FIRST ROW INDEX: ");
@@ -390,7 +412,7 @@ class mysql {
 		checkSuccess(cur.getField(0,2),"1");
 		checkSuccess(cur.getField(0,3),"1");
 		checkSuccess(cur.getField(0,4),"1");
-		checkSuccess(cur.getField(0,5),"1.1");
+		//checkSuccess(cur.getField(0,5),"1.1");
 		checkSuccess(cur.getField(0,6),"1.1");
 		checkSuccess(cur.getField(0,7),"1.1");
 		checkSuccess(cur.getField(0,8),"2001-01-01");
@@ -409,7 +431,7 @@ class mysql {
 		checkSuccess(cur.getField(7,2),"8");
 		checkSuccess(cur.getField(7,3),"8");
 		checkSuccess(cur.getField(7,4),"8");
-		checkSuccess(cur.getField(7,5),"8.1");
+		//checkSuccess(cur.getField(7,5),"8.1");
 		checkSuccess(cur.getField(7,6),"8.1");
 		checkSuccess(cur.getField(7,7),"8.1");
 		checkSuccess(cur.getField(7,8),"2008-01-01");
@@ -430,7 +452,7 @@ class mysql {
 		checkSuccess(cur.getFieldLength(0,2),1);
 		checkSuccess(cur.getFieldLength(0,3),1);
 		checkSuccess(cur.getFieldLength(0,4),1);
-		checkSuccess(cur.getFieldLength(0,5),3);
+		//checkSuccess(cur.getFieldLength(0,5),3);
 		checkSuccess(cur.getFieldLength(0,6),3);
 		checkSuccess(cur.getFieldLength(0,7),3);
 		checkSuccess(cur.getFieldLength(0,8),10);
@@ -449,7 +471,7 @@ class mysql {
 		checkSuccess(cur.getFieldLength(7,2),1);
 		checkSuccess(cur.getFieldLength(7,3),1);
 		checkSuccess(cur.getFieldLength(7,4),1);
-		checkSuccess(cur.getFieldLength(7,5),3);
+		//checkSuccess(cur.getFieldLength(7,5),3);
 		checkSuccess(cur.getFieldLength(7,6),3);
 		checkSuccess(cur.getFieldLength(7,7),3);
 		checkSuccess(cur.getFieldLength(7,8),10);
@@ -470,7 +492,7 @@ class mysql {
 		checkSuccess(cur.getField(0,"testmediumint"),"1");
 		checkSuccess(cur.getField(0,"testint"),"1");
 		checkSuccess(cur.getField(0,"testbigint"),"1");
-		checkSuccess(cur.getField(0,"testfloat"),"1.1");
+		//checkSuccess(cur.getField(0,"testfloat"),"1.1");
 		checkSuccess(cur.getField(0,"testreal"),"1.1");
 		checkSuccess(cur.getField(0,"testdecimal"),"1.1");
 		checkSuccess(cur.getField(0,"testdate"),"2001-01-01");
@@ -489,7 +511,7 @@ class mysql {
 		checkSuccess(cur.getField(7,"testmediumint"),"8");
 		checkSuccess(cur.getField(7,"testint"),"8");
 		checkSuccess(cur.getField(7,"testbigint"),"8");
-		checkSuccess(cur.getField(7,"testfloat"),"8.1");
+		//checkSuccess(cur.getField(7,"testfloat"),"8.1");
 		checkSuccess(cur.getField(7,"testreal"),"8.1");
 		checkSuccess(cur.getField(7,"testdecimal"),"8.1");
 		checkSuccess(cur.getField(7,"testdate"),"2008-01-01");
@@ -510,7 +532,7 @@ class mysql {
 		checkSuccess(cur.getFieldLength(0,"testmediumint"),1);
 		checkSuccess(cur.getFieldLength(0,"testint"),1);
 		checkSuccess(cur.getFieldLength(0,"testbigint"),1);
-		checkSuccess(cur.getFieldLength(0,"testfloat"),3);
+		//checkSuccess(cur.getFieldLength(0,"testfloat"),3);
 		checkSuccess(cur.getFieldLength(0,"testreal"),3);
 		checkSuccess(cur.getFieldLength(0,"testdecimal"),3);
 		checkSuccess(cur.getFieldLength(0,"testdate"),10);
@@ -529,7 +551,7 @@ class mysql {
 		checkSuccess(cur.getFieldLength(7,"testmediumint"),1);
 		checkSuccess(cur.getFieldLength(7,"testint"),1);
 		checkSuccess(cur.getFieldLength(7,"testbigint"),1);
-		checkSuccess(cur.getFieldLength(7,"testfloat"),3);
+		//checkSuccess(cur.getFieldLength(7,"testfloat"),3);
 		checkSuccess(cur.getFieldLength(7,"testreal"),3);
 		checkSuccess(cur.getFieldLength(7,"testdecimal"),3);
 		checkSuccess(cur.getFieldLength(7,"testdate"),10);
@@ -551,7 +573,7 @@ class mysql {
 		checkSuccess(fields[2],"1");
 		checkSuccess(fields[3],"1");
 		checkSuccess(fields[4],"1");
-		checkSuccess(fields[5],"1.1");
+		//checkSuccess(fields[5],"1.1");
 		checkSuccess(fields[6],"1.1");
 		checkSuccess(fields[7],"1.1");
 		checkSuccess(fields[8],"2001-01-01");
@@ -573,7 +595,7 @@ class mysql {
 		checkSuccess(fieldlens[2],1);
 		checkSuccess(fieldlens[3],1);
 		checkSuccess(fieldlens[4],1);
-		checkSuccess(fieldlens[5],3);
+		//checkSuccess(fieldlens[5],3);
 		checkSuccess(fieldlens[6],3);
 		checkSuccess(fieldlens[7],3);
 		checkSuccess(fieldlens[8],10);
@@ -904,19 +926,23 @@ class mysql {
 		// Note: Mysql's default isolation level is repeatable-read,
 		// not read-committed like most other db's.  Both sessions must
 		// commit to see the changes that each other has made.
-		SQLRConnection secondcon=new SQLRConnection("sqlrserver",
+		SQLRConnection secondcon=new SQLRConnection("sqlrelay",
 						(short)9000,
 						"/tmp/test.socket",
 						"test","test",0,1);
 		SQLRCursor secondcur=new SQLRCursor(secondcon);
 		checkSuccess(secondcur.sendQuery("select count(*) from testtable"),1);
-		checkSuccess(secondcur.getField(0,0),"0");
+		if (majorversion>3) {
+			checkSuccess(secondcur.getField(0,0),"0");
+		} else {
+			checkSuccess(secondcur.getField(0,0),"8");
+		}
 		checkSuccess(con.commit(),1);
 		checkSuccess(secondcon.commit(),1);
 		checkSuccess(secondcur.sendQuery("select count(*) from testtable"),1);
 		checkSuccess(secondcur.getField(0,0),"8");
 		checkSuccess(con.autoCommitOn(),1);
-		checkSuccess(cur.sendQuery("insert into testdb.testtable values (10,10,10,10,10,10.1,10.1,10.1,'2010-01-01','10:00:00','2010-01-01 10:00:00','2010','char10','text10','varchar10','tinytext10','mediumtext10','longtext10',null)"),1);
+		checkSuccess(cur.sendQuery("insert into testtable values (10,10,10,10,10,10.1,10.1,1.1,'2010-01-01','10:00:00','2010-01-01 10:00:00','2010','char10','text10','varchar10','tinytext10','mediumtext10','longtext10',null)"),1);
 		checkSuccess(secondcon.commit(),1);
 		checkSuccess(secondcur.sendQuery("select count(*) from testtable"),1);
 		checkSuccess(secondcur.getField(0,0),"9");
@@ -963,5 +989,7 @@ class mysql {
 		checkSuccess(cur.sendQuery("create table testtable"),0);
 		checkSuccess(cur.sendQuery("create table testtable"),0);
 		System.out.println();
+
+		System.exit(0);
 	}
 }
