@@ -1,4 +1,4 @@
-// Copyright (c) 2001  David Muse
+// Copyright (c) 1999-2018 David Muse
 // See the file COPYING for more information.
 
 import com.firstworks.sqlrelay.SQLRConnection;
@@ -72,7 +72,7 @@ class postgresql {
 		long[]	fieldlens;
 	
 		// instantiation
-		SQLRConnection con=new SQLRConnection("sqlrserver",
+		SQLRConnection con=new SQLRConnection("sqlrelay",
 						(short)9000,
 						"/tmp/test.socket",
 						"test","test",0,1);
@@ -153,7 +153,6 @@ class postgresql {
 		cur.inputBind("6","testvarchar8");
 		cur.inputBind("7","01/01/2008");
 		cur.inputBind("8","08:00:00");
-		cur.inputBind("9","junkvalue");
 		cur.validateBinds();
 		checkSuccess(cur.executeQuery(),1);
 		System.out.println();
@@ -253,9 +252,9 @@ class postgresql {
 		checkSuccess(cur.rowCount(),8);
 		System.out.println();
 	
-		System.out.println("TOTAL ROWS: ");
+		/*System.out.println("TOTAL ROWS: ");
 		checkSuccess(cur.totalRows(),8);
-		System.out.println();
+		System.out.println();*/
 	
 		System.out.println("FIRST ROW INDEX: ");
 		checkSuccess(cur.firstRowIndex(),0);
@@ -663,7 +662,7 @@ class postgresql {
 		System.out.println();
 	
 		System.out.println("COMMIT AND ROLLBACK: ");
-		SQLRConnection secondcon=new SQLRConnection("sqlrserver",
+		SQLRConnection secondcon=new SQLRConnection("sqlrelay",
 						(short)9000,
 						"/tmp/test.socket",
 						"test","test",0,1);
@@ -765,5 +764,7 @@ class postgresql {
 		checkSuccess(cur.sendQuery("create table testtable"),0);
 		checkSuccess(cur.sendQuery("create table testtable"),0);
 		System.out.println();
+
+		System.exit(0);
 	}
 }
