@@ -1,4 +1,4 @@
-// Copyright (c) 2001  David Muse
+// Copyright (c) 1999-2018 David Muse
 // See the file COPYING for more information.
 
 import com.firstworks.sqlrelay.SQLRConnection;
@@ -72,7 +72,7 @@ class sqlite {
 		long[]	fieldlens;
 	
 		// instantiation
-		SQLRConnection con=new SQLRConnection("sqlrserver",
+		SQLRConnection con=new SQLRConnection("sqlrelay",
 						(short)9000,
 						"/tmp/test.socket",
 						"test","test",0,1);
@@ -575,7 +575,7 @@ class sqlite {
 		System.out.println();
 
 	    	System.out.println("COMMIT AND ROLLBACK: \n");
-		SQLRConnection secondcon=new SQLRConnection("sqlrserver",
+		SQLRConnection secondcon=new SQLRConnection("sqlrelay",
 						(short)9000,
 						"/tmp/test.socket",
 						"test","test",0,1);
@@ -630,6 +630,7 @@ class sqlite {
 		checkSuccess(cur.sendQuery("create table testtable"),0);
 		checkSuccess(cur.sendQuery("create table testtable"),0);
 		System.out.println();
-	
+
+		System.exit(0);
 	}
 }
