@@ -1,4 +1,4 @@
-// Copyright (c) 2015  David Muse
+// Copyright (c) 1999-2018 David Muse
 // See the file COPYING for more information.
 
 var	sqlrelay=require("sqlrelay");
@@ -38,7 +38,7 @@ var	filename;
 var	fieldlens;
 	
 // instantiation
-var	con=new sqlrelay.SQLRConnection("sqlrserver",
+var	con=new sqlrelay.SQLRConnection("sqlrelay",
 					9000,
 					"/tmp/test.socket",
 					"test","test",0,1);
@@ -681,7 +681,7 @@ cur.setResultSetBufferSize(0);
 console.log("\n");
 	
 //console.log("COMMIT AND ROLLBACK: ");
-var	secondcon=new sqlrelay.SQLRConnection("sqlrserver",
+var	secondcon=new sqlrelay.SQLRConnection("sqlrelay",
 						9000,
 						"/tmp/test.socket",
 						"test","test",0,1);
@@ -740,3 +740,5 @@ checkSuccess(cur.sendQuery("create table testtable"),0);
 checkSuccess(cur.sendQuery("create table testtable"),0);
 checkSuccess(cur.sendQuery("create table testtable"),0);
 console.log("\n");
+
+process.exit(0);
