@@ -1,4 +1,4 @@
-// Copyright (c) 2015  David Muse
+// Copyright (c) 1999-2018 David Muse
 // See the file COPYING for more information.
 
 var	sqlrelay=require("sqlrelay");
@@ -32,7 +32,7 @@ var	filename;
 var	fieldlens;
 	
 // instantiation
-var	con=new sqlrelay.SQLRConnection("sqlrserver",
+var	con=new sqlrelay.SQLRConnection("sqlrelay",
 				9000,
 				"/tmp/test.socket",
 				"test","test",0,1);
@@ -113,7 +113,6 @@ cur.inputBind("5","testchar8");
 cur.inputBind("6","testvarchar8");
 cur.inputBind("7","01/01/2008");
 cur.inputBind("8","08:00:00");
-cur.inputBind("9","junkvalue");
 cur.validateBinds();
 checkSuccess(cur.executeQuery(),1);
 console.log("\n");
@@ -213,9 +212,9 @@ console.log("ROW COUNT: ");
 checkSuccess(cur.rowCount(),8);
 console.log("\n");
 	
-console.log("TOTAL ROWS: ");
+/*console.log("TOTAL ROWS: ");
 checkSuccess(cur.totalRows(),8);
-console.log("\n");
+console.log("\n");*/
 	
 console.log("FIRST ROW INDEX: ");
 checkSuccess(cur.firstRowIndex(),0);
@@ -623,7 +622,7 @@ cur.setResultSetBufferSize(0);
 console.log("\n");
 	
 console.log("COMMIT AND ROLLBACK: ");
-var	secondcon=new sqlrelay.SQLRConnection("sqlrserver",
+var	secondcon=new sqlrelay.SQLRConnection("sqlrelay",
 				9000,
 				"/tmp/test.socket",
 				"test","test",0,1);
@@ -725,3 +724,5 @@ checkSuccess(cur.sendQuery("create table testtable"),0);
 checkSuccess(cur.sendQuery("create table testtable"),0);
 checkSuccess(cur.sendQuery("create table testtable"),0);
 console.log("\n");
+
+process.exit(0);
