@@ -1,6 +1,6 @@
 #! /usr/bin/env perl
 
-# Copyright (c) 2001  David Muse
+# Copyright (c) 1999-2018 David Muse
 # See the file COPYING for more information.
 
 
@@ -51,7 +51,7 @@ sub checkSuccessString {
 
 
 # instantiation
-$con=SQLRelay::Connection->new("sqlrserver",9000,"/tmp/test.socket",
+$con=SQLRelay::Connection->new("sqlrelay",9000,"/tmp/test.socket",
 							"test","test",0,1);
 $cur=SQLRelay::Cursor->new($con);
 
@@ -102,6 +102,7 @@ $cur->inputBind("12","testchar2");
 $cur->inputBind("13","testvarchar2");
 $cur->inputBind("14",1);
 checkSuccess($cur->executeQuery(),1);
+$con->debugOff();
 $cur->clearBinds();
 $cur->inputBind("1",3);
 $cur->inputBind("2",3);
@@ -904,5 +905,4 @@ checkSuccess($cur->sendQuery("create table testtable"),0);
 checkSuccess($cur->sendQuery("create table testtable"),0);
 print("\n");
 
-
-
+exit(0);
