@@ -1,6 +1,6 @@
 #! /usr/bin/env perl
 
-# Copyright (c) 2001  David Muse
+# Copyright (c) 1999-2018 David Muse
 # See the file COPYING for more information.
 
 
@@ -47,16 +47,16 @@ sub checkSuccessString {
 	}
 }
 
-$cert="/usr/local/firstworks/etc/client.pem";
-$ca="/usr/local/firstworks/etc/ca.pem";
+$cert="/usr/local/firstworks/etc/sqlrelay.conf.d/client.pem";
+$ca="/usr/local/firstworks/etc/sqlrelay.conf.d/ca.pem";
 if ($^O eq "MSWin32") {
-	$cert="C:\\Program Files\\Firstworks\\etc\\client.pfx";
-	$ca="C:\\Program Files\\Firstworks\\etc\\ca.pfx";
+	$cert="C:\\Program Files\\Firstworks\\etc\\sqlrelay.conf.d\\client.pfx";
+	$ca="C:\\Program Files\\Firstworks\\etc\\sqlrelay.conf.d\\ca.pfx";
 }
 
 
 # instantiation
-$con=SQLRelay::Connection->new("sqlrserver",9000,"/tmp/test.socket","","",0,1);
+$con=SQLRelay::Connection->new("sqlrelay",9000,"/tmp/test.socket","","",0,1);
 $cur=SQLRelay::Cursor->new($con);
 $con->enableTls("",$cert,"","","ca",$ca,0);
 
@@ -74,7 +74,6 @@ print("\n");
 $cur->sendQuery("drop table testtable");
 
 print("CREATE TEMPTABLE: \n");
-#$con->debugOn();
 checkSuccess($cur->sendQuery("create table testtable (testnumber number, testchar char(40), testvarchar varchar2(40), testdate date, testlong long, testclob clob, testblob blob)"),1);
 print("\n");
 
@@ -231,41 +230,41 @@ print("\n");
 
 print("COLUMN TYPES: \n");
 checkSuccessString($cur->getColumnType(0),"NUMBER");
-checkSuccessString($cur->getColumnType('testnumber'),"NUMBER");
+checkSuccessString($cur->getColumnType('TESTNUMBER'),"NUMBER");
 checkSuccessString($cur->getColumnType(1),"CHAR");
-checkSuccessString($cur->getColumnType('testchar'),"CHAR");
+checkSuccessString($cur->getColumnType('TESTCHAR'),"CHAR");
 checkSuccessString($cur->getColumnType(2),"VARCHAR2");
-checkSuccessString($cur->getColumnType('testvarchar'),"VARCHAR2");
+checkSuccessString($cur->getColumnType('TESTVARCHAR'),"VARCHAR2");
 checkSuccessString($cur->getColumnType(3),"DATE");
-checkSuccessString($cur->getColumnType('testdate'),"DATE");
+checkSuccessString($cur->getColumnType('TESTDATE'),"DATE");
 checkSuccessString($cur->getColumnType(4),"LONG");
-checkSuccessString($cur->getColumnType('testlong'),"LONG");
+checkSuccessString($cur->getColumnType('TESTLONG'),"LONG");
 print("\n");
 
 print("COLUMN LENGTH: \n");
 checkSuccess($cur->getColumnLength(0),22);
-checkSuccess($cur->getColumnLength('testnumber'),22);
+checkSuccess($cur->getColumnLength('TESTNUMBER'),22);
 checkSuccess($cur->getColumnLength(1),40);
-checkSuccess($cur->getColumnLength('testchar'),40);
+checkSuccess($cur->getColumnLength('TESTCHAR'),40);
 checkSuccess($cur->getColumnLength(2),40);
-checkSuccess($cur->getColumnLength('testvarchar'),40);
+checkSuccess($cur->getColumnLength('TESTVARCHAR'),40);
 checkSuccess($cur->getColumnLength(3),7);
-checkSuccess($cur->getColumnLength('testdate'),7);
+checkSuccess($cur->getColumnLength('TESTDATE'),7);
 checkSuccess($cur->getColumnLength(4),0);
-checkSuccess($cur->getColumnLength('testlong'),0);
+checkSuccess($cur->getColumnLength('TESTLONG'),0);
 print("\n");
 
 print("LONGEST COLUMN: \n");
 checkSuccess($cur->getLongest(0),1);
-checkSuccess($cur->getLongest('testnumber'),1);
+checkSuccess($cur->getLongest('TESTNUMBER'),1);
 checkSuccess($cur->getLongest(1),40);
-checkSuccess($cur->getLongest('testchar'),40);
+checkSuccess($cur->getLongest('TESTCHAR'),40);
 checkSuccess($cur->getLongest(2),12);
-checkSuccess($cur->getLongest('testvarchar'),12);
+checkSuccess($cur->getLongest('TESTVARCHAR'),12);
 checkSuccess($cur->getLongest(3),9);
-checkSuccess($cur->getLongest('testdate'),9);
+checkSuccess($cur->getLongest('TESTDATE'),9);
 checkSuccess($cur->getLongest(4),9);
-checkSuccess($cur->getLongest('testlong'),9);
+checkSuccess($cur->getLongest('TESTLONG'),9);
 print("\n");
 
 print("ROW COUNT: \n");
@@ -321,39 +320,39 @@ checkSuccess($cur->getFieldLength(7,6),9);
 print("\n");
 
 print("FIELDS BY NAME: \n");
-checkSuccessString($cur->getField(0,"testnumber"),"1");
-checkSuccessString($cur->getField(0,"testchar"),"testchar1                               ");
-checkSuccessString($cur->getField(0,"testvarchar"),"testvarchar1");
-checkSuccessString($cur->getField(0,"testdate"),"01-JAN-01");
-checkSuccessString($cur->getField(0,"testlong"),"testlong1");
-checkSuccessString($cur->getField(0,"testclob"),"testclob1");
-checkSuccessString($cur->getField(0,"testblob"),"");
+checkSuccessString($cur->getField(0,"TESTNUMBER"),"1");
+checkSuccessString($cur->getField(0,"TESTCHAR"),"testchar1                               ");
+checkSuccessString($cur->getField(0,"TESTVARCHAR"),"testvarchar1");
+checkSuccessString($cur->getField(0,"TESTDATE"),"01-JAN-01");
+checkSuccessString($cur->getField(0,"TESTLONG"),"testlong1");
+checkSuccessString($cur->getField(0,"TESTCLOB"),"testclob1");
+checkSuccessString($cur->getField(0,"TESTBLOB"),"");
 print("\n");
-checkSuccessString($cur->getField(7,"testnumber"),"8");
-checkSuccessString($cur->getField(7,"testchar"),"testchar8                               ");
-checkSuccessString($cur->getField(7,"testvarchar"),"testvarchar8");
-checkSuccessString($cur->getField(7,"testdate"),"01-JAN-08");
-checkSuccessString($cur->getField(7,"testlong"),"testlong8");
-checkSuccessString($cur->getField(7,"testclob"),"testclob8");
-checkSuccessString($cur->getField(7,"testblob"),"testblob8");
+checkSuccessString($cur->getField(7,"TESTNUMBER"),"8");
+checkSuccessString($cur->getField(7,"TESTCHAR"),"testchar8                               ");
+checkSuccessString($cur->getField(7,"TESTVARCHAR"),"testvarchar8");
+checkSuccessString($cur->getField(7,"TESTDATE"),"01-JAN-08");
+checkSuccessString($cur->getField(7,"TESTLONG"),"testlong8");
+checkSuccessString($cur->getField(7,"TESTCLOB"),"testclob8");
+checkSuccessString($cur->getField(7,"TESTBLOB"),"testblob8");
 print("\n");
 
 print("FIELD LENGTHS BY NAME: \n");
-checkSuccess($cur->getFieldLength(0,"testnumber"),1);
-checkSuccess($cur->getFieldLength(0,"testchar"),40);
-checkSuccess($cur->getFieldLength(0,"testvarchar"),12);
-checkSuccess($cur->getFieldLength(0,"testdate"),9);
-checkSuccess($cur->getFieldLength(0,"testlong"),9);
-checkSuccess($cur->getFieldLength(0,"testclob"),9);
-checkSuccess($cur->getFieldLength(0,"testblob"),0);
+checkSuccess($cur->getFieldLength(0,"TESTNUMBER"),1);
+checkSuccess($cur->getFieldLength(0,"TESTCHAR"),40);
+checkSuccess($cur->getFieldLength(0,"TESTVARCHAR"),12);
+checkSuccess($cur->getFieldLength(0,"TESTDATE"),9);
+checkSuccess($cur->getFieldLength(0,"TESTLONG"),9);
+checkSuccess($cur->getFieldLength(0,"TESTCLOB"),9);
+checkSuccess($cur->getFieldLength(0,"TESTBLOB"),0);
 print("\n");
-checkSuccess($cur->getFieldLength(7,"testnumber"),1);
-checkSuccess($cur->getFieldLength(7,"testchar"),40);
-checkSuccess($cur->getFieldLength(7,"testvarchar"),12);
-checkSuccess($cur->getFieldLength(7,"testdate"),9);
-checkSuccess($cur->getFieldLength(7,"testlong"),9);
-checkSuccess($cur->getFieldLength(7,"testclob"),9);
-checkSuccess($cur->getFieldLength(7,"testblob"),9);
+checkSuccess($cur->getFieldLength(7,"TESTNUMBER"),1);
+checkSuccess($cur->getFieldLength(7,"TESTCHAR"),40);
+checkSuccess($cur->getFieldLength(7,"TESTVARCHAR"),12);
+checkSuccess($cur->getFieldLength(7,"TESTDATE"),9);
+checkSuccess($cur->getFieldLength(7,"TESTLONG"),9);
+checkSuccess($cur->getFieldLength(7,"TESTCLOB"),9);
+checkSuccess($cur->getFieldLength(7,"TESTBLOB"),9);
 print("\n");
 
 print("FIELDS BY ARRAY: \n");
@@ -695,7 +694,7 @@ $cur->setResultSetBufferSize(0);
 print("\n");
 
 print("COMMIT AND ROLLBACK: \n");
-$secondcon=SQLRelay::Connection->new("sqlrserver",9000,"/tmp/test.socket",
+$secondcon=SQLRelay::Connection->new("sqlrelay",9000,"/tmp/test.socket",
 								"","",0,1);
 $secondcur=SQLRelay::Cursor->new($secondcon);
 $secondcon->enableTls("",$cert,"","","ca",$ca,0);
@@ -817,7 +816,7 @@ for ($i=0; $i<4000; $i++) {
 $cur->inputBind("testval",$testval);
 checkSuccess($cur->executeQuery(),1);
 $cur->sendQuery("select testval from testtable2");
-checkSuccess($testval,$cur->getField(0,"testval"));
+checkSuccess($testval,$cur->getField(0,"TESTVAL"));
 $query="begin :bindval:='".$testval."'; end;";
 $cur->prepareQuery($query);
 $cur->defineOutputBindString("bindval",4000);
@@ -834,7 +833,7 @@ $cur->prepareQuery("insert into testtable2 values (:testval)");
 $cur->inputBind("testval",-1);
 checkSuccess($cur->executeQuery(),1);
 $cur->sendQuery("select testval from testtable2");
-checkSuccess($cur->getField(0,"testval"),"-1");
+checkSuccess($cur->getField(0,"TESTVAL"),"-1");
 $cur->sendQuery("drop table testtable2");
 print("\n");
 
@@ -905,3 +904,5 @@ checkSuccess($cur->sendQuery("create table testtable"),0);
 checkSuccess($cur->sendQuery("create table testtable"),0);
 checkSuccess($cur->sendQuery("create table testtable"),0);
 print("\n");
+
+exit(0);
