@@ -1,11 +1,12 @@
 #! /usr/bin/env perl
 
-# Copyright (c) 2001  David Muse
+# Copyright (c) 1999-2018 David Muse
 # See the file COPYING for more information.
 
 use DBI;
 use DBI::Const::GetInfoType;
 use Data::Dumper;
+use Sys::Hostname;
 
 sub checkUndef {
 
@@ -59,17 +60,17 @@ sub checkSuccessString {
 	}
 }
 
-$tlscert="/usr/local/firstworks/etc/client.pem";
-$tlsca="/usr/local/firstworks/etc/ca.pem";
+$tlscert="/usr/local/firstworks/etc/sqlrelay.conf.d/client.pem";
+$tlsca="/usr/local/firstworks/etc/sqlrelay.conf.d/ca.pem";
 if ($^O eq "MSWin32") {
-	$tlscert="C:\\Program Files\\Firstworks\\etc\\client.pfx";
-	$tlsca="C:\\Program Files\\Firstworks\\etc\\ca.pfx";
+	$tlscert="C:\\Program Files\\Firstworks\\etc\\sqlrelay.conf.d\\client.pfx";
+	$tlsca="C:\\Program Files\\Firstworks\\etc\\sqlrelay.conf.d\\ca.pfx";
 }
 
+
 # instantiation
 my $prefix="DBI:SQLRelay(AutoCommit=>0,PrintError=>0):";
-my $connectstring="host=sqlrserver;port=9000;socket=/tmp/test.socket;debug=0;tls=yes;tlscert=$tlscert;tlsvalidate=ca;tlsca=$tlsca";
-printf("$connectstring\n");
+my $connectstring="host=sqlrelay;port=9000;socket=/tmp/test.socket;debug=0;tls=yes;tlscert=$tlscert;tlsvalidate=ca;tlsca=$tlsca";
 my $dsn=$prefix.$connectstring;
 
 # parse dsn
@@ -755,9 +756,14 @@ print("\n");
 
 # get info
 print("GET INFO: \n");
-checkSuccessString($dbh->get_info($GetInfoType{SQL_DATA_SOURCE_NAME}),"TESTUSER");
+my $hostname=hostname();
+if (index($hostname,".")!=-1) {
+	($hostname)=split(/\./,$hostname);
+}
+$hostname=uc($hostname);
+checkSuccessString($dbh->get_info($GetInfoType{SQL_DATA_SOURCE_NAME}),$hostname);
 checkSuccessString($dbh->get_info($GetInfoType{SQL_DBMS_NAME}),"oracle");
-checkSuccessString($dbh->get_info($GetInfoType{SQL_DBMS_VER}),"Oracle Database 12c Enterprise Edition Release 12.1.0.1.0 - 64bit Production\nWith the Partitioning, OLAP, Advanced Analytics and Real Application Testing options");
+checkSuccessString($dbh->get_info($GetInfoType{SQL_DBMS_VER}),"Oracle Database 12c Enterprise Edition Release 12.2.0.1.0 - 64bit Production");
 checkSuccessString($dbh->get_info($GetInfoType{SQL_USER_NAME}),"");
 checkSuccessString($dbh->get_info($GetInfoType{SQL_IDENTIFIER_QUOTE_CHAR}),"\"");
 checkSuccessString($dbh->get_info($GetInfoType{SQL_CATALOG_NAME_SEPARATOR}),"@");
@@ -800,3 +806,5 @@ print("\n");
 
 
 $dbh->disconnect();
+
+exit(0);
