@@ -1,5 +1,5 @@
 <html><pre><?php
-# Copyright (c) 2001  David Muse
+# Copyright (c) 1999-2018 David Muse
 # See the file COPYING for more information.
 
 	function checkSuccess($value,$success) {
@@ -15,7 +15,7 @@
 		}
 	}
 
-	$host="sqlrserver";
+	$host="sqlrelay";
 	$port=9000;
 	$socket="/tmp/test.socket";
 	$user="test";
@@ -277,51 +277,51 @@
 	echo("\n");
 
 	echo("FIELDS BY NAME: \n");
-	checkSuccess(sqlrcur_getField($cur,0,"testsmallint"),"1");
-	checkSuccess(sqlrcur_getField($cur,0,"testint"),"1");
-	checkSuccess(sqlrcur_getField($cur,0,"testbigint"),"1");
-	checkSuccess(sqlrcur_getField($cur,0,"testdecimal"),"1.10");
-	#checkSuccess(sqlrcur_getField($cur,0,"testreal"),"1.1");
-	#checkSuccess(sqlrcur_getField($cur,0,"testdouble"),"1.1");
-	checkSuccess(sqlrcur_getField($cur,0,"testchar"),"testchar1                               ");
-	checkSuccess(sqlrcur_getField($cur,0,"testvarchar"),"testvarchar1");
-	checkSuccess(sqlrcur_getField($cur,0,"testdate"),"2001-01-01");
-	checkSuccess(sqlrcur_getField($cur,0,"testtime"),"01:00:00");
+	checkSuccess(sqlrcur_getField($cur,0,"TESTSMALLINT"),"1");
+	checkSuccess(sqlrcur_getField($cur,0,"TESTINT"),"1");
+	checkSuccess(sqlrcur_getField($cur,0,"TESTBIGINT"),"1");
+	checkSuccess(sqlrcur_getField($cur,0,"TESTDECIMAL"),"1.10");
+	#checkSuccess(sqlrcur_getField($cur,0,"TESTREAL"),"1.1");
+	#checkSuccess(sqlrcur_getField($cur,0,"TESTDOUBLE"),"1.1");
+	checkSuccess(sqlrcur_getField($cur,0,"TESTCHAR"),"testchar1                               ");
+	checkSuccess(sqlrcur_getField($cur,0,"TESTVARCHAR"),"testvarchar1");
+	checkSuccess(sqlrcur_getField($cur,0,"TESTDATE"),"2001-01-01");
+	checkSuccess(sqlrcur_getField($cur,0,"TESTTIME"),"01:00:00");
 	echo("\n");
-	checkSuccess(sqlrcur_getField($cur,7,"testsmallint"),"8");
-	checkSuccess(sqlrcur_getField($cur,7,"testint"),"8");
-	checkSuccess(sqlrcur_getField($cur,7,"testbigint"),"8");
-	checkSuccess(sqlrcur_getField($cur,7,"testdecimal"),"8.80");
-	#checkSuccess(sqlrcur_getField($cur,7,"testreal"),"8.8");
-	#checkSuccess(sqlrcur_getField($cur,7,"testdouble"),"8.8");
-	checkSuccess(sqlrcur_getField($cur,7,"testchar"),"testchar8                               ");
-	checkSuccess(sqlrcur_getField($cur,7,"testvarchar"),"testvarchar8");
-	checkSuccess(sqlrcur_getField($cur,7,"testdate"),"2008-01-01");
-	checkSuccess(sqlrcur_getField($cur,7,"testtime"),"08:00:00");
+	checkSuccess(sqlrcur_getField($cur,7,"TESTSMALLINT"),"8");
+	checkSuccess(sqlrcur_getField($cur,7,"TESTINT"),"8");
+	checkSuccess(sqlrcur_getField($cur,7,"TESTBIGINT"),"8");
+	checkSuccess(sqlrcur_getField($cur,7,"TESTDECIMAL"),"8.80");
+	#checkSuccess(sqlrcur_getField($cur,7,"TESTREAL"),"8.8");
+	#checkSuccess(sqlrcur_getField($cur,7,"TESTDOUBLE"),"8.8");
+	checkSuccess(sqlrcur_getField($cur,7,"TESTCHAR"),"testchar8                               ");
+	checkSuccess(sqlrcur_getField($cur,7,"TESTVARCHAR"),"testvarchar8");
+	checkSuccess(sqlrcur_getField($cur,7,"TESTDATE"),"2008-01-01");
+	checkSuccess(sqlrcur_getField($cur,7,"TESTTIME"),"08:00:00");
 	echo("\n");
 
 	echo("FIELD LENGTHS BY NAME: \n");
-	checkSuccess(sqlrcur_getFieldLength($cur,0,"testsmallint"),1);
-	checkSuccess(sqlrcur_getFieldLength($cur,0,"testint"),1);
-	checkSuccess(sqlrcur_getFieldLength($cur,0,"testbigint"),1);
-	checkSuccess(sqlrcur_getFieldLength($cur,0,"testdecimal"),4);
-	#checkSuccess(sqlrcur_getFieldLength($cur,0,"testreal"),3);
-	#checkSuccess(sqlrcur_getFieldLength($cur,0,"testdouble"),3);
-	checkSuccess(sqlrcur_getFieldLength($cur,0,"testchar"),40);
-	checkSuccess(sqlrcur_getFieldLength($cur,0,"testvarchar"),12);
-	checkSuccess(sqlrcur_getFieldLength($cur,0,"testdate"),10);
-	checkSuccess(sqlrcur_getFieldLength($cur,0,"testtime"),8);
+	checkSuccess(sqlrcur_getFieldLength($cur,0,"TESTSMALLINT"),1);
+	checkSuccess(sqlrcur_getFieldLength($cur,0,"TESTINT"),1);
+	checkSuccess(sqlrcur_getFieldLength($cur,0,"TESTBIGINT"),1);
+	checkSuccess(sqlrcur_getFieldLength($cur,0,"TESTDECIMAL"),4);
+	#checkSuccess(sqlrcur_getFieldLength($cur,0,"TESTREAL"),3);
+	#checkSuccess(sqlrcur_getFieldLength($cur,0,"TESTDOUBLE"),3);
+	checkSuccess(sqlrcur_getFieldLength($cur,0,"TESTCHAR"),40);
+	checkSuccess(sqlrcur_getFieldLength($cur,0,"TESTVARCHAR"),12);
+	checkSuccess(sqlrcur_getFieldLength($cur,0,"TESTDATE"),10);
+	checkSuccess(sqlrcur_getFieldLength($cur,0,"TESTTIME"),8);
 	echo("\n");
-	checkSuccess(sqlrcur_getFieldLength($cur,7,"testsmallint"),1);
-	checkSuccess(sqlrcur_getFieldLength($cur,7,"testint"),1);
-	checkSuccess(sqlrcur_getFieldLength($cur,7,"testbigint"),1);
-	checkSuccess(sqlrcur_getFieldLength($cur,7,"testdecimal"),4);
-	#checkSuccess(sqlrcur_getFieldLength($cur,7,"testreal"),3);
-	#checkSuccess(sqlrcur_getFieldLength($cur,7,"testdouble"),3);
-	checkSuccess(sqlrcur_getFieldLength($cur,7,"testchar"),40);
-	checkSuccess(sqlrcur_getFieldLength($cur,7,"testvarchar"),12);
-	checkSuccess(sqlrcur_getFieldLength($cur,7,"testdate"),10);
-	checkSuccess(sqlrcur_getFieldLength($cur,7,"testtime"),8);
+	checkSuccess(sqlrcur_getFieldLength($cur,7,"TESTSMALLINT"),1);
+	checkSuccess(sqlrcur_getFieldLength($cur,7,"TESTINT"),1);
+	checkSuccess(sqlrcur_getFieldLength($cur,7,"TESTBIGINT"),1);
+	checkSuccess(sqlrcur_getFieldLength($cur,7,"TESTDECIMAL"),4);
+	#checkSuccess(sqlrcur_getFieldLength($cur,7,"TESTREAL"),3);
+	#checkSuccess(sqlrcur_getFieldLength($cur,7,"TESTDOUBLE"),3);
+	checkSuccess(sqlrcur_getFieldLength($cur,7,"TESTCHAR"),40);
+	checkSuccess(sqlrcur_getFieldLength($cur,7,"TESTVARCHAR"),12);
+	checkSuccess(sqlrcur_getFieldLength($cur,7,"TESTDATE"),10);
+	checkSuccess(sqlrcur_getFieldLength($cur,7,"TESTTIME"),8);
 	echo("\n");
 
 	echo("FIELDS BY ARRAY: \n");
