@@ -1,5 +1,5 @@
 <html><pre><?php
-# Copyright (c) 2001  David Muse
+# Copyright (c) 1999-2018 David Muse
 # See the file COPYING for more information.
 
 	function checkSuccess($value,$success) {
@@ -15,7 +15,7 @@
 		}
 	}
 
-	$host="sqlrserver";
+	$host="sqlrelay";
 	$port=9000;
 	$socket="/tmp/test.socket";
 	$user=null;
@@ -200,53 +200,53 @@
 
 	echo("COLUMN TYPES: \n");
 	checkSuccess(sqlrcur_getColumnType($cur,0),"NUMBER");
-	checkSuccess(sqlrcur_getColumnType($cur,"testnumber"),"NUMBER");
+	checkSuccess(sqlrcur_getColumnType($cur,"TESTNUMBER"),"NUMBER");
 	checkSuccess(sqlrcur_getColumnType($cur,1),"CHAR");
-	checkSuccess(sqlrcur_getColumnType($cur,"testchar"),"CHAR");
+	checkSuccess(sqlrcur_getColumnType($cur,"TESTCHAR"),"CHAR");
 	checkSuccess(sqlrcur_getColumnType($cur,2),"VARCHAR2");
-	checkSuccess(sqlrcur_getColumnType($cur,"testvarchar"),"VARCHAR2");
+	checkSuccess(sqlrcur_getColumnType($cur,"TESTVARCHAR"),"VARCHAR2");
 	checkSuccess(sqlrcur_getColumnType($cur,3),"DATE");
-	checkSuccess(sqlrcur_getColumnType($cur,"testdate"),"DATE");
+	checkSuccess(sqlrcur_getColumnType($cur,"TESTDATE"),"DATE");
 	checkSuccess(sqlrcur_getColumnType($cur,4),"LONG");
-	checkSuccess(sqlrcur_getColumnType($cur,"testlong"),"LONG");
+	checkSuccess(sqlrcur_getColumnType($cur,"TESTLONG"),"LONG");
 	checkSuccess(sqlrcur_getColumnType($cur,5),"CLOB");
-	checkSuccess(sqlrcur_getColumnType($cur,"testclob"),"CLOB");
+	checkSuccess(sqlrcur_getColumnType($cur,"TESTCLOB"),"CLOB");
 	checkSuccess(sqlrcur_getColumnType($cur,6),"BLOB");
-	checkSuccess(sqlrcur_getColumnType($cur,"testblob"),"BLOB");
+	checkSuccess(sqlrcur_getColumnType($cur,"TESTBLOB"),"BLOB");
 	echo("\n");
 
 	echo("COLUMN LENGTH: \n");
 	checkSuccess(sqlrcur_getColumnLength($cur,0),22);
-	checkSuccess(sqlrcur_getColumnLength($cur,"testnumber"),22);
+	checkSuccess(sqlrcur_getColumnLength($cur,"TESTNUMBER"),22);
 	checkSuccess(sqlrcur_getColumnLength($cur,1),40);
-	checkSuccess(sqlrcur_getColumnLength($cur,"testchar"),40);
+	checkSuccess(sqlrcur_getColumnLength($cur,"TESTCHAR"),40);
 	checkSuccess(sqlrcur_getColumnLength($cur,2),40);
-	checkSuccess(sqlrcur_getColumnLength($cur,"testvarchar"),40);
+	checkSuccess(sqlrcur_getColumnLength($cur,"TESTVARCHAR"),40);
 	checkSuccess(sqlrcur_getColumnLength($cur,3),7);
-	checkSuccess(sqlrcur_getColumnLength($cur,"testdate"),7);
+	checkSuccess(sqlrcur_getColumnLength($cur,"TESTDATE"),7);
 	checkSuccess(sqlrcur_getColumnLength($cur,4),0);
-	checkSuccess(sqlrcur_getColumnLength($cur,"testlong"),0);
+	checkSuccess(sqlrcur_getColumnLength($cur,"TESTLONG"),0);
 	checkSuccess(sqlrcur_getColumnLength($cur,5),0);
-	checkSuccess(sqlrcur_getColumnLength($cur,"testclob"),0);
+	checkSuccess(sqlrcur_getColumnLength($cur,"TESTCLOB"),0);
 	checkSuccess(sqlrcur_getColumnLength($cur,6),0);
-	checkSuccess(sqlrcur_getColumnLength($cur,"testblob"),0);
+	checkSuccess(sqlrcur_getColumnLength($cur,"TESTBLOB"),0);
 	echo("\n");
 
 	echo("LONGEST COLUMN: \n");
 	checkSuccess(sqlrcur_getLongest($cur,0),1);
-	checkSuccess(sqlrcur_getLongest($cur,"testnumber"),1);
+	checkSuccess(sqlrcur_getLongest($cur,"TESTNUMBER"),1);
 	checkSuccess(sqlrcur_getLongest($cur,1),40);
-	checkSuccess(sqlrcur_getLongest($cur,"testchar"),40);
+	checkSuccess(sqlrcur_getLongest($cur,"TESTCHAR"),40);
 	checkSuccess(sqlrcur_getLongest($cur,2),12);
-	checkSuccess(sqlrcur_getLongest($cur,"testvarchar"),12);
+	checkSuccess(sqlrcur_getLongest($cur,"TESTVARCHAR"),12);
 	checkSuccess(sqlrcur_getLongest($cur,3),9);
-	checkSuccess(sqlrcur_getLongest($cur,"testdate"),9);
+	checkSuccess(sqlrcur_getLongest($cur,"TESTDATE"),9);
 	checkSuccess(sqlrcur_getLongest($cur,4),9);
-	checkSuccess(sqlrcur_getLongest($cur,"testlong"),9);
+	checkSuccess(sqlrcur_getLongest($cur,"TESTLONG"),9);
 	checkSuccess(sqlrcur_getLongest($cur,5),9);
-	checkSuccess(sqlrcur_getLongest($cur,"testclob"),9);
+	checkSuccess(sqlrcur_getLongest($cur,"TESTCLOB"),9);
 	checkSuccess(sqlrcur_getLongest($cur,6),9);
-	checkSuccess(sqlrcur_getLongest($cur,"testblob"),9);
+	checkSuccess(sqlrcur_getLongest($cur,"TESTBLOB"),9);
 	echo("\n");
 
 	echo("ROW COUNT: \n");
@@ -302,39 +302,39 @@
 	echo("\n");
 
 	echo("FIELDS BY NAME: \n");
-	checkSuccess(sqlrcur_getField($cur,0,"testnumber"),"1");
-	checkSuccess(sqlrcur_getField($cur,0,"testchar"),"testchar1                               ");
-	checkSuccess(sqlrcur_getField($cur,0,"testvarchar"),"testvarchar1");
-	checkSuccess(sqlrcur_getField($cur,0,"testdate"),"01-JAN-01");
-	checkSuccess(sqlrcur_getField($cur,0,"testlong"),"testlong1");
-	checkSuccess(sqlrcur_getField($cur,0,"testclob"),"testclob1");
-	checkSuccess(sqlrcur_getField($cur,0,"testblob"),"");
+	checkSuccess(sqlrcur_getField($cur,0,"TESTNUMBER"),"1");
+	checkSuccess(sqlrcur_getField($cur,0,"TESTCHAR"),"testchar1                               ");
+	checkSuccess(sqlrcur_getField($cur,0,"TESTVARCHAR"),"testvarchar1");
+	checkSuccess(sqlrcur_getField($cur,0,"TESTDATE"),"01-JAN-01");
+	checkSuccess(sqlrcur_getField($cur,0,"TESTLONG"),"testlong1");
+	checkSuccess(sqlrcur_getField($cur,0,"TESTCLOB"),"testclob1");
+	checkSuccess(sqlrcur_getField($cur,0,"TESTBLOB"),"");
 	echo("\n");
-	checkSuccess(sqlrcur_getField($cur,7,"testnumber"),"8");
-	checkSuccess(sqlrcur_getField($cur,7,"testchar"),"testchar8                               ");
-	checkSuccess(sqlrcur_getField($cur,7,"testvarchar"),"testvarchar8");
-	checkSuccess(sqlrcur_getField($cur,7,"testdate"),"01-JAN-08");
-	checkSuccess(sqlrcur_getField($cur,7,"testlong"),"testlong8");
-	checkSuccess(sqlrcur_getField($cur,7,"testclob"),"testclob8");
-	checkSuccess(sqlrcur_getField($cur,7,"testblob"),"testblob8");
+	checkSuccess(sqlrcur_getField($cur,7,"TESTNUMBER"),"8");
+	checkSuccess(sqlrcur_getField($cur,7,"TESTCHAR"),"testchar8                               ");
+	checkSuccess(sqlrcur_getField($cur,7,"TESTVARCHAR"),"testvarchar8");
+	checkSuccess(sqlrcur_getField($cur,7,"TESTDATE"),"01-JAN-08");
+	checkSuccess(sqlrcur_getField($cur,7,"TESTLONG"),"testlong8");
+	checkSuccess(sqlrcur_getField($cur,7,"TESTCLOB"),"testclob8");
+	checkSuccess(sqlrcur_getField($cur,7,"TESTBLOB"),"testblob8");
 	echo("\n");
 
 	echo("FIELD LENGTHS BY NAME: \n");
-	checkSuccess(sqlrcur_getFieldLength($cur,0,"testnumber"),1);
-	checkSuccess(sqlrcur_getFieldLength($cur,0,"testchar"),40);
-	checkSuccess(sqlrcur_getFieldLength($cur,0,"testvarchar"),12);
-	checkSuccess(sqlrcur_getFieldLength($cur,0,"testdate"),9);
-	checkSuccess(sqlrcur_getFieldLength($cur,0,"testlong"),9);
-	checkSuccess(sqlrcur_getFieldLength($cur,0,"testclob"),9);
-	checkSuccess(sqlrcur_getFieldLength($cur,0,"testblob"),0);
+	checkSuccess(sqlrcur_getFieldLength($cur,0,"TESTNUMBER"),1);
+	checkSuccess(sqlrcur_getFieldLength($cur,0,"TESTCHAR"),40);
+	checkSuccess(sqlrcur_getFieldLength($cur,0,"TESTVARCHAR"),12);
+	checkSuccess(sqlrcur_getFieldLength($cur,0,"TESTDATE"),9);
+	checkSuccess(sqlrcur_getFieldLength($cur,0,"TESTLONG"),9);
+	checkSuccess(sqlrcur_getFieldLength($cur,0,"TESTCLOB"),9);
+	checkSuccess(sqlrcur_getFieldLength($cur,0,"TESTBLOB"),0);
 	echo("\n");
-	checkSuccess(sqlrcur_getFieldLength($cur,7,"testnumber"),1);
-	checkSuccess(sqlrcur_getFieldLength($cur,7,"testchar"),40);
-	checkSuccess(sqlrcur_getFieldLength($cur,7,"testvarchar"),12);
-	checkSuccess(sqlrcur_getFieldLength($cur,7,"testdate"),9);
-	checkSuccess(sqlrcur_getFieldLength($cur,7,"testlong"),9);
-	checkSuccess(sqlrcur_getFieldLength($cur,7,"testclob"),9);
-	checkSuccess(sqlrcur_getFieldLength($cur,7,"testblob"),9);
+	checkSuccess(sqlrcur_getFieldLength($cur,7,"TESTNUMBER"),1);
+	checkSuccess(sqlrcur_getFieldLength($cur,7,"TESTCHAR"),40);
+	checkSuccess(sqlrcur_getFieldLength($cur,7,"TESTVARCHAR"),12);
+	checkSuccess(sqlrcur_getFieldLength($cur,7,"TESTDATE"),9);
+	checkSuccess(sqlrcur_getFieldLength($cur,7,"TESTLONG"),9);
+	checkSuccess(sqlrcur_getFieldLength($cur,7,"TESTCLOB"),9);
+	checkSuccess(sqlrcur_getFieldLength($cur,7,"TESTBLOB"),9);
 	echo("\n");
 
 	echo("FIELDS BY ARRAY: \n");
@@ -760,7 +760,7 @@
 	sqlrcur_inputBindClob($cur,"clobval",$clobval,8*1024);
 	checkSuccess(sqlrcur_executeQuery($cur),1);
 	sqlrcur_sendQuery($cur,"select testclob from testtable2");
-	checkSuccess($clobval,sqlrcur_getField($cur,0,"testclob"));
+	checkSuccess($clobval,sqlrcur_getField($cur,0,"TESTCLOB"));
 	sqlrcur_prepareQuery($cur,"begin select testclob into :clobbindval from testtable2; end;");
 	sqlrcur_defineOutputBindClob($cur,"clobbindval");
 	checkSuccess(sqlrcur_executeQuery($cur),1);
@@ -782,7 +782,7 @@
 	sqlrcur_inputBind($cur,"testval",$testval);
 	checkSuccess(sqlrcur_executeQuery($cur),1);
 	sqlrcur_sendQuery($cur,"select testval from testtable2");
-	checkSuccess($testval,sqlrcur_getField($cur,0,"testval"));
+	checkSuccess($testval,sqlrcur_getField($cur,0,"TESTVAL"));
 	$query="begin :bindval:='".$testval."'; end;";
 	sqlrcur_prepareQuery($cur,$query);
 	sqlrcur_defineOutputBindString($cur,"bindval",4000);
@@ -798,7 +798,7 @@
 	sqlrcur_inputBind($cur,"testval",-1);
 	checkSuccess(sqlrcur_executeQuery($cur),1);
 	sqlrcur_sendQuery($cur,"select testval from testtable2");
-	checkSuccess(sqlrcur_getField($cur,0,"testval"),"-1");
+	checkSuccess(sqlrcur_getField($cur,0,"TESTVAL"),"-1");
 	sqlrcur_sendQuery($cur,"drop table testtable2");
 	echo("\n");
 
