@@ -1,5 +1,5 @@
 <html><pre><?php
-# Copyright (c) 2001  David Muse
+# Copyright (c) 1999-2018 David Muse
 # See the file COPYING for more information.
 
 	function checkSuccess($value,$success) {
@@ -15,7 +15,7 @@
 		}
 	}
 
-	$host="sqlrserver";
+	$host="sqlrelay";
 	$port=9000;
 	$socket="/tmp/test.socket";
 	$user="test";
@@ -100,7 +100,6 @@
 	sqlrcur_inputBind($cur,"6","testvarchar8");
 	sqlrcur_inputBind($cur,"7","01/01/2008");
 	sqlrcur_inputBind($cur,"8","08:00:00");
-	sqlrcur_inputBind($cur,"9","junkvalue");
 	sqlrcur_validateBinds($cur);
 	checkSuccess(sqlrcur_executeQuery($cur),1);
 	echo("\n");
@@ -200,9 +199,9 @@
 	checkSuccess(sqlrcur_rowCount($cur),8);
 	echo("\n");
 
-	echo("TOTAL ROWS: \n");
+	/*echo("TOTAL ROWS: \n");
 	checkSuccess(sqlrcur_totalRows($cur),8);
-	echo("\n");
+	echo("\n");*/
 
 	echo("FIRST ROW INDEX: \n");
 	checkSuccess(sqlrcur_firstRowIndex($cur),0);
