@@ -1,5 +1,5 @@
 <html><pre><?php
-# Copyright (c) 2001  David Muse
+# Copyright (c) 1999-2018 David Muse
 # See the file COPYING for more information.
 
 	function checkSuccess($value,$success) {
@@ -15,7 +15,7 @@
 		}
 	}
 
-	$host="sqlrserver";
+	$host="sqlrelay";
 	$port=9000;
 	$socket="/tmp/test.socket";
 	$user="test";
