@@ -2,7 +2,7 @@
 
 	print("\n");
 
-	$host="sqlrserver";
+	$host="sqlrelay";
 	$port=9000;
 	$socket="/tmp/test.socket";
 	$user="test";
