@@ -1,9 +1,9 @@
 <html><pre><?php
-# Copyright (c) 2014  David Muse
+# Copyright (c) 1999-2018 David Muse
 # See the file COPYING for more information.
 
 	# sqlrelay
-	$host="sqlrserver";
+	$host="sqlrelay";
 	$port=9000;
 	$socket="/tmp/test.socket";
 	$user="test";
