@@ -1,5 +1,5 @@
 <html><pre><?php
-# Copyright (c) 2013  David Muse
+# Copyright (c) 1999-2018 David Muse
 # See the file COPYING for more information.
 
 	function checkSuccess($value,$success) {
@@ -13,16 +13,16 @@
 		}
 	}
 
-	$host="sqlrserver";
+	$host="sqlrelay";
 	$port=9000;
 	$socket="/tmp/test.socket";
 	$user="";
 	$password="";
-	$tlscert="/usr/local/firstworks/etc/client.pem";
-	$tlsca="/usr/local/firstworks/etc/ca.pem";
+	$tlscert="/usr/local/firstworks/etc/sqlrelay.conf.d/client.pem";
+	$tlsca="/usr/local/firstworks/etc/sqlrelay.conf.d/ca.pem";
 	if (strtoupper(substr(PHP_OS,0,3))==='WIN') {
-		$tlscert="C:\\Program Files\\Firstworks\\etc\\client.pfx";
-		$tlsca="C:\\Program Files\\Firstworks\\etc\\ca.pfx";
+		$tlscert="C:\\Program Files\\Firstworks\\etc\\sqlrelay.conf.d\\client.pfx";
+		$tlsca="C:\\Program Files\\Firstworks\\etc\\sqlrelay.conf.d\\ca.pfx";
 	}
 	$dsn = "sqlrelay:host=$host;port=$port;socket=$socket;tries=0;retrytime=1;tls=yes;tlscert=$tlscert;tlsvalidate=ca;tlsca=$tlsca;debug=0";
 
@@ -520,9 +520,13 @@
 	echo("COMMIT AND ROLLBACK: \n");
 	$dbh->exec("drop table testtable1");
 	checkSuccess($dbh->exec("create table testtable1 (testnumber number)"),0);
-	checkSuccess($dbh->inTransaction(),0);
+	if (method_exists($dbh,"inTransaction")) {
+		checkSuccess($dbh->inTransaction(),0);
+	}
 	$dbh->beginTransaction();
-	checkSuccess($dbh->inTransaction(),1);
+	if (method_exists($dbh,"inTransaction")) {
+		checkSuccess($dbh->inTransaction(),1);
+	}
 	checkSuccess($dbh->exec("insert into testtable1 values (1)"),1);
 	$dbh2=new PDO($dsn,$user,$password);
 	$stmt2=$dbh2->query("select count(*) from testtable1");
@@ -544,13 +548,17 @@
 	echo("\n");
 
 	echo("AUTOCOMMIT: \n");
-	checkSuccess($dbh->inTransaction(),0);
+	if (method_exists($dbh,"inTransaction")) {
+		checkSuccess($dbh->inTransaction(),0);
+	}
 	$dbh->setAttribute(PDO::ATTR_AUTOCOMMIT,TRUE);
 	checkSuccess($dbh->exec("insert into testtable1 values (1)"),1);
 	$stmt2=$dbh2->query("select count(*) from testtable1");
 	$result2=$stmt2->fetch();
 	checkSuccess($result2[0],2);
-	checkSuccess($dbh->inTransaction(),0);
+	if (method_exists($dbh,"inTransaction")) {
+		checkSuccess($dbh->inTransaction(),0);
+	}
 	$dbh->setAttribute(PDO::ATTR_AUTOCOMMIT,FALSE);
 	$dbh->beginTransaction();
 	checkSuccess($dbh->exec("insert into testtable1 values (1)"),1);
@@ -579,6 +587,8 @@
 	$dbh->exec("drop table testtable");
 	$dbh->exec("drop table testtable1");
 
+# output binds don't appear to work with PDO for PHP7
+if (PHP_VERSION_ID < 70000) {
 	echo("OUTPUT BIND BY NAME: \n");
 	$stmt=$dbh->prepare("begin  :numvar:=1; :stringvar:='hello'; end;");
 	$param1=0;
@@ -634,15 +644,23 @@
 	fclose($stream);
 	unlink("test.blob");
 	echo("\n");
-
-	echo("NON-LAZY CONNECT: \n");
-	$dsn = "sqlrelay:host=invalidhost;port=0;socket=/invalidsocket;tries=1;retrytime=1;tls=yes;tlscert=$tlscert;tlsvalidate=ca;tlsca=$tlsca;debug=0;lazyconnect=0";
-	checkSuccess(new PDO($dsn,$user,$password),0);
-	echo("\n");
-
+}
 
 	$dbh->setAttribute(PDO::ATTR_ERRMODE,PDO::ERRMODE_SILENT);
 
+	# this throws an execption and doesn't continue on PHP7
+	try {
+
+		echo("NON-LAZY CONNECT: \n");
+		$dsn = "sqlrelay:host=invalidhost;port=0;socket=/invalidsocket;tries=1;retrytime=1;tls=yes;tlscert=$tlscert;tlsvalidate=ca;tlsca=$tlsca;debug=0;lazyconnect=0";
+		checkSuccess(new PDO($dsn,$user,$password),0);
+		echo("\n");
+
+	} catch (Exception $e) {
+		echo($e->getMessage());
+		echo("\n");
+	}
+
 	echo("INVALID QUERIES: \n");
 	checkSuccess($dbh->query("select 1"),0);
 	checkSuccess($dbh->errorCode(),"HY000");
@@ -659,12 +677,17 @@
 	checkSuccess($info[2],"ORA-00923: FROM keyword not found where expected");
 	echo("\n");
 
+	echo("QUOTE: \n");
+	checkSuccess($dbh->quote("select * from table"),"'select * from table'");
+	checkSuccess($dbh->quote("Naughty ' string"),"'Naughty '' string'");
+	checkSuccess($dbh->quote("Co'mpl''ex \"st'\"ring"),"'Co''mpl''''ex \"st''\"ring'");
+	echo("\n");
+
 	echo("INVALID OPERATIONS: \n");
 	checkSuccess($stmt->nextRowset(),0);
 	checkSuccess($stmt->setAttribute(PDO::ATTR_AUTOCOMMIT,FALSE),0);
 	checkSuccess($stmt->getAttribute(PDO::ATTR_AUTOCOMMIT),0);
-	checkSuccess($dbh->quote("select * from table"),null);
-	checkSuccess($stmt->bindValue(1,1,9999),true);
+	#checkSuccess($stmt->bindValue(1,1,9999),true);
 	echo("\n");
 
 	$dbh->exec("drop table testtable");
