@@ -1,6 +1,6 @@
 #! /usr/bin/env python
 
-# Copyright (c) 2001  David Muse
+# Copyright (c) 1999-2018 David Muse
 # See the file COPYING for more information.
 
 from SQLRelay import PySQLRClient
@@ -22,7 +22,7 @@ def main():
 	PySQLRClient.getNumericFieldsAsNumbers()
 
 	# instantiation
-	con=PySQLRClient.sqlrconnection("sqlrserver",9000,"/tmp/test.socket",
+	con=PySQLRClient.sqlrconnection("sqlrelay",9000,"/tmp/test.socket",
 								"test","test")
 	cur=PySQLRClient.sqlrcursor(con)
 
@@ -280,51 +280,51 @@ def main():
 	print()
 
 	print("FIELDS BY NAME: ")
-	checkSuccess(cur.getField(0,"testsmallint"),1)
-	checkSuccess(cur.getField(0,"testint"),1)
-	checkSuccess(cur.getField(0,"testbigint"),1)
-	checkSuccess(cur.getField(0,"testdecimal"),Decimal("1.10"))
-	#checkSuccess(cur.getField(0,"testreal"),Decimal("1.1"))
-	#checkSuccess(cur.getField(0,"testdouble"),Decimal("1.1"))
-	checkSuccess(cur.getField(0,"testchar"),"testchar1                               ")
-	checkSuccess(cur.getField(0,"testvarchar"),"testvarchar1")
-	checkSuccess(cur.getField(0,"testdate"),"2001-01-01")
-	checkSuccess(cur.getField(0,"testtime"),"01:00:00")
+	checkSuccess(cur.getField(0,"TESTSMALLINT"),1)
+	checkSuccess(cur.getField(0,"TESTINT"),1)
+	checkSuccess(cur.getField(0,"TESTBIGINT"),1)
+	checkSuccess(cur.getField(0,"TESTDECIMAL"),Decimal("1.10"))
+	#checkSuccess(cur.getField(0,"TESTREAL"),Decimal("1.1"))
+	#checkSuccess(cur.getField(0,"TESTDOUBLE"),Decimal("1.1"))
+	checkSuccess(cur.getField(0,"TESTCHAR"),"testchar1                               ")
+	checkSuccess(cur.getField(0,"TESTVARCHAR"),"testvarchar1")
+	checkSuccess(cur.getField(0,"TESTDATE"),"2001-01-01")
+	checkSuccess(cur.getField(0,"TESTTIME"),"01:00:00")
 	print()
-	checkSuccess(cur.getField(7,"testsmallint"),8)
-	checkSuccess(cur.getField(7,"testint"),8)
-	checkSuccess(cur.getField(7,"testbigint"),8)
-	checkSuccess(cur.getField(7,"testdecimal"),Decimal("8.80"))
-	#checkSuccess(cur.getField(7,"testreal"),Decimal("8.8"))
-	#checkSuccess(cur.getField(7,"testdouble"),Decimal("8.8"))
-	checkSuccess(cur.getField(7,"testchar"),"testchar8                               ")
-	checkSuccess(cur.getField(7,"testvarchar"),"testvarchar8")
-	checkSuccess(cur.getField(7,"testdate"),"2008-01-01")
-	checkSuccess(cur.getField(7,"testtime"),"08:00:00")
+	checkSuccess(cur.getField(7,"TESTSMALLINT"),8)
+	checkSuccess(cur.getField(7,"TESTINT"),8)
+	checkSuccess(cur.getField(7,"TESTBIGINT"),8)
+	checkSuccess(cur.getField(7,"TESTDECIMAL"),Decimal("8.80"))
+	#checkSuccess(cur.getField(7,"TESTREAL"),Decimal("8.8"))
+	#checkSuccess(cur.getField(7,"TESTDOUBLE"),Decimal("8.8"))
+	checkSuccess(cur.getField(7,"TESTCHAR"),"testchar8                               ")
+	checkSuccess(cur.getField(7,"TESTVARCHAR"),"testvarchar8")
+	checkSuccess(cur.getField(7,"TESTDATE"),"2008-01-01")
+	checkSuccess(cur.getField(7,"TESTTIME"),"08:00:00")
 	print()
 
 	print("FIELD LENGTHS BY NAME: ")
-	checkSuccess(cur.getFieldLength(0,"testsmallint"),1)
-	checkSuccess(cur.getFieldLength(0,"testint"),1)
-	checkSuccess(cur.getFieldLength(0,"testbigint"),1)
-	checkSuccess(cur.getFieldLength(0,"testdecimal"),4)
-	#checkSuccess(cur.getFieldLength(0,"testreal"),3)
-	#checkSuccess(cur.getFieldLength(0,"testdouble"),3)
-	checkSuccess(cur.getFieldLength(0,"testchar"),40)
-	checkSuccess(cur.getFieldLength(0,"testvarchar"),12)
-	checkSuccess(cur.getFieldLength(0,"testdate"),10)
-	checkSuccess(cur.getFieldLength(0,"testtime"),8)
+	checkSuccess(cur.getFieldLength(0,"TESTSMALLINT"),1)
+	checkSuccess(cur.getFieldLength(0,"TESTINT"),1)
+	checkSuccess(cur.getFieldLength(0,"TESTBIGINT"),1)
+	checkSuccess(cur.getFieldLength(0,"TESTDECIMAL"),4)
+	#checkSuccess(cur.getFieldLength(0,"TESTREAL"),3)
+	#checkSuccess(cur.getFieldLength(0,"TESTDOUBLE"),3)
+	checkSuccess(cur.getFieldLength(0,"TESTCHAR"),40)
+	checkSuccess(cur.getFieldLength(0,"TESTVARCHAR"),12)
+	checkSuccess(cur.getFieldLength(0,"TESTDATE"),10)
+	checkSuccess(cur.getFieldLength(0,"TESTTIME"),8)
 	print()
-	checkSuccess(cur.getFieldLength(7,"testsmallint"),1)
-	checkSuccess(cur.getFieldLength(7,"testint"),1)
-	checkSuccess(cur.getFieldLength(7,"testbigint"),1)
-	checkSuccess(cur.getFieldLength(7,"testdecimal"),4)
-	#checkSuccess(cur.getFieldLength(7,"testreal"),3)
-	#checkSuccess(cur.getFieldLength(7,"testdouble"),3)
-	checkSuccess(cur.getFieldLength(7,"testchar"),40)
-	checkSuccess(cur.getFieldLength(7,"testvarchar"),12)
-	checkSuccess(cur.getFieldLength(7,"testdate"),10)
-	checkSuccess(cur.getFieldLength(7,"testtime"),8)
+	checkSuccess(cur.getFieldLength(7,"TESTSMALLINT"),1)
+	checkSuccess(cur.getFieldLength(7,"TESTINT"),1)
+	checkSuccess(cur.getFieldLength(7,"TESTBIGINT"),1)
+	checkSuccess(cur.getFieldLength(7,"TESTDECIMAL"),4)
+	#checkSuccess(cur.getFieldLength(7,"TESTREAL"),3)
+	#checkSuccess(cur.getFieldLength(7,"TESTDOUBLE"),3)
+	checkSuccess(cur.getFieldLength(7,"TESTCHAR"),40)
+	checkSuccess(cur.getFieldLength(7,"TESTVARCHAR"),12)
+	checkSuccess(cur.getFieldLength(7,"TESTDATE"),10)
+	checkSuccess(cur.getFieldLength(7,"TESTTIME"),8)
 	print()
 
 	print("FIELDS BY ARRAY: ")
@@ -800,3 +800,4 @@ def main():
 
 if __name__ == "__main__":
 	main()
+	sys.exit(0)
