@@ -1,6 +1,6 @@
 #! /usr/bin/env python
 
-# Copyright (c) 2001  David Muse
+# Copyright (c) 1999-2018 David Muse
 # See the file COPYING for more information.
 
 from SQLRelay import PySQLRClient
@@ -24,7 +24,7 @@ def main():
 	PySQLRClient.getNumericFieldsAsNumbers()
 
 	# instantiation
-	con=PySQLRClient.sqlrconnection("sqlrserver",9000,
+	con=PySQLRClient.sqlrconnection("sqlrelay",9000,
 						"/tmp/test.socket",
 						"test","test")
 	cur=PySQLRClient.sqlrcursor(con)
@@ -104,7 +104,6 @@ def main():
 	cur.inputBind("6","testvarchar8")
 	cur.inputBind("7","01/01/2008")
 	cur.inputBind("8","08:00:00")
-	cur.inputBind("9","junkvalue")
 	cur.validateBinds()
 	checkSuccess(cur.executeQuery(),1)
 	print()
@@ -204,9 +203,9 @@ def main():
 	checkSuccess(cur.rowCount(),8)
 	print()
 
-	print("TOTAL ROWS: ")
-	checkSuccess(cur.totalRows(),8)
-	print()
+	#print("TOTAL ROWS: ")
+	#checkSuccess(cur.totalRows(),8)
+	#print()
 
 	print("FIRST ROW INDEX: ")
 	checkSuccess(cur.firstRowIndex(),0)
@@ -635,7 +634,7 @@ def main():
 	print()
 
 	print("COMMIT AND ROLLBACK: ")
-	secondcon=PySQLRClient.sqlrconnection("sqlrserver",9000,
+	secondcon=PySQLRClient.sqlrconnection("sqlrelay",9000,
 						"/tmp/test.socket",
 						"test","test")
 	secondcur=PySQLRClient.sqlrcursor(secondcon)
@@ -773,3 +772,4 @@ def main():
 
 if __name__ == "__main__":
 	main()
+	sys.exit(0)
