@@ -1,6 +1,6 @@
 #! /usr/bin/env python
 
-# Copyright (c) 2001  David Muse
+# Copyright (c) 1999-2018 David Muse
 # See the file COPYING for more information.
 
 from SQLRelay import PySQLRClient
@@ -23,7 +23,7 @@ def main():
 	PySQLRClient.getNumericFieldsAsNumbers()
 
 	# instantiation
-	con=PySQLRClient.sqlrconnection("sqlrserver",9000,
+	con=PySQLRClient.sqlrconnection("sqlrelay",9000,
 						"/tmp/test.socket",
 						"test","test")
 	cur=PySQLRClient.sqlrcursor(con)
@@ -974,3 +974,4 @@ def main():
 
 if __name__ == "__main__":
 	main()
+	sys.exit(0)
