@@ -1,6 +1,6 @@
 #! /usr/bin/env python
 
-# Copyright (c) 2001  David Muse
+# Copyright (c) 1999-2018 David Muse
 # See the file COPYING for more information.
 
 from SQLRelay import PySQLRClient
@@ -20,16 +20,16 @@ def checkSuccess(value,success):
 
 def main():
 
-	cert="/usr/local/firstworks/etc/client.pem"
-	ca="/usr/local/firstworks/etc/client.pem"
+	cert="/usr/local/firstworks/etc/sqlrelay.conf.d/client.pem"
+	ca="/usr/local/firstworks/etc/sqlrelay.conf.d/ca.pem"
 	if platform.system()=="Windows":
-		cert="C:\\Program Files\\Firstworks\\etc\\client.pfx"
-		ca="C:\\Program Files\\Firstworks\\etc\\ca.pfx"
+		cert="C:\\Program Files\\Firstworks\\etc\\sqlrelay.conf.d\\client.pfx"
+		ca="C:\\Program Files\\Firstworks\\etc\\sqlrelay.conf.d\\ca.pfx"
 
 	PySQLRClient.getNumericFieldsAsNumbers()
 
 	# instantiation
-	con=PySQLRClient.sqlrconnection("sqlrserver",9000,
+	con=PySQLRClient.sqlrconnection("sqlrelay",9000,
 						"/tmp/test.socket",
 						"","")
 	cur=PySQLRClient.sqlrcursor(con)
@@ -209,53 +209,53 @@ def main():
 
 	print("COLUMN TYPES: ")
 	checkSuccess(cur.getColumnType(0),"NUMBER")
-	checkSuccess(cur.getColumnType('testnumber'),"NUMBER")
+	checkSuccess(cur.getColumnType('TESTNUMBER'),"NUMBER")
 	checkSuccess(cur.getColumnType(1),"CHAR")
-	checkSuccess(cur.getColumnType('testchar'),"CHAR")
+	checkSuccess(cur.getColumnType('TESTCHAR'),"CHAR")
 	checkSuccess(cur.getColumnType(2),"VARCHAR2")
-	checkSuccess(cur.getColumnType('testvarchar'),"VARCHAR2")
+	checkSuccess(cur.getColumnType('TESTVARCHAR'),"VARCHAR2")
 	checkSuccess(cur.getColumnType(3),"DATE")
-	checkSuccess(cur.getColumnType('testdate'),"DATE")
+	checkSuccess(cur.getColumnType('TESTDATE'),"DATE")
 	checkSuccess(cur.getColumnType(4),"LONG")
-	checkSuccess(cur.getColumnType('testlong'),"LONG")
+	checkSuccess(cur.getColumnType('TESTLONG'),"LONG")
 	checkSuccess(cur.getColumnType(5),"CLOB")
-	checkSuccess(cur.getColumnType('testclob'),"CLOB")
+	checkSuccess(cur.getColumnType('TESTCLOB'),"CLOB")
 	checkSuccess(cur.getColumnType(6),"BLOB")
-	checkSuccess(cur.getColumnType('testblob'),"BLOB")
+	checkSuccess(cur.getColumnType('TESTBLOB'),"BLOB")
 	print()
 
 	print("COLUMN LENGTH: ")
 	checkSuccess(cur.getColumnLength(0),22)
-	checkSuccess(cur.getColumnLength('testnumber'),22)
+	checkSuccess(cur.getColumnLength('TESTNUMBER'),22)
 	checkSuccess(cur.getColumnLength(1),40)
-	checkSuccess(cur.getColumnLength('testchar'),40)
+	checkSuccess(cur.getColumnLength('TESTCHAR'),40)
 	checkSuccess(cur.getColumnLength(2),40)
-	checkSuccess(cur.getColumnLength('testvarchar'),40)
+	checkSuccess(cur.getColumnLength('TESTVARCHAR'),40)
 	checkSuccess(cur.getColumnLength(3),7)
-	checkSuccess(cur.getColumnLength('testdate'),7)
+	checkSuccess(cur.getColumnLength('TESTDATE'),7)
 	checkSuccess(cur.getColumnLength(4),0)
-	checkSuccess(cur.getColumnLength('testlong'),0)
+	checkSuccess(cur.getColumnLength('TESTLONG'),0)
 	checkSuccess(cur.getColumnLength(5),0)
-	checkSuccess(cur.getColumnLength('testclob'),0)
+	checkSuccess(cur.getColumnLength('TESTCLOB'),0)
 	checkSuccess(cur.getColumnLength(6),0)
-	checkSuccess(cur.getColumnLength('testblob'),0)
+	checkSuccess(cur.getColumnLength('TESTBLOB'),0)
 	print()
 
 	print("LONGEST COLUMN: ")
 	checkSuccess(cur.getLongest(0),1)
-	checkSuccess(cur.getLongest('testnumber'),1)
+	checkSuccess(cur.getLongest('TESTNUMBER'),1)
 	checkSuccess(cur.getLongest(1),40)
-	checkSuccess(cur.getLongest('testchar'),40)
+	checkSuccess(cur.getLongest('TESTCHAR'),40)
 	checkSuccess(cur.getLongest(2),12)
-	checkSuccess(cur.getLongest('testvarchar'),12)
+	checkSuccess(cur.getLongest('TESTVARCHAR'),12)
 	checkSuccess(cur.getLongest(3),9)
-	checkSuccess(cur.getLongest('testdate'),9)
+	checkSuccess(cur.getLongest('TESTDATE'),9)
 	checkSuccess(cur.getLongest(4),9)
-	checkSuccess(cur.getLongest('testlong'),9)
+	checkSuccess(cur.getLongest('TESTLONG'),9)
 	checkSuccess(cur.getLongest(5),9)
-	checkSuccess(cur.getLongest('testclob'),9)
+	checkSuccess(cur.getLongest('TESTCLOB'),9)
 	checkSuccess(cur.getLongest(6),9)
-	checkSuccess(cur.getLongest('testblob'),9)
+	checkSuccess(cur.getLongest('TESTBLOB'),9)
 	print()
 
 	print("ROW COUNT: ")
@@ -311,39 +311,39 @@ def main():
 	print()
 
 	print("FIELDS BY NAME: ")
-	checkSuccess(cur.getField(0,"testnumber"),1)
-	checkSuccess(cur.getField(0,"testchar"),"testchar1                               ")
-	checkSuccess(cur.getField(0,"testvarchar"),"testvarchar1")
-	checkSuccess(cur.getField(0,"testdate"),"01-JAN-01")
-	checkSuccess(cur.getField(0,"testlong"),"testlong1")
-	checkSuccess(cur.getField(0,"testclob"),"testclob1")
-	checkSuccess(cur.getField(0,"testblob"),"")
+	checkSuccess(cur.getField(0,"TESTNUMBER"),1)
+	checkSuccess(cur.getField(0,"TESTCHAR"),"testchar1                               ")
+	checkSuccess(cur.getField(0,"TESTVARCHAR"),"testvarchar1")
+	checkSuccess(cur.getField(0,"TESTDATE"),"01-JAN-01")
+	checkSuccess(cur.getField(0,"TESTLONG"),"testlong1")
+	checkSuccess(cur.getField(0,"TESTCLOB"),"testclob1")
+	checkSuccess(cur.getField(0,"TESTBLOB"),"")
 	print()
-	checkSuccess(cur.getField(7,"testnumber"),8)
-	checkSuccess(cur.getField(7,"testchar"),"testchar8                               ")
-	checkSuccess(cur.getField(7,"testvarchar"),"testvarchar8")
-	checkSuccess(cur.getField(7,"testdate"),"01-JAN-08")
-	checkSuccess(cur.getField(7,"testlong"),"testlong8")
-	checkSuccess(cur.getField(7,"testclob"),"testclob8")
-	checkSuccess(cur.getField(7,"testblob"),"testblob8")
+	checkSuccess(cur.getField(7,"TESTNUMBER"),8)
+	checkSuccess(cur.getField(7,"TESTCHAR"),"testchar8                               ")
+	checkSuccess(cur.getField(7,"TESTVARCHAR"),"testvarchar8")
+	checkSuccess(cur.getField(7,"TESTDATE"),"01-JAN-08")
+	checkSuccess(cur.getField(7,"TESTLONG"),"testlong8")
+	checkSuccess(cur.getField(7,"TESTCLOB"),"testclob8")
+	checkSuccess(cur.getField(7,"TESTBLOB"),"testblob8")
 	print()
 
 	print("FIELD LENGTHS BY NAME: ")
-	checkSuccess(cur.getFieldLength(0,"testnumber"),1)
-	checkSuccess(cur.getFieldLength(0,"testchar"),40)
-	checkSuccess(cur.getFieldLength(0,"testvarchar"),12)
-	checkSuccess(cur.getFieldLength(0,"testdate"),9)
-	checkSuccess(cur.getFieldLength(0,"testlong"),9)
-	checkSuccess(cur.getFieldLength(0,"testclob"),9)
-	checkSuccess(cur.getFieldLength(0,"testblob"),0)
+	checkSuccess(cur.getFieldLength(0,"TESTNUMBER"),1)
+	checkSuccess(cur.getFieldLength(0,"TESTCHAR"),40)
+	checkSuccess(cur.getFieldLength(0,"TESTVARCHAR"),12)
+	checkSuccess(cur.getFieldLength(0,"TESTDATE"),9)
+	checkSuccess(cur.getFieldLength(0,"TESTLONG"),9)
+	checkSuccess(cur.getFieldLength(0,"TESTCLOB"),9)
+	checkSuccess(cur.getFieldLength(0,"TESTBLOB"),0)
 	print()
-	checkSuccess(cur.getFieldLength(7,"testnumber"),1)
-	checkSuccess(cur.getFieldLength(7,"testchar"),40)
-	checkSuccess(cur.getFieldLength(7,"testvarchar"),12)
-	checkSuccess(cur.getFieldLength(7,"testdate"),9)
-	checkSuccess(cur.getFieldLength(7,"testlong"),9)
-	checkSuccess(cur.getFieldLength(7,"testclob"),9)
-	checkSuccess(cur.getFieldLength(7,"testblob"),9)
+	checkSuccess(cur.getFieldLength(7,"TESTNUMBER"),1)
+	checkSuccess(cur.getFieldLength(7,"TESTCHAR"),40)
+	checkSuccess(cur.getFieldLength(7,"TESTVARCHAR"),12)
+	checkSuccess(cur.getFieldLength(7,"TESTDATE"),9)
+	checkSuccess(cur.getFieldLength(7,"TESTLONG"),9)
+	checkSuccess(cur.getFieldLength(7,"TESTCLOB"),9)
+	checkSuccess(cur.getFieldLength(7,"TESTBLOB"),9)
 	print()
 
 	print("FIELDS BY ARRAY: ")
@@ -686,7 +686,7 @@ def main():
 	print()
 
 	print("COMMIT AND ROLLBACK: ")
-	secondcon=PySQLRClient.sqlrconnection("sqlrserver",9000,
+	secondcon=PySQLRClient.sqlrconnection("sqlrelay",9000,
 						"/tmp/test.socket",
 						"","")
 	secondcur=PySQLRClient.sqlrcursor(secondcon)
@@ -811,7 +811,7 @@ def main():
 	cur.inputBindClob("clobval",clobval,8*1024)
 	checkSuccess(cur.executeQuery(),1)
 	cur.sendQuery("select testclob from testtable2")
-	checkSuccess(clobval,cur.getField(0,"testclob"))
+	checkSuccess(clobval,cur.getField(0,"TESTCLOB"))
 	cur.prepareQuery("begin select testclob into :clobbindval from testtable2; end;")
 	cur.defineOutputBindClob("clobbindval")
 	checkSuccess(cur.executeQuery(),1)
@@ -893,3 +893,4 @@ def main():
 
 if __name__ == "__main__":
 	main()
+	sys.exit(0)
