@@ -1,10 +1,11 @@
 #! /usr/bin/env ruby
 
-# Copyright (c) 2001  David Muse
+# Copyright (c) 1999-2018 David Muse
 # See the file COPYING for more information.
 
 
 
+require 'rbconfig'
 require 'sqlrelay'
 
 def checkSuccess(value,success)
@@ -20,7 +21,7 @@ end
 
 
 # instantiation
-con=SQLRConnection.new("sqlrserver",9000,"/tmp/test.socket","test","test",0,1)
+con=SQLRConnection.new("sqlrelay",9000,"/tmp/test.socket","test","test",0,1)
 cur=SQLRCursor.new(con)
 
 # get database type
@@ -276,51 +277,51 @@ checkSuccess(cur.getFieldLength(7,9),8)
 print "\n"
 
 print "FIELDS BY NAME: \n"
-checkSuccess(cur.getField(0,"testsmallint"),"1")
-checkSuccess(cur.getField(0,"testint"),"1")
-checkSuccess(cur.getField(0,"testbigint"),"1")
-checkSuccess(cur.getField(0,"testdecimal"),"1.10")
-#checkSuccess(cur.getField(0,"testreal"),"1.1")
-#checkSuccess(cur.getField(0,"testdouble"),"1.1")
-checkSuccess(cur.getField(0,"testchar"),"testchar1                               ")
-checkSuccess(cur.getField(0,"testvarchar"),"testvarchar1")
-checkSuccess(cur.getField(0,"testdate"),"2001-01-01")
-checkSuccess(cur.getField(0,"testtime"),"01:00:00")
+checkSuccess(cur.getField(0,"TESTSMALLINT"),"1")
+checkSuccess(cur.getField(0,"TESTINT"),"1")
+checkSuccess(cur.getField(0,"TESTBIGINT"),"1")
+checkSuccess(cur.getField(0,"TESTDECIMAL"),"1.10")
+#checkSuccess(cur.getField(0,"TESTREAL"),"1.1")
+#checkSuccess(cur.getField(0,"TESTDOUBLE"),"1.1")
+checkSuccess(cur.getField(0,"TESTCHAR"),"testchar1                               ")
+checkSuccess(cur.getField(0,"TESTVARCHAR"),"testvarchar1")
+checkSuccess(cur.getField(0,"TESTDATE"),"2001-01-01")
+checkSuccess(cur.getField(0,"TESTTIME"),"01:00:00")
 print "\n"
-checkSuccess(cur.getField(7,"testsmallint"),"8")
-checkSuccess(cur.getField(7,"testint"),"8")
-checkSuccess(cur.getField(7,"testbigint"),"8")
-checkSuccess(cur.getField(7,"testdecimal"),"8.80")
-#checkSuccess(cur.getField(7,"testreal"),"8.8")
-#checkSuccess(cur.getField(7,"testdouble"),"8.8")
-checkSuccess(cur.getField(7,"testchar"),"testchar8                               ")
-checkSuccess(cur.getField(7,"testvarchar"),"testvarchar8")
-checkSuccess(cur.getField(7,"testdate"),"2008-01-01")
-checkSuccess(cur.getField(7,"testtime"),"08:00:00")
+checkSuccess(cur.getField(7,"TESTSMALLINT"),"8")
+checkSuccess(cur.getField(7,"TESTINT"),"8")
+checkSuccess(cur.getField(7,"TESTBIGINT"),"8")
+checkSuccess(cur.getField(7,"TESTDECIMAL"),"8.80")
+#checkSuccess(cur.getField(7,"TESTREAL"),"8.8")
+#checkSuccess(cur.getField(7,"TESTDOUBLE"),"8.8")
+checkSuccess(cur.getField(7,"TESTCHAR"),"testchar8                               ")
+checkSuccess(cur.getField(7,"TESTVARCHAR"),"testvarchar8")
+checkSuccess(cur.getField(7,"TESTDATE"),"2008-01-01")
+checkSuccess(cur.getField(7,"TESTTIME"),"08:00:00")
 print "\n"
 
 print "FIELD LENGTHS BY NAME: \n"
-checkSuccess(cur.getFieldLength(0,"testsmallint"),1)
-checkSuccess(cur.getFieldLength(0,"testint"),1)
-checkSuccess(cur.getFieldLength(0,"testbigint"),1)
-checkSuccess(cur.getFieldLength(0,"testdecimal"),4)
-#checkSuccess(cur.getFieldLength(0,"testreal"),3)
-#checkSuccess(cur.getFieldLength(0,"testdouble"),3)
-checkSuccess(cur.getFieldLength(0,"testchar"),40)
-checkSuccess(cur.getFieldLength(0,"testvarchar"),12)
-checkSuccess(cur.getFieldLength(0,"testdate"),10)
-checkSuccess(cur.getFieldLength(0,"testtime"),8)
+checkSuccess(cur.getFieldLength(0,"TESTSMALLINT"),1)
+checkSuccess(cur.getFieldLength(0,"TESTINT"),1)
+checkSuccess(cur.getFieldLength(0,"TESTBIGINT"),1)
+checkSuccess(cur.getFieldLength(0,"TESTDECIMAL"),4)
+#checkSuccess(cur.getFieldLength(0,"TESTREAL"),3)
+#checkSuccess(cur.getFieldLength(0,"TESTDOUBLE"),3)
+checkSuccess(cur.getFieldLength(0,"TESTCHAR"),40)
+checkSuccess(cur.getFieldLength(0,"TESTVARCHAR"),12)
+checkSuccess(cur.getFieldLength(0,"TESTDATE"),10)
+checkSuccess(cur.getFieldLength(0,"TESTTIME"),8)
 print "\n"
-checkSuccess(cur.getFieldLength(7,"testsmallint"),1)
-checkSuccess(cur.getFieldLength(7,"testint"),1)
-checkSuccess(cur.getFieldLength(7,"testbigint"),1)
-checkSuccess(cur.getFieldLength(7,"testdecimal"),4)
-#checkSuccess(cur.getFieldLength(7,"testreal"),3)
-#checkSuccess(cur.getFieldLength(7,"testdouble"),3)
-checkSuccess(cur.getFieldLength(7,"testchar"),40)
-checkSuccess(cur.getFieldLength(7,"testvarchar"),12)
-checkSuccess(cur.getFieldLength(7,"testdate"),10)
-checkSuccess(cur.getFieldLength(7,"testtime"),8)
+checkSuccess(cur.getFieldLength(7,"TESTSMALLINT"),1)
+checkSuccess(cur.getFieldLength(7,"TESTINT"),1)
+checkSuccess(cur.getFieldLength(7,"TESTBIGINT"),1)
+checkSuccess(cur.getFieldLength(7,"TESTDECIMAL"),4)
+#checkSuccess(cur.getFieldLength(7,"TESTREAL"),3)
+#checkSuccess(cur.getFieldLength(7,"TESTDOUBLE"),3)
+checkSuccess(cur.getFieldLength(7,"TESTCHAR"),40)
+checkSuccess(cur.getFieldLength(7,"TESTVARCHAR"),12)
+checkSuccess(cur.getFieldLength(7,"TESTDATE"),10)
+checkSuccess(cur.getFieldLength(7,"TESTTIME"),8)
 print "\n"
 
 print "FIELDS BY ARRAY: \n"
@@ -723,5 +724,4 @@ checkSuccess(cur.sendQuery("create table testtable"),0)
 checkSuccess(cur.sendQuery("create table testtable"),0)
 print "\n"
 
-
-
+exit(0)
