@@ -1,10 +1,11 @@
 #! /usr/bin/env ruby
 
-# Copyright (c) 2001  David Muse
+# Copyright (c) 1999-2018 David Muse
 # See the file COPYING for more information.
 
 
 
+require 'rbconfig'
 require 'sqlrelay'
 
 
@@ -21,7 +22,7 @@ end
 
 
 # instantiation
-con=SQLRConnection.new("sqlrserver",9000,"/tmp/test.socket",
+con=SQLRConnection.new("sqlrelay",9000,"/tmp/test.socket",
 						"test","test",0,1);
 cur=SQLRCursor.new(con)
 
@@ -873,5 +874,4 @@ checkSuccess(cur.sendQuery("create table testtable"),0)
 checkSuccess(cur.sendQuery("create table testtable"),0)
 print "\n"
 
-
-
+exit(0)
