@@ -1,10 +1,11 @@
 #! /usr/bin/env ruby
 
-# Copyright (c) 2001  David Muse
+# Copyright (c) 1999-2018 David Muse
 # See the file COPYING for more information.
 
 
 
+require 'rbconfig'
 require 'sqlrelay'
 
 def checkSuccess(value,success)
@@ -20,7 +21,7 @@ end
 
 
 # instantiation
-con=SQLRConnection.new("sqlrserver",9000,"/tmp/test.socket",
+con=SQLRConnection.new("sqlrelay",9000,"/tmp/test.socket",
 						"test","test",0,1);
 cur=SQLRCursor.new(con)
 
@@ -520,7 +521,7 @@ cur.setResultSetBufferSize(0)
 print "\n"
 
 print "COMMIT AND ROLLBACK: \n"
-secondcon=SQLRConnection.new("sqlrserver",9000,"/tmp/test.socket",
+secondcon=SQLRConnection.new("sqlrelay",9000,"/tmp/test.socket",
 						"test","test",0,1);
 secondcur=SQLRCursor.new(secondcon)
 checkSuccess(secondcur.sendQuery("select count(*) from testtable"),1)
@@ -573,5 +574,4 @@ checkSuccess(cur.sendQuery("create table testtable"),0)
 checkSuccess(cur.sendQuery("create table testtable"),0)
 print "\n"
 
-
-
+exit(0)
